package com.enus.myzik;

import android.view.View;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.AlphaAnimation;
import android.view.animation.Animation;
import android.view.animation.Animation.AnimationListener;
import android.view.animation.AnimationSet;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.Interpolator;
import android.view.animation.TranslateAnimation;
import android.widget.ViewAnimator;
import com.enus.myzik.FlipAnimation.ScaleUpDownEnum;

public class AnimationFactory {

    class C00451 implements AnimationListener {
        private final /* synthetic */ AnimationFinishedListener val$listener;

        C00451(AnimationFinishedListener animationFinishedListener) {
            this.val$listener = animationFinishedListener;
        }

        public void onAnimationStart(Animation animation) {
        }

        public void onAnimationRepeat(Animation animation) {
        }

        public void onAnimationEnd(Animation animation) {
            this.val$listener.onAnimationFinished();
        }
    }

    class C00462 implements AnimationListener {
        private final /* synthetic */ View val$view;

        C00462(View view) {
            this.val$view = view;
        }

        public void onAnimationEnd(Animation animation) {
            this.val$view.setVisibility(0);
        }

        public void onAnimationRepeat(Animation animation) {
        }

        public void onAnimationStart(Animation animation) {
            this.val$view.setVisibility(8);
        }
    }

    class C00473 implements AnimationListener {
        private final /* synthetic */ View val$view;

        C00473(View view) {
            this.val$view = view;
        }

        public void onAnimationEnd(Animation animation) {
            this.val$view.setVisibility(8);
        }

        public void onAnimationRepeat(Animation animation) {
        }

        public void onAnimationStart(Animation animation) {
            this.val$view.setVisibility(0);
        }
    }

    class C00484 implements AnimationListener {
        private final /* synthetic */ View val$v;

        C00484(View view) {
            this.val$v = view;
        }

        public void onAnimationEnd(Animation animation) {
            this.val$v.setVisibility(8);
        }

        public void onAnimationRepeat(Animation animation) {
        }

        public void onAnimationStart(Animation animation) {
            this.val$v.setVisibility(0);
        }
    }

    public interface AnimationFinishedListener {
        void onAnimationFinished();
    }

    public enum FlipDirection {
        LEFT_RIGHT,
        RIGHT_LEFT;

        public float getStartDegreeForFirstView() {
            return 0.0f;
        }

        public float getStartDegreeForSecondView() {
            switch ($SWITCH_TABLE$com$enus$myzik$AnimationFactory$FlipDirection()[ordinal()]) {
                case 1:
                    return -90.0f;
                case 2:
                    return 90.0f;
                default:
                    return 0.0f;
            }
        }

        public float getEndDegreeForFirstView() {
            switch ($SWITCH_TABLE$com$enus$myzik$AnimationFactory$FlipDirection()[ordinal()]) {
                case 1:
                    return 90.0f;
                case 2:
                    return -90.0f;
                default:
                    return 0.0f;
            }
        }

        public float getEndDegreeForSecondView() {
            return 0.0f;
        }

        public FlipDirection theOtherDirection() {
            switch ($SWITCH_TABLE$com$enus$myzik$AnimationFactory$FlipDirection()[ordinal()]) {
                case 1:
                    return RIGHT_LEFT;
                case 2:
                    return LEFT_RIGHT;
                default:
                    return null;
            }
        }
    }

    public static Animation[] flipAnimation(View fromView, View toView, FlipDirection dir, long duration, Interpolator interpolator) {
        Interpolator accelerateInterpolator;
        Animation[] result = new Animation[2];
        float centerX = ((float) fromView.getWidth()) / 2.0f;
        float centerY = ((float) fromView.getHeight()) / 2.0f;
        Animation outFlip = new FlipAnimation(dir.getStartDegreeForFirstView(), dir.getEndDegreeForFirstView(), centerX, centerY, FlipAnimation.SCALE_DEFAULT, ScaleUpDownEnum.SCALE_DOWN);
        outFlip.setDuration(duration);
        outFlip.setFillAfter(true);
        if (interpolator == null) {
            accelerateInterpolator = new AccelerateInterpolator();
        } else {
            accelerateInterpolator = interpolator;
        }
        outFlip.setInterpolator(accelerateInterpolator);
        AnimationSet outAnimation = new AnimationSet(true);
        outAnimation.addAnimation(outFlip);
        result[0] = outAnimation;
        Animation inFlip = new FlipAnimation(dir.getStartDegreeForSecondView(), dir.getEndDegreeForSecondView(), centerX, centerY, FlipAnimation.SCALE_DEFAULT, ScaleUpDownEnum.SCALE_UP);
        inFlip.setDuration(duration);
        inFlip.setFillAfter(true);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        inFlip.setInterpolator(interpolator);
        inFlip.setStartOffset(duration);
        AnimationSet inAnimation = new AnimationSet(true);
        inAnimation.addAnimation(inFlip);
        result[1] = inAnimation;
        return result;
    }

    public static void flipTransition(ViewAnimator viewAnimator, FlipDirection dir, AnimationFinishedListener listener) {
        FlipDirection theOtherDirection;
        View fromView = viewAnimator.getCurrentView();
        int currentIndex = viewAnimator.getDisplayedChild();
        int nextIndex = (currentIndex + 1) % viewAnimator.getChildCount();
        View toView = viewAnimator.getChildAt(nextIndex);
        if (nextIndex < currentIndex) {
            theOtherDirection = dir.theOtherDirection();
        } else {
            theOtherDirection = dir;
        }
        Animation[] animc = flipAnimation(fromView, toView, theOtherDirection, 350, null);
        viewAnimator.setOutAnimation(animc[0]);
        viewAnimator.setInAnimation(animc[1]);
        animc[1].setAnimationListener(new C00451(listener));
        viewAnimator.showNext();
    }

    public static Animation inFromLeftAnimation(long duration, Interpolator interpolator) {
        Animation inFromLeft = new TranslateAnimation(2, -1.0f, 2, 0.0f, 2, 0.0f, 2, 0.0f);
        inFromLeft.setDuration(duration);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        inFromLeft.setInterpolator(interpolator);
        return inFromLeft;
    }

    public static Animation outToRightAnimation(long duration, Interpolator interpolator) {
        Animation outtoRight = new TranslateAnimation(2, 0.0f, 2, 1.0f, 2, 0.0f, 2, 0.0f);
        outtoRight.setDuration(duration);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        outtoRight.setInterpolator(interpolator);
        return outtoRight;
    }

    public static Animation inFromRightAnimation(long duration, Interpolator interpolator) {
        Animation inFromRight = new TranslateAnimation(2, 1.0f, 2, 0.0f, 2, 0.0f, 2, 0.0f);
        inFromRight.setDuration(duration);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        inFromRight.setInterpolator(interpolator);
        return inFromRight;
    }

    public static Animation outToLeftAnimation(long duration, Interpolator interpolator) {
        Animation outtoLeft = new TranslateAnimation(2, 0.0f, 2, -1.0f, 2, 0.0f, 2, 0.0f);
        outtoLeft.setDuration(duration);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        outtoLeft.setInterpolator(interpolator);
        return outtoLeft;
    }

    public static Animation inFromTopAnimation(long duration, Interpolator interpolator) {
        Animation infromtop = new TranslateAnimation(2, 0.0f, 2, 0.0f, 2, -1.0f, 2, 0.0f);
        infromtop.setDuration(duration);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        infromtop.setInterpolator(interpolator);
        return infromtop;
    }

    public static Animation outToTopAnimation(long duration, Interpolator interpolator) {
        Animation outtotop = new TranslateAnimation(2, 0.0f, 2, 0.0f, 2, 0.0f, 2, -1.0f);
        outtotop.setDuration(duration);
        if (interpolator == null) {
            interpolator = new AccelerateInterpolator();
        }
        outtotop.setInterpolator(interpolator);
        return outtotop;
    }

    public static Animation fadeInAnimation(long duration, long delay) {
        Animation fadeIn = new AlphaAnimation(0.0f, 1.0f);
        fadeIn.setInterpolator(new DecelerateInterpolator());
        fadeIn.setDuration(duration);
        fadeIn.setStartOffset(delay);
        return fadeIn;
    }

    public static Animation fadeOutAnimation(long duration, long delay) {
        Animation fadeOut = new AlphaAnimation(1.0f, 0.0f);
        fadeOut.setInterpolator(new AccelerateInterpolator());
        fadeOut.setStartOffset(delay);
        fadeOut.setDuration(duration);
        return fadeOut;
    }

    public static Animation fadeInAnimation(long duration, View view) {
        Animation animation = fadeInAnimation(500, 0);
        animation.setAnimationListener(new C00462(view));
        return animation;
    }

    public static Animation fadeOutAnimation(long duration, View view) {
        Animation animation = fadeOutAnimation(500, 0);
        animation.setAnimationListener(new C00473(view));
        return animation;
    }

    public static Animation[] fadeInThenOutAnimation(long duration, long delay) {
        return new Animation[]{fadeInAnimation(duration, 0), fadeOutAnimation(duration, duration + delay)};
    }

    public static void fadeOut(View v) {
        if (v != null) {
            v.startAnimation(fadeOutAnimation(500, v));
        }
    }

    public static void fadeIn(View v) {
        if (v != null) {
            v.startAnimation(fadeInAnimation(500, v));
        }
    }

    public static void fadeInThenOut(View v, long delay) {
        if (v != null) {
            v.setVisibility(0);
            AnimationSet animation = new AnimationSet(true);
            Animation[] fadeInOut = fadeInThenOutAnimation(500, delay);
            animation.addAnimation(fadeInOut[0]);
            animation.addAnimation(fadeInOut[1]);
            animation.setAnimationListener(new C00484(v));
            v.startAnimation(animation);
        }
    }
}
