package com.enus.myzik;

import android.content.ContentResolver;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources.NotFoundException;
import android.database.Cursor;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.os.Environment;
import android.provider.MediaStore.Audio.Playlists;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.View.OnKeyListener;
import android.view.View.OnLongClickListener;
import android.view.ViewGroup;
import android.view.inputmethod.InputMethodManager;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;
import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import org.teleal.cling.model.message.header.EXTHeader;

public class CustomPlayListAdapter extends ArrayAdapter<CustomPlayListItem> {
    private ArrayList<CustomPlayListItem> Items;
    private boolean[] isCheckedConfrim = null;
    Context mContext;
    public DatabaseManager mDBManager = null;
    private List_Activity mParent;
    int mState = 0;
    public int nCheckedList = -1;
    public int nPrevCheckedList = -1;
    private String strTableName = EXTHeader.DEFAULT_VALUE;

    static class ViewHolder {
        Button butListName;
        CheckBox cbChecked;
        EditText edListName;
        ImageView lvICon;
        TextView tvListName;

        ViewHolder() {
        }
    }

    public CustomPlayListAdapter(Context context, int textViewResourceId, ArrayList<CustomPlayListItem> items) {
        super(context, textViewResourceId, items);
        this.mContext = context;
        this.Items = items;
    }

    public void Refresh() {
        onItemSize();
    }

    public void onItemSize() {
        if (this.isCheckedConfrim != null) {
            Arrays.fill(this.isCheckedConfrim, false);
        }
        this.isCheckedConfrim = null;
        if (this.Items.size() > 0) {
            this.isCheckedConfrim = new boolean[this.Items.size()];
        }
    }

    public void onClose() {
        Boolean bool = null;
        if (this.isCheckedConfrim != null) {
            Arrays.fill(this.isCheckedConfrim, bool.booleanValue());
        }
        this.isCheckedConfrim = bool;
    }

    public void onInit(DatabaseManager DBManager, String strTableName, List_Activity Parent) {
        this.mDBManager = DBManager;
        this.strTableName = strTableName;
        this.mParent = Parent;
        onItemSize();
    }

    public int getCount() {
        return this.Items.size();
    }

    public long getItemId(int position) {
        return (long) position;
    }

    public void setChecked(int position) {
        try {
            this.isCheckedConfrim[position] = !this.isCheckedConfrim[position];
            if (this.isCheckedConfrim[position]) {
                this.nCheckedList = position;
            }
        } catch (ArrayIndexOutOfBoundsException e) {
            e.printStackTrace();
        }
    }

    public void setChecked(int position, boolean bChecked) {
        this.isCheckedConfrim[position] = bChecked;
    }

    public ArrayList<Integer> getChecked() {
        if (this.isCheckedConfrim == null) {
            return null;
        }
        int tempSize = this.isCheckedConfrim.length;
        ArrayList<Integer> mArrayList = new ArrayList();
        for (int i = 0; i < tempSize; i++) {
            if (this.isCheckedConfrim[i]) {
                mArrayList.add(Integer.valueOf(i));
            }
        }
        return mArrayList;
    }

    public boolean isCheckedList(int position) {
        return this.isCheckedConfrim[position];
    }

    public int getCheckedPosition() {
        return this.nCheckedList;
    }

    public static long getPlaylist(ContentResolver resolver, String name) {
        long id = -1;
        ContentResolver contentResolver = resolver;
        Cursor cursor = contentResolver.query(Playlists.EXTERNAL_CONTENT_URI, new String[]{"_id"}, "name=?", new String[]{name}, null);
        if (cursor != null) {
            if (cursor.moveToNext()) {
                id = cursor.getLong(0);
            }
            cursor.close();
        }
        return id;
    }

    public static void deletePlaylist(ContentResolver resolver, long id) {
        resolver.delete(ContentUris.withAppendedId(Playlists.EXTERNAL_CONTENT_URI, id), null, null);
    }

    public static void renamePlaylist(Context pContext, long id, String newName) {
        ContentResolver resolver = pContext.getContentResolver();
        long existingId = getPlaylist(resolver, newName);
        if (existingId != id) {
            if (existingId != -1) {
                Toast.makeText(pContext, "deletePlaylist", 1).show();
                deletePlaylist(resolver, existingId);
            }
            resolver = pContext.getContentResolver();
            ContentValues values = new ContentValues(1);
            values.put("name", newName);
            resolver.update(Playlists.EXTERNAL_CONTENT_URI, values, "_id=" + id, null);
        }
    }

    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder holder;
        View v = convertView;
        final int pos = position;
        if (v == null) {
            v = ((LayoutInflater) getContext().getSystemService("layout_inflater")).inflate(C0181R.layout.list_item, null);
            holder = new ViewHolder();
            holder.lvICon = (ImageView) v.findViewById(C0181R.id.list_item_imageView_Icon);
            holder.butListName = (Button) v.findViewById(C0181R.id.list_item_button_Name);
            holder.cbChecked = (CheckBox) v.findViewById(C0181R.id.list_item_checkBox_Checkbox);
            holder.edListName = (EditText) v.findViewById(C0181R.id.list_item_ed_Name);
            v.setTag(holder);
        } else {
            holder = (ViewHolder) v.getTag();
        }
        CustomPlayListItem item = (CustomPlayListItem) this.Items.get(pos);
        if (item != null) {
            if (v != null) {
                Drawable drawable;
                if ((position & 1) == 1) {
                    try {
                        drawable = this.mContext.getResources().getDrawable(C0181R.drawable.list_bg01);
                    } catch (NotFoundException e) {
                        e.printStackTrace();
                    }
                } else {
                    drawable = this.mContext.getResources().getDrawable(C0181R.drawable.list_bg02);
                }
                v.setBackgroundDrawable(drawable);
            }
            String strLPLName1 = this.mContext.getResources().getString(C0181R.string.lpl_name1);
            String strLPLName2 = this.mContext.getResources().getString(C0181R.string.lpl_name2);
            String strLPLName3 = this.mContext.getResources().getString(C0181R.string.lpl_name3);
            if (item.getType() == 1) {
                if (item.getListName().compareTo(strLPLName1) == 0) {
                    holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_music));
                } else {
                    holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_music_b));
                }
            } else if (item.getType() == 2) {
                if (item.getListName().compareTo(strLPLName2) == 0) {
                    holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_pic));
                } else {
                    holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_pic_b));
                }
            } else if (item.getType() == 3) {
                if (item.getListName().compareTo(strLPLName3) == 0) {
                    holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_movie));
                } else {
                    holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_movie_b));
                }
            } else if (item.getType() == 4) {
                holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_doc_b));
            } else if (item.getType() == 5) {
                holder.lvICon.setImageDrawable(this.mContext.getResources().getDrawable(C0181R.drawable.listicon_pen_b));
            }
            holder.butListName.setText(item.getListName());
            holder.edListName.setText(item.getListName());
            if (item.getTypeListName() == 1) {
                holder.butListName.setVisibility(8);
                holder.edListName.setVisibility(0);
                holder.edListName.clearFocus();
                holder.edListName.setInputType(1);
                holder.edListName.setSelection(holder.edListName.length());
                holder.edListName.requestFocus();
                ((InputMethodManager) this.mContext.getSystemService("input_method")).toggleSoftInput(0, 1);
            } else {
                holder.butListName.setVisibility(0);
                holder.edListName.setVisibility(8);
            }
            if (this.mState == 0) {
                holder.cbChecked.setBackgroundResource(C0181R.drawable.chk_enable2);
            } else if (this.mState == 2) {
                holder.cbChecked.setBackgroundResource(C0181R.drawable.ic_export);
            } else {
                holder.cbChecked.setBackgroundResource(C0181R.drawable.chk_disable2);
            }
            if (this.isCheckedConfrim != null) {
                if (this.isCheckedConfrim[position]) {
                    holder.cbChecked.setChecked(true);
                    holder.butListName.setTextColor(Color.parseColor("#a8ff52"));
                    this.nCheckedList = position;
                } else {
                    holder.cbChecked.setChecked(false);
                    holder.butListName.setTextColor(Color.parseColor("#d9d9d9"));
                }
            }
            final EditText edTmp = holder.edListName;
            holder.edListName.setOnKeyListener(new OnKeyListener() {
                public boolean onKey(View v, int keyCode, KeyEvent event) {
                    if (event.getAction() == 0 && keyCode == 66) {
                        String strNewName = EXTHeader.DEFAULT_VALUE;
                        strNewName = edTmp.getText().toString();
                        String strContent = EXTHeader.DEFAULT_VALUE;
                        strContent = ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getContent();
                        if (strContent.substring(0, 3).compareTo("PL_") == 0) {
                            Toast.makeText(CustomPlayListAdapter.this.mContext, "renamePlaylist", 1).show();
                            CustomPlayListAdapter.renamePlaylist(CustomPlayListAdapter.this.mContext, Long.valueOf(strContent.substring(3)).longValue(), edTmp.getText().toString());
                        } else if (((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType() == 5) {
                            String strPLpath = new StringBuilder(String.valueOf(Environment.getExternalStorageDirectory().toString())).append(File.separator).append(CustomPlayListAdapter.this.mContext.getResources().getString(C0181R.string.root_directory)).append(File.separator).toString();
                            new File(strPLpath, ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getListName()).renameTo(new File(strPLpath, strNewName));
                        }
                        String strQuery = EXTHeader.DEFAULT_VALUE;
                        strQuery = String.format("update playlist set list_name='%s' where list_name='%s' and type = %d", new Object[]{strNewName, ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getListName(), Integer.valueOf(((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType())});
                        if (CustomPlayListAdapter.this.mDBManager.execSQL(strQuery)) {
                            ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).setListName(edTmp.getText().toString());
                        } else {
                            Toast.makeText(CustomPlayListAdapter.this.mContext, strQuery, 1).show();
                            Toast.makeText(CustomPlayListAdapter.this.mContext, strQuery, 1).show();
                        }
                        ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).setTypeListName(0);
                        CustomPlayListAdapter.this.notifyDataSetChanged();
                        return true;
                    } else if (event.getAction() != 0 || keyCode != 4) {
                        return false;
                    } else {
                        ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).setTypeListName(0);
                        CustomPlayListAdapter.this.notifyDataSetChanged();
                        return true;
                    }
                }
            });
            holder.butListName.setOnLongClickListener(new OnLongClickListener() {
                public boolean onLongClick(View v) {
                    for (int i = 0; i < CustomPlayListAdapter.this.Items.size(); i++) {
                        ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(i)).setTypeListName(0);
                    }
                    String strLPLName1 = CustomPlayListAdapter.this.mContext.getResources().getString(C0181R.string.lpl_name1);
                    String strLPLName2 = CustomPlayListAdapter.this.mContext.getResources().getString(C0181R.string.lpl_name2);
                    String strLPLName3 = CustomPlayListAdapter.this.mContext.getResources().getString(C0181R.string.lpl_name3);
                    String strCmpName = ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getListName();
                    if (!(strLPLName1.compareTo(strCmpName) == 0 || strLPLName2.compareTo(strCmpName) == 0 || strLPLName3.compareTo(strCmpName) == 0)) {
                        ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).setTypeListName(1);
                    }
                    CustomPlayListAdapter.this.notifyDataSetChanged();
                    return true;
                }
            });
            holder.butListName.setOnClickListener(new OnClickListener() {
                public void onClick(View v) {
                    Intent intent;
                    String strListName = EXTHeader.DEFAULT_VALUE;
                    String strTableName = EXTHeader.DEFAULT_VALUE;
                    MzServerApp MzApp = (MzServerApp) CustomPlayListAdapter.this.mContext.getApplicationContext();
                    if (((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType() == 1) {
                        intent = new Intent(CustomPlayListAdapter.this.mContext, View_Audio_Activity.class);
                    } else if (((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType() == 2) {
                        intent = new Intent(CustomPlayListAdapter.this.mContext, View_Image_Activity.class);
                    } else if (((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType() == 3) {
                        intent = new Intent(CustomPlayListAdapter.this.mContext, View_Video_Activity.class);
                    } else if (((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType() == 4) {
                        intent = new Intent(CustomPlayListAdapter.this.mContext, View_File_Activity.class);
                    } else if (((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType() == 5) {
                        intent = new Intent(CustomPlayListAdapter.this.mContext, View_File_Activity2.class);
                    } else if (MzApp != null) {
                        MzApp.ShowMsg("Error", 1);
                        return;
                    } else {
                        return;
                    }
                    int nType = ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getType();
                    strListName = ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getListName();
                    strTableName = ((CustomPlayListItem) CustomPlayListAdapter.this.Items.get(pos)).getContent();
                    intent.putExtra("type", nType);
                    intent.putExtra("list_name", strListName);
                    intent.putExtra("table_name", strTableName);
                    CustomPlayListAdapter.this.mContext.startActivity(intent);
                }
            });
            holder.cbChecked.setOnClickListener(new OnClickListener() {
                public void onClick(View v) {
                    CustomPlayListAdapter.this.nPrevCheckedList = CustomPlayListAdapter.this.nCheckedList;
                    CustomPlayListAdapter.this.nCheckedList = pos;
                    int nSize = CustomPlayListAdapter.this.getChecked().size();
                    for (int i = 0; i < nSize; i++) {
                        int nChecked = ((Integer) CustomPlayListAdapter.this.getChecked().get(i)).intValue();
                        if (pos != nChecked) {
                            CustomPlayListAdapter.this.setChecked(nChecked);
                        } else {
                            CustomPlayListAdapter.this.setChecked(nChecked);
                        }
                    }
                    CustomPlayListAdapter.this.setChecked(pos);
                    CustomPlayListAdapter.this.notifyDataSetChanged();
                    CustomPlayListAdapter.this.mParent.onActivate();
                }
            });
        }
        return v;
    }

    protected void setEdVisibility(int i) {
    }

    public void setBackChecked() {
        this.nCheckedList = this.nPrevCheckedList;
        int nSize = getChecked().size();
        for (int i = 0; i < nSize; i++) {
            int nChecked = ((Integer) getChecked().get(i)).intValue();
            if (this.nCheckedList != nChecked) {
                setChecked(nChecked);
            } else if (isCheckedList(nChecked)) {
                this.nCheckedList = -1;
            }
        }
        if (this.nCheckedList >= 0) {
            setChecked(this.nCheckedList);
        }
        notifyDataSetChanged();
    }

    public void setState(int nState) {
        this.mState = nState;
        notifyDataSetChanged();
    }

    public int getState() {
        return this.mState;
    }
}
