package com.enus.myzik;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.graphics.Rect;
import android.os.Vibrator;
import android.util.AttributeSet;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.view.WindowManager.LayoutParams;
import android.widget.ImageView;
import android.widget.ListView;

public class DFileView2 extends ListView {
    CustomEditFileAdapter2 Adapter;
    Context mContext;
    private int mCoordOffset;
    private Bitmap mDragBitmap;
    private DragListener mDragListener;
    private int mDragPoint;
    private int mDragPos;
    private ImageView mDragView;
    private DropListener mDropListener;
    private int mFirstDragPos;
    private int mHeight;
    private boolean mIsScrollEnd = false;
    private int mItemHeightHalf;
    private int mItemHeightNormal;
    private int mLowerBound;
    private Rect mTempRect = new Rect();
    private int mTouchSlop;
    private int mUpperBound;
    Vibrator mVib;
    private WindowManager mWindowManager;
    private LayoutParams mWindowParams;
    private int mnVBottom = 0;

    public interface DragListener {
        void drag(int i, int i2);
    }

    public interface DropListener {
        void drop(int i, int i2);
    }

    public interface RemoveListener {
        void remove(int i);
    }

    public DFileView2(Context context) {
        super(context);
        this.mContext = context;
    }

    public DFileView2(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.mContext = context;
    }

    public DFileView2(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        this.mContext = context;
    }

    public boolean onInterceptTouchEvent(MotionEvent ev) {
        if (!(this.mDragListener == null && this.mDropListener == null)) {
            switch (ev.getAction()) {
                case 0:
                    if (onInitView(ev)) {
                        return false;
                    }
                    return super.onInterceptTouchEvent(ev);
            }
        }
        return super.onInterceptTouchEvent(ev);
    }

    public boolean onTouchEvent(MotionEvent ev) {
        if ((this.mDragListener == null && this.mDropListener == null) || this.mDragView == null) {
            return super.onTouchEvent(ev);
        }
        switch (ev.getAction()) {
            case 0:
            case 2:
                onDrawView(ev);
                break;
            case 1:
            case 3:
                int nX = (int) ev.getX();
                int nY = (int) ev.getY();
                dragView(0, nY);
                int nItemNum = getItemForPosition(nY);
                if (nItemNum != -1) {
                    onRefresh(this.mDragPos, nItemNum);
                }
                this.mDragView.getDrawingRect(this.mTempRect);
                stopDragging();
                if (this.mDropListener != null && this.mDragPos >= 0 && this.mDragPos < getCount()) {
                    this.mDropListener.drop(this.mFirstDragPos, this.mDragPos);
                }
                unExpandViews(false);
                ((CustomEditFileAdapter2) getAdapter()).notifyDataSetChanged();
                break;
        }
        return true;
    }

    public void setDragListener(DragListener l) {
        this.mDragListener = l;
    }

    public void setDropListener(DropListener l) {
        this.mDropListener = l;
    }

    public void onInit() {
        this.mContext = getContext();
        this.mTouchSlop = ViewConfiguration.get(this.mContext).getScaledTouchSlop();
        this.mVib = (Vibrator) this.mContext.getSystemService("vibrator");
    }

    public void onClose() {
        this.mTempRect = null;
        stopDragging();
    }

    public boolean onInitView(MotionEvent ev) {
        Rect rtRect = this.mTempRect;
        this.Adapter = (CustomEditFileAdapter2) getAdapter();
        int nX = (int) ev.getX();
        int nY = (int) ev.getY();
        int nItemNum = pointToPosition(nX, nY);
        if (nItemNum == -1) {
            return false;
        }
        ViewGroup Item = (ViewGroup) getChildAt(nItemNum - getFirstVisiblePosition());
        ViewHolder holder = (ViewHolder) Item.getTag();
        holder.butMinus.getHitRect(rtRect);
        if (rtRect.contains(nX, nY - Item.getTop())) {
            return false;
        }
        holder.ivDelete.getHitRect(rtRect);
        if (rtRect.contains(nX, nY - Item.getTop()) && ((CustomListItem) this.Adapter.getItem(nItemNum)).isSelected()) {
            return false;
        }
        if (!rtRect.contains(nX, nY - Item.getTop())) {
            return false;
        }
        this.mDragPoint = nY - Item.getTop();
        this.mCoordOffset = ((int) ev.getRawY()) - nY;
        Item.setDrawingCacheEnabled(true);
        Bitmap bm = Bitmap.createBitmap(Item.getDrawingCache());
        Item.setDrawingCacheEnabled(false);
        startDragging(bm, nY, Item);
        this.mVib.vibrate(500);
        this.mDragPos = nItemNum;
        this.mFirstDragPos = this.mDragPos;
        this.mHeight = getHeight();
        this.mUpperBound = Math.min(nY - 0, this.mHeight / 4);
        this.mLowerBound = Math.max(nY + 0, (this.mHeight * 3) / 4);
        this.mItemHeightNormal = Item.getHeight();
        this.mItemHeightHalf = this.mItemHeightNormal / 2;
        return true;
    }

    public boolean IsScrollEnd() {
        return this.mIsScrollEnd;
    }

    protected void onScrollChanged(int l, int t, int oldl, int oldt) {
        if (getChildCount() > 0) {
            View view = getChildAt(getChildCount() - 1);
            if (this.mnVBottom < getHeight()) {
                this.mnVBottom = getHeight();
            }
            int diff = view.getBottom() - (this.mnVBottom + getScrollY());
            Log.d("myzik", Integer.valueOf(diff).toString());
            if (diff <= 0 || this.mnVBottom != getHeight()) {
                this.mIsScrollEnd = true;
            } else {
                this.mIsScrollEnd = false;
            }
        }
        super.onScrollChanged(l, t, oldl, oldt);
    }

    private void startDragging(Bitmap bm, int y, ViewGroup Item) {
        stopDragging();
        this.mWindowParams = new LayoutParams();
        this.mWindowParams.gravity = 51;
        this.mWindowParams.x = 0;
        this.mWindowParams.y = (y - this.mDragPoint) + this.mCoordOffset;
        this.mWindowParams.height = Item.getHeight();
        this.mWindowParams.width = -2;
        this.mWindowParams.flags = 920;
        this.mWindowParams.format = -3;
        this.mWindowParams.windowAnimations = 0;
        Context context = getContext();
        ImageView v = new ImageView(context);
        v.setBackgroundColor(Color.parseColor("red"));
        v.setImageBitmap(bm);
        this.mDragBitmap = bm;
        this.mWindowManager = (WindowManager) context.getSystemService("window");
        this.mWindowManager.addView(v, this.mWindowParams);
        this.mDragView = v;
    }

    private void stopDragging() {
        if (this.mDragView != null) {
            ((WindowManager) getContext().getSystemService("window")).removeView(this.mDragView);
            this.mDragView.setImageDrawable(null);
            this.mDragView = null;
        }
        if (this.mDragBitmap != null) {
            this.mDragBitmap.recycle();
            this.mDragBitmap = null;
        }
    }

    private void onDrawView(MotionEvent ev) {
        int nSpeed = 0;
        int nX = (int) ev.getX();
        int nY = (int) ev.getY();
        dragView(0, nY);
        int nItemNum = getItemForPosition(nY);
        if (nItemNum >= 0) {
            if ((0 == 0 || nItemNum != this.mDragPos) && this.mDragListener != null) {
                this.mDragListener.drag(this.mDragPos, nItemNum);
            }
            adjustScrollBounds(nY);
            int half;
            if (nY > this.mLowerBound) {
                nSpeed = nY > (this.mHeight + this.mLowerBound) / 2 ? 16 : 4;
                if (nY > (this.mHeight + this.mLowerBound) / 2) {
                    half = this.mItemHeightNormal / 4;
                } else {
                    half = this.mItemHeightNormal / 16;
                }
            } else if (nY < this.mUpperBound) {
                nSpeed = nY < this.mUpperBound / 2 ? -16 : -4;
                if (nY < this.mUpperBound / 2) {
                    half = this.mItemHeightNormal / -4;
                } else {
                    half = this.mItemHeightNormal / -16;
                }
            }
            if (nSpeed != 0) {
                int nDist;
                if (nSpeed < 0) {
                    nDist = nY - this.mUpperBound;
                } else {
                    nDist = nY - this.mLowerBound;
                }
                int ref = pointToPosition(0, this.mHeight / 2);
                if (ref == -1) {
                    ref = pointToPosition(0, ((this.mHeight / 2) + getDividerHeight()) + 64);
                }
                View v = getChildAt(ref - getFirstVisiblePosition());
                if (v != null) {
                    int pos = v.getTop();
                    int pos2 = getItemForPosition(nY);
                    int nCount = getCount();
                    if (pos2 == 0) {
                        smoothScrollToPosition(pos2 - 1);
                    } else if (pos2 + 1 == nCount) {
                        smoothScrollToPosition(pos2 + 1);
                    } else {
                        smoothScrollBy(nDist, 1000);
                    }
                }
            }
        }
    }

    private void dragView(int x, int y) {
        this.mWindowParams.x = 0;
        this.mWindowParams.y = (y - this.mDragPoint) + this.mCoordOffset;
        this.mWindowManager.updateViewLayout(this.mDragView, this.mWindowParams);
    }

    private int myPointToPosition(int x, int y) {
        if (y < 0) {
            return 0;
        }
        Rect frame = this.mTempRect;
        int count = getChildCount();
        for (int i = 0; i < count; i++) {
            View child = getChildAt(i);
            int nInRange = child.getBottom() - (child.getHeight() / 2);
            if (nInRange > y) {
                return getFirstVisiblePosition() + i;
            }
            if (i == count - 1 && nInRange < y) {
                return getFirstVisiblePosition() + i;
            }
        }
        return -1;
    }

    private int getItemForPosition(int y) {
        return myPointToPosition(0, y - this.mDragPoint);
    }

    private void onRefresh(int from, int to) {
        int nStart = from;
        int nEnd = to;
        int i;
        if (from >= to) {
            for (i = nStart; i > nEnd; i--) {
                ViewGroup v2 = (ViewGroup) getChildAt((i - 1) - getFirstVisiblePosition());
                this.Adapter.getView(i, (ViewGroup) getChildAt(i - getFirstVisiblePosition()), this);
                this.Adapter.getView(i, v2, this);
                this.Adapter.onRefresh(i, i - 1);
            }
            return;
        }
        for (i = nStart; i < nEnd; i++) {
            v2 = (ViewGroup) getChildAt((i + 1) - getFirstVisiblePosition());
            this.Adapter.getView(i, (ViewGroup) getChildAt(i - getFirstVisiblePosition()), this);
            this.Adapter.getView(i + 1, v2, this);
            this.Adapter.onRefresh(i, i + 1);
        }
    }

    private void doExpansion() {
        int nChildPos = this.mDragPos - getFirstVisiblePosition();
        int i = 0;
        while (true) {
            View vv = getChildAt(i);
            if (vv != null) {
                int nHeight = vv.getHeight();
                int nVisibility = 0;
                if (i == nChildPos) {
                    nVisibility = 4;
                }
                ViewGroup.LayoutParams params = vv.getLayoutParams();
                params.width = vv.getWidth();
                params.height = nHeight;
                vv.setLayoutParams(params);
                vv.setVisibility(nVisibility);
                i++;
            } else {
                return;
            }
        }
    }

    private void adjustScrollBounds(int y) {
        if (y >= this.mHeight / 4) {
            this.mUpperBound = this.mHeight / 4;
        }
        if (y <= (this.mHeight * 3) / 4) {
            this.mLowerBound = (this.mHeight * 3) / 4;
        }
    }

    private void unExpandViews(boolean deletion) {
        int i = 0;
        while (true) {
            View v = getChildAt(i);
            if (v == null) {
                break;
            }
            ViewGroup.LayoutParams params = v.getLayoutParams();
            params.width = v.getWidth();
            params.height = v.getHeight();
            v.setLayoutParams(params);
            v.setVisibility(0);
            i++;
        }
        if (deletion) {
            int position = getFirstVisiblePosition();
            int y = getChildAt(0).getTop();
            setAdapter(getAdapter());
            setSelectionFromTop(position, y);
        }
        layoutChildren();
        if (getChildAt(i) != null) {
        }
    }
}
