package com.enus.myzik;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.graphics.Rect;
import android.os.Vibrator;
import android.util.AttributeSet;
import android.util.Log;
import android.view.GestureDetector;
import android.view.GestureDetector.SimpleOnGestureListener;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.view.WindowManager.LayoutParams;
import android.widget.GridView;
import android.widget.ImageView;

public class DGridView extends GridView {
    static final int GRIDROWCOUNT = 3;
    CustomEditImageAdapter Adapter;
    private GestureDetector gestureDetector = null;
    Context mContext;
    private int mCoordXOffset;
    private int mCoordYOffset;
    private Bitmap mDragBitmap;
    ViewGroup mDragItem;
    private DragListener mDragListener;
    private int mDragPos;
    private ImageView mDragView;
    private int mDragXPoint;
    private int mDragYPoint;
    private DropListener mDropListener;
    private int mFirstDragPos;
    private int mHeight = 0;
    private boolean mIsScrollEnd = false;
    private int mItemHeightHalf;
    private int mItemHeightNormal;
    private int mItemWidthNormal;
    private int mLowerBound;
    private Rect mTempRect = new Rect();
    private int mTouchSlop;
    private int mUpperBound;
    Vibrator mVib;
    private WindowManager mWindowManager;
    private LayoutParams mWindowParams;
    private boolean mbDragStart = false;
    private boolean mbLongChecked = false;
    private int mnVBottom = 0;

    class C00901 extends SimpleOnGestureListener {
        C00901() {
        }

        public boolean onSingleTapUp(MotionEvent e) {
            return super.onSingleTapUp(e);
        }

        public void onLongPress(MotionEvent e) {
            super.onLongPress(e);
            ViewGroup Item = DGridView.this.mDragItem;
            if (Item != null) {
                int nX = (int) e.getX();
                int nY = (int) e.getY();
                Item.setDrawingCacheEnabled(true);
                Bitmap bm = Bitmap.createBitmap(Item.getDrawingCache());
                Item.setDrawingCacheEnabled(false);
                DGridView.this.startDragging(bm, nX, nY, Item);
                DGridView.this.mbLongChecked = true;
                DGridView.this.mVib.vibrate(500);
            }
        }
    }

    public interface DragListener {
        void drag(int i, int i2, MotionEvent motionEvent);
    }

    public interface DropListener {
        void drop(int i, int i2, MotionEvent motionEvent, int i3);
    }

    public interface RemoveListener {
        void remove(int i);
    }

    public DGridView(Context context) {
        super(context);
    }

    public DGridView(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    public DGridView(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
    }

    public void setDragListener(DragListener l) {
        this.mDragListener = l;
    }

    public void setDropListener(DropListener l) {
        this.mDropListener = l;
    }

    public boolean onInterceptTouchEvent(MotionEvent ev) {
        switch (ev.getAction()) {
            case 0:
                setSmoothScrollbarEnabled(true);
                if (onInitView(ev)) {
                    return false;
                }
                return super.onInterceptTouchEvent(ev);
            default:
                return super.onInterceptTouchEvent(ev);
        }
    }

    public boolean onTouchEvent(MotionEvent ev) {
        if (this.gestureDetector != null && !this.mbLongChecked) {
            this.gestureDetector.onTouchEvent(ev);
        } else if (!((this.mDragListener == null && this.mDropListener == null) || this.mDragView == null)) {
            switch (ev.getAction()) {
                case 0:
                case 2:
                    if (this.mbLongChecked) {
                        onDrawView(ev);
                        break;
                    }
                    break;
                case 1:
                case 3:
                    int nItemNum = getItemForPosition((int) ev.getX(), (int) ev.getY());
                    if (nItemNum != -1) {
                        onRefresh(this.mDragPos, nItemNum);
                    }
                    this.mbLongChecked = false;
                    this.mDragView.getDrawingRect(this.mTempRect);
                    stopDragging();
                    if (this.mDropListener != null && this.mDragPos >= 0 && this.mDragPos < getCount()) {
                        this.mDropListener.drop(this.mFirstDragPos, this.mDragPos, ev, this.mHeight);
                    }
                    unExpandViews(false);
                    this.Adapter.notifyDataSetChanged();
                    this.mbDragStart = false;
                    break;
            }
            return true;
        }
        return super.onTouchEvent(ev);
    }

    public void onInit() {
        this.mContext = getContext();
        this.mTempRect = new Rect();
        this.Adapter = (CustomEditImageAdapter) getAdapter();
        this.mVib = (Vibrator) this.mContext.getSystemService("vibrator");
        this.gestureDetector = new GestureDetector(new C00901());
    }

    public boolean onInitView(MotionEvent ev) {
        int nX = (int) ev.getX();
        int nY = (int) ev.getY();
        int nItemNum = pointToPosition(nX, nY);
        if (nItemNum == -1) {
            return false;
        }
        ViewGroup Item = (ViewGroup) getChildAt(nItemNum - getFirstVisiblePosition());
        if (Item == null) {
            return false;
        }
        this.mDragXPoint = nX - Item.getLeft();
        this.mDragYPoint = nY - Item.getTop();
        this.mCoordXOffset = ((int) ev.getRawX()) - nX;
        this.mCoordYOffset = ((int) ev.getRawY()) - nY;
        this.mDragItem = Item;
        this.mDragPos = nItemNum;
        this.mFirstDragPos = this.mDragPos;
        this.mHeight = getHeight();
        int touchSlop = this.mTouchSlop;
        this.mUpperBound = Math.min(nY - touchSlop, this.mHeight / 3);
        this.mLowerBound = Math.max(nY + touchSlop, (this.mHeight * 2) / 3);
        this.mItemWidthNormal = Item.getWidth();
        this.mItemHeightNormal = Item.getHeight();
        return true;
    }

    public boolean onDrawView(MotionEvent ev) {
        int nSpeed = 0;
        int nX = (int) ev.getX();
        int nY = (int) ev.getY();
        dragView(nX, nY);
        int nItemNum = pointToPosition(nX, nY);
        if (nItemNum == -1) {
            nItemNum = getItemForPosition(nX, nY);
            if (nItemNum == -1) {
                return false;
            }
        }
        if (nItemNum >= 0) {
            if (!this.mbDragStart) {
                if (this.mDragListener != null) {
                    this.mDragListener.drag(this.mDragPos, nItemNum, ev);
                }
                this.mbDragStart = true;
            }
            adjustScrollBounds(nY);
            if (nY > this.mLowerBound) {
                nSpeed = nY > (this.mHeight + this.mLowerBound) / 2 ? 16 : 4;
            } else if (nY < this.mUpperBound) {
                nSpeed = nY < this.mUpperBound / 2 ? -16 : -4;
            }
            if (nSpeed != 0) {
                int nDist;
                int nAlpha = 0;
                if (nSpeed < 0) {
                    if (nSpeed == -16) {
                        nAlpha = -3;
                    }
                    nDist = nY - this.mUpperBound;
                } else {
                    if (nSpeed == 16) {
                        nAlpha = 3;
                    }
                    nDist = nY - this.mLowerBound;
                }
                int ref = getItemForPosition(0, nY);
                if (getChildAt(ref - getFirstVisiblePosition()) != null) {
                    int nCount = getCount();
                    if (ref / 3 == 0) {
                        smoothScrollToPosition(ref + nAlpha);
                    } else if (ref / 3 == nCount / 3) {
                        smoothScrollToPosition(ref + nAlpha);
                    } else {
                        smoothScrollBy(nDist, 1000);
                    }
                }
            }
        }
        return true;
    }

    public boolean IsScrollEnd() {
        return this.mIsScrollEnd;
    }

    protected void onScrollChanged(int l, int t, int oldl, int oldt) {
        if (getChildCount() > 0) {
            View view = getChildAt(getChildCount() - 1);
            if (this.mnVBottom < getHeight()) {
                this.mnVBottom = getHeight();
            }
            int diff = view.getBottom() - (this.mnVBottom + getScrollY());
            Log.d("myzik", Integer.valueOf(diff).toString());
            if (diff <= 0 || this.mnVBottom != getHeight()) {
                this.mIsScrollEnd = true;
            } else {
                this.mIsScrollEnd = false;
            }
        }
        super.onScrollChanged(l, t, oldl, oldt);
    }

    private void startDragging(Bitmap bm, int x, int y, ViewGroup Item) {
        stopDragging();
        this.mWindowParams = new LayoutParams();
        this.mWindowParams.gravity = 51;
        this.mWindowParams.x = (x - this.mDragXPoint) + this.mCoordXOffset;
        this.mWindowParams.y = (y - this.mDragYPoint) + this.mCoordYOffset;
        this.mWindowParams.height = Item.getHeight();
        this.mWindowParams.width = -2;
        this.mWindowParams.flags = 920;
        this.mWindowParams.format = -3;
        this.mWindowParams.windowAnimations = 0;
        Context context = getContext();
        ImageView v = new ImageView(context);
        v.setBackgroundColor(Color.argb(255, 100, 255, 255));
        v.setImageBitmap(bm);
        this.mDragBitmap = bm;
        this.mWindowManager = (WindowManager) context.getSystemService("window");
        this.mWindowManager.addView(v, this.mWindowParams);
        this.mDragView = v;
    }

    private int getItemForPosition(int x, int y) {
        return myPointToPosition((x - this.mDragXPoint) + (this.mItemWidthNormal / 2), (y - this.mDragYPoint) + (this.mItemHeightNormal / 2));
    }

    private int myPointToPosition(int x, int y) {
        int nCount = getChildCount();
        for (int i = 0; i < nCount; i += 3) {
            if (getChildAt(i).getBottom() > y) {
                int nWidth = getWidth();
                if (x > nWidth) {
                    x = nWidth - 1;
                }
                for (int j = 0; j < 3; j++) {
                    if (getChildAt(i + j) == null) {
                        return (getFirstVisiblePosition() + (i + j)) - 1;
                    }
                    if ((nWidth / 3) * (j + 1) > x) {
                        return getFirstVisiblePosition() + (i + j);
                    }
                }
                continue;
            }
        }
        return -1;
    }

    private void dragView(int x, int y) {
        this.mWindowParams.x = (x - this.mDragXPoint) + this.mCoordXOffset;
        this.mWindowParams.y = (y - this.mDragYPoint) + this.mCoordYOffset;
        this.mWindowManager.updateViewLayout(this.mDragView, this.mWindowParams);
    }

    private void adjustScrollBounds(int y) {
        if (y >= this.mHeight / 3) {
            this.mUpperBound = this.mHeight / 3;
        }
        if (y <= (this.mHeight * 2) / 3) {
            this.mLowerBound = (this.mHeight * 2) / 3;
        }
    }

    private void stopDragging() {
        if (this.mDragView != null) {
            ((WindowManager) getContext().getSystemService("window")).removeView(this.mDragView);
            this.mDragView.setImageDrawable(null);
            this.mDragView = null;
        }
        if (this.mDragBitmap != null) {
            this.mDragBitmap.recycle();
            this.mDragBitmap = null;
        }
    }

    private void onRefresh(int from, int to) {
        int nStart;
        int nEnd;
        this.Adapter.onRefresh(from, to);
        if (from >= to) {
            nStart = to;
        } else {
            nStart = from;
        }
        if (from >= to) {
            nEnd = from;
        } else {
            nEnd = to;
        }
        for (int i = nStart; i <= nEnd; i++) {
            this.Adapter.getView(i, (ViewGroup) getChildAt(i - getFirstVisiblePosition()), this);
        }
    }

    private void doExpansion() {
        int nChildPos = this.mDragPos - getFirstVisiblePosition();
    }

    private void unExpandViews(boolean deletion) {
        int i = 0;
        while (true) {
            View v = getChildAt(i);
            if (v != null) {
                ViewGroup.LayoutParams params = v.getLayoutParams();
                params.width = v.getWidth();
                params.height = v.getHeight();
                v.setLayoutParams(params);
                v.setVisibility(0);
                i++;
            } else {
                return;
            }
        }
    }
}
