package com.enus.myzik;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabase.CursorFactory;
import android.database.sqlite.SQLiteOpenHelper;
import android.widget.Toast;
import java.io.File;
import java.util.ArrayList;
import org.teleal.cling.model.message.header.EXTHeader;

public class DatabaseManager {
    private String DATABASE_NAME = EXTHeader.DEFAULT_VALUE;
    private int DATABASE_VERSION = 0;
    private String SQL_TABLE_CREATE = EXTHeader.DEFAULT_VALUE;
    Context mContext;
    private SQLiteDatabase mDB = null;
    private DatabaseHelper mDBHelper;
    SQLException mError;

    private class DatabaseHelper extends SQLiteOpenHelper {
        public DatabaseHelper(Context context, String name, CursorFactory factory, int version) {
            super(context, name, factory, version);
        }

        public void onCreate(SQLiteDatabase db) {
            try {
                db.execSQL(DatabaseManager.this.SQL_TABLE_CREATE);
            } catch (SQLException e) {
            }
        }

        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
            db.execSQL("DROP TABLE IF EXISTS " + DatabaseManager.this.DATABASE_NAME);
            onCreate(db);
        }
    }

    public DatabaseManager(Context context, String strDBName, int nVersion, String strSQL) {
        this.mContext = context;
        this.DATABASE_NAME = strDBName;
        if (nVersion == 1 || nVersion == 2) {
            nVersion = 3;
        }
        this.DATABASE_VERSION = nVersion;
        this.SQL_TABLE_CREATE = strSQL;
    }

    public DatabaseManager open() throws SQLException {
        this.mDBHelper = new DatabaseHelper(this.mContext, this.DATABASE_NAME, null, this.DATABASE_VERSION);
        this.mDB = this.mDBHelper.getWritableDatabase();
        return this;
    }

    public void close() {
        if (this.mDB != null) {
            this.mDB.close();
        }
        this.mDB = null;
    }

    public boolean execSQL(String strQuery) {
        if (strQuery.length() <= 0) {
            this.mError = null;
            return false;
        }
        try {
            this.mDB.execSQL(strQuery);
            return true;
        } catch (SQLException e) {
            e.printStackTrace();
            this.mError = e;
            return false;
        }
    }

    public long onInsert(String strTableName, ContentValues values) {
        long j = -1;
        if (strTableName.length() <= 0) {
            this.mError = null;
        } else {
            try {
                j = this.mDB.insert(strTableName, null, values);
            } catch (SQLException e) {
                e.printStackTrace();
                this.mError = e;
            }
        }
        return j;
    }

    public Cursor onSelect(String strQuery) {
        Cursor cursor = null;
        if (strQuery.length() <= 0) {
            this.mError = cursor;
        } else {
            try {
                cursor = this.mDB.rawQuery(strQuery, null);
            } catch (SQLException e) {
                e.printStackTrace();
                this.mError = e;
            }
        }
        return cursor;
    }

    public boolean delete(String strTableName, String pkColumn, String pkData) {
        if (strTableName.length() <= 0) {
            this.mError = null;
            return false;
        }
        try {
            if (this.mDB.delete(strTableName, new StringBuilder(String.valueOf(pkColumn)).append("=?").toString(), new String[]{pkData.toString()}) > 0) {
                return true;
            }
            return false;
        } catch (SQLException e) {
            e.printStackTrace();
            this.mError = e;
            return false;
        }
    }

    public int onCount(String strTableName, String strArgs) {
        String strQuery = EXTHeader.DEFAULT_VALUE;
        Cursor cursor = null;
        if (strTableName.length() <= 0) {
            this.mError = null;
            return -1;
        }
        int nCount;
        try {
            if (strArgs.length() > 0) {
                strQuery = "SELECT count(*) FROM " + strTableName + " " + strArgs;
            } else {
                strQuery = "SELECT count(*) FROM " + strTableName;
            }
            cursor = onSelect(strQuery);
            if (cursor == null) {
                this.mError = null;
                return -1;
            } else if (cursor.moveToFirst()) {
                nCount = cursor.getInt(cursor.getColumnIndex("count(*)"));
                cursor.close();
                return nCount;
            } else {
                this.mError = null;
                cursor.close();
                return -1;
            }
        } catch (SQLException e) {
            e.printStackTrace();
            if (cursor != null) {
                cursor.close();
            }
            this.mError = e;
            nCount = -1;
        }
    }

    public boolean onSync(String strTableName) {
        String strQuery = EXTHeader.DEFAULT_VALUE;
        String strPath = EXTHeader.DEFAULT_VALUE;
        Cursor cursor = onSelect("SELECT `idx`, `path` FROM `" + strTableName + "`");
        if (cursor == null) {
            return false;
        }
        if (!cursor.moveToFirst()) {
            return false;
        }
        ArrayList<SyncItem> Items = new ArrayList();
        while (!cursor.isAfterLast()) {
            int nIdx = cursor.getInt(cursor.getColumnIndex("idx"));
            File file = new File(cursor.getString(cursor.getColumnIndex("path")));
            boolean bExists = false;
            if (file != null) {
                bExists = file.exists();
            }
            Items.add(new SyncItem(nIdx, bExists));
            cursor.moveToNext();
        }
        cursor.close();
        int nCount = Items.size();
        for (int i = 0; i < nCount; i++) {
            if (!((SyncItem) Items.get(i)).getExists()) {
                if (!execSQL("DELETE FROM `" + strTableName + "` WHERE `idx` = " + ((SyncItem) Items.get(i)).getIdx())) {
                    Toast.makeText(this.mContext, "Error", 0).show();
                }
            }
        }
        if (Items != null) {
            Items.clear();
        }
        return true;
    }
}
