package com.enus.myzik;

import android.app.Notification;
import android.app.PendingIntent;
import android.app.Service;
import android.content.ComponentName;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.Message;
import android.os.Process;
import android.os.RemoteCallbackList;
import android.os.RemoteException;
import android.util.Log;
import com.enus.myzik.IBService.Stub;
import com.enus.myzik.UDPBroadcast.UDPBroadcastListener;
import com.wireme.mediaserver.ContentTree;
import com.wireme.mediaserver.MediaServer;
import org.teleal.cling.android.AndroidUpnpService;

public class MService extends Service implements UDPBroadcastListener {
    private static final int GetApMac = 1;
    private static final int GetDInfo = 2;
    private static final int GetFVer = 0;
    private static final int GetMSIP = 20;
    private static final int GetMode = 3;
    private static final int GetPort = 4;
    private static final int ParseInfo = 10;
    private static final int REQ_APLIST = 6;
    private static final int REQ_INFO = 5;
    private static final int SET_APLIST = 7;
    private static final int SET_HOTSPOT = 8;
    private static final int SeTCPMode = 1;
    private static final int SetFReset = 9;
    private static final int SetTCPActive = 0;
    private static final int SetTCPUpgrade = 2;
    private static final int SetUDPIP = 11;
    private static final int SetUDPPort = 12;
    private static MediaServer mediaServer = null;
    private Intent INIO = null;
    private ServiceConnection INIOServiceConnection = new C01745();
    private Intent IUDP = null;
    private ServiceConnection IUDPServiceConnection = new C01756();
    private Intent IUPNP = null;
    private ServiceConnection IUPNPServiceConnection = new C01767();
    private final Stub mBinder = new C04858();
    final RemoteCallbackList<IBServiceCallback> mCallbacks = new RemoteCallbackList();
    private final Handler mHandler = new C01779();
    private INIOServiceCallback mINOCallback = new C04844();
    private Handler mNIOHandler = new C01732();
    INIOService mNIOservice = null;
    private IUDPServiceCallback mUDPCallback = new C04833();
    private Handler mUDPHandler = new C01721();
    IUDPService mUDPservice = null;
    IUPNPService mUPNPservice = null;
    private AndroidUpnpService upnpService = null;

    class C01721 extends Handler {
        C01721() {
        }

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    return;
                default:
                    super.handleMessage(msg);
                    return;
            }
        }
    }

    class C01732 extends Handler {
        C01732() {
        }

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    return;
                default:
                    super.handleMessage(msg);
                    return;
            }
        }
    }

    class C01745 implements ServiceConnection {
        C01745() {
        }

        public void onServiceConnected(ComponentName className, IBinder service) {
            Log.d("NIO", "onServiceConnected");
            MService.this.mNIOservice = INIOService.Stub.asInterface(service);
            if (MService.this.mNIOservice == null) {
                Log.d("jmgs", "INIOService onServiceConnected fail");
            } else {
                Log.d("jmgs", "INIOService onServiceConnected OK!");
            }
        }

        public void onServiceDisconnected(ComponentName className) {
            MService.this.mNIOservice = null;
            Log.d("chkerr", "mNIOservice = null");
        }
    }

    class C01756 implements ServiceConnection {
        C01756() {
        }

        public void onServiceConnected(ComponentName className, IBinder service) {
            MService.this.mUDPservice = IUDPService.Stub.asInterface(service);
            if (MService.this.mUDPservice == null) {
                Log.d("jmgs", "UDPService onServiceConnected fail");
                return;
            }
            Log.d("jmgs", "UDPService onServiceConnected OK!");
            try {
                if (MService.this.mNIOservice != null) {
                    String strPort = MService.this.mNIOservice.GetValue(4);
                    if (strPort.length() > 0) {
                        MService.this.mUDPservice.SetCmd(12, strPort);
                    }
                }
            } catch (RemoteException e1) {
                e1.printStackTrace();
            } catch (NullPointerException e12) {
                e12.printStackTrace();
            }
        }

        public void onServiceDisconnected(ComponentName className) {
            MService.this.mNIOservice = null;
            Log.d("chkerr", "mUDPservice = null");
        }
    }

    class C01767 implements ServiceConnection {
        C01767() {
        }

        public void onServiceConnected(ComponentName className, IBinder service) {
            MService.this.mUPNPservice = IUPNPService.Stub.asInterface(service);
            if (MService.this.mUPNPservice == null) {
                Log.d("jmgs", "IUPNPService onServiceConnected fail");
            } else {
                Log.d("jmgs", "IUPNPService onServiceConnected OK!");
            }
        }

        public void onServiceDisconnected(ComponentName className) {
            MService.this.upnpService = null;
        }
    }

    class C01779 extends Handler {
        C01779() {
        }

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    int N = MService.this.mCallbacks.beginBroadcast();
                    for (int i = 0; i < N; i++) {
                        try {
                            ((IBServiceCallback) MService.this.mCallbacks.getBroadcastItem(i)).GetResult(1);
                        } catch (RemoteException e) {
                        }
                    }
                    MService.this.mCallbacks.finishBroadcast();
                    sendMessageDelayed(obtainMessage(1), 1000);
                    return;
                default:
                    super.handleMessage(msg);
                    return;
            }
        }
    }

    class C04833 extends IUDPServiceCallback.Stub {
        C04833() {
        }

        public void GetResult(int nCmd) {
            MService.this.mUDPHandler.sendMessage(MService.this.mUDPHandler.obtainMessage(1, nCmd, 0));
        }
    }

    class C04844 extends INIOServiceCallback.Stub {
        C04844() {
        }

        public void GetResult(int nCmd) {
            MService.this.mNIOHandler.sendMessage(MService.this.mNIOHandler.obtainMessage(1, nCmd, 0));
        }
    }

    class C04858 extends Stub {
        C04858() {
        }

        public void registerCallback(IBServiceCallback cb) {
            if (cb != null) {
                MService.this.mCallbacks.register(cb);
            }
        }

        public void unregisterCallback(IBServiceCallback cb) {
            if (cb != null) {
                MService.this.mCallbacks.unregister(cb);
            }
        }

        public void SetCmd(int nCmd, String strValue) throws RemoteException {
            if (nCmd == 255) {
                if (MService.this.mUPNPservice != null) {
                    MService.this.mUPNPservice.SetCmd(nCmd, strValue);
                }
            } else if (nCmd < 11) {
                if (MService.this.mNIOservice != null) {
                    MService.this.mNIOservice.SetCmd(nCmd, strValue);
                }
            } else if (nCmd >= 11 && MService.this.mUDPservice != null) {
                MService.this.mUDPservice.SetCmd(nCmd, strValue);
            }
        }

        public String GetValue(int nType) throws RemoteException {
            String strRes = ContentTree.ROOT_ID;
            if (nType <= 11) {
                return MService.this.mNIOservice != null ? MService.this.mNIOservice.GetValue(nType) : strRes;
            } else {
                if (nType <= 11 || nType >= 20) {
                    if (nType < 20 || MService.this.mUPNPservice == null) {
                        return strRes;
                    }
                    return MService.this.mUPNPservice.GetValue(nType);
                } else if (MService.this.mUDPservice != null) {
                    return MService.this.mUDPservice.GetValue(nType);
                } else {
                    return strRes;
                }
            }
        }
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        Log.d("jmgs", "IBService onStartCommand");
        return 3;
    }

    public void onCreate() {
        super.onCreate();
        Log.d("jmgs", "IBService onCreate");
        bindService(new Intent(INIOService.class.getName()), this.INIOServiceConnection, 1);
        bindService(new Intent(IUPNPService.class.getName()), this.IUPNPServiceConnection, 1);
        bindService(new Intent(IUDPService.class.getName()), this.IUDPServiceConnection, 1);
    }

    public void onDestroy() {
        super.onDestroy();
        Log.d("jmgs", "IBService onDestroy");
        stopForeground(true);
        getBaseContext().unbindService(this.IUPNPServiceConnection);
        getBaseContext().unbindService(this.IUDPServiceConnection);
        getBaseContext().unbindService(this.INIOServiceConnection);
        this.mCallbacks.kill();
    }

    public IBinder onBind(Intent intent) {
        Log.d("jmgs", "IBService onBind");
        if (!IBService.class.getName().equals(intent.getAction())) {
            return null;
        }
        Notification note = new Notification(C0181R.drawable.icon, getResources().getString(C0181R.string.app_name), System.currentTimeMillis());
        Intent i = new Intent(this, List_Activity.class);
        i.setFlags(603979776);
        note.setLatestEventInfo(this, getResources().getString(C0181R.string.app_name), "Started", PendingIntent.getActivity(this, 0, i, 0));
        note.flags |= 32;
        startForeground(Process.myPid(), note);
        return this.mBinder;
    }

    public void onReceived(final String aData) {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            public void run() {
                Log.d(getClass().getSimpleName(), "Received message: " + aData);
            }
        });
    }
}
