package com.enus.myzik;

import android.content.Context;
import android.content.Intent;
import android.os.Environment;
import android.os.StatFs;
import android.text.format.DateFormat;
import android.util.Log;
import com.wireme.mediaserver.ContentTree;
import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.ServerSocket;
import java.net.SocketException;
import java.nio.ByteBuffer;
import java.nio.channels.SelectionKey;
import java.nio.channels.Selector;
import java.nio.channels.ServerSocketChannel;
import java.nio.channels.SocketChannel;
import java.util.Date;
import org.teleal.cling.model.message.header.EXTHeader;

public class NIOServer implements Runnable {
    public static final int ACK_ACTIVATE = 22;
    public static final int ACK_FW = 12;
    public static final int ACK_HB = 9;
    public static final int ACK_PASSWD = 6;
    public static final int CMD_ACTIVATE = 1;
    public static final int CMD_HB = 8;
    public static final int CMD_WAIT = 2;
    public static final int FW_UPGRADE = 11;
    public static final int FW_UPGRADE2 = 20;
    public static final int HEADER_LEN = 4;
    public static final int INFO = 10;
    public static final int NOTIFY_FILE_MANIPULATION = 21;
    public static final int REQ_ACTIVATE = 3;
    public static final int REQ_APLIST = 18;
    public static final int REQ_BYEBYE = 7;
    public static final int REQ_FRESET = 15;
    public static final int REQ_INFO = 17;
    public static final int REQ_PASSWD = 5;
    public static final int REQ_TETHER = 13;
    public static final int REQ_WAIT = 4;
    public static final int RESP_APLIST = 19;
    public static final int RESP_FRESET = 16;
    public static final int RESP_TETHER = 14;
    public static String[] mInfo = new String[]{EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE};
    public static String[] mTModeInfo = new String[]{EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE, EXTHeader.DEFAULT_VALUE};
    boolean isDoSetActive = false;
    boolean isDoSetDeActive = false;
    boolean isEnableWrite = false;
    private Context mContext = null;
    public String mDInfo = EXTHeader.DEFAULT_VALUE;
    public String mInfos = EXTHeader.DEFAULT_VALUE;
    protected int mMode = 0;
    public int mnTmode = 0;
    int port = 0;
    SocketChannel selSC = null;
    SelectionKey selected = null;
    Selector selector;
    ServerSocket socket = null;

    public NIOServer(Context context, boolean EnableWriteMode) throws IOException {
        this.isEnableWrite = EnableWriteMode;
        this.mContext = context;
        this.selector = Selector.open();
        ServerSocketChannel channel = ServerSocketChannel.open();
        this.socket = channel.socket();
        this.socket.bind(new InetSocketAddress(this.port));
        channel.configureBlocking(false);
        channel.register(this.selector, 16);
        System.out.println("---- Client의 접속을 기다립니다... ----");
        System.out.println(Integer.toString(this.socket.getLocalPort()));
    }

    public static final byte[] intToByte1(int intVar) {
        return new byte[]{(byte) ((intVar >> 0) & 255)};
    }

    public String GetFVer() {
        if (this.selSC == null || !this.selSC.isConnected() || mInfo.length <= 0) {
            return "none";
        }
        return "v" + mInfo[0];
    }

    public String GetApMac() {
        if (this.selSC == null || !this.selSC.isConnected() || mInfo.length <= 1) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return mInfo[1];
    }

    public String GetApMode() {
        if (this.selSC == null || !this.selSC.isConnected() || mInfo.length <= 2) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return mInfo[2];
    }

    public String GetApCSSID() {
        if (this.selSC == null || !this.selSC.isConnected() || mInfo[3] == null || mInfo.length <= 3) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return mInfo[3];
    }

    public String GetApCCnt() {
        Log.d("testinfo", "GetApCCnt");
        if (this.selSC == null || !this.selSC.isConnected() || mInfo[4] == null || mInfo.length <= 4) {
            return EXTHeader.DEFAULT_VALUE;
        }
        Log.d("testinfo", "GetApCCnt:" + mInfo[4]);
        return mInfo[4];
    }

    public String GetApSSID() {
        Log.d("testinfo", "GetApSSID");
        if (this.selSC == null || !this.selSC.isConnected() || mInfo[5] == null || mInfo.length <= 5) {
            return EXTHeader.DEFAULT_VALUE;
        }
        Log.d("testinfo", "GetApSSID:" + mInfo[5]);
        return mInfo[5];
    }

    public void ParseInfo() {
        if (this.selSC != null && this.selSC.isConnected() && this.mInfos != null && this.mInfos.length() > 0) {
            Intent iset;
            int nFindVID = this.mInfos.indexOf("VID=");
            if (nFindVID > 1) {
                String strVid = EXTHeader.DEFAULT_VALUE;
                strVid = this.mInfos.substring(nFindVID + 4);
                iset = new Intent("cling.android.Router");
                iset.putExtra("enus", "VID" + strVid);
                this.mContext.sendBroadcast(iset);
                this.mInfos = this.mInfos.substring(0, nFindVID - 1);
            }
            mInfo = this.mInfos.split(",", 7);
            if (mInfo.length != 7) {
                iset = new Intent("cling.android.Router");
                iset.putExtra("enus", "getInfo");
                this.mContext.sendBroadcast(iset);
            } else if (mInfo[6].compareTo("RESET") == 0) {
                iset = new Intent("cling.android.Router");
                iset.putExtra("enus", "HWReset");
                this.mContext.sendBroadcast(iset);
            }
        }
    }

    public String GetTModeInfo1() {
        if (mTModeInfo[0] == null || mTModeInfo.length <= 0) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return mTModeInfo[0];
    }

    public String GetTModeInfo2() {
        if (mTModeInfo[1] == null || mTModeInfo.length <= 1) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return mTModeInfo[1];
    }

    public String GetTModeInfo3() {
        if (mTModeInfo[2] == null || mTModeInfo.length <= 2) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return mTModeInfo[2];
    }

    public static final byte[] intToByte2(int intVar) {
        return new byte[]{(byte) ((intVar >> 8) & 255), (byte) ((intVar >> 0) & 255)};
    }

    public int getPort() {
        if (this.socket != null) {
            return this.socket.getLocalPort();
        }
        return 0;
    }

    public String getDInfo() {
        return this.mDInfo;
    }

    public int getMode() {
        return this.mMode;
    }

    public void setMode(int nMode) {
        this.mMode = nMode;
    }

    public void setActive() {
        Log.d("TCP", "setActive-1");
        this.isDoSetActive = true;
        if (this.isDoSetActive) {
            this.isDoSetActive = false;
            if (this.selSC != null && this.selSC.isConnected()) {
                Log.d("TCP", "setActive-2");
                byte[] DataBody = new byte[0];
                byte[] dataLen = new byte[2];
                byte[] sendData = new byte[1024];
                int nDataLen = DataBody.length;
                dataLen = intToByte2(nDataLen);
                sendData[0] = (byte) 1;
                sendData[1] = (byte) 3;
                System.arraycopy(dataLen, 0, sendData, 2, 2);
                if (nDataLen > 0) {
                    System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
                }
                ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
                try {
                    this.selSC.write(sendbuf);
                    sendbuf.clear();
                } catch (SocketException se) {
                    se.printStackTrace();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public long getSDCardFree() {
        StatFs stat = new StatFs(Environment.getExternalStorageDirectory().getAbsolutePath());
        long free_memory = ((long) stat.getAvailableBlocks()) * ((long) stat.getBlockSize());
        if (free_memory < 2247483648L) {
            return 2247483648L;
        }
        return free_memory;
    }

    public void setActiveAck() {
        this.isDoSetActive = true;
        if (this.isDoSetActive) {
            this.isDoSetActive = false;
            if (this.selSC != null && this.selSC.isConnected()) {
                CharSequence s = DateFormat.format("yyyyMMddkkmmss", new Date().getTime());
                String strUUID = ContentTree.GetUUID();
                String strTmpData = EXTHeader.DEFAULT_VALUE;
                String strWiteMode = "READ";
                if (ContentTree.GetWriteFlag().booleanValue()) {
                    strWiteMode = "WRITE";
                }
                strTmpData = String.format("%s,%d,%s", new Object[]{s.toString(), Long.valueOf(getSDCardFree()), strWiteMode});
                byte[] DataBody = new byte[0];
                byte[] dataLen = new byte[2];
                byte[] sendData = new byte[1024];
                DataBody = strTmpData.getBytes();
                int nDataLen = DataBody.length;
                dataLen = intToByte2(nDataLen);
                sendData[0] = (byte) 1;
                sendData[1] = (byte) 22;
                Log.d("ACK_ACTIVATE", new StringBuilder(String.valueOf(strTmpData)).append("[LEN]:").append(nDataLen).toString());
                System.arraycopy(dataLen, 0, sendData, 2, 2);
                if (nDataLen > 0) {
                    System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
                }
                ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
                try {
                    this.selSC.write(sendbuf);
                    sendbuf.clear();
                } catch (SocketException se) {
                    se.printStackTrace();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public void Req_Info() {
        Log.d("TCP", "REQ_INFO-1");
        this.isDoSetActive = true;
        if (this.isDoSetActive) {
            this.isDoSetActive = false;
            if (this.selSC != null && this.selSC.isConnected()) {
                Log.d("TCP", "REQ_INFO-2");
                byte[] DataBody = new byte[0];
                byte[] dataLen = new byte[2];
                byte[] sendData = new byte[1024];
                int nDataLen = DataBody.length;
                dataLen = intToByte2(nDataLen);
                sendData[0] = (byte) 1;
                sendData[1] = (byte) 17;
                System.arraycopy(dataLen, 0, sendData, 2, 2);
                if (nDataLen > 0) {
                    System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
                }
                ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
                try {
                    this.selSC.write(sendbuf);
                    sendbuf.clear();
                } catch (SocketException se) {
                    se.printStackTrace();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public void Req_ApList() {
        Log.d("TCP1", "Req_ApList-1");
        this.isDoSetActive = true;
        if (this.isDoSetActive) {
            this.isDoSetActive = false;
            if (this.selSC != null && this.selSC.isConnected()) {
                Log.d("TCP", "Req_ApList-2");
                byte[] DataBody = new byte[0];
                byte[] dataLen = new byte[2];
                byte[] sendData = new byte[1024];
                DataBody = "REQ".getBytes();
                int nDataLen = DataBody.length;
                dataLen = intToByte2(nDataLen);
                sendData[0] = (byte) 1;
                sendData[1] = (byte) 18;
                System.arraycopy(dataLen, 0, sendData, 2, 2);
                if (nDataLen > 0) {
                    System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
                }
                ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
                try {
                    this.selSC.write(sendbuf);
                    sendbuf.clear();
                } catch (SocketException se) {
                    se.printStackTrace();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public void setAddApList(String strApList) {
        Log.d("setAddApList", strApList);
        if (this.selSC != null && this.selSC.isConnected()) {
            byte[] DataBody = new byte[0];
            byte[] dataLen = new byte[2];
            byte[] sendData = new byte[1024];
            DataBody = strApList.getBytes();
            int nDataLen = DataBody.length;
            dataLen = intToByte2(nDataLen);
            sendData[0] = (byte) 1;
            sendData[1] = (byte) 18;
            System.arraycopy(dataLen, 0, sendData, 2, 2);
            if (nDataLen > 0) {
                System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
            }
            ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
            try {
                this.selSC.write(sendbuf);
                sendbuf.clear();
            } catch (SocketException se) {
                se.printStackTrace();
            } catch (IOException e) {
                Log.d("NIO", "Err" + e.toString());
                e.printStackTrace();
            }
        }
    }

    public void setACK() {
        if (this.selSC == null || !this.selSC.isConnected()) {
            Log.d("NIO", "SetACK Fail");
            return;
        }
        byte[] bufHB = new byte[4];
        bufHB[0] = (byte) 1;
        bufHB[1] = (byte) 9;
        try {
            if (this.selSC.write(ByteBuffer.wrap(bufHB)) <= 0) {
                Intent iset = new Intent("cling.android.Router");
                iset.putExtra("enus", "tcp_dc");
                this.mContext.sendBroadcast(iset);
                Log.d("NIOS", "Socket Disconnected!!");
                this.mInfos = EXTHeader.DEFAULT_VALUE;
                mInfo = new String[7];
                mInfo[0] = EXTHeader.DEFAULT_VALUE;
                mInfo[1] = EXTHeader.DEFAULT_VALUE;
                mInfo[2] = EXTHeader.DEFAULT_VALUE;
                mInfo[3] = EXTHeader.DEFAULT_VALUE;
                mInfo[4] = EXTHeader.DEFAULT_VALUE;
                mInfo[5] = EXTHeader.DEFAULT_VALUE;
                mInfo[6] = EXTHeader.DEFAULT_VALUE;
                this.selSC.socket().close();
                this.selSC.close();
                if (this.selected != null) {
                    this.selected.attach(null);
                    this.selected.cancel();
                }
            }
        } catch (SocketException se) {
            se.printStackTrace();
        } catch (IOException e) {
            Log.d("NIO", "Err" + e.toString());
            e.printStackTrace();
        }
    }

    public void setUpgrade(String strPath) {
        Log.d("Set_FW", strPath);
        if (this.selSC != null && this.selSC.isConnected()) {
            byte[] DataBody = new byte[0];
            byte[] dataLen = new byte[2];
            byte[] sendData = new byte[1024];
            DataBody = strPath.getBytes();
            int nDataLen = DataBody.length;
            dataLen = intToByte2(nDataLen);
            sendData[0] = (byte) 1;
            sendData[1] = (byte) 11;
            System.arraycopy(dataLen, 0, sendData, 2, 2);
            if (nDataLen > 0) {
                System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
            }
            ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
            try {
                this.selSC.write(sendbuf);
                sendbuf.clear();
            } catch (SocketException se) {
                se.printStackTrace();
            } catch (IOException e) {
                Log.d("NIO", "Err" + e.toString());
                e.printStackTrace();
            }
        }
    }

    public void setFReset(String strPW) {
        Log.d("Set_FReset", strPW);
        if (this.selSC != null && this.selSC.isConnected()) {
            byte[] DataBody = new byte[0];
            byte[] dataLen = new byte[2];
            byte[] sendData = new byte[1024];
            DataBody = strPW.getBytes();
            int nDataLen = DataBody.length;
            dataLen = intToByte2(nDataLen);
            sendData[0] = (byte) 1;
            sendData[1] = (byte) 15;
            System.arraycopy(dataLen, 0, sendData, 2, 2);
            if (nDataLen > 0) {
                System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
            }
            ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
            try {
                this.selSC.write(sendbuf);
                sendbuf.clear();
            } catch (SocketException se) {
                se.printStackTrace();
            } catch (IOException e) {
                Log.d("NIO", "Err" + e.toString());
                e.printStackTrace();
            }
        }
    }

    public void setNewAPInfo(String strSSID, String strOldPW, String strNewPW) {
        if (this.selSC != null && this.selSC.isConnected()) {
            int nSSIDLen = strSSID.getBytes().length;
            int nOldPWLen = strOldPW.length();
            int nNewPWLen = strNewPW.length();
            byte[] SSIDLen = intToByte1(nSSIDLen);
            byte[] OldPWLen = intToByte1(nOldPWLen);
            byte[] NewPWLen = intToByte1(nNewPWLen);
            byte[] dataLen = new byte[2];
            byte[] sendData = new byte[1024];
            int nDataLen = ((nSSIDLen + nOldPWLen) + nNewPWLen) + 3;
            dataLen = intToByte2(nDataLen);
            sendData[0] = (byte) 1;
            sendData[1] = (byte) 5;
            System.arraycopy(dataLen, 0, sendData, 2, 2);
            if (nDataLen > 0) {
                System.arraycopy(SSIDLen, 0, sendData, 4, 1);
                int nPos = 4 + 1;
                if (nSSIDLen > 0) {
                    System.arraycopy(strSSID.getBytes(), 0, sendData, nPos, nSSIDLen);
                    nPos = nSSIDLen + 5;
                }
                System.arraycopy(OldPWLen, 0, sendData, nPos, 1);
                nPos++;
                if (nOldPWLen > 0) {
                    System.arraycopy(strOldPW.getBytes(), 0, sendData, nPos, nOldPWLen);
                    nPos += nOldPWLen;
                }
                System.arraycopy(NewPWLen, 0, sendData, nPos, 1);
                nPos++;
                if (nNewPWLen > 0) {
                    System.arraycopy(strNewPW.getBytes(), 0, sendData, nPos, nNewPWLen);
                    int i = nPos + nNewPWLen;
                }
            }
            ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
            try {
                this.selSC.write(sendbuf);
                sendbuf.clear();
            } catch (SocketException se) {
                se.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    public void setDeActive() {
        this.isDoSetDeActive = true;
    }

    public void setTETHER(String strData) {
        if (this.selSC != null && this.selSC.isConnected()) {
            byte[] DataBody = new byte[0];
            byte[] dataLen = new byte[2];
            byte[] sendData = new byte[1024];
            DataBody = strData.getBytes();
            int nDataLen = DataBody.length;
            dataLen = intToByte2(nDataLen);
            sendData[0] = (byte) 1;
            sendData[1] = (byte) 13;
            System.arraycopy(dataLen, 0, sendData, 2, 2);
            if (nDataLen > 0) {
                System.arraycopy(DataBody, 0, sendData, 4, nDataLen);
            }
            ByteBuffer sendbuf = ByteBuffer.wrap(sendData);
            try {
                int nWriteSize = this.selSC.write(sendbuf);
                sendbuf.clear();
                Log.d("setteher03", String.format("%d/%d/%s", new Object[]{Integer.valueOf(nDataLen), Integer.valueOf(nWriteSize), strData}));
            } catch (SocketException se) {
                se.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    public static final int byte2ToInt(byte[] buffer, int offset, int nMod) {
        if (nMod == 1) {
            return ((buffer[offset] & 255) << 8) | (buffer[offset + 1] & 255);
        }
        return ((buffer[offset + 1] & 255) << 8) | (buffer[offset] & 255);
    }

    /* JADX WARNING: inconsistent code. */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void run() {
        /*
        r43 = this;
        r31 = 1;
        r20 = 4;
        r17 = 1024; // 0x400 float:1.435E-42 double:5.06E-321;
        r7 = 0;
        r8 = 0;
        r12 = 0;
        r7 = java.nio.ByteBuffer.allocateDirect(r17);
        r8 = java.nio.ByteBuffer.allocateDirect(r20);
        r37 = "NIO";
        r38 = "run";
        android.util.Log.d(r37, r38);
        r37 = 0;
        r0 = r37;
        r1 = r43;
        r1.selected = r0;
    L_0x0020:
        r0 = r43;
        r0 = r0.selector;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r37 = r37.select();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        if (r37 > 0) goto L_0x002d;
    L_0x002c:
        return;
    L_0x002d:
        r0 = r43;
        r0 = r0.selector;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r16 = r37.selectedKeys();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r15 = r16.iterator();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r13 = r12;
    L_0x003c:
        r37 = r15.hasNext();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        if (r37 != 0) goto L_0x0044;
    L_0x0042:
        r12 = r13;
        goto L_0x0020;
    L_0x0044:
        r37 = r15.next();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = (java.nio.channels.SelectionKey) r37;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r37;
        r1 = r43;
        r1.selected = r0;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r15.remove();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        r9 = r37.channel();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r9 instanceof java.nio.channels.ServerSocketChannel;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        if (r37 == 0) goto L_0x00c2;
    L_0x0063:
        r0 = r9;
        r0 = (java.nio.channels.ServerSocketChannel) r0;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r29 = r0;
        r30 = r29.accept();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        if (r30 != 0) goto L_0x0083;
    L_0x006e:
        r37 = "NIO";
        r38 = "## null server socket";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        goto L_0x003c;
    L_0x0076:
        r10 = move-exception;
        r12 = r13;
    L_0x0078:
        r37 = "NIO";
        r38 = "Error";
        android.util.Log.d(r37, r38);
        r10.printStackTrace();
        goto L_0x002c;
    L_0x0083:
        r37 = "NIO";
        r38 = new java.lang.StringBuilder;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r39 = "## socket accepted : ";
        r38.<init>(r39);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r38;
        r1 = r30;
        r38 = r0.append(r1);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r38 = r38.toString();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = 0;
        r0 = r30;
        r1 = r37;
        r0.configureBlocking(r1);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r43;
        r0 = r0.selector;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        r0 = r30;
        r1 = r37;
        r2 = r31;
        r0.register(r1, r2);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        goto L_0x003c;
    L_0x00b4:
        r10 = move-exception;
        r12 = r13;
    L_0x00b6:
        r37 = "NIO";
        r38 = "Error";
        android.util.Log.d(r37, r38);
        r10.printStackTrace();
        goto L_0x002c;
    L_0x00c2:
        r0 = r9;
        r0 = (java.nio.channels.SocketChannel) r0;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r30 = r0;
        r8.clear();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r20;
        r0 = new byte[r0];	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r8.put(r0);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r8.clear();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        r37 = r37.isConnectable();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        if (r37 == 0) goto L_0x010b;
    L_0x00e4:
        r37 = "NIO";
        r38 = "Client와의 연결 설정 OK~";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r30.isConnectionPending();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        if (r37 == 0) goto L_0x003c;
    L_0x00f1:
        r37 = "NIO";
        r38 = "Client와의 연결 설정을 마무리 중입니다~";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r30.finishConnect();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        goto L_0x003c;
    L_0x00fd:
        r10 = move-exception;
        r12 = r13;
    L_0x00ff:
        r37 = "NIO";
        r38 = "Socket Error";
        android.util.Log.d(r37, r38);
        r10.printStackTrace();
        goto L_0x002c;
    L_0x010b:
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        r37 = r37.isReadable();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        if (r37 == 0) goto L_0x0801;
    L_0x0117:
        r0 = r30;
        r23 = r0.read(r8);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 4;
        r0 = r23;
        r1 = r37;
        if (r0 < r1) goto L_0x073b;
    L_0x0125:
        r24 = 0;
        r5 = 0;
        r6 = 0;
        r8.flip();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r21 = 0;
        r37 = r8.capacity();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r37;
        r5 = new byte[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 0;
        r38 = 4;
        r0 = r37;
        r1 = r38;
        r8.get(r5, r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 2;
        r38 = 1;
        r0 = r37;
        r1 = r38;
        r21 = byte2ToInt(r5, r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        if (r21 <= 0) goto L_0x0175;
    L_0x014f:
        r7 = java.nio.ByteBuffer.allocateDirect(r21);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r7.clear();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r21;
        r0 = new byte[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r7.put(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r7.clear();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r30;
        r23 = r0.read(r7);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r7.flip();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r7.capacity();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r37;
        r6 = new byte[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x0175:
        r37 = 0;
        r37 = r5[r37];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = java.lang.Integer.valueOf(r37);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r27 = r37.intValue();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 1;
        r37 = r5[r37];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = java.lang.Integer.valueOf(r37);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r18 = r37.intValue();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 1;
        r0 = r27;
        r1 = r37;
        if (r0 != r1) goto L_0x019d;
    L_0x0195:
        r37 = 21;
        r0 = r18;
        r1 = r37;
        if (r0 <= r1) goto L_0x01c1;
    L_0x019d:
        r37 = 1;
        r0 = r27;
        r1 = r37;
        if (r0 == r1) goto L_0x01af;
    L_0x01a5:
        r37 = "ui2f";
        r38 = "Dummy Packet - Wrong Ver";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x0020;
    L_0x01af:
        r37 = 1;
        r0 = r27;
        r1 = r37;
        if (r0 == r1) goto L_0x0042;
    L_0x01b7:
        r37 = "ui2f";
        r38 = "Dummy Packet - Wrong Cmd_Type";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x0020;
    L_0x01c1:
        r28 = 0;
        r37 = "nReadLen : %d";
        r38 = 1;
        r0 = r38;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r0;
        r39 = 0;
        r40 = java.lang.Integer.valueOf(r23);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r33 = java.lang.String.format(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 8;
        r0 = r18;
        r1 = r37;
        if (r0 == r1) goto L_0x01ea;
    L_0x01e1:
        r37 = "Test";
        r0 = r37;
        r1 = r33;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x01ea:
        r37 = "Head:%02X/%02X/%d";
        r38 = 3;
        r0 = r38;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r0;
        r39 = 0;
        r40 = java.lang.Integer.valueOf(r27);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 1;
        r40 = java.lang.Integer.valueOf(r18);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 2;
        r40 = java.lang.Integer.valueOf(r21);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r33 = java.lang.String.format(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 8;
        r0 = r18;
        r1 = r37;
        if (r0 == r1) goto L_0x0221;
    L_0x0218:
        r37 = "Test";
        r0 = r37;
        r1 = r33;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x0221:
        r19 = r21;
        if (r21 >= 0) goto L_0x0228;
    L_0x0225:
        r12 = r13;
        goto L_0x0020;
    L_0x0228:
        if (r21 <= 0) goto L_0x02ef;
    L_0x022a:
        r37 = r7.remaining();	 Catch:{ BufferUnderflowException -> 0x024b, SocketTimeoutException -> 0x048c, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r37;
        r1 = r21;
        if (r0 < r1) goto L_0x0042;
    L_0x0234:
        r37 = 0;
        r0 = r37;
        r1 = r21;
        r7.get(r6, r0, r1);	 Catch:{ BufferUnderflowException -> 0x024b, SocketTimeoutException -> 0x048c, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r6.length;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r1 = r21;
        if (r0 >= r1) goto L_0x0289;
    L_0x0246:
        r5 = 0;
        r6 = 0;
        r12 = r13;
        goto L_0x0020;
    L_0x024b:
        r10 = move-exception;
        r37 = "ui2fz";
        r38 = new java.lang.StringBuilder;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = "buff:";
        r38.<init>(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r7.remaining();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = java.lang.Integer.valueOf(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r39.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = "> buf2:";
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r6.length;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r0;
        r39 = java.lang.Integer.valueOf(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r39.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r5 = 0;
        r6 = 0;
        r10.printStackTrace();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x0020;
    L_0x0289:
        r0 = r6.length;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r38 = 5;
        r0 = r37;
        r1 = r38;
        if (r0 < r1) goto L_0x02ef;
    L_0x0294:
        r37 = "Dump2 : %02X/%02X/%02X/%02X/%02X";
        r38 = 5;
        r0 = r38;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r0;
        r39 = 0;
        r40 = 0;
        r40 = r6[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Byte.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 1;
        r40 = 1;
        r40 = r6[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Byte.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 2;
        r40 = 2;
        r40 = r6[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Byte.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 3;
        r40 = 3;
        r40 = r6[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Byte.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 4;
        r40 = 4;
        r40 = r6[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Byte.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r33 = java.lang.String.format(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 8;
        r0 = r18;
        r1 = r37;
        if (r0 == r1) goto L_0x02ef;
    L_0x02e6:
        r37 = "Test2";
        r0 = r37;
        r1 = r33;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x02ef:
        if (r19 <= 0) goto L_0x0306;
    L_0x02f1:
        r0 = r19;
        r0 = new byte[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r28 = r0;
        r37 = 0;
        r38 = 0;
        r0 = r37;
        r1 = r28;
        r2 = r38;
        r3 = r19;
        java.lang.System.arraycopy(r6, r0, r1, r2, r3);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x0306:
        r4 = new com.enus.myzik.CGetData;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r27;
        r1 = r18;
        r2 = r21;
        r3 = r28;
        r4.<init>(r0, r1, r2, r3);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r24 = r24 + r21;
        r0 = r4.nCmd;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        switch(r37) {
            case 1: goto L_0x0326;
            case 2: goto L_0x03a9;
            case 3: goto L_0x031c;
            case 4: goto L_0x031c;
            case 5: goto L_0x031c;
            case 6: goto L_0x0490;
            case 7: goto L_0x031c;
            case 8: goto L_0x05c7;
            case 9: goto L_0x031c;
            case 10: goto L_0x05f8;
            case 11: goto L_0x031c;
            case 12: goto L_0x0671;
            case 13: goto L_0x031c;
            case 14: goto L_0x04d2;
            case 15: goto L_0x031c;
            case 16: goto L_0x06f5;
            case 17: goto L_0x031c;
            case 18: goto L_0x031c;
            case 19: goto L_0x0645;
            case 20: goto L_0x031c;
            case 21: goto L_0x0555;
            default: goto L_0x031c;
        };
    L_0x031c:
        r12 = r13;
    L_0x031d:
        r7.clear();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r8.clear();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x0326:
        r0 = r43;
        r0 = r0.selSC;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        if (r37 == 0) goto L_0x033a;
    L_0x032e:
        r0 = r43;
        r0 = r0.selSC;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r1 = r30;
        if (r0 == r1) goto L_0x0340;
    L_0x033a:
        r0 = r30;
        r1 = r43;
        r1.selSC = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x0340:
        r37 = "TCP";
        r38 = "CMD_ACTIVATE";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r4.nCmd;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r1 = r43;
        r1.mMode = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "active";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.isEnableWrite;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        if (r37 == 0) goto L_0x031d;
    L_0x0378:
        r43.setActiveAck();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        goto L_0x031d;
    L_0x037c:
        r10 = move-exception;
    L_0x037d:
        r37 = 0;
        r0 = r37;
        r1 = r43;
        r1.selSC = r0;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r10.printStackTrace();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r30.socket();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r30.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r38 = 0;
        r37.attach(r38);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r37.cancel();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x03a9:
        r0 = r43;
        r0 = r0.selSC;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        if (r37 == 0) goto L_0x03bd;
    L_0x03b1:
        r0 = r43;
        r0 = r0.selSC;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r1 = r30;
        if (r0 == r1) goto L_0x03c3;
    L_0x03bd:
        r0 = r30;
        r1 = r43;
        r1.selSC = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x03c3:
        r0 = r4.nCmd;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r1 = r43;
        r1.mMode = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        if (r21 <= 0) goto L_0x0483;
    L_0x03cf:
        r34 = new java.lang.String;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "UTF-8";
        r0 = r34;
        r1 = r28;
        r2 = r37;
        r0.<init>(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "waitm";
        r38 = new java.lang.StringBuilder;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = java.lang.Integer.valueOf(r21);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r39.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = java.lang.String.valueOf(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38.<init>(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = "/";
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = java.lang.Integer.valueOf(r19);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r39.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = "/";
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r38;
        r1 = r34;
        r38 = r0.append(r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = ",";
        r38 = 2;
        r0 = r34;
        r1 = r37;
        r2 = r38;
        r32 = r0.split(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 1;
        r37 = r32[r37];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r37;
        r1 = r43;
        r1.mDInfo = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x042e:
        r37 = "TCP";
        r38 = "CMD_WAIT";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "wait";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        goto L_0x031d;
    L_0x0456:
        r10 = move-exception;
    L_0x0457:
        r37 = 0;
        r0 = r37;
        r1 = r43;
        r1.selSC = r0;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r10.printStackTrace();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r30.socket();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r30.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r38 = 0;
        r37.attach(r38);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r37.cancel();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x0483:
        r37 = "";
        r0 = r37;
        r1 = r43;
        r1.mDInfo = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        goto L_0x042e;
    L_0x048c:
        r10 = move-exception;
        r12 = r13;
        goto L_0x037d;
    L_0x0490:
        r37 = "TCP";
        r38 = "ACK_PASSWD";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 1;
        r0 = r19;
        r1 = r37;
        if (r0 != r1) goto L_0x07fe;
    L_0x049f:
        r37 = "TCP";
        r38 = "ACK_PASSWD1";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 0;
        r25 = r28[r37];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r22 = java.lang.Integer.valueOf(r25);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "TCP";
        r38 = new java.lang.StringBuilder;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = "ACK_PASSWD2";
        r38.<init>(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r22.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = com.enus.myzik.Home_Activity.mSetAckPasswordHandler;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = 0;
        r38 = r28[r38];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37.sendEmptyMessage(r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x031d;
    L_0x04d2:
        if (r19 <= 0) goto L_0x07fe;
    L_0x04d4:
        r34 = new java.lang.String;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "UTF-8";
        r0 = r34;
        r1 = r28;
        r2 = r37;
        r0.<init>(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r34 = r34.trim();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 3;
        r0 = r37;
        r0 = new java.lang.String[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        mTModeInfo = r37;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = ",";
        r38 = 3;
        r0 = r34;
        r1 = r37;
        r2 = r38;
        r37 = r0.split(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        mTModeInfo = r37;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "cmd_tether";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        goto L_0x031d;
    L_0x0520:
        r10 = move-exception;
    L_0x0521:
        r37 = 0;
        r0 = r37;
        r1 = r43;
        r1.selSC = r0;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r10.printStackTrace();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = "";
        r0 = r37;
        r1 = r43;
        r1.mInfos = r0;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r30.socket();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r30.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r38 = 0;
        r37.attach(r38);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r37.cancel();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x0555:
        if (r19 <= 0) goto L_0x07fe;
    L_0x0557:
        r34 = new java.lang.String;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "UTF-8";
        r0 = r34;
        r1 = r28;
        r2 = r37;
        r0.<init>(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r34 = r34.trim();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = new java.lang.StringBuilder;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r39 = "NF";
        r38.<init>(r39);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r38;
        r1 = r34;
        r38 = r0.append(r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = r38.toString();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        goto L_0x031d;
    L_0x059a:
        r11 = move-exception;
    L_0x059b:
        r37 = 0;
        r0 = r37;
        r1 = r43;
        r1.selSC = r0;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r11.printStackTrace();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r30.socket();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r30.close();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r38 = 0;
        r37.attach(r38);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r37.cancel();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x05c7:
        r43.setACK();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "cmd_hb";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        goto L_0x031d;
    L_0x05eb:
        r10 = move-exception;
    L_0x05ec:
        r37 = "NIO";
        r38 = "Error";
        android.util.Log.d(r37, r38);
        r10.printStackTrace();
        goto L_0x002c;
    L_0x05f8:
        if (r19 <= 0) goto L_0x063b;
    L_0x05fa:
        r34 = new java.lang.String;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "UTF-8";
        r0 = r34;
        r1 = r28;
        r2 = r37;
        r0.<init>(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r34 = r34.trim();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "testinfo";
        r0 = r37;
        r1 = r34;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r34;
        r1 = r43;
        r1.mInfos = r0;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "pre_getInfo";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        goto L_0x031d;
    L_0x063b:
        r37 = "testinfo";
        r38 = "Len 0";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x031d;
    L_0x0645:
        if (r19 <= 0) goto L_0x0667;
    L_0x0647:
        r43.setACK();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r34 = new java.lang.String;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "UTF-8";
        r0 = r34;
        r1 = r28;
        r2 = r37;
        r0.<init>(r1, r2);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r34 = r34.trim();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "TCP1";
        r0 = r37;
        r1 = r34;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x031d;
    L_0x0667:
        r37 = "RESP_APLIST";
        r38 = "Len 0";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x031d;
    L_0x0671:
        r37 = 0;
        r37 = r28[r37];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r36 = java.lang.Integer.valueOf(r37);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "ACK_FW %d[%02X]";
        r38 = 2;
        r0 = r38;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r0;
        r39 = 0;
        r40 = 0;
        r40 = r28[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Integer.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 1;
        r40 = 0;
        r40 = r28[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Integer.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r34 = java.lang.String.format(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "ACK_FW";
        r0 = r37;
        r1 = r34;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 1;
        r0 = r19;
        r1 = r37;
        if (r0 != r1) goto L_0x07fe;
    L_0x06b0:
        r26 = 0;
        r37 = 0;
        r26 = r28[r37];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        if (r26 >= 0) goto L_0x06be;
    L_0x06b8:
        r0 = r26;
        r0 = r0 + 208;
        r26 = r0;
    L_0x06be:
        r14 = 0;
        r14 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r14.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "%02dACK_FW";
        r39 = 1;
        r0 = r39;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = r0;
        r40 = 0;
        r41 = java.lang.Integer.valueOf(r26);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39[r40] = r41;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = java.lang.String.format(r38, r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r37;
        r1 = r38;
        r14.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r14);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r12 = r13;
        goto L_0x031d;
    L_0x06f5:
        r37 = "RESP_FRESET %d[%02X]";
        r38 = 2;
        r0 = r38;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r0;
        r39 = 0;
        r40 = 0;
        r40 = r28[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Integer.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = 1;
        r40 = 0;
        r40 = r28[r40];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = java.lang.Integer.valueOf(r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38[r39] = r40;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r35 = java.lang.String.format(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "ACK_FW";
        r0 = r37;
        r1 = r35;
        android.util.Log.d(r0, r1);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = 1;
        r0 = r19;
        r1 = r37;
        if (r0 != r1) goto L_0x07fe;
    L_0x072c:
        r37 = com.enus.myzik.Home_Activity.mSetRespFResetHandler;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = 0;
        r38 = r28[r38];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37.sendEmptyMessage(r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        goto L_0x031c;
    L_0x0737:
        r10 = move-exception;
        r12 = r13;
        goto L_0x0457;
    L_0x073b:
        r37 = -1;
        r0 = r23;
        r1 = r37;
        if (r0 != r1) goto L_0x07d4;
    L_0x0743:
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r37 = "enus";
        r38 = "tcp_dc";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = "NIOS";
        r38 = "Socket Disconnected!!";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = "";
        r0 = r37;
        r1 = r43;
        r1.mInfos = r0;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = 7;
        r0 = r37;
        r0 = new java.lang.String[r0];	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        mInfo = r37;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 0;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 1;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 2;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 3;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 4;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 5;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = mInfo;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r38 = 6;
        r39 = "";
        r37[r38] = r39;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r30.socket();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37.close();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r30.close();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r38 = 0;
        r37.attach(r38);	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r37 = r0;
        r37.cancel();	 Catch:{ SocketTimeoutException -> 0x037c, BufferUnderflowException -> 0x0456, SocketException -> 0x0520, IOException -> 0x059a, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x07d4:
        r37 = "NIOS";
        r38 = new java.lang.StringBuilder;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = "Wrong Length!! ";
        r38.<init>(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = ":%d";
        r40 = 1;
        r0 = r40;
        r0 = new java.lang.Object[r0];	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40 = r0;
        r41 = 0;
        r42 = java.lang.Integer.valueOf(r23);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r40[r41] = r42;	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r39 = java.lang.String.format(r39, r40);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.append(r39);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        r38 = r38.toString();	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x048c, BufferUnderflowException -> 0x0737, SocketException -> 0x085d, IOException -> 0x0859, Exception -> 0x084c }
    L_0x07fe:
        r12 = r13;
        goto L_0x031d;
    L_0x0801:
        r0 = r43;
        r0 = r0.selected;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = r0;
        r37 = r37.isValid();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        if (r37 != 0) goto L_0x0844;
    L_0x080d:
        r12 = new android.content.Intent;	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = "cling.android.Router";
        r0 = r37;
        r12.<init>(r0);	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r37 = "enus";
        r38 = "tcp_dc";
        r0 = r37;
        r1 = r38;
        r12.putExtra(r0, r1);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r0 = r43;
        r0 = r0.mContext;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = r0;
        r0 = r37;
        r0.sendBroadcast(r12);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r7.clear();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r8.clear();	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = "NIOS";
        r38 = "isValid()";
        android.util.Log.d(r37, r38);	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r37 = 0;
        r0 = r37;
        r1 = r43;
        r1.mMode = r0;	 Catch:{ SocketTimeoutException -> 0x0856, BufferUnderflowException -> 0x0853, SocketException -> 0x0850, Exception -> 0x05eb }
        r13 = r12;
        goto L_0x003c;
    L_0x0844:
        r7.clear();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        r8.clear();	 Catch:{ SocketTimeoutException -> 0x0076, BufferUnderflowException -> 0x00b4, SocketException -> 0x00fd, Exception -> 0x084c }
        goto L_0x003c;
    L_0x084c:
        r10 = move-exception;
        r12 = r13;
        goto L_0x05ec;
    L_0x0850:
        r10 = move-exception;
        goto L_0x00ff;
    L_0x0853:
        r10 = move-exception;
        goto L_0x00b6;
    L_0x0856:
        r10 = move-exception;
        goto L_0x0078;
    L_0x0859:
        r11 = move-exception;
        r12 = r13;
        goto L_0x059b;
    L_0x085d:
        r10 = move-exception;
        r12 = r13;
        goto L_0x0521;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.enus.myzik.NIOServer.run():void");
    }
}
