package com.enus.myzik;

import android.annotation.SuppressLint;
import android.app.Service;
import android.content.Intent;
import android.net.DhcpInfo;
import android.net.wifi.WifiManager;
import android.net.wifi.WifiManager.MulticastLock;
import android.os.AsyncTask;
import android.os.Binder;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.RemoteCallbackList;
import android.os.RemoteException;
import android.util.Log;
import com.enus.myzik.IUDPService.Stub;
import com.wireme.mediaserver.ContentTree;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.util.Enumeration;
import org.teleal.cling.model.message.header.EXTHeader;

public class UDPBroadcast extends Service {
    private static final int BROADCAST_PORT = 20000;
    private static final int GetUDPIP = 12;
    private static final int SetUDPIP = 11;
    private static final int SetUDPPort = 12;
    private DatagramPacket fDatagramPacket = null;
    private UDPBroadcastListener fListener = null;
    private MulticastLock fMulticastLock = null;
    private DatagramSocket fMulticastSocket = null;
    private byte[] fReceivedData = null;
    private final Stub mBinder = new C04871();
    final RemoteCallbackList<IUDPServiceCallback> mCallbacks = new RemoteCallbackList();
    private final Handler mHandler = new C02772();
    private String mStrIP = EXTHeader.DEFAULT_VALUE;
    private int m_nPort = 0;

    class C02772 extends Handler {
        C02772() {
        }

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 1:
                    int N = UDPBroadcast.this.mCallbacks.beginBroadcast();
                    for (int i = 0; i < N; i++) {
                        try {
                            ((IUDPServiceCallback) UDPBroadcast.this.mCallbacks.getBroadcastItem(i)).GetResult(1);
                        } catch (RemoteException e) {
                        }
                    }
                    UDPBroadcast.this.mCallbacks.finishBroadcast();
                    sendMessageDelayed(obtainMessage(1), 1000);
                    return;
                default:
                    super.handleMessage(msg);
                    return;
            }
        }
    }

    class C02783 implements Runnable {
        C02783() {
        }

        public void run() {
            boolean stop = false;
            while (!stop) {
                try {
                    UDPBroadcast.this.receiveMessage();
                } catch (UnsupportedEncodingException e) {
                    e.printStackTrace();
                } catch (IOException e2) {
                    stop = true;
                }
            }
        }
    }

    public final class MulticastBinder extends Binder {
        public UDPBroadcast getService() {
            return UDPBroadcast.this;
        }
    }

    private class SendMessageTask extends AsyncTask<DatagramPacket, Void, Void> {
        private SendMessageTask() {
        }

        protected Void doInBackground(DatagramPacket... aDatagramPackets) {
            try {
                for (DatagramPacket aPacket : aDatagramPackets) {
                    if (!(UDPBroadcast.this.fMulticastSocket == null || aPacket == null || aPacket.getLength() <= 0)) {
                        UDPBroadcast.this.fMulticastSocket.send(aPacket);
                    }
                }
            } catch (IOException e) {
                Log.d("fMulticast", e.toString());
                e.printStackTrace();
            }
            return null;
        }
    }

    public interface UDPBroadcastListener {
        void onReceived(String str);
    }

    class C04871 extends Stub {
        C04871() {
        }

        public void registerCallback(IUDPServiceCallback cb) {
            if (cb != null) {
                UDPBroadcast.this.mCallbacks.register(cb);
            }
        }

        public void unregisterCallback(IUDPServiceCallback cb) {
            if (cb != null) {
                UDPBroadcast.this.mCallbacks.unregister(cb);
            }
        }

        public void SetCmd(int nCmd, String strValue) throws RemoteException {
            switch (nCmd) {
                case 11:
                    UDPBroadcast.this.send_ip();
                    return;
                case 12:
                    UDPBroadcast.this.setPort(Integer.valueOf(strValue).intValue());
                    return;
                default:
                    return;
            }
        }

        public String GetValue(int nType) throws RemoteException {
            String strRes = EXTHeader.DEFAULT_VALUE;
            switch (nType) {
                case 12:
                    return UDPBroadcast.this.get_ip();
                default:
                    return strRes;
            }
        }
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        Log.d("jmgs", "IUDPService onStartCommand");
        return 3;
    }

    public void attachListener(UDPBroadcastListener aListener) {
        synchronized (this) {
            this.fListener = aListener;
        }
    }

    public String getLocalIpAddr() {
        try {
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                Enumeration<InetAddress> ips = ((NetworkInterface) en.nextElement()).getInetAddresses();
                while (ips.hasMoreElements()) {
                    InetAddress inetAddress = (InetAddress) ips.nextElement();
                    if (!inetAddress.isLoopbackAddress()) {
                        return inetAddress.getHostAddress();
                    }
                }
            }
        } catch (SocketException ex) {
            Log.e("Testing", ex.toString());
        }
        return null;
    }

    public void startUDP() {
        this.fMulticastLock = ((WifiManager) getSystemService("wifi")).createMulticastLock("myLock");
        this.fMulticastLock.acquire();
        try {
            this.fMulticastSocket = new DatagramSocket(0);
            this.fReceivedData = new byte[65536];
            this.fDatagramPacket = new DatagramPacket(this.fReceivedData, 65536);
            new Thread(new C02783()).start();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public void onCreate() {
        super.onCreate();
        startUDP();
        Log.d("jmgs", "IUDPService onCreate");
    }

    public void onDestroy() {
        super.onDestroy();
        Log.d("jmgs", "IUDPService onDestroy");
        this.fMulticastSocket.close();
        this.fMulticastLock.release();
        this.mCallbacks.kill();
    }

    public IBinder onBind(Intent intent) {
        Log.d("jmgs", "IUDPService onBind");
        if (IUDPService.class.getName().equals(intent.getAction())) {
            return this.mBinder;
        }
        return null;
    }

    public void send(String aData) {
        try {
            Log.d("UDP", "Send");
            byte[] data = new byte[aData.getBytes("UTF-8").length];
            data = aData.getBytes("UTF-8");
            InetAddress BCAddr = getBCastIpAddress(1);
            Log.i("svr", "***** IP0=" + BCAddr.getHostAddress());
            if (!(this.fMulticastSocket == null || data == null || data.length <= 0 || BCAddr == null || BCAddr.toString().compareTo("0.0.0.0") == 0)) {
                this.fMulticastSocket.send(new DatagramPacket(data, data.length, BCAddr, 20000));
            }
            BCAddr = getBCastIpAddress(2);
            if (this.fMulticastSocket != null && data != null && data.length > 0 && BCAddr != null && BCAddr.toString().compareTo("0.0.0.0") != 0) {
                this.fMulticastSocket.send(new DatagramPacket(data, data.length, BCAddr, 20000));
            }
        } catch (UnsupportedEncodingException e) {
            Log.i("4test", "UnsupportedEncodingException");
            e.printStackTrace();
        } catch (SocketException e2) {
            Log.i("4test", "SocketException");
            e2.printStackTrace();
        } catch (IOException e3) {
            Log.i("4test", "IOException");
            e3.printStackTrace();
        }
    }

    public void setPort(int nPort) {
        this.m_nPort = nPort;
    }

    public String get_ip() {
        return this.mStrIP;
    }

    public String getLocalIpAddress() {
        try {
            String strIP = EXTHeader.DEFAULT_VALUE;
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                NetworkInterface intf = (NetworkInterface) en.nextElement();
                Enumeration<InetAddress> enumIpAddr = intf.getInetAddresses();
                while (enumIpAddr.hasMoreElements()) {
                    InetAddress inetAddress = (InetAddress) enumIpAddr.nextElement();
                    if (!inetAddress.isLoopbackAddress() && (inetAddress instanceof Inet4Address)) {
                        if (intf.getName().startsWith("eth") || intf.getName().startsWith("wlan")) {
                            strIP = inetAddress.getHostAddress().toString();
                            Log.i("svr", "***** IP1=" + inetAddress.getHostAddress() + " //" + intf.getName());
                            break;
                        } else if (inetAddress.getHostAddress().toString().startsWith("192") && strIP.length() < 1) {
                            strIP = inetAddress.getHostAddress().toString();
                            Log.i("svr", "***** IP2=" + inetAddress.getHostAddress() + " //" + intf.getName());
                        }
                    }
                }
            }
            return strIP;
        } catch (Exception ex) {
            Log.e("svr", ex.toString());
            return null;
        }
    }

    public InetAddress getBCastIpAddress(int nType) {
        byte[] quads = new byte[4];
        try {
            String strIP = EXTHeader.DEFAULT_VALUE;
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                NetworkInterface intf = (NetworkInterface) en.nextElement();
                Enumeration<InetAddress> enumIpAddr = intf.getInetAddresses();
                while (enumIpAddr.hasMoreElements()) {
                    InetAddress inetAddress = (InetAddress) enumIpAddr.nextElement();
                    if (!inetAddress.isLoopbackAddress() && (inetAddress instanceof Inet4Address)) {
                        if (intf.getName().startsWith("eth") || intf.getName().startsWith("wlan")) {
                            quads = inetAddress.getAddress();
                            if (nType == 2) {
                                quads[2] = (byte) -1;
                            }
                            quads[3] = (byte) -1;
                            strIP = inetAddress.getHostAddress().toString();
                            Log.i("svr", "***** IP1=" + inetAddress.getHostAddress() + " //" + intf.getName());
                        } else if (inetAddress.getHostAddress().toString().startsWith("192") && strIP.length() < 1) {
                            quads = inetAddress.getAddress();
                            quads[3] = (byte) -1;
                            strIP = inetAddress.getHostAddress().toString();
                            Log.i("svr", "***** IP2=" + inetAddress.getHostAddress() + " //" + intf.getName());
                        }
                    }
                }
            }
            return InetAddress.getByAddress(quads);
        } catch (SocketException ex) {
            Log.e("svr", ex.toString());
        } catch (UnknownHostException e) {
            e.printStackTrace();
        }
        return null;
    }

    @SuppressLint({"DefaultLocale"})
    public String send_ip() {
        String strIP = EXTHeader.DEFAULT_VALUE;
        String strIPInfo = EXTHeader.DEFAULT_VALUE;
        MzServerApp MzApp = (MzServerApp) getApplicationContext();
        strIP = getLocalIpAddress();
        if (strIP.length() > 0 && this.m_nPort > 0) {
            Integer nPort = Integer.valueOf(this.m_nPort);
            String strUUID = ContentTree.GetUUID();
            strIPInfo = String.format("CONN_NOTIFY,%s:%d,%s,%s", new Object[]{strIP, nPort, MzApp.strSysInf, strUUID});
            Log.d("UDP", strIPInfo);
            if (strIPInfo != null) {
                send(strIPInfo);
            }
        }
        this.mStrIP = strIP;
        return strIP;
    }

    private void receiveMessage() throws IOException {
        DatagramPacket packet = this.fDatagramPacket;
        this.fMulticastSocket.receive(packet);
        if (!packet.getAddress().equals(getMyAddress())) {
            this.fListener.onReceived(new String(packet.getData(), packet.getOffset(), packet.getLength(), "UTF-8"));
        }
    }

    private InetAddress getBroadcastAddress() throws IOException {
        DhcpInfo dhcp = ((WifiManager) getSystemService("wifi")).getDhcpInfo();
        int broadcast = (dhcp.ipAddress & dhcp.netmask) | (dhcp.netmask ^ -1);
        byte[] quads = new byte[4];
        for (int k = 0; k < 4; k++) {
            quads[k] = (byte) ((broadcast >> (k * 8)) & 255);
        }
        return InetAddress.getByAddress(quads);
    }

    private InetAddress getMyAddress() throws IOException {
        int broadcast = ((WifiManager) getSystemService("wifi")).getDhcpInfo().ipAddress;
        byte[] quads = new byte[4];
        for (int k = 0; k < 4; k++) {
            quads[k] = (byte) ((broadcast >> (k * 8)) & 255);
        }
        return InetAddress.getByAddress(quads);
    }
}
