package com.enus.myzik;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.NetworkInfo.State;
import android.net.wifi.SupplicantState;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.util.Log;

public class WiFiMonitor extends BroadcastReceiver {
    public static final int NETWORK_STATE_CONNECTED = 5;
    public static final int NETWORK_STATE_CONNECTING = 6;
    public static final int NETWORK_STATE_DISCONNECTED = 7;
    public static final int NETWORK_STATE_DISCONNECTING = 8;
    public static final int NETWORK_STATE_SUSPENDED = 9;
    public static final int NETWORK_STATE_UNKNOWN = 10;
    public static final int WIFI_STATE_DISABLED = 0;
    public static final int WIFI_STATE_DISABLING = 1;
    public static final int WIFI_STATE_ENABLED = 2;
    public static final int WIFI_STATE_ENABLING = 3;
    public static final int WIFI_STATE_UNKNOWN = 4;
    private ConnectivityManager m_ConnManager = null;
    private OnChangeNetworkStatusListener m_OnChangeNetworkStatusListener = null;
    private WifiInfo m_WifiInfo = null;
    private WifiManager m_WifiManager = null;

    public interface OnChangeNetworkStatusListener {
        void OnChanged(int i);
    }

    public WiFiMonitor(Context context) {
        this.m_WifiManager = (WifiManager) context.getSystemService("wifi");
        this.m_WifiInfo = this.m_WifiManager.getConnectionInfo();
        this.m_ConnManager = (ConnectivityManager) context.getSystemService("connectivity");
    }

    public void setOnChangeNetworkStatusListener(OnChangeNetworkStatusListener listener) {
        this.m_OnChangeNetworkStatusListener = listener;
    }

    public String getSSID() {
        NetworkInfo networkInfo = this.m_ConnManager.getNetworkInfo(1);
        if (networkInfo != null && networkInfo.isAvailable() && networkInfo.getState() == State.CONNECTED) {
            return this.m_WifiInfo.getSSID();
        }
        return null;
    }

    public boolean isConnectToWifi() {
        return this.m_ConnManager.getNetworkInfo(1).isConnectedOrConnecting();
    }

    public boolean isConnectTo3G() {
        return this.m_ConnManager.getNetworkInfo(0).isConnectedOrConnecting();
    }

    private void handleSupplicantStateChanged(SupplicantState state, boolean hasError, int error) {
        if (hasError && error == 1) {
            Log.d("wifierr", "Find!!!");
        }
    }

    public void onReceive(Context context, Intent intent) {
        if (this.m_OnChangeNetworkStatusListener != null) {
            String strAction = intent.getAction();
            if (strAction.equals("android.net.wifi.WIFI_STATE_CHANGED")) {
                switch (this.m_WifiManager.getWifiState()) {
                    case 0:
                        this.m_OnChangeNetworkStatusListener.OnChanged(1);
                        return;
                    case 1:
                        this.m_OnChangeNetworkStatusListener.OnChanged(0);
                        return;
                    case 2:
                        this.m_OnChangeNetworkStatusListener.OnChanged(3);
                        return;
                    case 3:
                        this.m_OnChangeNetworkStatusListener.OnChanged(2);
                        return;
                    case 4:
                        this.m_OnChangeNetworkStatusListener.OnChanged(4);
                        return;
                    default:
                        return;
                }
            } else if (strAction.equals("android.net.wifi.STATE_CHANGE")) {
                NetworkInfo networkInfo = this.m_ConnManager.getNetworkInfo(1);
                if (networkInfo != null && networkInfo.isAvailable()) {
                    if (networkInfo.getState() == State.CONNECTED) {
                        this.m_OnChangeNetworkStatusListener.OnChanged(5);
                    } else if (networkInfo.getState() == State.CONNECTING) {
                        this.m_OnChangeNetworkStatusListener.OnChanged(10);
                    } else if (networkInfo.getState() == State.DISCONNECTED) {
                        this.m_OnChangeNetworkStatusListener.OnChanged(7);
                    } else if (networkInfo.getState() == State.DISCONNECTING) {
                        this.m_OnChangeNetworkStatusListener.OnChanged(8);
                    } else if (networkInfo.getState() == State.SUSPENDED) {
                        this.m_OnChangeNetworkStatusListener.OnChanged(9);
                    } else if (networkInfo.getState() == State.UNKNOWN) {
                        this.m_OnChangeNetworkStatusListener.OnChanged(10);
                    }
                }
            } else if (strAction.equals("android.net.wifi.supplicant.STATE_CHANGE")) {
                handleSupplicantStateChanged((SupplicantState) intent.getParcelableExtra("newState"), intent.hasExtra("supplicantError"), intent.getIntExtra("supplicantError", 0));
            }
        }
    }
}
