package com.enus.myzik;

import android.content.Intent;
import android.net.wifi.WifiManager;
import android.os.IBinder;
import android.os.RemoteCallbackList;
import android.os.RemoteException;
import android.util.Log;
import android.widget.ArrayAdapter;
import com.enus.myzik.IUPNPService.Stub;
import com.wireme.activity.ContentItem;
import com.wireme.activity.DeviceItem;
import com.wireme.mediaserver.MediaServer;
import java.net.InetAddress;
import java.net.UnknownHostException;
import org.teleal.cling.android.AndroidUpnpServiceConfiguration;
import org.teleal.cling.android.AndroidUpnpServiceImpl;
import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.cling.model.meta.Device;
import org.teleal.cling.model.meta.LocalDevice;
import org.teleal.cling.model.meta.RemoteDevice;
import org.teleal.cling.registry.DefaultRegistryListener;
import org.teleal.cling.registry.Registry;

public class WireUpnpService extends AndroidUpnpServiceImpl {
    private static final int GetMSIP = 20;
    private static final String LOGTAG = "WireMe";
    private MzNIOService NIOService = null;
    private ArrayAdapter<ContentItem> contentListAdapter = null;
    private ArrayAdapter<DeviceItem> deviceListAdapter = null;
    private DeviceListRegistryListener deviceListRegistryListener = null;
    public UDPBroadcast fService = null;
    private final Stub mBinder = new C04881();
    final RemoteCallbackList<IUPNPServiceCallback> mCallbacks = new RemoteCallbackList();
    private MediaServer mediaServer = null;

    class C04881 extends Stub {
        C04881() {
        }

        public void registerCallback(IUPNPServiceCallback cb) {
            if (cb != null) {
                WireUpnpService.this.mCallbacks.register(cb);
            }
        }

        public void unregisterCallback(IUPNPServiceCallback cb) {
            if (cb != null) {
                WireUpnpService.this.mCallbacks.unregister(cb);
            }
        }

        public void SetCmd(int nCmd, String strValue) throws RemoteException {
            if (WireUpnpService.this.mediaServer != null) {
                switch (nCmd) {
                    case 255:
                        if (WireUpnpService.this.mediaServer != null) {
                            WireUpnpService.this.mediaServer.setFriendlyName(strValue);
                            return;
                        }
                        return;
                    default:
                        return;
                }
            }
        }

        public String GetValue(int nType) throws RemoteException {
            String strRes = EXTHeader.DEFAULT_VALUE;
            switch (nType) {
                case 20:
                    if (WireUpnpService.this.mediaServer != null) {
                        strRes = WireUpnpService.this.mediaServer.getAddress();
                    }
                    Log.d("UDPC", strRes);
                    break;
            }
            return strRes;
        }
    }

    public class DeviceListRegistryListener extends DefaultRegistryListener {
        public void remoteDeviceDiscoveryStarted(Registry registry, RemoteDevice device) {
        }

        public void remoteDeviceDiscoveryFailed(Registry registry, RemoteDevice device, Exception ex) {
        }

        public void remoteDeviceAdded(Registry registry, RemoteDevice device) {
            if (device.getType().getNamespace().equals("schemas-upnp-org") && device.getType().getType().equals("MediaServer")) {
                deviceAdded(new DeviceItem(device, device.getDetails().getFriendlyName(), device.getDisplayString(), "(REMOTE) " + device.getType().getDisplayString()));
            }
        }

        public void remoteDeviceRemoved(Registry registry, RemoteDevice device) {
            deviceRemoved(new DeviceItem(device, device.getDisplayString()));
        }

        public void localDeviceAdded(Registry registry, LocalDevice device) {
            deviceAdded(new DeviceItem(device, device.getDetails().getFriendlyName(), device.getDisplayString(), "(REMOTE) " + device.getType().getDisplayString()));
        }

        public void localDeviceRemoved(Registry registry, LocalDevice device) {
            deviceRemoved(new DeviceItem(device, device.getDisplayString()));
        }

        public void deviceAdded(final DeviceItem di) {
            Thread thread = new Thread(new Runnable() {
                public void run() {
                    int position = WireUpnpService.this.deviceListAdapter.getPosition(di);
                    if (position >= 0) {
                        WireUpnpService.this.deviceListAdapter.remove(di);
                        WireUpnpService.this.deviceListAdapter.insert(di, position);
                        return;
                    }
                    WireUpnpService.this.deviceListAdapter.add(di);
                }
            });
        }

        public void deviceRemoved(final DeviceItem di) {
            Thread thread = new Thread(new Runnable() {
                public void run() {
                    WireUpnpService.this.deviceListAdapter.remove(di);
                }
            });
        }
    }

    protected AndroidUpnpServiceConfiguration createConfiguration(WifiManager wifiManager) {
        return new AndroidUpnpServiceConfiguration(wifiManager) {
        };
    }

    private InetAddress getLocalIpAddress() throws UnknownHostException {
        int ipAddress = ((WifiManager) getSystemService("wifi")).getConnectionInfo().getIpAddress();
        return InetAddress.getByName(String.format("%d.%d.%d.%d", new Object[]{Integer.valueOf(ipAddress & 255), Integer.valueOf((ipAddress >> 8) & 255), Integer.valueOf((ipAddress >> 16) & 255), Integer.valueOf((ipAddress >> 24) & 255)}));
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        Log.d("jmgs", "IUPNPService onStartCommand");
        return 3;
    }

    public IBinder onBind(Intent intent) {
        Log.d("jmgs", "IUPNPService onBind");
        if (!IUPNPService.class.getName().equals(intent.getAction())) {
            return null;
        }
        this.deviceListAdapter = new ArrayAdapter(getBaseContext(), 17367043);
        this.deviceListRegistryListener = new DeviceListRegistryListener();
        if (this.mediaServer == null) {
            try {
                this.mediaServer = new MediaServer(getLocalIpAddress());
                this.upnpService.getRegistry().addDevice(this.mediaServer.getDevice());
            } catch (Exception e) {
                Log.d("err", "Creating demo device failed");
                return this.mBinder;
            }
        }
        this.deviceListAdapter.clear();
        for (Device<?, ?, ?> device : this.upnpService.getRegistry().getDevices()) {
            this.deviceListRegistryListener.deviceAdded(new DeviceItem(device));
        }
        this.upnpService.getRegistry().addListener(this.deviceListRegistryListener);
        this.upnpService.getControlPoint().search();
        return this.mBinder;
    }

    public void onDestroy() {
        super.onDestroy();
        Log.d("jmgs", "IUPNPService onDestroy");
        if (this.upnpService != null) {
            this.upnpService.getRegistry().removeListener(this.deviceListRegistryListener);
            try {
                this.upnpService.shutdown();
                if (0 == 1) {
                    try {
                        this.upnpService.shutdown();
                    } catch (Exception e) {
                    }
                }
            } catch (Exception e2) {
                if (1 == 1) {
                    try {
                        this.upnpService.shutdown();
                    } catch (Exception e3) {
                    }
                }
            } catch (Throwable th) {
                if (0 == 1) {
                    try {
                        this.upnpService.shutdown();
                    } catch (Exception e4) {
                    }
                }
            }
        }
        this.mCallbacks.kill();
    }
}
