package com.gc.android.market.api;

import com.gc.android.market.api.Tools.HttpException;
import com.gc.android.market.api.model.Market.AppsRequest;
import com.gc.android.market.api.model.Market.AppsResponse;
import com.gc.android.market.api.model.Market.CategoriesRequest;
import com.gc.android.market.api.model.Market.CategoriesResponse;
import com.gc.android.market.api.model.Market.CommentsRequest;
import com.gc.android.market.api.model.Market.CommentsResponse;
import com.gc.android.market.api.model.Market.GetImageRequest;
import com.gc.android.market.api.model.Market.GetImageResponse;
import com.gc.android.market.api.model.Market.Request;
import com.gc.android.market.api.model.Market.Request.RequestGroup;
import com.gc.android.market.api.model.Market.RequestContext;
import com.gc.android.market.api.model.Market.RequestContext.Builder;
import com.gc.android.market.api.model.Market.Response;
import com.gc.android.market.api.model.Market.Response.ResponseGroup;
import com.gc.android.market.api.model.Market.ResponseContext;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.Vector;
import java.util.zip.GZIPInputStream;

public class MarketSession {
    public static final String ACCOUNT_TYPE_GOOGLE = "GOOGLE";
    public static final String ACCOUNT_TYPE_HOSTED = "HOSTED";
    public static final String ACCOUNT_TYPE_HOSTED_OR_GOOGLE = "HOSTED_OR_GOOGLE";
    public static final int PROTOCOL_VERSION = 2;
    public static final String SERVICE = "android";
    private static final String URL_LOGIN = "https://www.google.com/accounts/ClientLogin";
    String authSubToken = null;
    List<Callback<?>> callbacks = new Vector();
    Builder context = RequestContext.newBuilder();
    Request.Builder request = Request.newBuilder();

    public interface Callback<T> {
        void onResult(ResponseContext responseContext, T t);
    }

    public Builder getContext() {
        return this.context;
    }

    public String getAuthSubToken() {
        return this.authSubToken;
    }

    public MarketSession() {
        this.context.setUnknown1(0);
        this.context.setVersion(1002012);
        this.context.setAndroidId("0123456789123456");
        setLocale(Locale.getDefault());
        this.context.setDeviceAndSdkVersion("crespo:8");
        setOperatorTMobile();
    }

    public void setLocale(Locale locale) {
        this.context.setUserLanguage(locale.getLanguage().toLowerCase());
        this.context.setUserCountry(locale.getCountry().toLowerCase());
    }

    public void setOperator(String alpha, String numeric) {
        setOperator(alpha, alpha, numeric, numeric);
    }

    public void setOperatorTMobile() {
        setOperator("T-Mobile", "310260");
    }

    public void setOperatorSFR() {
        setOperator("F SFR", "20810");
    }

    public void setOperatorO2() {
        setOperator("o2 - de", "26207");
    }

    public void setOperatorSimyo() {
        setOperator("E-Plus", "simyo", "26203", "26203");
    }

    public void setOperatorSunrise() {
        setOperator("sunrise", "22802");
    }

    public void setOperator(String alpha, String simAlpha, String numeric, String simNumeric) {
        this.context.setOperatorAlpha(alpha);
        this.context.setSimOperatorAlpha(simAlpha);
        this.context.setOperatorNumeric(numeric);
        this.context.setSimOperatorNumeric(simNumeric);
    }

    public void setAuthSubToken(String authSubToken) {
        this.context.setAuthSubToken(authSubToken);
        this.authSubToken = authSubToken;
    }

    public void login(String email, String password) {
        login(email, password, ACCOUNT_TYPE_HOSTED_OR_GOOGLE);
    }

    public void login(String email, String password, String accountType) {
        Map<String, String> params = new LinkedHashMap();
        params.put("Email", email);
        params.put("Passwd", password);
        params.put("service", SERVICE);
        params.put("accountType", accountType);
        StringTokenizer st;
        try {
            String data = Tools.postUrl(URL_LOGIN, params);
            st = new StringTokenizer(data, "\n\r=");
            String authKey = null;
            while (st.hasMoreTokens()) {
                if (st.nextToken().equalsIgnoreCase("Auth")) {
                    authKey = st.nextToken();
                    break;
                }
            }
            if (authKey == null) {
                throw new RuntimeException("authKey not found in " + data);
            }
            setAuthSubToken(authKey);
        } catch (HttpException httpEx) {
            if (httpEx.getErrorCode() != 403) {
                throw httpEx;
            }
            st = new StringTokenizer(httpEx.getErrorData(), "\n\r=");
            String googleErrorCode = null;
            while (st.hasMoreTokens()) {
                if (st.nextToken().equalsIgnoreCase("Error")) {
                    googleErrorCode = st.nextToken();
                    break;
                }
            }
            if (googleErrorCode == null) {
                throw httpEx;
            }
            throw new LoginException(googleErrorCode);
        } catch (IOException ex) {
            throw new RuntimeException(ex);
        }
    }

    public List<Object> queryApp(AppsRequest requestGroup) {
        List<Object> retList = new ArrayList();
        this.request.addRequestGroup(RequestGroup.newBuilder().setAppsRequest(requestGroup));
        RequestContext ctxt = this.context.build();
        this.context = RequestContext.newBuilder(ctxt);
        this.request.setContext(ctxt);
        try {
            for (ResponseGroup grp : executeProtobuf(this.request.build()).getResponseGroupList()) {
                if (grp.hasAppsResponse()) {
                    retList.add(grp.getAppsResponse());
                }
            }
            return retList;
        } finally {
            this.request = Request.newBuilder();
        }
    }

    public void append(AppsRequest requestGroup, Callback<AppsResponse> responseCallback) {
        this.request.addRequestGroup(RequestGroup.newBuilder().setAppsRequest(requestGroup));
        this.callbacks.add(responseCallback);
    }

    public void append(GetImageRequest requestGroup, Callback<GetImageResponse> responseCallback) {
        this.request.addRequestGroup(RequestGroup.newBuilder().setImageRequest(requestGroup));
        this.callbacks.add(responseCallback);
    }

    public void append(CommentsRequest requestGroup, Callback<CommentsResponse> responseCallback) {
        this.request.addRequestGroup(RequestGroup.newBuilder().setCommentsRequest(requestGroup));
        this.callbacks.add(responseCallback);
    }

    public void append(CategoriesRequest requestGroup, Callback<CategoriesResponse> responseCallback) {
        this.request.addRequestGroup(RequestGroup.newBuilder().setCategoriesRequest(requestGroup));
        this.callbacks.add(responseCallback);
    }

    public void flush() {
        RequestContext ctxt = this.context.build();
        this.context = RequestContext.newBuilder(ctxt);
        this.request.setContext(ctxt);
        try {
            int i = 0;
            for (ResponseGroup grp : executeProtobuf(this.request.build()).getResponseGroupList()) {
                Object val = null;
                if (grp.hasAppsResponse()) {
                    val = grp.getAppsResponse();
                }
                if (grp.hasCategoriesResponse()) {
                    val = grp.getCategoriesResponse();
                }
                if (grp.hasCommentsResponse()) {
                    val = grp.getCommentsResponse();
                }
                if (grp.hasImageResponse()) {
                    val = grp.getImageResponse();
                }
                ((Callback) this.callbacks.get(i)).onResult(grp.getContext(), val);
                i++;
            }
        } finally {
            this.request = Request.newBuilder();
            this.callbacks.clear();
        }
    }

    public ResponseGroup execute(RequestGroup requestGroup) {
        RequestContext ctxt = this.context.build();
        this.context = RequestContext.newBuilder(ctxt);
        this.request.setContext(ctxt);
        return executeProtobuf(this.request.addRequestGroup(requestGroup).setContext(ctxt).build()).getResponseGroup(0);
    }

    private Response executeProtobuf(Request request) {
        try {
            return Response.parseFrom(executeRawHttpQuery(request.toByteArray()));
        } catch (Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    private byte[] executeRawHttpQuery(byte[] request) {
        try {
            HttpURLConnection cnx = (HttpURLConnection) new URL("http://android.clients.google.com/market/api/ApiRequest").openConnection();
            cnx.setDoOutput(true);
            cnx.setRequestMethod("POST");
            cnx.setRequestProperty("Cookie", "ANDROID=" + this.authSubToken);
            cnx.setRequestProperty("User-Agent", "Android-Market/2 (sapphire PLAT-RC33); gzip");
            cnx.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
            cnx.setRequestProperty("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
            String requestData = "version=2&request=" + Base64.encodeBytes(request, 16);
            cnx.setFixedLengthStreamingMode(requestData.getBytes("UTF-8").length);
            OutputStream os = cnx.getOutputStream();
            os.write(requestData.getBytes());
            os.close();
            if (cnx.getResponseCode() >= 400) {
                throw new RuntimeException("Response code = " + cnx.getResponseCode() + ", msg = " + cnx.getResponseMessage());
            }
            InputStream is = cnx.getInputStream();
            GZIPInputStream gzIs = new GZIPInputStream(is);
            ByteArrayOutputStream bos = new ByteArrayOutputStream();
            byte[] buff = new byte[1024];
            while (true) {
                int nb = gzIs.read(buff);
                if (nb < 0) {
                    is.close();
                    cnx.disconnect();
                    return bos.toByteArray();
                }
                bos.write(buff, 0, nb);
            }
        } catch (Exception ex) {
            throw new RuntimeException(ex);
        }
    }
}
