package com.gc.android.market.api;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.util.Map;
import org.teleal.cling.model.message.header.EXTHeader;

public class Tools {

    public static class HttpException extends RuntimeException {
        private int errorCode;
        private String errorData;

        public HttpException(int errorCode, String errorData) {
            super("HTTP Code " + errorCode + " : " + errorData);
            this.errorCode = errorCode;
            this.errorData = errorData;
        }

        public int getErrorCode() {
            return this.errorCode;
        }

        public String getErrorData() {
            return this.errorData;
        }
    }

    public static String postUrl(String url, Map<String, String> params) throws IOException {
        InputStream errorStream;
        InputStream resultStream;
        String data = EXTHeader.DEFAULT_VALUE;
        for (String key : params.keySet()) {
            data = new StringBuilder(String.valueOf(data)).append("&").append(URLEncoder.encode(key, "UTF-8")).append("=").append(URLEncoder.encode((String) params.get(key), "UTF-8")).toString();
        }
        data = data.substring(1);
        HttpURLConnection aConnection = (HttpURLConnection) new URL(url).openConnection();
        try {
            aConnection.setDoOutput(true);
            aConnection.setDoInput(true);
            aConnection.setRequestMethod("POST");
            OutputStreamWriter streamToAuthorize = new OutputStreamWriter(aConnection.getOutputStream());
            streamToAuthorize.write(data);
            streamToAuthorize.flush();
            streamToAuthorize.close();
            int errorCode = aConnection.getResponseCode();
            if (errorCode >= 400) {
                errorStream = aConnection.getErrorStream();
                throw new HttpException(errorCode, streamToString(errorStream));
            }
            resultStream = aConnection.getInputStream();
            String responseData = streamToString(resultStream);
            resultStream.close();
            aConnection.disconnect();
            return responseData;
        } catch (Throwable th) {
            aConnection.disconnect();
        }
    }

    private static String streamToString(InputStream resultStream) throws IOException {
        BufferedReader aReader = new BufferedReader(new InputStreamReader(resultStream));
        StringBuffer aResponse = new StringBuffer();
        for (String aLine = aReader.readLine(); aLine != null; aLine = aReader.readLine()) {
            aResponse.append(new StringBuilder(String.valueOf(aLine)).append("\n").toString());
        }
        return aResponse.toString();
    }
}
