package com.wireme.mediaserver;

import android.content.Intent;
import android.os.Environment;
import android.util.Log;
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.io.UnsupportedEncodingException;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.SocketTimeoutException;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Properties;
import java.util.StringTokenizer;
import java.util.TimeZone;
import java.util.Vector;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import org.teleal.cling.model.ServiceReference;
import org.teleal.cling.model.message.header.EXTHeader;

public class HttpServer {
    public static final String HTTP_BADREQUEST = "400 Bad Request";
    public static final String HTTP_FORBIDDEN = "403 Forbidden";
    public static final String HTTP_INTERNALERROR = "500 Internal Server Error";
    public static final String HTTP_NOTFOUND = "404 Not Found";
    public static final String HTTP_NOTIMPLEMENTED = "501 Not Implemented";
    public static final String HTTP_OK = "200 OK";
    public static final String HTTP_PARTIALCONTENT = "206 Partial Content";
    public static final String HTTP_RANGE_NOT_SATISFIABLE = "416 Requested Range Not Satisfiable";
    public static final String HTTP_REDIRECT = "301 Moved Permanently";
    private static final String LICENCE = "Copyright (C) 2001,2005-2011 by Jarno Elonen <elonen@iki.fi>\nand Copyright (C) 2010 by Konstantinos Togias <info@ktogias.gr>\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions\nare met:\n\nRedistributions of source code must retain the above copyright notice,\nthis list of conditions and the following disclaimer. Redistributions in\nbinary form must reproduce the above copyright notice, this list of\nconditions and the following disclaimer in the documentation and/or other\nmaterials provided with the distribution. The name of the author may not\nbe used to endorse or promote products derived from this software without\nspecific prior written permission. \n \nTHIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR\nIMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES\nOF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.\nIN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,\nINCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT\nNOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,\nDATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY\nTHEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\nOF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.";
    public static final long LONG_HIGH_BITS = -2147483648L;
    public static final String MIME_DEFAULT_BINARY = "application/octet-stream";
    public static final String MIME_HTML = "text/html";
    public static final String MIME_PLAINTEXT = "text/plain";
    public static final String MIME_XML = "text/xml";
    private static SimpleDateFormat gmtFrmt = new SimpleDateFormat("E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
    private static Hashtable theMimeTypes = new Hashtable();
    final String DL_Path = "/Download/";
    final String FILE_DELETE = "/FILE_DELETE";
    final String FILE_MOVE = "/FILE_MOVE";
    final String FILE_READ = "/FILE_READ";
    final String FILE_RENAME = "/FILE_RENAME";
    final String FILE_SIZE = "/FILE_SIZE";
    final String FILE_WRITE = "/FILE_WRITE";
    final String FW_Path = "/bcoda/fw/";
    final String ResDN = "DOWNLOAD";
    final String TMP_Path = "/bcoda_tmp";
    private ExecutorService es;
    private ThreadPoolExecutor mThreadPoolExec = null;
    private File myRootDir;
    private final ServerSocket myServerSocket;
    private int myTcpPort;
    private Thread myThread;
    private boolean shutdown;

    class C03771 implements Runnable {
        C03771() {
        }

        public void run() {
            while (!HttpServer.this.shutdown) {
                try {
                    try {
                        Socket s = HttpServer.this.myServerSocket.accept();
                        s.setReceiveBufferSize(500000);
                        HttpServer.this.handleSession(s, HttpServer.this.es);
                    } catch (SocketTimeoutException e) {
                    }
                } catch (IOException ioe) {
                    ioe.printStackTrace();
                    return;
                }
            }
            HttpServer.this.es.shutdown();
            if (HttpServer.this.es instanceof ThreadPoolExecutor) {
                ThreadPoolExecutor threadPoolExecutor = (ThreadPoolExecutor) HttpServer.this.es;
            }
        }
    }

    private class HTTPSession implements Runnable {
        final int TMP_BUF_SIZE = 512;
        byte[] m_buf = null;
        InputStream m_in = null;
        InputStreamReader m_isr = null;
        OutputStream m_out = null;
        byte[] m_tmpBuf = new byte[512];
        private Socket mySocket;

        public HTTPSession(Socket s) {
            this.mySocket = s;
        }

        public void run_o() {
            try {
                InputStream is = this.mySocket.getInputStream();
                if (is != null) {
                    byte[] buf = new byte[8192];
                    int rlen = is.read(buf, 0, 8192);
                    if (rlen > 0) {
                        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(buf, 0, rlen)));
                        Properties pre = new Properties();
                        Properties parms = new Properties();
                        Properties header = new Properties();
                        Properties files = new Properties();
                        decodeHeader(bufferedReader, pre, parms, header);
                        String method = pre.getProperty("method");
                        String uri = pre.getProperty("uri");
                        long size = Long.MAX_VALUE;
                        String contentLength = header.getProperty("content-length");
                        if (contentLength != null) {
                            try {
                                size = (long) Integer.parseInt(contentLength);
                            } catch (NumberFormatException e) {
                            }
                        }
                        int splitbyte = 0;
                        boolean sbfound = false;
                        while (splitbyte < rlen) {
                            if (buf[splitbyte] == (byte) 13) {
                                splitbyte++;
                                if (buf[splitbyte] == (byte) 10) {
                                    splitbyte++;
                                    if (buf[splitbyte] == (byte) 13) {
                                        splitbyte++;
                                        if (buf[splitbyte] == (byte) 10) {
                                            sbfound = true;
                                            break;
                                        }
                                    } else {
                                        continue;
                                    }
                                } else {
                                    continue;
                                }
                            }
                            splitbyte++;
                        }
                        splitbyte++;
                        ByteArrayOutputStream f = new ByteArrayOutputStream();
                        if (splitbyte < rlen) {
                            f.write(buf, splitbyte, rlen - splitbyte);
                        }
                        if (splitbyte < rlen) {
                            size -= (long) (rlen - splitbyte);
                        } else if (!sbfound || size == Long.MAX_VALUE) {
                            size = 0;
                        }
                        buf = new byte[512];
                        while (rlen >= 0 && size > 0) {
                            rlen = is.read(buf, 0, 512);
                            size -= (long) rlen;
                            if (rlen > 0) {
                                f.write(buf, 0, rlen);
                            }
                        }
                        byte[] fbuf = f.toByteArray();
                        BufferedReader in = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(fbuf)));
                        if (method.equalsIgnoreCase("POST")) {
                            Log.d("ui2f", "POST");
                            String contentType = EXTHeader.DEFAULT_VALUE;
                            StringTokenizer stringTokenizer = new StringTokenizer(header.getProperty("content-type"), "; ");
                            if (stringTokenizer.hasMoreTokens()) {
                                contentType = stringTokenizer.nextToken();
                            }
                            if (contentType.equalsIgnoreCase("multipart/form-data")) {
                                if (!stringTokenizer.hasMoreTokens()) {
                                    sendError(HttpServer.HTTP_BADREQUEST, "BAD REQUEST: Content type is multipart/form-data but boundary missing. Usage: GET /example/file.html");
                                }
                                stringTokenizer = new StringTokenizer(stringTokenizer.nextToken(), "=");
                                if (stringTokenizer.countTokens() != 2) {
                                    sendError(HttpServer.HTTP_BADREQUEST, "BAD REQUEST: Content type is multipart/form-data but boundary syntax error. Usage: GET /example/file.html");
                                }
                                stringTokenizer.nextToken();
                                decodeMultipartData(stringTokenizer.nextToken(), fbuf, in, parms, files);
                            } else {
                                String postLine = EXTHeader.DEFAULT_VALUE;
                                char[] pbuf = new char[512];
                                for (int read = in.read(pbuf); read >= 0; read = in.read(pbuf)) {
                                    if (postLine.endsWith("\r\n")) {
                                        break;
                                    }
                                    postLine = new StringBuilder(String.valueOf(postLine)).append(String.valueOf(pbuf, 0, read)).toString();
                                }
                                decodeParms(postLine.trim(), parms);
                            }
                        }
                        boolean isEnable = true;
                        Response r = HttpServer.this.serveWrite(uri, method, header, fbuf);
                        if (uri.equals("/FILE_WRITE")) {
                            isEnable = false;
                        }
                        if (r == null) {
                            r = HttpServer.this.serve(uri, method, header, parms, files);
                        }
                        if (isEnable) {
                            if (r == null) {
                                sendError(HttpServer.HTTP_INTERNALERROR, "SERVER INTERNAL ERROR: Serve() returned a null response.");
                            } else {
                                sendResponse(r.status, r.mimeType, r.header, r.data);
                            }
                        }
                        in.close();
                        is.close();
                    }
                }
            } catch (IOException ioe) {
                sendError(HttpServer.HTTP_INTERNALERROR, "SERVER INTERNAL ERROR: IOException: " + ioe.getMessage());
            } catch (InterruptedException e2) {
            } catch (Throwable th) {
            }
        }

        private byte[] getHeader2() {
            String strHead = EXTHeader.DEFAULT_VALUE;
            try {
                strHead = HttpServer.readLine(this.m_in);
            } catch (IOException e) {
                e.printStackTrace();
            }
            if (strHead == null) {
                return null;
            }
            return strHead.getBytes();
        }

        private void getpre(ByteArrayOutputStream f, int nSize) {
            int bufsize = 8192;
            byte[] buf = null;
            int nRead = 0;
            while (nRead < nSize) {
                int nEnd = nRead + bufsize;
                if (nEnd > nSize) {
                    bufsize = nEnd - nSize;
                }
                int nR = 0;
                try {
                    buf = new byte[bufsize];
                    nR = this.m_in.read(buf, 0, bufsize);
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (nR > 0) {
                    f.write(buf, 0, nR);
                    nRead += nR;
                } else {
                    return;
                }
            }
        }

        private byte[] getpre2(int nSize) {
            StringBuffer sb = new StringBuffer();
            int bufsize = 8192;
            byte[] buf = null;
            int nRead = 0;
            while (nRead < nSize) {
                int nEnd = nRead + bufsize;
                if (nEnd > nSize) {
                    bufsize = nEnd - nSize;
                }
                int nR = 0;
                try {
                    buf = new byte[bufsize];
                    nR = this.m_in.read(buf, 0, bufsize);
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (nR <= 0) {
                    return sb.toString().getBytes();
                }
                sb.append(buf);
                nRead += nR;
            }
            return sb.toString().getBytes();
        }

        private byte[] getHeader() {
            int splitbyte;
            int size = 0;
            byte[] buf = this.m_tmpBuf;
            int rlen = 0;
            int bufsize = 512 - 4;
            if (this.m_buf != null) {
                System.arraycopy(this.m_buf, 0, buf, 0, this.m_buf.length);
                rlen = this.m_buf.length;
                bufsize = 508 - rlen;
                this.m_buf = null;
            }
            boolean method_found = false;
            boolean sbfound;
            do {
                splitbyte = 0;
                sbfound = false;
                while (splitbyte < rlen) {
                    int chk_pos = splitbyte;
                    if ((buf[chk_pos] == (byte) 112 && buf[chk_pos + 1] == (byte) 117 && buf[chk_pos + 2] == (byte) 116) || ((buf[chk_pos] == (byte) 103 && buf[chk_pos + 1] == (byte) 101 && buf[chk_pos + 2] == (byte) 116) || ((buf[chk_pos] == (byte) 80 && buf[chk_pos + 1] == (byte) 85 && buf[chk_pos + 2] == (byte) 84) || (buf[chk_pos] == (byte) 71 && buf[chk_pos + 1] == (byte) 69 && buf[chk_pos + 2] == (byte) 84)))) {
                        method_found = true;
                    }
                    if (buf[splitbyte] == (byte) 13) {
                        splitbyte++;
                        if (buf[splitbyte] == (byte) 10) {
                            splitbyte++;
                            if (buf[splitbyte] == (byte) 13) {
                                splitbyte++;
                                if (buf[splitbyte] == (byte) 10) {
                                    if (method_found) {
                                        sbfound = true;
                                        splitbyte++;
                                        if (!sbfound) {
                                            buf[rlen] = (byte) 0;
                                            Log.d("ui2http", "ThreadID : " + Thread.currentThread().getId() + " , Not Found EOF size=" + rlen + ", Last read size=" + size);
                                            try {
                                                size = this.m_in.read(buf, rlen, bufsize);
                                            } catch (IOException e) {
                                                e.printStackTrace();
                                            }
                                            if (size > 0) {
                                                rlen += size;
                                            }
                                            if (rlen > 0 || size <= 0) {
                                                String strTmp = EXTHeader.DEFAULT_VALUE;
                                                Log.d("ui2http", String.format("ui2http_size %d, rlen %d", new Object[]{Integer.valueOf(size), Integer.valueOf(rlen)}));
                                                return null;
                                            }
                                            bufsize -= size;
                                            continue;
                                        }
                                    } else {
                                        Log.d("ui2http", "Parse Wrong! - re-init");
                                        return null;
                                    }
                                }
                            } else {
                                continue;
                            }
                        } else {
                            continue;
                        }
                    }
                    splitbyte++;
                }
                splitbyte++;
                if (!sbfound) {
                    buf[rlen] = (byte) 0;
                    Log.d("ui2http", "ThreadID : " + Thread.currentThread().getId() + " , Not Found EOF size=" + rlen + ", Last read size=" + size);
                    size = this.m_in.read(buf, rlen, bufsize);
                    if (size > 0) {
                        rlen += size;
                    }
                    if (rlen > 0) {
                    }
                    String strTmp2 = EXTHeader.DEFAULT_VALUE;
                    Log.d("ui2http", String.format("ui2http_size %d, rlen %d", new Object[]{Integer.valueOf(size), Integer.valueOf(rlen)}));
                    return null;
                }
            } while (!sbfound);
            int nPos = -1;
            byte[] value = new byte[splitbyte];
            if (value != null) {
                System.arraycopy(buf, 0, value, 0, splitbyte);
                if (splitbyte > 3) {
                    String str = new String(buf);
                    String strTmpStart = str.substring(0, 3);
                    if (!(strTmpStart.equalsIgnoreCase("PUT") || strTmpStart.equalsIgnoreCase("GET"))) {
                        nPos = str.indexOf("PUT");
                        if (nPos < 0) {
                            nPos = str.indexOf("put");
                            if (nPos < 0) {
                                nPos = str.indexOf("GET");
                                if (nPos < 0) {
                                    nPos = str.indexOf("get");
                                }
                            }
                        }
                        if (nPos > 0) {
                            Log.d("ui2http", "Parse Wrong!! but, Has Method -_____-++ => " + str);
                            strTmp2 = str.substring(nPos);
                            int nPos2 = strTmp2.indexOf("\r\n\r\n");
                            if (nPos2 > 0) {
                                strTmp2 = strTmp2.substring(0, nPos2);
                            }
                            value = strTmp2.getBytes();
                            Log.d("ui2http", "Parse Wrong2!! ==> " + new String(value));
                        }
                    }
                }
            }
            if (rlen <= splitbyte) {
                return value;
            }
            if (nPos > 0) {
                Log.d("ui2http", String.format("Parse Wrong3!! rlen - splitbyte:%d, nPos:%d, buf_len:%d", new Object[]{Integer.valueOf(rlen - splitbyte), Integer.valueOf(nPos), Integer.valueOf(buf.length)}));
                return null;
            }
            this.m_buf = new byte[(rlen - splitbyte)];
            System.arraycopy(buf, splitbyte, this.m_buf, 0, rlen - splitbyte);
            return value;
        }

        private int getData(ByteArrayOutputStream f, int size) {
            int count = size;
            if (this.m_buf != null) {
                if (size < this.m_buf.length) {
                    f.write(this.m_buf, 0, size);
                    byte[] tmp = new byte[(this.m_buf.length - size)];
                    System.arraycopy(this.m_buf, size, tmp, 0, this.m_buf.length - size);
                    this.m_buf = tmp;
                    return size;
                }
                f.write(this.m_buf, 0, this.m_buf.length);
                size -= this.m_buf.length;
                Log.d("ui2http", "[0]ThreadID : " + Thread.currentThread().getId() + " , size:" + count + "m_buf: " + this.m_buf.length);
                this.m_buf = null;
            }
            byte[] buf = this.m_tmpBuf;
            int rlen = 1;
            while (rlen > 0 && size > 0) {
                int tmp2 = 512;
                if (512 > size) {
                    tmp2 = size;
                }
                try {
                    rlen = this.m_in.read(buf, 0, tmp2);
                } catch (IOException e) {
                    e.printStackTrace();
                }
                if (rlen > 0) {
                    size -= rlen;
                    f.write(buf, 0, rlen);
                } else {
                    Log.d("ui2httpd", "getData rlen <= 0");
                }
            }
            return count;
        }

        /* JADX WARNING: inconsistent code. */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        public void run() {
            /*
            r40 = this;
            r0 = r40;
            r4 = r0.mySocket;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = r4.getInputStream();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r0.m_in = r4;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = new java.io.InputStreamReader;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r10 = r0.m_in;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4.<init>(r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r0.m_isr = r4;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r4 = r0.m_in;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 != 0) goto L_0x0020;
        L_0x001f:
            return;
        L_0x0020:
            r36 = 0;
            r35 = 0;
            r18 = r40.getHeader();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r18 == 0) goto L_0x004c;
        L_0x002a:
            r4 = "ui2f";
            r10 = new java.lang.StringBuilder;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r14 = "getHeader2:";
            r10.<init>(r14);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r14 = new java.lang.String;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r18;
            r14.<init>(r0);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r10 = r10.append(r14);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r10 = r10.toString();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            android.util.Log.d(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r36 = 1;
            r0 = r18;
            r0 = r0.length;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r35 = r0;
        L_0x004c:
            if (r35 > 0) goto L_0x0085;
        L_0x004e:
            r4 = "ui2f";
            r10 = "httpd_return #1";
            android.util.Log.d(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x0055:
            r0 = r40;
            r4 = r0.m_in;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4.close();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r4 = r0.m_out;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4.close();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x001f;
        L_0x0064:
            r28 = move-exception;
            r28.printStackTrace();
            r4 = "500 Internal Server Error";
            r10 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x0083 }
            r14 = "SERVER INTERNAL ERROR: IOException: ";
            r10.<init>(r14);	 Catch:{ Throwable -> 0x0083 }
            r14 = r28.getMessage();	 Catch:{ Throwable -> 0x0083 }
            r10 = r10.append(r14);	 Catch:{ Throwable -> 0x0083 }
            r10 = r10.toString();	 Catch:{ Throwable -> 0x0083 }
            r0 = r40;
            r0.sendError(r4, r10);	 Catch:{ Throwable -> 0x0083 }
            goto L_0x001f;
        L_0x0083:
            r4 = move-exception;
            goto L_0x001f;
        L_0x0085:
            r24 = new java.io.ByteArrayOutputStream;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r24.<init>();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r25 = new java.io.ByteArrayInputStream;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = 0;
            r0 = r25;
            r1 = r18;
            r2 = r35;
            r0.<init>(r1, r4, r2);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r26 = new java.io.BufferedReader;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = new java.io.InputStreamReader;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r25;
            r4.<init>(r0);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r26;
            r0.<init>(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r32 = new java.util.Properties;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r32.<init>();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r8 = new java.util.Properties;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r8.<init>();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r13 = new java.util.Properties;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r13.<init>();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r9 = new java.util.Properties;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r9.<init>();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r1 = r26;
            r2 = r32;
            r0.decodeHeader(r1, r2, r8, r13);	 Catch:{ InterruptedException -> 0x01e1, IOException -> 0x0064, NullPointerException -> 0x01e7 }
        L_0x00c1:
            r26.close();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = "method";
            r0 = r32;
            r12 = r0.getProperty(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = "uri";
            r0 = r32;
            r11 = r0.getProperty(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r38 = 9223372036854775807; // 0x7fffffffffffffff float:NaN double:NaN;
            r4 = "content-length";
            r19 = r13.getProperty(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r19 == 0) goto L_0x00e8;
        L_0x00e1:
            r4 = java.lang.Integer.parseInt(r19);	 Catch:{ NumberFormatException -> 0x0268 }
            r0 = (long) r4;
            r38 = r0;
        L_0x00e8:
            if (r36 == 0) goto L_0x00f3;
        L_0x00ea:
            r14 = 9223372036854775807; // 0x7fffffffffffffff float:NaN double:NaN;
            r4 = (r38 > r14 ? 1 : (r38 == r14 ? 0 : -1));
            if (r4 != 0) goto L_0x00f5;
        L_0x00f3:
            r38 = 0;
        L_0x00f5:
            r14 = 0;
            r4 = (r38 > r14 ? 1 : (r38 == r14 ? 0 : -1));
            if (r4 <= 0) goto L_0x0105;
        L_0x00fb:
            r0 = r38;
            r4 = (int) r0;
            r0 = r40;
            r1 = r24;
            r0.getData(r1, r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x0105:
            r6 = r24.toByteArray();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r24 = 0;
            r16 = new java.io.ByteArrayInputStream;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r16;
            r0.<init>(r6);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r7 = new java.io.BufferedReader;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = new java.io.InputStreamReader;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r16;
            r4.<init>(r0);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r7.<init>(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = "POST";
            r4 = r12.equalsIgnoreCase(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x018e;
        L_0x0126:
            r4 = "ui2f";
            r10 = "POST";
            android.util.Log.d(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r20 = "";
            r4 = "content-type";
            r21 = r13.getProperty(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r37 = new java.util.StringTokenizer;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = "; ";
            r0 = r37;
            r1 = r21;
            r0.<init>(r1, r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = r37.hasMoreTokens();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x014a;
        L_0x0146:
            r20 = r37.nextToken();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x014a:
            r4 = "multipart/form-data";
            r0 = r20;
            r4 = r0.equalsIgnoreCase(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x01ed;
        L_0x0154:
            r4 = r37.hasMoreTokens();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 != 0) goto L_0x0163;
        L_0x015a:
            r4 = "400 Bad Request";
            r10 = "BAD REQUEST: Content type is multipart/form-data but boundary missing. Usage: GET /example/file.html";
            r0 = r40;
            r0.sendError(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x0163:
            r17 = r37.nextToken();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r37 = new java.util.StringTokenizer;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = "=";
            r0 = r37;
            r1 = r17;
            r0.<init>(r1, r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = r37.countTokens();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r10 = 2;
            if (r4 == r10) goto L_0x0182;
        L_0x0179:
            r4 = "400 Bad Request";
            r10 = "BAD REQUEST: Content type is multipart/form-data but boundary syntax error. Usage: GET /example/file.html";
            r0 = r40;
            r0.sendError(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x0182:
            r37.nextToken();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r5 = r37.nextToken();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = r40;
            r4.decodeMultipartData(r5, r6, r7, r8, r9);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x018e:
            r33 = 0;
            r29 = 1;
            r0 = r40;
            r4 = com.wireme.mediaserver.HttpServer.this;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r33 = r4.serveWrite(r11, r12, r13, r6);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r22 = 0;
            r4 = "/FILE_WRITE";
            r4 = r11.equals(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x01a6;
        L_0x01a4:
            r22 = 1;
        L_0x01a6:
            if (r33 != 0) goto L_0x01b2;
        L_0x01a8:
            r0 = r40;
            r10 = com.wireme.mediaserver.HttpServer.this;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r14 = r8;
            r15 = r9;
            r33 = r10.serve(r11, r12, r13, r14, r15);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x01b2:
            r32 = 0;
            r8 = 0;
            r13 = 0;
            r9 = 0;
            r6 = 0;
            if (r29 == 0) goto L_0x0020;
        L_0x01ba:
            if (r33 != 0) goto L_0x0235;
        L_0x01bc:
            r4 = "500 Internal Server Error";
            r10 = "SERVER INTERNAL ERROR: Serve() returned a null response.";
            r0 = r40;
            r0.sendError(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x01c5:
            r7.close();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r33 = 0;
            r4 = "get";
            r4 = r12.equalsIgnoreCase(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x0020;
        L_0x01d2:
            r4 = "ui2f";
            r10 = "httpd_return #2";
            android.util.Log.d(r4, r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x0055;
        L_0x01db:
            r27 = move-exception;
            r27.printStackTrace();
            goto L_0x001f;
        L_0x01e1:
            r23 = move-exception;
            r23.printStackTrace();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x00c1;
        L_0x01e7:
            r27 = move-exception;
            r27.printStackTrace();
            goto L_0x001f;
        L_0x01ed:
            r31 = "";
            r4 = 512; // 0x200 float:7.175E-43 double:2.53E-321;
            r0 = new char[r4];	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r30 = r0;
            r0 = r30;
            r34 = r7.read(r0);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
        L_0x01fb:
            if (r34 < 0) goto L_0x0207;
        L_0x01fd:
            r4 = "\r\n";
            r0 = r31;
            r4 = r0.endsWith(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x0214;
        L_0x0207:
            r31 = r31.trim();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r1 = r31;
            r0.decodeParms(r1, r8);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x018e;
        L_0x0214:
            r4 = new java.lang.StringBuilder;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r10 = java.lang.String.valueOf(r31);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4.<init>(r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r10 = 0;
            r0 = r30;
            r1 = r34;
            r10 = java.lang.String.valueOf(r0, r10, r1);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r4 = r4.append(r10);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r31 = r4.toString();	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r30;
            r34 = r7.read(r0);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x01fb;
        L_0x0235:
            r4 = "POST";
            r4 = r12.equalsIgnoreCase(r4);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            if (r4 == 0) goto L_0x0251;
        L_0x023d:
            r0 = r33;
            r4 = r0.status;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r33;
            r10 = r0.mimeType;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r33;
            r14 = r0.header;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r15 = 0;
            r0 = r40;
            r0.sendResponse(r4, r10, r14, r15);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x01c5;
        L_0x0251:
            r0 = r33;
            r4 = r0.status;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r33;
            r10 = r0.mimeType;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r33;
            r14 = r0.header;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r33;
            r15 = r0.data;	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            r0 = r40;
            r0.sendResponse(r4, r10, r14, r15);	 Catch:{ IOException -> 0x0064, InterruptedException -> 0x01db, NullPointerException -> 0x01e7 }
            goto L_0x01c5;
        L_0x0268:
            r4 = move-exception;
            goto L_0x00e8;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.wireme.mediaserver.HttpServer.HTTPSession.run():void");
        }

        private void decodeHeader(BufferedReader in, Properties pre, Properties parms, Properties header) throws InterruptedException {
            try {
                String inLine = in.readLine();
                if (inLine != null && !inLine.trim().isEmpty()) {
                    StringTokenizer st = new StringTokenizer(inLine);
                    if (!st.hasMoreTokens()) {
                        Log.d("ui2http", "HTTP_BADREQUEST:" + inLine);
                        sendError(HttpServer.HTTP_BADREQUEST, "BAD REQUEST: Syntax error. Usage: GET /example/file.html");
                    }
                    pre.put("method", st.nextToken());
                    if (!st.hasMoreTokens()) {
                        Log.d("ui2http", "HTTP_BADREQUEST:" + inLine);
                        sendError(HttpServer.HTTP_BADREQUEST, "BAD REQUEST: Missing URI. Usage: GET /example/file.html");
                    }
                    String uri = st.nextToken();
                    int qmi = uri.indexOf(63);
                    if (qmi >= 0) {
                        decodeParms(uri.substring(qmi + 1), parms);
                        uri = decodePercent(uri.substring(0, qmi));
                    } else {
                        uri = decodePercent(uri);
                    }
                    if (st.hasMoreTokens()) {
                        String line = in.readLine();
                        while (line != null && line.trim().length() > 0) {
                            int p = line.indexOf(58);
                            if (p >= 0) {
                                header.put(line.substring(0, p).trim().toLowerCase(), line.substring(p + 1).trim());
                            }
                            line = in.readLine();
                        }
                    }
                    pre.put("uri", uri);
                }
            } catch (IOException ioe) {
                sendError(HttpServer.HTTP_INTERNALERROR, "SERVER INTERNAL ERROR: IOException: " + ioe.getMessage());
            }
        }

        private void decodeMultipartData(String boundary, byte[] fbuf, BufferedReader in, Properties parms, Properties files) throws InterruptedException {
            try {
                int[] bpositions = getBoundaryPositions(fbuf, boundary.getBytes());
                int boundarycount = 1;
                String mpline = in.readLine();
                while (mpline != null) {
                    int p;
                    if (mpline.indexOf(boundary) == -1) {
                        sendError(HttpServer.HTTP_BADREQUEST, "BAD REQUEST: Content type is multipart/form-data but next chunk does not start with boundary. Usage: GET /example/file.html");
                    }
                    boundarycount++;
                    Properties item = new Properties();
                    mpline = in.readLine();
                    while (mpline != null && mpline.trim().length() > 0) {
                        p = mpline.indexOf(58);
                        if (p != -1) {
                            item.put(mpline.substring(0, p).trim().toLowerCase(), mpline.substring(p + 1).trim());
                        }
                        mpline = in.readLine();
                    }
                    if (mpline != null) {
                        String contentDisposition = item.getProperty("content-disposition");
                        if (contentDisposition == null) {
                            sendError(HttpServer.HTTP_BADREQUEST, "BAD REQUEST: Content type is multipart/form-data but no content-disposition info found. Usage: GET /example/file.html");
                        }
                        StringTokenizer st = new StringTokenizer(contentDisposition, "; ");
                        Properties disposition = new Properties();
                        while (st.hasMoreTokens()) {
                            String token = st.nextToken();
                            p = token.indexOf(61);
                            if (p != -1) {
                                disposition.put(token.substring(0, p).trim().toLowerCase(), token.substring(p + 1).trim());
                            }
                        }
                        String pname = disposition.getProperty("name");
                        pname = pname.substring(1, pname.length() - 1);
                        String value = EXTHeader.DEFAULT_VALUE;
                        if (item.getProperty("content-type") != null) {
                            if (boundarycount > bpositions.length) {
                                sendError(HttpServer.HTTP_INTERNALERROR, "Error processing request");
                            }
                            int offset = stripMultipartHeaders(fbuf, bpositions[boundarycount - 2]);
                            files.put(pname, saveTmpFile(fbuf, offset, (bpositions[boundarycount - 1] - offset) - 4));
                            value = disposition.getProperty("filename");
                            value = value.substring(1, value.length() - 1);
                            do {
                                mpline = in.readLine();
                                if (mpline == null) {
                                    break;
                                }
                            } while (mpline.indexOf(boundary) == -1);
                        } else {
                            while (mpline != null && mpline.indexOf(boundary) == -1) {
                                mpline = in.readLine();
                                if (mpline != null) {
                                    int d = mpline.indexOf(boundary);
                                    if (d == -1) {
                                        value = new StringBuilder(String.valueOf(value)).append(mpline).toString();
                                    } else {
                                        value = new StringBuilder(String.valueOf(value)).append(mpline.substring(0, d - 2)).toString();
                                    }
                                }
                            }
                        }
                        parms.put(pname, value);
                    }
                }
            } catch (IOException ioe) {
                sendError(HttpServer.HTTP_INTERNALERROR, "SERVER INTERNAL ERROR: IOException: " + ioe.getMessage());
            }
        }

        public int[] getBoundaryPositions(byte[] b, byte[] boundary) {
            int matchcount = 0;
            int matchbyte = -1;
            Vector matchbytes = new Vector();
            int i = 0;
            while (i < b.length) {
                if (b[i] == boundary[matchcount]) {
                    if (matchcount == 0) {
                        matchbyte = i;
                    }
                    matchcount++;
                    if (matchcount == boundary.length) {
                        matchbytes.addElement(new Integer(matchbyte));
                        matchcount = 0;
                        matchbyte = -1;
                    }
                } else {
                    i -= matchcount;
                    matchcount = 0;
                    matchbyte = -1;
                }
                i++;
            }
            int[] ret = new int[matchbytes.size()];
            for (i = 0; i < ret.length; i++) {
                ret[i] = ((Integer) matchbytes.elementAt(i)).intValue();
            }
            return ret;
        }

        private String saveTmpFile(byte[] b, int offset, int len) {
            String path = EXTHeader.DEFAULT_VALUE;
            if (len > 0) {
                try {
                    File temp = File.createTempFile("NanoHTTPD", EXTHeader.DEFAULT_VALUE, new File(System.getProperty("java.io.tmpdir")));
                    OutputStream fstream = new FileOutputStream(temp);
                    fstream.write(b, offset, len);
                    fstream.close();
                    path = temp.getAbsolutePath();
                } catch (Exception e) {
                    System.err.println("Error: " + e.getMessage());
                }
            }
            return path;
        }

        private int stripMultipartHeaders(byte[] b, int offset) {
            int i = offset;
            while (i < b.length) {
                if (b[i] == (byte) 13) {
                    i++;
                    if (b[i] == (byte) 10) {
                        i++;
                        if (b[i] == (byte) 13) {
                            i++;
                            if (b[i] == (byte) 10) {
                                break;
                            }
                        } else {
                            continue;
                        }
                    } else {
                        continue;
                    }
                }
                i++;
            }
            return i + 1;
        }

        private String decodePercent(String str) throws InterruptedException {
            String decoded = null;
            try {
                decoded = URLDecoder.decode(str, "UTF8");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            return decoded;
        }

        private void decodeParms(String parms, Properties p) throws InterruptedException {
            if (parms != null) {
                StringTokenizer st = new StringTokenizer(parms, "&");
                while (st.hasMoreTokens()) {
                    String e = st.nextToken();
                    int sep = e.indexOf(61);
                    if (sep >= 0) {
                        p.put(decodePercent(e.substring(0, sep)).trim(), decodePercent(e.substring(sep + 1)));
                    }
                }
            }
        }

        private void sendError(String status, String msg) throws InterruptedException {
            sendResponse(status, HttpServer.MIME_PLAINTEXT, null, new ByteArrayInputStream(msg.getBytes()));
            throw new InterruptedException();
        }

        public long unsigned32(int n) {
            return ((long) n) & 4294967295L;
        }

        /* JADX WARNING: inconsistent code. */
        /* Code decompiled incorrectly, please refer to instructions dump. */
        private void sendResponse(java.lang.String r17, java.lang.String r18, java.util.Properties r19, java.io.InputStream r20) {
            /*
            r16 = this;
            if (r17 != 0) goto L_0x0013;
        L_0x0002:
            r12 = new java.lang.Error;	 Catch:{ IOException -> 0x000a }
            r13 = "sendResponse(): Status can't be null.";
            r12.<init>(r13);	 Catch:{ IOException -> 0x000a }
            throw r12;	 Catch:{ IOException -> 0x000a }
        L_0x000a:
            r4 = move-exception;
            r0 = r16;
            r12 = r0.mySocket;	 Catch:{ Throwable -> 0x0110 }
            r12.close();	 Catch:{ Throwable -> 0x0110 }
        L_0x0012:
            return;
        L_0x0013:
            r0 = r16;
            r12 = r0.m_out;	 Catch:{ IOException -> 0x000a }
            if (r12 != 0) goto L_0x0025;
        L_0x0019:
            r0 = r16;
            r12 = r0.mySocket;	 Catch:{ IOException -> 0x000a }
            r12 = r12.getOutputStream();	 Catch:{ IOException -> 0x000a }
            r0 = r16;
            r0.m_out = r12;	 Catch:{ IOException -> 0x000a }
        L_0x0025:
            r0 = r16;
            r6 = r0.m_out;	 Catch:{ IOException -> 0x000a }
            r7 = new java.io.PrintWriter;	 Catch:{ IOException -> 0x000a }
            r7.<init>(r6);	 Catch:{ IOException -> 0x000a }
            r12 = new java.lang.StringBuilder;	 Catch:{ IOException -> 0x000a }
            r13 = "HTTP/1.0 ";
            r12.<init>(r13);	 Catch:{ IOException -> 0x000a }
            r0 = r17;
            r12 = r12.append(r0);	 Catch:{ IOException -> 0x000a }
            r13 = " \r\n";
            r12 = r12.append(r13);	 Catch:{ IOException -> 0x000a }
            r12 = r12.toString();	 Catch:{ IOException -> 0x000a }
            r7.print(r12);	 Catch:{ IOException -> 0x000a }
            if (r18 == 0) goto L_0x0064;
        L_0x004a:
            r12 = new java.lang.StringBuilder;	 Catch:{ IOException -> 0x000a }
            r13 = "Content-Type: ";
            r12.<init>(r13);	 Catch:{ IOException -> 0x000a }
            r0 = r18;
            r12 = r12.append(r0);	 Catch:{ IOException -> 0x000a }
            r13 = "\r\n";
            r12 = r12.append(r13);	 Catch:{ IOException -> 0x000a }
            r12 = r12.toString();	 Catch:{ IOException -> 0x000a }
            r7.print(r12);	 Catch:{ IOException -> 0x000a }
        L_0x0064:
            if (r19 == 0) goto L_0x0070;
        L_0x0066:
            r12 = "Date";
            r0 = r19;
            r12 = r0.getProperty(r12);	 Catch:{ IOException -> 0x000a }
            if (r12 != 0) goto L_0x0095;
        L_0x0070:
            r12 = new java.lang.StringBuilder;	 Catch:{ IOException -> 0x000a }
            r13 = "Date: ";
            r12.<init>(r13);	 Catch:{ IOException -> 0x000a }
            r13 = com.wireme.mediaserver.HttpServer.gmtFrmt;	 Catch:{ IOException -> 0x000a }
            r14 = new java.util.Date;	 Catch:{ IOException -> 0x000a }
            r14.<init>();	 Catch:{ IOException -> 0x000a }
            r13 = r13.format(r14);	 Catch:{ IOException -> 0x000a }
            r12 = r12.append(r13);	 Catch:{ IOException -> 0x000a }
            r13 = "\r\n";
            r12 = r12.append(r13);	 Catch:{ IOException -> 0x000a }
            r12 = r12.toString();	 Catch:{ IOException -> 0x000a }
            r7.print(r12);	 Catch:{ IOException -> 0x000a }
        L_0x0095:
            if (r19 == 0) goto L_0x00a1;
        L_0x0097:
            r3 = r19.keys();	 Catch:{ IOException -> 0x000a }
        L_0x009b:
            r12 = r3.hasMoreElements();	 Catch:{ IOException -> 0x000a }
            if (r12 != 0) goto L_0x00c9;
        L_0x00a1:
            r12 = "\r\n";
            r7.print(r12);	 Catch:{ IOException -> 0x000a }
            r7.flush();	 Catch:{ IOException -> 0x000a }
            if (r20 == 0) goto L_0x00bf;
        L_0x00ab:
            r12 = r20.available();	 Catch:{ IOException -> 0x000a }
            r0 = r16;
            r8 = r0.unsigned32(r12);	 Catch:{ IOException -> 0x000a }
            r12 = 2048; // 0x800 float:2.87E-42 double:1.0118E-320;
            r2 = new byte[r12];	 Catch:{ IOException -> 0x000a }
        L_0x00b9:
            r12 = 0;
            r12 = (r8 > r12 ? 1 : (r8 == r12 ? 0 : -1));
            if (r12 > 0) goto L_0x00f6;
        L_0x00bf:
            r6.flush();	 Catch:{ IOException -> 0x000a }
            if (r20 == 0) goto L_0x0012;
        L_0x00c4:
            r20.close();	 Catch:{ IOException -> 0x000a }
            goto L_0x0012;
        L_0x00c9:
            r5 = r3.nextElement();	 Catch:{ IOException -> 0x000a }
            r5 = (java.lang.String) r5;	 Catch:{ IOException -> 0x000a }
            r0 = r19;
            r11 = r0.getProperty(r5);	 Catch:{ IOException -> 0x000a }
            r12 = new java.lang.StringBuilder;	 Catch:{ IOException -> 0x000a }
            r13 = java.lang.String.valueOf(r5);	 Catch:{ IOException -> 0x000a }
            r12.<init>(r13);	 Catch:{ IOException -> 0x000a }
            r13 = ": ";
            r12 = r12.append(r13);	 Catch:{ IOException -> 0x000a }
            r12 = r12.append(r11);	 Catch:{ IOException -> 0x000a }
            r13 = "\r\n";
            r12 = r12.append(r13);	 Catch:{ IOException -> 0x000a }
            r12 = r12.toString();	 Catch:{ IOException -> 0x000a }
            r7.print(r12);	 Catch:{ IOException -> 0x000a }
            goto L_0x009b;
        L_0x00f6:
            r13 = 0;
            r14 = 2048; // 0x800 float:2.87E-42 double:1.0118E-320;
            r12 = (r8 > r14 ? 1 : (r8 == r14 ? 0 : -1));
            if (r12 <= 0) goto L_0x010e;
        L_0x00fd:
            r12 = 2048; // 0x800 float:2.87E-42 double:1.0118E-320;
        L_0x00ff:
            r0 = r20;
            r10 = r0.read(r2, r13, r12);	 Catch:{ IOException -> 0x000a }
            if (r10 <= 0) goto L_0x00bf;
        L_0x0107:
            r12 = 0;
            r6.write(r2, r12, r10);	 Catch:{ IOException -> 0x000a }
            r12 = (long) r10;
            r8 = r8 - r12;
            goto L_0x00b9;
        L_0x010e:
            r12 = (int) r8;
            goto L_0x00ff;
        L_0x0110:
            r12 = move-exception;
            goto L_0x0012;
            */
            throw new UnsupportedOperationException("Method not decompiled: com.wireme.mediaserver.HttpServer.HTTPSession.sendResponse(java.lang.String, java.lang.String, java.util.Properties, java.io.InputStream):void");
        }
    }

    public class Response {
        public InputStream data;
        public Properties header;
        public String mimeType;
        public String status;

        public Response() {
            this.header = new Properties();
            this.status = HttpServer.HTTP_OK;
        }

        public Response(String status, String mimeType, InputStream data) {
            this.header = new Properties();
            this.status = status;
            this.mimeType = mimeType;
            this.data = data;
        }

        public Response(String status, String mimeType, String txt) {
            this.header = new Properties();
            this.status = status;
            this.mimeType = mimeType;
            try {
                this.data = new ByteArrayInputStream(txt.getBytes("UTF-8"));
            } catch (UnsupportedEncodingException uee) {
                uee.printStackTrace();
            }
        }

        public void addHeader(String name, String value) {
            this.header.put(name, value);
        }
    }

    private static String readLine(InputStream r) throws IOException {
        StringBuffer sb = new StringBuffer();
        int nFind = 0;
        while (true) {
            String strTmp;
            String strTmpStart;
            int c = r.read();
            switch (c) {
                case -1:
                    break;
                case 10:
                    if (nFind == 1 || nFind == 3) {
                        nFind++;
                    }
                    sb.append((char) c);
                    if (nFind == 4) {
                        strTmp = new String(sb.toString().trim());
                        if (strTmp.length() <= 3) {
                            nFind = 0;
                            sb = new StringBuffer();
                            break;
                        }
                        strTmpStart = strTmp.substring(0, 3);
                        if (!(strTmpStart.equalsIgnoreCase("PUT") || strTmpStart.equalsIgnoreCase("GET"))) {
                            Log.d("ui2http", "Parse Wrong!!:" + strTmpStart);
                            return null;
                        }
                    }
                    continue;
                case 13:
                    if (nFind == 0 || nFind == 2) {
                        nFind++;
                    }
                    sb.append((char) c);
                    continue;
                default:
                    nFind = 0;
                    sb.append((char) c);
                    continue;
            }
            strTmp = new String(sb.toString());
            if (strTmp.length() > 3) {
                strTmpStart = strTmp.substring(0, 3);
                if (!(strTmpStart.equalsIgnoreCase("PUT") || strTmpStart.equalsIgnoreCase("GET"))) {
                    int nPos = strTmp.indexOf("PUT");
                    if (nPos < 0) {
                        nPos = strTmp.indexOf("put");
                        if (nPos < 0) {
                            nPos = strTmp.indexOf("GET");
                            if (nPos < 0) {
                                nPos = strTmp.indexOf("get");
                            }
                        }
                    }
                    if (nPos > 0) {
                        Log.d("ui2http", "Parse Wrong!! but, Has Method -_____-++ => " + strTmp);
                        strTmp = strTmp.substring(nPos);
                        int nPos2 = strTmp.indexOf("\r\n\r\n");
                        if (nPos2 > 0) {
                            strTmp = strTmp.substring(0, nPos2);
                        }
                        Log.d("ui2http", "Parse Wrong2!! ==> " + strTmp);
                        return strTmp;
                    } else if (nPos < 0) {
                        Log.d("ui2http", "Parse Wrong!! but, Has Method -_____-++ => " + strTmp);
                        return null;
                    }
                }
            }
            return sb.toString();
        }
    }

    public static int safeLongToInt(long l) {
        if ((l & LONG_HIGH_BITS) == 0 || (l & LONG_HIGH_BITS) == LONG_HIGH_BITS) {
            return (int) l;
        }
        throw new IllegalArgumentException("...");
    }

    public File getfSDPath() {
        return Environment.getExternalStorageDirectory();
    }

    public String getstrDLPath() {
        String strSD = new StringBuilder(String.valueOf(Environment.getExternalStorageDirectory().getAbsolutePath())).append("/Download/").toString();
        return ContentTree.GetPLHome();
    }

    public String getstrTPath() {
        return new StringBuilder(String.valueOf(Environment.getExternalStorageDirectory().toString())).append("/bcoda_tmp").toString();
    }

    public void mkTDir() {
        File fNewFolder = new File(getstrTPath());
        if (!fNewFolder.exists()) {
            fNewFolder.mkdirs();
        }
    }

    public void rmTDir() {
        File fNewFolder = new File(getstrTPath());
        if (fNewFolder.exists() && fNewFolder.isDirectory()) {
            String[] children = fNewFolder.list();
            for (String file : children) {
                new File(fNewFolder, file).delete();
            }
        }
    }

    public Response internalFileRename(Properties header) {
        String newUri;
        String itemId;
        ContentNode node;
        int nPos;
        String oldFileName = header.getProperty("filename");
        String fileName = header.getProperty("newfilename");
        String strRes = header.getProperty("resource");
        String strnewRes = header.getProperty("newresource");
        String strDir = EXTHeader.DEFAULT_VALUE;
        String strNewDir = EXTHeader.DEFAULT_VALUE;
        if (strRes.isEmpty() || strRes.compareTo("NONE") != 0) {
            newUri = EXTHeader.DEFAULT_VALUE;
            itemId = strRes;
            if (itemId.compareTo("DOWNLOAD") == 0) {
                strDir = getstrDLPath();
            } else if (ContentTree.hasNode(itemId)) {
                node = ContentTree.getNode(itemId);
                if (node.isItem()) {
                    newUri = node.getFullPath();
                    nPos = newUri.lastIndexOf(ServiceReference.DELIMITER);
                    if (nPos > 0) {
                        strDir = newUri.substring(0, nPos);
                    } else {
                        strDir = newUri;
                    }
                }
            } else {
                strDir = getstrDLPath();
            }
        } else {
            strDir = getstrTPath();
        }
        if (strnewRes.isEmpty() || strnewRes.compareTo("NONE") != 0) {
            newUri = EXTHeader.DEFAULT_VALUE;
            itemId = strnewRes;
            if (itemId.compareTo("DOWNLOAD") == 0) {
                strNewDir = getstrDLPath();
            } else if (ContentTree.hasNode(itemId)) {
                node = ContentTree.getNode(itemId);
                if (node.isItem()) {
                    newUri = node.getFullPath();
                    nPos = newUri.lastIndexOf(ServiceReference.DELIMITER);
                    if (nPos > 0) {
                        strNewDir = newUri.substring(0, nPos);
                    } else {
                        strNewDir = newUri;
                    }
                }
            } else {
                strNewDir = getstrDLPath();
            }
        } else {
            strNewDir = getstrTPath();
        }
        Log.d("ui2f", "ifRename:" + strRes + ":" + strDir + File.separator + oldFileName + "=>" + ":" + strnewRes + ":" + strNewDir + File.separator + fileName);
        boolean success = new File(strDir, oldFileName).renameTo(new File(strNewDir, fileName));
        Response res = new Response();
        if (res != null) {
            res.status = success ? HTTP_OK : HTTP_NOTFOUND;
        }
        return res;
    }

    public Response internalFileMove(Properties header) {
        FileNotFoundException e;
        ArrayIndexOutOfBoundsException e2;
        IOException e3;
        NullPointerException e4;
        Throwable th;
        Response response;
        mkTDir();
        long pos = 0;
        String strRes = header.getProperty("resource");
        String fileName = EXTHeader.DEFAULT_VALUE;
        String oldFileName = getstrTPath() + File.separator + header.getProperty("contentfilename");
        String strPos = header.getProperty("pos");
        if (strRes.isEmpty() || strRes.compareTo("NONE") != 0) {
            String newUri = EXTHeader.DEFAULT_VALUE;
            String itemId = strRes;
            if (itemId.compareTo("DOWNLOAD") == 0) {
                fileName = getstrDLPath() + header.getProperty("filename");
            } else if (ContentTree.hasNode(itemId)) {
                ContentNode node = ContentTree.getNode(itemId);
                if (node.isItem()) {
                    newUri = node.getFullPath();
                    int nPos = newUri.lastIndexOf(ServiceReference.DELIMITER);
                    if (nPos > 0) {
                        fileName = newUri.substring(0, nPos + 1) + header.getProperty("filename");
                    } else {
                        fileName = newUri;
                    }
                }
            } else {
                fileName = getstrDLPath() + header.getProperty("filename");
            }
        } else {
            fileName = getstrTPath() + File.separator + header.getProperty("filename");
        }
        Log.d("ui2f", "ifMove:" + strRes + ":" + oldFileName + "=>" + fileName);
        long startFrom = 0;
        long endAt = -1;
        String range = header.getProperty("range");
        if (range != null && range.startsWith("bytes=")) {
            range = range.substring("bytes=".length());
            int minus = range.indexOf(45);
            if (minus > 0) {
                try {
                    startFrom = Long.parseLong(range.substring(0, minus));
                    endAt = Long.parseLong(range.substring(minus + 1));
                    pos = Long.parseLong(strPos);
                } catch (NumberFormatException e5) {
                }
            }
        }
        boolean enable = false;
        RandomAccessFile fileSrc = null;
        RandomAccessFile file = null;
        long count = endAt - startFrom;
        byte[] data = new byte[((int) 500000)];
        try {
            RandomAccessFile fileSrc2 = new RandomAccessFile(oldFileName, "r");
            try {
                RandomAccessFile file2 = new RandomAccessFile(fileName, "rw");
                long nTmpPos = pos;
                try {
                    fileSrc2.seek(startFrom);
                    file2.seek(nTmpPos);
                    do {
                        long nTmpcount = 500000;
                        if (count < nTmpcount) {
                            nTmpcount = count;
                        }
                        int nResRead = fileSrc2.read(data, 0, safeLongToInt(nTmpcount));
                        if (nResRead <= 0) {
                            Log.d("ui2fe", "Failed to read file " + oldFileName);
                            break;
                        }
                        file2.write(data, 0, nResRead);
                        count -= (long) nResRead;
                    } while (count > 0);
                    enable = true;
                    if (fileSrc2 != null) {
                        try {
                            fileSrc2.close();
                        } catch (IOException e6) {
                        }
                    }
                    if (file2 != null) {
                        try {
                            file2.close();
                        } catch (IOException e7) {
                        }
                    } else {
                        file = file2;
                    }
                } catch (FileNotFoundException e8) {
                    e = e8;
                    file = file2;
                    fileSrc = fileSrc2;
                } catch (ArrayIndexOutOfBoundsException e9) {
                    e2 = e9;
                    file = file2;
                    fileSrc = fileSrc2;
                } catch (IOException e10) {
                    e3 = e10;
                    file = file2;
                    fileSrc = fileSrc2;
                } catch (NullPointerException e11) {
                    e4 = e11;
                    file = file2;
                    fileSrc = fileSrc2;
                } catch (Throwable th2) {
                    th = th2;
                    file = file2;
                    fileSrc = fileSrc2;
                }
            } catch (FileNotFoundException e12) {
                e = e12;
                fileSrc = fileSrc2;
                try {
                    e.printStackTrace();
                    if (fileSrc != null) {
                        try {
                            fileSrc.close();
                        } catch (IOException e13) {
                        }
                    }
                    if (file != null) {
                        try {
                            file.close();
                        } catch (IOException e14) {
                        }
                    }
                    Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
                    response = new Response();
                    if (response != null) {
                        response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
                    }
                    return response;
                } catch (Throwable th3) {
                    th = th3;
                    if (fileSrc != null) {
                        try {
                            fileSrc.close();
                        } catch (IOException e15) {
                        }
                    }
                    if (file != null) {
                        try {
                            file.close();
                        } catch (IOException e16) {
                        }
                    }
                    throw th;
                }
            } catch (ArrayIndexOutOfBoundsException e17) {
                e2 = e17;
                fileSrc = fileSrc2;
                e2.printStackTrace();
                Log.d("ui2fe", "startFrom:" + Long.valueOf(startFrom).toString() + " count:" + Long.valueOf(count).toString());
                if (fileSrc != null) {
                    try {
                        fileSrc.close();
                    } catch (IOException e18) {
                    }
                }
                if (file != null) {
                    try {
                        file.close();
                    } catch (IOException e19) {
                    }
                }
                Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
                response = new Response();
                if (response != null) {
                    if (enable) {
                    }
                    response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
                }
                return response;
            } catch (IOException e20) {
                e3 = e20;
                fileSrc = fileSrc2;
                enable = false;
                e3.printStackTrace();
                if (fileSrc != null) {
                    try {
                        fileSrc.close();
                    } catch (IOException e21) {
                    }
                }
                if (file != null) {
                    try {
                        file.close();
                    } catch (IOException e22) {
                    }
                }
                Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
                response = new Response();
                if (response != null) {
                    if (enable) {
                    }
                    response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
                }
                return response;
            } catch (NullPointerException e23) {
                e4 = e23;
                fileSrc = fileSrc2;
                e4.printStackTrace();
                if (fileSrc != null) {
                    try {
                        fileSrc.close();
                    } catch (IOException e24) {
                    }
                }
                if (file != null) {
                    try {
                        file.close();
                    } catch (IOException e25) {
                    }
                }
                Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
                response = new Response();
                if (response != null) {
                    if (enable) {
                    }
                    response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
                }
                return response;
            } catch (Throwable th4) {
                th = th4;
                fileSrc = fileSrc2;
                if (fileSrc != null) {
                    fileSrc.close();
                }
                if (file != null) {
                    file.close();
                }
                throw th;
            }
        } catch (FileNotFoundException e26) {
            e = e26;
            e.printStackTrace();
            if (fileSrc != null) {
                fileSrc.close();
            }
            if (file != null) {
                file.close();
            }
            Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
            response = new Response();
            if (response != null) {
                if (enable) {
                }
                response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
            }
            return response;
        } catch (ArrayIndexOutOfBoundsException e27) {
            e2 = e27;
            e2.printStackTrace();
            Log.d("ui2fe", "startFrom:" + Long.valueOf(startFrom).toString() + " count:" + Long.valueOf(count).toString());
            if (fileSrc != null) {
                fileSrc.close();
            }
            if (file != null) {
                file.close();
            }
            Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
            response = new Response();
            if (response != null) {
                if (enable) {
                }
                response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
            }
            return response;
        } catch (IOException e28) {
            e3 = e28;
            enable = false;
            e3.printStackTrace();
            if (fileSrc != null) {
                fileSrc.close();
            }
            if (file != null) {
                file.close();
            }
            Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
            response = new Response();
            if (response != null) {
                if (enable) {
                }
                response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
            }
            return response;
        } catch (NullPointerException e29) {
            e4 = e29;
            e4.printStackTrace();
            if (fileSrc != null) {
                fileSrc.close();
            }
            if (file != null) {
                file.close();
            }
            Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
            response = new Response();
            if (response != null) {
                if (enable) {
                }
                response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
            }
            return response;
        }
        Log.d("ui2fn", "ifMove:" + strRes + ":" + fileName + ":startFrom:" + Long.valueOf(startFrom).toString() + ":count:" + Long.valueOf(count).toString() + ":data len:" + Long.valueOf((long) data.length).toString());
        response = new Response();
        if (response != null) {
            if (enable) {
            }
            response.status = enable ? HTTP_NOTFOUND : HTTP_OK;
        }
        return response;
    }

    public Response internalFileDelete(Properties header) {
        String fileName = EXTHeader.DEFAULT_VALUE;
        String strRes = header.getProperty("resource");
        if (strRes.isEmpty() || strRes.compareTo("NONE") != 0) {
            String newUri = EXTHeader.DEFAULT_VALUE;
            String itemId = strRes;
            if (itemId.compareTo("DOWNLOAD") == 0) {
                fileName = getstrDLPath() + header.getProperty("filename");
            } else if (ContentTree.hasNode(itemId)) {
                ContentNode node = ContentTree.getNode(itemId);
                if (node.isItem()) {
                    newUri = node.getFullPath();
                    int nPos = newUri.lastIndexOf(ServiceReference.DELIMITER);
                    if (nPos > 0) {
                        fileName = newUri.substring(0, nPos + 1) + header.getProperty("filename");
                    } else {
                        fileName = newUri;
                    }
                }
            } else {
                fileName = getstrDLPath() + header.getProperty("filename");
            }
        } else {
            fileName = getstrTPath() + File.separator + header.getProperty("filename");
        }
        Log.d("ui2fhttp", "ifDelete:" + strRes + ":" + fileName);
        Response res = new Response();
        if (res != null) {
            res.status = true ? HTTP_OK : HTTP_NOTFOUND;
        }
        return res;
    }

    public Response internalFileDeleteUnkown(Properties header) {
        boolean enable = true;
        String fileName = EXTHeader.DEFAULT_VALUE;
        String strcmp = EXTHeader.DEFAULT_VALUE;
        strcmp = header.getProperty("filename");
        String strRes = header.getProperty("resource");
        if (!strRes.isEmpty() && strRes.compareTo("NONE") == 0 && strcmp.startsWith("unknown-")) {
            fileName = getstrTPath() + File.separator + strcmp;
            File file = new File(fileName);
            enable = false;
            if (file != null) {
                enable = file.delete();
            }
            Log.d("ui2f", "ifDelete:" + strRes + ":" + fileName);
        }
        Response res = new Response();
        if (res != null) {
            res.status = enable ? HTTP_OK : HTTP_NOTFOUND;
        }
        return res;
    }

    public Response internalFileWrite(Properties header, byte[] data) {
        String strHex;
        Response response;
        Throwable th;
        mkTDir();
        RandomAccessFile file = null;
        String fileName = EXTHeader.DEFAULT_VALUE;
        long size = Long.MAX_VALUE;
        String contentLength = header.getProperty("content-length");
        String strRes = header.getProperty("resource");
        if (contentLength != null) {
            try {
                size = (long) Integer.parseInt(contentLength);
            } catch (NumberFormatException e) {
            }
        }
        if (size != ((long) data.length)) {
            Log.d("ui2fn", "ifWrite:size:" + Long.valueOf(size).toString() + "data len:" + Long.valueOf((long) data.length).toString());
            return null;
        }
        long startFrom = 0;
        String range = header.getProperty("range");
        if (range != null && range.startsWith("bytes=")) {
            range = range.substring("bytes=".length());
            int minus = range.indexOf(45);
            if (minus > 0) {
                try {
                    startFrom = Long.parseLong(range.substring(0, minus));
                    long endAt = Long.parseLong(range.substring(minus + 1));
                } catch (NumberFormatException e2) {
                }
            }
        }
        if (strRes.isEmpty() || strRes.compareTo("NONE") != 0) {
            String newUri = EXTHeader.DEFAULT_VALUE;
            String itemId = strRes;
            if (itemId.compareTo("DOWNLOAD") == 0) {
                fileName = getstrDLPath() + header.getProperty("filename");
            } else if (ContentTree.hasNode(itemId)) {
                ContentNode node = ContentTree.getNode(itemId);
                if (node.isItem()) {
                    newUri = node.getFullPath();
                    int nPos = newUri.lastIndexOf(ServiceReference.DELIMITER);
                    if (nPos > 0) {
                        fileName = newUri.substring(0, nPos + 1) + header.getProperty("filename");
                    } else {
                        fileName = newUri;
                    }
                }
            } else {
                fileName = getstrDLPath() + header.getProperty("filename");
            }
        } else {
            fileName = getstrTPath() + File.separator + header.getProperty("filename");
        }
        boolean enable = true;
        try {
            if (fileName.getBytes().length > 255) {
                enable = false;
            } else {
                RandomAccessFile file2 = new RandomAccessFile(fileName, "rw");
                try {
                    file2.seek(startFrom);
                    file2.write(data, 0, data.length);
                    file = file2;
                } catch (IOException e3) {
                    file = file2;
                    enable = false;
                    if (file != null) {
                        try {
                            file.close();
                        } catch (IOException e4) {
                        }
                    }
                    if (strRes.isEmpty()) {
                        Log.d("ui2f", "ifWrite:ResEmpty:" + fileName);
                    } else {
                        Log.d("ui2f", "ifWrite:" + strRes + ":" + fileName);
                    }
                    strHex = EXTHeader.DEFAULT_VALUE;
                    Log.d("ui2fn", "ifWrite:" + strRes + ":" + fileName + ":range:" + range + ":startFrom:" + Long.valueOf(startFrom).toString() + ":size:" + Long.valueOf(size).toString() + ":data len:" + Long.valueOf((long) data.length).toString() + String.format("D[%02X %02X]", new Object[]{Byte.valueOf(data[0]), Byte.valueOf(data[1])}));
                    response = new Response();
                    if (response != null) {
                        response.status = enable ? HTTP_OK : HTTP_NOTFOUND;
                    }
                    return response;
                } catch (Throwable th2) {
                    th = th2;
                    file = file2;
                    if (file != null) {
                        try {
                            file.close();
                        } catch (IOException e5) {
                        }
                    }
                    throw th;
                }
            }
            if (file != null) {
                try {
                    file.close();
                } catch (IOException e6) {
                }
            }
        } catch (IOException e7) {
            enable = false;
            if (file != null) {
                file.close();
            }
            if (strRes.isEmpty()) {
                Log.d("ui2f", "ifWrite:" + strRes + ":" + fileName);
            } else {
                Log.d("ui2f", "ifWrite:ResEmpty:" + fileName);
            }
            strHex = EXTHeader.DEFAULT_VALUE;
            Log.d("ui2fn", "ifWrite:" + strRes + ":" + fileName + ":range:" + range + ":startFrom:" + Long.valueOf(startFrom).toString() + ":size:" + Long.valueOf(size).toString() + ":data len:" + Long.valueOf((long) data.length).toString() + String.format("D[%02X %02X]", new Object[]{Byte.valueOf(data[0]), Byte.valueOf(data[1])}));
            response = new Response();
            if (response != null) {
                if (enable) {
                }
                response.status = enable ? HTTP_OK : HTTP_NOTFOUND;
            }
            return response;
        } catch (Throwable th3) {
            th = th3;
            if (file != null) {
                file.close();
            }
            throw th;
        }
        if (strRes.isEmpty()) {
            Log.d("ui2f", "ifWrite:ResEmpty:" + fileName);
        } else {
            Log.d("ui2f", "ifWrite:" + strRes + ":" + fileName);
        }
        strHex = EXTHeader.DEFAULT_VALUE;
        Log.d("ui2fn", "ifWrite:" + strRes + ":" + fileName + ":range:" + range + ":startFrom:" + Long.valueOf(startFrom).toString() + ":size:" + Long.valueOf(size).toString() + ":data len:" + Long.valueOf((long) data.length).toString() + String.format("D[%02X %02X]", new Object[]{Byte.valueOf(data[0]), Byte.valueOf(data[1])}));
        response = new Response();
        if (response != null) {
            if (enable) {
            }
            response.status = enable ? HTTP_OK : HTTP_NOTFOUND;
        }
        return response;
    }

    public Response internalFileSize(Properties header) {
        IOException e;
        Response response;
        Throwable th;
        RandomAccessFile file = null;
        long endAt = -1;
        String fileName = header.getProperty("filename");
        String range = header.getProperty("range");
        String strRes = header.getProperty("resource");
        if (range != null && range.startsWith("bytes=")) {
            range = range.substring("bytes=".length());
            int minus = range.indexOf(45);
            if (minus > 0) {
                try {
                    long startFrom = Long.parseLong(range.substring(0, minus));
                    endAt = Long.parseLong(range.substring(minus + 1));
                } catch (NumberFormatException e2) {
                }
            }
        }
        boolean enable = true;
        String strDir = EXTHeader.DEFAULT_VALUE;
        String strsrcDir = EXTHeader.DEFAULT_VALUE;
        if (strRes.isEmpty() || strRes.compareTo("NONE") != 0) {
            String newUri = EXTHeader.DEFAULT_VALUE;
            String itemId = strRes;
            if (itemId.compareTo("DOWNLOAD") == 0) {
                strDir = getstrDLPath();
                strsrcDir = getstrDLPath();
            } else if (ContentTree.hasNode(itemId)) {
                ContentNode node = ContentTree.getNode(itemId);
                if (node.isItem()) {
                    newUri = node.getFullPath();
                    int nPos = newUri.lastIndexOf(ServiceReference.DELIMITER);
                    if (nPos > 0) {
                        strDir = newUri.substring(0, nPos);
                    } else {
                        strDir = newUri;
                    }
                    strsrcDir = strDir;
                }
            } else {
                strDir = getstrDLPath();
                strsrcDir = getstrTPath();
            }
        } else {
            strsrcDir = getstrTPath();
            strDir = getstrDLPath();
        }
        try {
            if (!new File(strsrcDir, fileName).exists()) {
                strsrcDir = getstrTPath();
            }
            RandomAccessFile file2 = new RandomAccessFile(new StringBuilder(String.valueOf(strsrcDir)).append(File.separator).append(fileName).toString(), "rw");
            try {
                String strLen = EXTHeader.DEFAULT_VALUE;
                long nSrcSize = file2.length();
                strLen = new StringBuilder(String.valueOf(Long.valueOf(nSrcSize).toString())).append("=>").toString();
                file2.setLength(endAt);
                Log.d("ui2f", "ifSize:" + new StringBuilder(String.valueOf(strLen)).append(Long.valueOf(nSrcSize).toString()).append("(").append(Long.valueOf(endAt).toString()).append(")").toString());
                if (file2 != null) {
                    try {
                        file2.close();
                    } catch (IOException e3) {
                    }
                }
            } catch (IOException e4) {
                e = e4;
                file = file2;
                try {
                    e.printStackTrace();
                    enable = false;
                    if (file != null) {
                        try {
                            file.close();
                        } catch (IOException e5) {
                        }
                    }
                    Log.d("ui2fhttp", "ifSize:" + strRes + ":" + strsrcDir + File.separator + fileName + ":" + range + "(" + Long.valueOf(endAt).toString() + ")=>" + strDir + File.separator + fileName);
                    response = new Response();
                    if (response != null) {
                        response.status = enable ? HTTP_OK : HTTP_NOTFOUND;
                    }
                    return response;
                } catch (Throwable th2) {
                    th = th2;
                    if (file != null) {
                        try {
                            file.close();
                        } catch (IOException e6) {
                        }
                    }
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                file = file2;
                if (file != null) {
                    file.close();
                }
                throw th;
            }
        } catch (IOException e7) {
            e = e7;
            e.printStackTrace();
            enable = false;
            if (file != null) {
                file.close();
            }
            Log.d("ui2fhttp", "ifSize:" + strRes + ":" + strsrcDir + File.separator + fileName + ":" + range + "(" + Long.valueOf(endAt).toString() + ")=>" + strDir + File.separator + fileName);
            response = new Response();
            if (response != null) {
                if (enable) {
                }
                response.status = enable ? HTTP_OK : HTTP_NOTFOUND;
            }
            return response;
        }
        Log.d("ui2fhttp", "ifSize:" + strRes + ":" + strsrcDir + File.separator + fileName + ":" + range + "(" + Long.valueOf(endAt).toString() + ")=>" + strDir + File.separator + fileName);
        response = new Response();
        if (response != null) {
            if (enable) {
            }
            response.status = enable ? HTTP_OK : HTTP_NOTFOUND;
        }
        return response;
    }

    public Response internalFileRead(Properties header) {
        String range = header.getProperty("range");
        if (range != null && range.startsWith("bytes=")) {
            range = range.substring("bytes=".length());
            int minus = range.indexOf(45);
            if (minus > 0) {
                try {
                    long startFrom = Long.parseLong(range.substring(0, minus));
                    long endAt = Long.parseLong(range.substring(minus + 1));
                } catch (NumberFormatException e) {
                }
            }
        }
        String fileName = header.getProperty("filename");
        String strRes = header.getProperty("resource");
        String str = EXTHeader.DEFAULT_VALUE;
        str = getstrDLPath();
        String strUri = EXTHeader.DEFAULT_VALUE;
        if (!strRes.isEmpty()) {
            if (strRes.compareTo("NONE") == 0) {
                strUri = getstrTPath() + File.separator + fileName;
                Log.d("ui2f", "ifRead:" + strRes + ":" + fileName);
                return serveFile(strUri, header, this.myRootDir, false, false);
            }
        }
        String newUri = EXTHeader.DEFAULT_VALUE;
        String itemId = strRes;
        if (itemId.compareTo("DOWNLOAD") == 0) {
            strUri = getstrDLPath() + header.getProperty("filename");
        } else if (ContentTree.hasNode(itemId)) {
            ContentNode node = ContentTree.getNode(itemId);
            if (node.isItem()) {
                newUri = node.getFullPath();
                strUri = newUri;
                Log.v("ui2f", "uri:" + newUri);
            }
        } else {
            strUri = getstrDLPath() + header.getProperty("filename");
        }
        Log.d("ui2f", "ifRead:" + strRes + ":" + fileName);
        return serveFile(strUri, header, this.myRootDir, false, false);
    }

    public Response serveWrite(String uri, String method, Properties header, byte[] data) {
        Response res = null;
        if (method.equalsIgnoreCase("PUT")) {
            if (uri.equals("/FILE_WRITE")) {
                res = internalFileWrite(header, data);
            } else if (uri.equals("/FILE_RENAME")) {
                res = internalFileRename(header);
            } else if (uri.equals("/FILE_DELETE")) {
                res = internalFileDeleteUnkown(header);
            } else if (uri.equals("/FILE_SIZE")) {
                res = internalFileSize(header);
            } else if (uri.equals("/FILE_MOVE")) {
                res = internalFileMove(header);
            }
            new Intent("cling.android.Router").putExtra("enus", "cmd_hb");
            return res;
        } else if (method.equalsIgnoreCase("GET") && uri.equals("/FILE_READ")) {
            return internalFileRead(header);
        } else {
            return null;
        }
    }

    public String GetFWPath(String strName) {
        String strRes = EXTHeader.DEFAULT_VALUE;
        if (strName.compareTo("upgrade.txt") == 0 || strName.compareTo("jmg.img") == 0 || strName.compareTo("jmg.md5") == 0) {
            return new StringBuilder(String.valueOf(Environment.getExternalStorageDirectory().getAbsolutePath())).append("/bcoda/fw/").append(strName).toString();
        }
        return strRes;
    }

    public Response serve(String uri, String method, Properties header, Properties parms, Properties files) {
        String itemId = uri.replaceFirst(ServiceReference.DELIMITER, EXTHeader.DEFAULT_VALUE);
        String newUri = null;
        if (itemId.indexOf("item") < 0) {
            Log.d("ui2http", "iid:" + itemId);
        }
        if (ContentTree.hasNode(itemId)) {
            ContentNode node = ContentTree.getNode(itemId);
            if (node.isItem()) {
                newUri = node.getFullPath();
                Log.v("http1", newUri);
            } else {
                Log.v("http2", uri);
            }
            if (newUri.startsWith(new StringBuilder(String.valueOf(Environment.getExternalStorageDirectory().getAbsolutePath())).append("/bcoda/fw/").toString())) {
                Log.d("http3", newUri);
                return serveFile(newUri, header, new File(ServiceReference.DELIMITER), false, true);
            }
        }
        String str = EXTHeader.DEFAULT_VALUE;
        str = GetFWPath(itemId);
        if (str.length() > 0) {
            newUri = str;
            Log.d("ACK_FW_H", str);
            return serveFile(newUri, header, new File(ServiceReference.DELIMITER), false, true);
        }
        if (newUri != null) {
            uri = newUri;
        }
        return serveFile(uri, header, this.myRootDir, true, false);
    }

    public HttpServer(int port) throws IOException {
        this.myTcpPort = port;
        this.myRootDir = new File(ServiceReference.DELIMITER);
        this.es = createThreadPool();
        this.myServerSocket = new ServerSocket(this.myTcpPort);
        Thread t = new Thread(new C03771());
        t.setPriority(5);
        t.start();
    }

    public void stop() {
        try {
            this.myServerSocket.close();
            this.myThread.join();
        } catch (IOException e) {
        } catch (InterruptedException e2) {
        }
    }

    public int getPort() {
        return this.myServerSocket.getLocalPort();
    }

    private String encodeUri(String uri) {
        String newUri = EXTHeader.DEFAULT_VALUE;
        StringTokenizer st = new StringTokenizer(uri, "/ ", true);
        while (st.hasMoreTokens()) {
            String tok = st.nextToken();
            if (tok.equals(ServiceReference.DELIMITER)) {
                newUri = new StringBuilder(String.valueOf(newUri)).append(ServiceReference.DELIMITER).toString();
            } else if (tok.equals(" ")) {
                newUri = new StringBuilder(String.valueOf(newUri)).append("%20").toString();
            } else {
                try {
                    newUri = new StringBuilder(String.valueOf(newUri)).append(URLEncoder.encode(tok, "UTF-8")).toString();
                } catch (UnsupportedEncodingException e) {
                    e.printStackTrace();
                }
            }
        }
        return newUri;
    }

    private ExecutorService createThreadPool() {
        this.mThreadPoolExec = new ThreadPoolExecutor(10, 30, 1, TimeUnit.MINUTES, new SynchronousQueue());
        return this.mThreadPoolExec;
    }

    private void handleSession(Socket s) {
        Thread t = new Thread(new HTTPSession(s));
        t.setDaemon(true);
        t.start();
    }

    private void handleSession(Socket s, ExecutorService es) {
        try {
            if (this.mThreadPoolExec != null) {
                Log.d("mztp", "pre-ActiveThread Count:" + Integer.valueOf(this.mThreadPoolExec.getActiveCount()).toString());
            }
            es.execute(new HTTPSession(s));
            if (this.mThreadPoolExec != null) {
                Log.d("mztp", "post-ActiveThread Count:" + Integer.valueOf(this.mThreadPoolExec.getActiveCount()).toString());
            }
        } catch (RejectedExecutionException e) {
            e.printStackTrace();
        }
    }

    public void shutdown() {
        this.shutdown = true;
    }

    public Response serveFile(String uri, Properties header, File homeDir, boolean allowDirectoryListing, boolean isFWUP) {
        Response res;
        String mime;
        int dot;
        long startFrom;
        long endAt;
        String range;
        int minus;
        long fileLen;
        Response response = null;
        String strDLPath = new StringBuilder(String.valueOf(Environment.getExternalStorageDirectory().getAbsolutePath())).append(File.separator).append("DownLoad").append(File.separator).toString();
        String strHomePath = getstrDLPath();
        Log.d("serveFile", "uri:" + uri + " | homeDir:" + homeDir + " | strHomePath:" + strHomePath);
        if (!(strHomePath.compareTo(strDLPath) == 0 || isFWUP)) {
            File file = new File(strHomePath);
            if (uri.startsWith(strHomePath)) {
                uri = uri.substring(strHomePath.length() - 1);
            }
            Log.d("serveFile", "isChangeHomeDir HomePath:" + strHomePath + " DLPath:" + strHomePath);
        }
        if (!homeDir.isDirectory()) {
            Response response2 = new Response(HTTP_INTERNALERROR, MIME_PLAINTEXT, "INTERNAL ERRROR: serveFile(): given homeDir is not a directory.");
        }
        if (response == null) {
            uri = uri.trim().replace(File.separatorChar, '/');
            if (uri.indexOf(63) >= 0) {
                uri = uri.substring(0, uri.indexOf(63));
            }
            if (uri.startsWith("..") || uri.endsWith("..") || uri.indexOf("../") >= 0) {
                response2 = new Response(HTTP_FORBIDDEN, MIME_PLAINTEXT, "FORBIDDEN: Won't serve ../ for security reasons.");
            }
        }
        File f = new File(homeDir, uri);
        if (response == null && !f.exists()) {
            response2 = new Response(HTTP_NOTFOUND, MIME_PLAINTEXT, "Error 404, file not found.");
        }
        if (response == null && f.isDirectory()) {
            if (!uri.endsWith(ServiceReference.DELIMITER)) {
                uri = new StringBuilder(String.valueOf(uri)).append(ServiceReference.DELIMITER).toString();
                response2 = new Response(HTTP_REDIRECT, MIME_HTML, "<html><meta content=\"text/html; charset=UTF-8\" http-equiv=\"content-type\"><body>Redirected: <a href=\"" + uri + "\">" + uri + "</a></body></html>");
                response2.addHeader("Location", uri);
            }
            if (response == null) {
                if (new File(f, "index.html").exists()) {
                    f = new File(homeDir, new StringBuilder(String.valueOf(uri)).append("/index.html").toString());
                    res = response;
                } else if (new File(f, "index.htm").exists()) {
                    f = new File(homeDir, new StringBuilder(String.valueOf(uri)).append("/index.htm").toString());
                    res = response;
                } else if (allowDirectoryListing && f.canRead()) {
                    String[] files = f.list();
                    String msg = "<html><meta content=\"text/html; charset=UTF-8\" http-equiv=\"content-type\"><body><h1>Directory " + uri + "</h1><br/>";
                    if (files != null) {
                        for (int i = 0; i < files.length; i++) {
                            File curFile = new File(f, files[i]);
                            boolean dir = curFile.isDirectory();
                            if (dir) {
                                msg = new StringBuilder(String.valueOf(msg)).append("<b>").toString();
                                files[i] = files[i] + ServiceReference.DELIMITER;
                            }
                            String strHome = EXTHeader.DEFAULT_VALUE;
                            msg = new StringBuilder(String.valueOf(msg)).append("<a href=\"").append(encodeUri(new StringBuilder(String.valueOf(uri)).append(files[i]).toString())).append("\">").append(files[i]).append("</a>").toString();
                            if (curFile.isFile()) {
                                long len = curFile.length();
                                msg = new StringBuilder(String.valueOf(msg)).append(" &nbsp;<font size=2>(").toString();
                                if (len < 1024) {
                                    msg = new StringBuilder(String.valueOf(msg)).append(len).append(" bytes").toString();
                                } else if (len < 1048576) {
                                    msg = new StringBuilder(String.valueOf(msg)).append(len / 1024).append(".").append(((len % 1024) / 10) % 100).append(" KB").toString();
                                } else {
                                    msg = new StringBuilder(String.valueOf(msg)).append(len / 1048576).append(".").append(((len % 1048576) / 10) % 100).append(" MB").toString();
                                }
                                msg = new StringBuilder(String.valueOf(msg)).append(")</font>").toString();
                            }
                            msg = new StringBuilder(String.valueOf(msg)).append("<br/>").toString();
                            if (dir) {
                                msg = new StringBuilder(String.valueOf(msg)).append("</b>").toString();
                            }
                        }
                    }
                    msg = new StringBuilder(String.valueOf(msg)).append("</body></html>").toString();
                    res = new Response(HTTP_OK, MIME_HTML, msg);
                } else {
                    res = new Response(HTTP_FORBIDDEN, MIME_PLAINTEXT, "FORBIDDEN: No directory listing.");
                }
                if (res != null) {
                    mime = null;
                    dot = f.getCanonicalPath().lastIndexOf(46);
                    if (dot >= 0) {
                        mime = (String) theMimeTypes.get(f.getCanonicalPath().substring(dot + 1).toLowerCase());
                    }
                    if (mime == null) {
                        mime = MIME_DEFAULT_BINARY;
                    }
                    startFrom = 0;
                    endAt = -1;
                    range = header.getProperty("range");
                    if (range != null && range.startsWith("bytes=")) {
                        range = range.substring("bytes=".length());
                        minus = range.indexOf(45);
                        if (minus > 0) {
                            try {
                                startFrom = Long.parseLong(range.substring(0, minus));
                                endAt = Long.parseLong(range.substring(minus + 1));
                            } catch (NumberFormatException e) {
                            }
                        }
                    }
                    try {
                        fileLen = f.length();
                        if (range != null || startFrom < 0) {
                            response2 = new Response(HTTP_OK, mime, new FileInputStream(f));
                            response2.addHeader("Content-Length", fileLen);
                        } else if (startFrom >= fileLen) {
                            response2 = new Response(HTTP_RANGE_NOT_SATISFIABLE, MIME_PLAINTEXT, EXTHeader.DEFAULT_VALUE);
                            try {
                                response2.addHeader("Content-Range", "bytes 0-0/" + fileLen);
                            } catch (IOException e2) {
                                response2 = new Response(HTTP_FORBIDDEN, MIME_PLAINTEXT, "FORBIDDEN: Reading file failed.");
                                response.addHeader("Accept-Ranges", "bytes");
                                return response;
                            }
                        } else {
                            if (endAt < 0) {
                                endAt = fileLen - 1;
                            }
                            long newLen = (endAt - startFrom) + 1;
                            if (newLen < 0) {
                                newLen = 0;
                            }
                            final long dataLen = newLen;
                            InputStream c03782 = new FileInputStream(f) {
                                public int available() throws IOException {
                                    return (int) dataLen;
                                }
                            };
                            c03782.skip(startFrom);
                            response2 = new Response(HTTP_PARTIALCONTENT, mime, c03782);
                            response2.addHeader("Content-Length", dataLen);
                            response2.addHeader("Content-Range", "bytes " + startFrom + "-" + endAt + ServiceReference.DELIMITER + fileLen);
                        }
                    } catch (IOException e3) {
                        response = res;
                        response2 = new Response(HTTP_FORBIDDEN, MIME_PLAINTEXT, "FORBIDDEN: Reading file failed.");
                        response.addHeader("Accept-Ranges", "bytes");
                        return response;
                    }
                }
                response = res;
                response.addHeader("Accept-Ranges", "bytes");
                return response;
            }
        }
        res = response;
        if (res != null) {
            response = res;
        } else {
            mime = null;
            dot = f.getCanonicalPath().lastIndexOf(46);
            if (dot >= 0) {
                mime = (String) theMimeTypes.get(f.getCanonicalPath().substring(dot + 1).toLowerCase());
            }
            if (mime == null) {
                mime = MIME_DEFAULT_BINARY;
            }
            startFrom = 0;
            endAt = -1;
            range = header.getProperty("range");
            range = range.substring("bytes=".length());
            minus = range.indexOf(45);
            if (minus > 0) {
                startFrom = Long.parseLong(range.substring(0, minus));
                endAt = Long.parseLong(range.substring(minus + 1));
            }
            fileLen = f.length();
            if (range != null) {
            }
            response2 = new Response(HTTP_OK, mime, new FileInputStream(f));
            response2.addHeader("Content-Length", fileLen);
        }
        response.addHeader("Accept-Ranges", "bytes");
        return response;
    }

    static {
        StringTokenizer st = new StringTokenizer("css\t\ttext/css js\t\t\ttext/javascript htm\t\ttext/html html\t\ttext/html txt\t\ttext/plain asc\t\ttext/plain gif\t\timage/gif jpg\t\timage/jpeg jpeg\t\timage/jpeg png\t\timage/png mp3\t\taudio/mpeg m3u\t\taudio/mpeg-url pdf\t\tapplication/pdf doc\t\tapplication/msword ogg\t\tapplication/x-ogg zip\t\tapplication/octet-stream exe\t\tapplication/octet-stream class\t\tapplication/octet-stream ");
        while (st.hasMoreTokens()) {
            theMimeTypes.put(st.nextToken(), st.nextToken());
        }
        gmtFrmt.setTimeZone(TimeZone.getTimeZone("GMT"));
    }
}
