package com.wireme.mediaserver;

import android.os.Build;
import android.util.Log;
import java.io.IOException;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.util.Enumeration;
import org.teleal.cling.binding.annotations.AnnotationLocalServiceBinder;
import org.teleal.cling.model.DefaultServiceManager;
import org.teleal.cling.model.ValidationException;
import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.cling.model.meta.DeviceDetails;
import org.teleal.cling.model.meta.DeviceIdentity;
import org.teleal.cling.model.meta.LocalDevice;
import org.teleal.cling.model.meta.LocalService;
import org.teleal.cling.model.meta.ManufacturerDetails;
import org.teleal.cling.model.meta.ModelDetails;
import org.teleal.cling.model.types.DeviceType;
import org.teleal.cling.model.types.UDADeviceType;
import org.teleal.cling.model.types.UDN;

public class MediaServer {
    private static final String LOGTAG = "GNaP-MediaServer";
    private static final String deviceType = "MediaServer";
    private static final int port = 8192;
    private static final int version = 1;
    DeviceDetails details = null;
    private InetAddress localAddress = null;
    private LocalDevice localDevice;
    private UDN udn = UDN.uniqueSystemIdentifier(LOGTAG);

    public MediaServer(InetAddress localAddress) throws ValidationException {
        DeviceType type = new UDADeviceType(deviceType, 1);
        this.details = new DeviceDetails(Build.MODEL, new ManufacturerDetails(Build.MANUFACTURER), new ModelDetails("GNaP", "GNaP MediaServer for Android", "v1"));
        LocalService service = new AnnotationLocalServiceBinder().read(ContentDirectoryService.class);
        service.setManager(new DefaultServiceManager(service, ContentDirectoryService.class));
        this.localDevice = new LocalDevice(new DeviceIdentity(this.udn), type, this.details, service);
        this.localAddress = localAddress;
        Log.v(LOGTAG, "MediaServer device created: ");
        Log.v(LOGTAG, "friendly name: " + this.details.getFriendlyName());
        Log.v(LOGTAG, "manufacturer: " + this.details.getManufacturerDetails().getManufacturer());
        Log.v(LOGTAG, "model: " + this.details.getModelDetails().getModelName());
        try {
            HttpServer httpServer = new HttpServer(port);
        } catch (IOException ioe) {
            System.err.println("Couldn't start server:\n" + ioe);
            System.exit(-1);
        }
        Log.v(LOGTAG, "Started Http Server on port 8192");
        ContentTree.SetUUID(this.udn.toString());
    }

    public LocalDevice getDevice() {
        return this.localDevice;
    }

    public void SetAddress(InetAddress ipaddr) {
        if (ipaddr != null) {
            this.localAddress = ipaddr;
        }
    }

    public void setFriendlyName(String strFriendlyName) {
        if (this.details != null) {
            this.details.setFriendlyName(strFriendlyName);
        }
        Log.d("mzc", "set friendly name: " + this.details.getFriendlyName());
    }

    public String getUUID() {
        return this.udn.toString();
    }

    public String getLocalIpAddress() {
        try {
            String strIP = EXTHeader.DEFAULT_VALUE;
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                NetworkInterface intf = (NetworkInterface) en.nextElement();
                Enumeration<InetAddress> enumIpAddr = intf.getInetAddresses();
                while (enumIpAddr.hasMoreElements()) {
                    InetAddress inetAddress = (InetAddress) enumIpAddr.nextElement();
                    if (!inetAddress.isLoopbackAddress() && (inetAddress instanceof Inet4Address)) {
                        if (intf.getName().startsWith("eth") || intf.getName().startsWith("wlan")) {
                            strIP = inetAddress.getHostAddress().toString();
                            Log.i("svr", "***** IP1=" + inetAddress.getHostAddress() + " //" + intf.getName());
                            break;
                        } else if (inetAddress.getHostAddress().toString().startsWith("192") && strIP.length() < 1) {
                            strIP = inetAddress.getHostAddress().toString();
                            Log.i("svr", "***** IP2=" + inetAddress.getHostAddress() + " //" + intf.getName());
                        }
                    }
                }
            }
            return strIP;
        } catch (SocketException ex) {
            Log.e("svr", ex.toString());
            return null;
        }
    }

    public String getAddress() {
        String str = EXTHeader.DEFAULT_VALUE;
        str = getLocalIpAddress();
        if (str == null || str.length() <= 0) {
            return str;
        }
        return new StringBuilder(String.valueOf(str)).append(":8192").toString();
    }
}
