package com.wireme.player;

import android.app.Activity;
import android.media.MediaPlayer;
import android.media.MediaPlayer.OnCompletionListener;
import android.media.MediaPlayer.OnErrorListener;
import android.media.MediaPlayer.OnInfoListener;
import android.media.MediaPlayer.OnPreparedListener;
import android.media.MediaPlayer.OnSeekCompleteListener;
import android.media.MediaPlayer.OnVideoSizeChangedListener;
import android.os.Bundle;
import android.util.Log;
import android.view.Display;
import android.view.MotionEvent;
import android.view.SurfaceHolder;
import android.view.SurfaceHolder.Callback;
import android.view.SurfaceView;
import android.widget.LinearLayout.LayoutParams;
import android.widget.MediaController;
import android.widget.MediaController.MediaPlayerControl;
import com.enus.myzik.C0181R;
import java.io.IOException;

public class GPlayer extends Activity implements OnCompletionListener, OnErrorListener, OnInfoListener, OnPreparedListener, OnSeekCompleteListener, OnVideoSizeChangedListener, Callback, MediaPlayerControl {
    public static final String LOGTAG = "Gnap-GPlayer";
    Display currentDisplay;
    MediaController mediaController;
    MediaPlayer mediaPlayer;
    String playURI;
    boolean readyToPlay = false;
    SurfaceHolder surfaceHolder;
    SurfaceView surfaceView;
    int videoHeight = 0;
    int videoWidth = 0;

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(C0181R.layout.gplayer);
        this.surfaceView = (SurfaceView) findViewById(C0181R.id.gplayer_surfaceview);
        this.surfaceHolder = this.surfaceView.getHolder();
        this.surfaceHolder.addCallback(this);
        this.surfaceHolder.setType(3);
        this.mediaPlayer = new MediaPlayer();
        this.mediaPlayer.setOnCompletionListener(this);
        this.mediaPlayer.setOnErrorListener(this);
        this.mediaPlayer.setOnInfoListener(this);
        this.mediaPlayer.setOnPreparedListener(this);
        this.mediaPlayer.setOnSeekCompleteListener(this);
        this.mediaPlayer.setOnVideoSizeChangedListener(this);
        this.mediaController = new MediaController(this);
        this.playURI = getIntent().getStringExtra("playURI");
        try {
            this.mediaPlayer.setDataSource(this.playURI);
        } catch (IllegalArgumentException e) {
            Log.v(LOGTAG, e.getMessage());
            finish();
        } catch (IllegalStateException e2) {
            Log.v(LOGTAG, e2.getMessage());
            finish();
        } catch (IOException e3) {
            Log.v(LOGTAG, e3.getMessage());
            finish();
        }
        this.currentDisplay = getWindowManager().getDefaultDisplay();
    }

    protected void onPause() {
        super.onPause();
    }

    protected void onStop() {
        super.onStop();
        this.mediaPlayer.stop();
    }

    protected void onDestroy() {
        super.onDestroy();
        if (this.mediaPlayer != null) {
            this.mediaPlayer.release();
            this.mediaPlayer = null;
        }
    }

    public boolean onTouchEvent(MotionEvent ev) {
        if (this.mediaController.isShowing()) {
            this.mediaController.hide();
        } else {
            this.mediaController.show(10000);
        }
        return false;
    }

    public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
        Log.v(LOGTAG, "surfaceChanged Called");
    }

    public void surfaceCreated(SurfaceHolder holder) {
        Log.v(LOGTAG, "surfaceCreated Called");
        this.mediaPlayer.setDisplay(holder);
        try {
            this.mediaPlayer.prepare();
        } catch (IllegalStateException e) {
            Log.v(LOGTAG, e.getMessage());
            finish();
        } catch (IOException e2) {
            Log.v(LOGTAG, e2.getMessage());
            finish();
        }
    }

    public void surfaceDestroyed(SurfaceHolder holder) {
        Log.v(LOGTAG, "surfaceDestroyed Called");
    }

    public void onVideoSizeChanged(MediaPlayer mp, int width, int height) {
        Log.v(LOGTAG, "onVideoSizeChanged Called");
    }

    public void onSeekComplete(MediaPlayer mp) {
        Log.v(LOGTAG, "onSeekComplete Called");
    }

    public void onPrepared(MediaPlayer mp) {
        Log.v(LOGTAG, "onPrepared Called");
        this.videoWidth = mp.getVideoWidth();
        this.videoHeight = mp.getVideoHeight();
        if (this.videoWidth > this.currentDisplay.getWidth() || this.videoHeight > this.currentDisplay.getHeight()) {
            float heightRatio = ((float) this.videoHeight) / ((float) this.currentDisplay.getHeight());
            float widthRatio = ((float) this.videoWidth) / ((float) this.currentDisplay.getWidth());
            if (heightRatio > 1.0f || widthRatio > 1.0f) {
                if (heightRatio > widthRatio) {
                    this.videoHeight = (int) Math.ceil((double) (((float) this.videoHeight) / heightRatio));
                    this.videoWidth = (int) Math.ceil((double) (((float) this.videoWidth) / heightRatio));
                } else {
                    this.videoHeight = (int) Math.ceil((double) (((float) this.videoHeight) / widthRatio));
                    this.videoWidth = (int) Math.ceil((double) (((float) this.videoWidth) / widthRatio));
                }
            }
        }
        this.surfaceView.setLayoutParams(new LayoutParams(this.videoWidth, this.videoHeight));
        mp.start();
        this.mediaController.setMediaPlayer(this);
        this.mediaController.setAnchorView(findViewById(C0181R.id.gplayer_surfaceview));
        this.mediaController.setEnabled(true);
        this.mediaController.show(10000);
    }

    public boolean onInfo(MediaPlayer mp, int whatInfo, int extra) {
        if (whatInfo == 800) {
            Log.v(LOGTAG, "Media Info, Media Info Bad Interleaving " + extra);
        } else if (whatInfo == 801) {
            Log.v(LOGTAG, "Media Info, Media Info Not Seekable " + extra);
        } else if (whatInfo == 1) {
            Log.v(LOGTAG, "Media Info, Media Info Unknown " + extra);
        } else if (whatInfo == 700) {
            Log.v(LOGTAG, "MediaInfo, Media Info Video Track Lagging " + extra);
        } else if (whatInfo == 802) {
            Log.v(LOGTAG, "MediaInfo, Media Info Metadata Update " + extra);
        }
        return false;
    }

    public void onCompletion(MediaPlayer mp) {
        Log.v(LOGTAG, "onCompletion Called");
        finish();
    }

    public boolean onError(MediaPlayer mp, int whatError, int extra) {
        Log.v(LOGTAG, "onError Called");
        if (whatError == 100) {
            Log.v(LOGTAG, "Media Error, Server Died " + extra);
        } else if (whatError == 1) {
            Log.v(LOGTAG, "Media Error, Error Unknown " + extra);
        }
        return false;
    }

    public boolean canPause() {
        return true;
    }

    public boolean canSeekBackward() {
        return true;
    }

    public boolean canSeekForward() {
        return true;
    }

    public int getBufferPercentage() {
        return 0;
    }

    public int getCurrentPosition() {
        return this.mediaPlayer.getCurrentPosition();
    }

    public int getDuration() {
        return this.mediaPlayer.getDuration();
    }

    public boolean isPlaying() {
        return this.mediaPlayer.isPlaying();
    }

    public void pause() {
        if (this.mediaPlayer.isPlaying()) {
            this.mediaPlayer.pause();
        }
    }

    public void seekTo(int pos) {
        this.mediaPlayer.seekTo(pos);
    }

    public void start() {
        this.mediaPlayer.start();
    }
}
