package org.teleal.cling;

import org.teleal.cling.model.message.header.STAllHeader;
import org.teleal.cling.model.meta.LocalDevice;
import org.teleal.cling.model.meta.RemoteDevice;
import org.teleal.cling.registry.Registry;
import org.teleal.cling.registry.RegistryListener;

public class Main {

    static class C04691 implements RegistryListener {
        C04691() {
        }

        public void remoteDeviceDiscoveryStarted(Registry registry, RemoteDevice device) {
            System.out.println("Discovery started: " + device.getDisplayString());
        }

        public void remoteDeviceDiscoveryFailed(Registry registry, RemoteDevice device, Exception ex) {
            System.out.println("Discovery failed: " + device.getDisplayString() + " => " + ex);
        }

        public void remoteDeviceAdded(Registry registry, RemoteDevice device) {
            System.out.println("Remote device added: " + device.getDisplayString());
        }

        public void remoteDeviceUpdated(Registry registry, RemoteDevice device) {
            System.out.println("Remote device updated: " + device.getDisplayString());
        }

        public void remoteDeviceRemoved(Registry registry, RemoteDevice device) {
            System.out.println("Remote device removed: " + device.getDisplayString());
        }

        public void localDeviceAdded(Registry registry, LocalDevice device) {
            System.out.println("Local device added: " + device.getDisplayString());
        }

        public void localDeviceRemoved(Registry registry, LocalDevice device) {
            System.out.println("Local device removed: " + device.getDisplayString());
        }

        public void beforeShutdown(Registry registry) {
            System.out.println("Before shutdown, the registry has devices: " + registry.getDevices().size());
        }

        public void afterShutdown() {
            System.out.println("Shutdown of registry complete!");
        }
    }

    public static void main(String[] args) throws Exception {
        System.out.println("Starting Cling...");
        UpnpService upnpService = new UpnpServiceImpl(new C04691());
        upnpService.getControlPoint().search(new STAllHeader());
        System.out.println("Waiting 10 seconds before shutting down...");
        Thread.sleep(10000);
        System.out.println("Stopping Cling...");
        upnpService.shutdown();
    }
}
