package org.teleal.cling.android;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.net.wifi.WifiManager.MulticastLock;
import java.lang.reflect.Method;
import java.util.logging.Logger;
import org.teleal.cling.UpnpServiceConfiguration;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.transport.Router;
import org.teleal.cling.transport.SwitchableRouterImpl;
import org.teleal.cling.transport.SwitchableRouterImpl.RouterLockAcquisitionException;
import org.teleal.cling.transport.spi.InitializationException;

public class AndroidWifiSwitchableRouter extends SwitchableRouterImpl {
    private static Logger log = Logger.getLogger(Router.class.getName());
    final int MODE_TETHER = 1;
    final int MODE_UNKNOWN = 0;
    final int MODE_WIFI = 2;
    final BroadcastReceiver broadcastReceiver = new C03831();
    final BroadcastReceiver broadcastTetherReceiver = new C03842();
    private final ConnectivityManager connectivityManager;
    private long mConnectedTime = 0;
    private int mIPAddress = 0;
    private String mSSID = null;
    private MulticastLock multicastLock;
    private int nCurMode;
    private final WifiManager wifiManager;

    class C03831 extends BroadcastReceiver {
        C03831() {
        }

        private boolean checkWifiState() {
            boolean isWifiAPenabled = false;
            WifiManager wifi = AndroidWifiSwitchableRouter.this.wifiManager;
            for (Method method : wifi.getClass().getDeclaredMethods()) {
                if (method.getName().equals("isWifiApEnabled")) {
                    try {
                        isWifiAPenabled = ((Boolean) method.invoke(wifi, new Object[0])).booleanValue();
                    } catch (Exception e) {
                    }
                }
            }
            return isWifiAPenabled;
        }

        private boolean checkWifiInfo(Context context) {
            WifiInfo info = ((WifiManager) context.getSystemService("wifi")).getConnectionInfo();
            if (info == null) {
                return true;
            }
            String ssid = info.getSSID();
            int ipAddress = info.getIpAddress();
            if (AndroidWifiSwitchableRouter.this.mSSID != null && AndroidWifiSwitchableRouter.this.mSSID.equals(ssid) && ipAddress == AndroidWifiSwitchableRouter.this.mIPAddress) {
                long curTime = Math.abs(System.currentTimeMillis() - AndroidWifiSwitchableRouter.this.mConnectedTime);
                AndroidWifiSwitchableRouter.this.mConnectedTime = System.currentTimeMillis();
                if (curTime >= 2000) {
                    return true;
                }
                return false;
            }
            AndroidWifiSwitchableRouter.this.mSSID = ssid;
            AndroidWifiSwitchableRouter.this.mIPAddress = ipAddress;
            AndroidWifiSwitchableRouter.this.mConnectedTime = System.currentTimeMillis();
            return true;
        }

        public void onReceive(Context context, Intent intent) {
            if (!intent.getAction().equals("android.net.conn.CONNECTIVITY_CHANGE")) {
                return;
            }
            if (AndroidWifiSwitchableRouter.this.getConnectivityManager().getNetworkInfo(1).isConnected()) {
                AndroidWifiSwitchableRouter.log.info("WiFi state changed, trying to enable router");
                Intent completeIntent;
                if (AndroidWifiSwitchableRouter.this.nCurMode != 2 || checkWifiInfo(context)) {
                    AndroidWifiSwitchableRouter.this.disable();
                    AndroidWifiSwitchableRouter.this.nCurMode = 2;
                    if (AndroidWifiSwitchableRouter.this.enable()) {
                        completeIntent = new Intent("cling.android.Router");
                        completeIntent.putExtra("enus", "OK");
                        context.sendBroadcast(completeIntent);
                        return;
                    }
                    return;
                }
                completeIntent = new Intent("cling.android.Router");
                completeIntent.putExtra("enus", "OK");
                context.sendBroadcast(completeIntent);
                AndroidWifiSwitchableRouter.log.info("Wifi info is same...");
            } else if (AndroidWifiSwitchableRouter.this.nCurMode == 1) {
                AndroidWifiSwitchableRouter.log.info("Tethering mode. so ignore WifiEvent...");
            } else {
                AndroidWifiSwitchableRouter.log.info("WiFi state changed, trying to disable router");
                AndroidWifiSwitchableRouter.this.disable();
                AndroidWifiSwitchableRouter.this.nCurMode = 0;
                AndroidWifiSwitchableRouter.this.mSSID = null;
                AndroidWifiSwitchableRouter.this.mIPAddress = 0;
                AndroidWifiSwitchableRouter.this.mConnectedTime = 0;
            }
        }
    }

    class C03842 extends BroadcastReceiver {
        C03842() {
        }

        public void onReceive(Context context, Intent intent) {
            String ACTION_TETHER_STATE_CHANGED = "android.net.conn.TETHER_STATE_CHANGED";
            String WIFI_AP_STATE_CHANGED_ACTION = "android.net.wifi.WIFI_AP_STATE_CHANGED";
            String EXTRA_WIFI_AP_STATE = "wifi_state";
            String EXTRA_AVAILABLE_TETHER = "availableArray";
            String EXTRA_ACTIVE_TETHER = "activeArray";
            String EXTRA_ERRORED_TETHER = "erroredArray";
            try {
                String action = intent.getAction();
                if (action.equals("android.net.wifi.WIFI_AP_STATE_CHANGED")) {
                    AndroidWifiSwitchableRouter.this.mSSID = null;
                    AndroidWifiSwitchableRouter.this.mIPAddress = 0;
                    AndroidWifiSwitchableRouter.this.mConnectedTime = 0;
                    int nWifiAPState = intent.getIntExtra("wifi_state", 4);
                    if (nWifiAPState >= 10) {
                        nWifiAPState -= 10;
                    }
                    AndroidWifiSwitchableRouter.log.info("WIFI_AP_STATE_CHANGED_ACTION is " + nWifiAPState);
                    Intent intent2;
                    if (nWifiAPState == 3) {
                        AndroidWifiSwitchableRouter.this.nCurMode = 1;
                        AndroidWifiSwitchableRouter.this.disable();
                        if (AndroidWifiSwitchableRouter.this.enable()) {
                            intent2 = new Intent("cling.android.Router");
                            intent2.putExtra("enus", "wifiap_on");
                            context.sendBroadcast(intent2);
                        }
                    } else if (nWifiAPState != 1) {
                        AndroidWifiSwitchableRouter.log.info(Integer.valueOf(intent.getIntExtra("wifi_state", 4)).toString());
                    } else if (AndroidWifiSwitchableRouter.this.nCurMode == 2) {
                        AndroidWifiSwitchableRouter.log.info("Wifi mode. so ignore TetheringEvent...");
                    } else {
                        AndroidWifiSwitchableRouter.this.nCurMode = 0;
                        intent2 = new Intent("cling.android.Router");
                        intent2.putExtra("enus", "wifiap_off");
                        context.sendBroadcast(intent2);
                    }
                } else if (action.equals("android.net.conn.TETHER_STATE_CHANGED")) {
                    AndroidWifiSwitchableRouter.log.info("ACTION_TETHER_STATE_CHANGED");
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public AndroidWifiSwitchableRouter(UpnpServiceConfiguration configuration, ProtocolFactory protocolFactory, WifiManager wifiManager, ConnectivityManager connectivityManager) {
        super(configuration, protocolFactory);
        this.wifiManager = wifiManager;
        this.connectivityManager = connectivityManager;
        this.nCurMode = 0;
    }

    public BroadcastReceiver getBroadcastReceiver() {
        return this.broadcastReceiver;
    }

    public BroadcastReceiver getBroadcastTetherReceiver() {
        return this.broadcastTetherReceiver;
    }

    protected WifiManager getWifiManager() {
        return this.wifiManager;
    }

    protected ConnectivityManager getConnectivityManager() {
        return this.connectivityManager;
    }

    public boolean enable() throws RouterLockAcquisitionException {
        lock(this.writeLock);
        try {
            boolean enabled = super.enable();
            if (enabled) {
                this.multicastLock = getWifiManager().createMulticastLock(getClass().getSimpleName());
                this.multicastLock.acquire();
            }
            unlock(this.writeLock);
            return enabled;
        } catch (Throwable th) {
            unlock(this.writeLock);
        }
    }

    public void handleStartFailure(InitializationException ex) {
        if (this.multicastLock != null && this.multicastLock.isHeld()) {
            this.multicastLock.release();
            this.multicastLock = null;
        }
        super.handleStartFailure(ex);
    }

    public boolean disable() throws RouterLockAcquisitionException {
        lock(this.writeLock);
        try {
            if (this.multicastLock != null && this.multicastLock.isHeld()) {
                this.multicastLock.release();
                this.multicastLock = null;
            }
            boolean disable = super.disable();
            return disable;
        } finally {
            unlock(this.writeLock);
        }
    }

    protected int getLockTimeoutMillis() {
        return 10000;
    }
}
