package org.teleal.cling.binding.xml;

import com.enus.myzik.NIOServer;
import com.gc.android.market.api.model.Market.App;
import com.gc.android.market.api.model.Market.App.ExtendedInfo;
import java.io.StringReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;
import org.teleal.cling.binding.staging.MutableDevice;
import org.teleal.cling.binding.staging.MutableIcon;
import org.teleal.cling.binding.staging.MutableService;
import org.teleal.cling.binding.staging.MutableUDAVersion;
import org.teleal.cling.binding.xml.Descriptor.Device.ELEMENT;
import org.teleal.cling.model.ValidationException;
import org.teleal.cling.model.meta.Device;
import org.teleal.cling.model.types.DLNACaps;
import org.teleal.cling.model.types.DLNADoc;
import org.teleal.cling.model.types.InvalidValueException;
import org.teleal.cling.model.types.ServiceId;
import org.teleal.cling.model.types.ServiceType;
import org.teleal.cling.model.types.UDN;
import org.teleal.common.xml.SAXParser;
import org.teleal.common.xml.SAXParser.Handler;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

public class UDA10DeviceDescriptorBinderSAXImpl extends UDA10DeviceDescriptorBinderImpl {
    private static Logger log = Logger.getLogger(DeviceDescriptorBinder.class.getName());

    protected static class DeviceDescriptorHandler<I> extends Handler<I> {
        public DeviceDescriptorHandler(I instance) {
            super(instance);
        }

        public DeviceDescriptorHandler(I instance, SAXParser parser) {
            super((Object) instance, parser);
        }

        public DeviceDescriptorHandler(I instance, DeviceDescriptorHandler parent) {
            super((Object) instance, (Handler) parent);
        }

        public DeviceDescriptorHandler(I instance, SAXParser parser, DeviceDescriptorHandler parent) {
            super(instance, parser, parent);
        }

        public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {
            super.startElement(uri, localName, qName, attributes);
            ELEMENT el = ELEMENT.valueOrNullOf(localName);
            if (el != null) {
                startElement(el, attributes);
            }
        }

        public void endElement(String uri, String localName, String qName) throws SAXException {
            super.endElement(uri, localName, qName);
            ELEMENT el = ELEMENT.valueOrNullOf(localName);
            if (el != null) {
                endElement(el);
            }
        }

        protected boolean isLastElement(String uri, String localName, String qName) {
            ELEMENT el = ELEMENT.valueOrNullOf(localName);
            return el != null && isLastElement(el);
        }

        public void startElement(ELEMENT element, Attributes attributes) throws SAXException {
        }

        public void endElement(ELEMENT element) throws SAXException {
        }

        public boolean isLastElement(ELEMENT element) {
            return false;
        }
    }

    protected static class DeviceHandler extends DeviceDescriptorHandler<MutableDevice> {
        public static final ELEMENT EL = ELEMENT.device;

        public DeviceHandler(MutableDevice instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void startElement(ELEMENT element, Attributes attributes) throws SAXException {
            if (element.equals(IconListHandler.EL)) {
                List<MutableIcon> icons = new ArrayList();
                ((MutableDevice) getInstance()).icons = icons;
                IconListHandler iconListHandler = new IconListHandler(icons, this);
            }
            if (element.equals(ServiceListHandler.EL)) {
                List<MutableService> services = new ArrayList();
                ((MutableDevice) getInstance()).services = services;
                ServiceListHandler serviceListHandler = new ServiceListHandler(services, this);
            }
            if (element.equals(DeviceListHandler.EL)) {
                List<MutableDevice> devices = new ArrayList();
                ((MutableDevice) getInstance()).embeddedDevices = devices;
                DeviceListHandler deviceListHandler = new DeviceListHandler(devices, this);
            }
        }

        public void endElement(ELEMENT element) throws SAXException {
            switch (element) {
                case deviceType:
                    ((MutableDevice) getInstance()).deviceType = getCharacters();
                    return;
                case friendlyName:
                    ((MutableDevice) getInstance()).friendlyName = getCharacters();
                    return;
                case manufacturer:
                    ((MutableDevice) getInstance()).manufacturer = getCharacters();
                    return;
                case manufacturerURL:
                    ((MutableDevice) getInstance()).manufacturerURI = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                case modelDescription:
                    ((MutableDevice) getInstance()).modelDescription = getCharacters();
                    return;
                case modelName:
                    ((MutableDevice) getInstance()).modelName = getCharacters();
                    return;
                case modelNumber:
                    ((MutableDevice) getInstance()).modelNumber = getCharacters();
                    return;
                case modelURL:
                    ((MutableDevice) getInstance()).modelURI = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                case presentationURL:
                    ((MutableDevice) getInstance()).presentationURI = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                case UPC:
                    ((MutableDevice) getInstance()).upc = getCharacters();
                    return;
                case serialNumber:
                    ((MutableDevice) getInstance()).serialNumber = getCharacters();
                    return;
                case UDN:
                    ((MutableDevice) getInstance()).udn = UDN.valueOf(getCharacters());
                    return;
                case X_DLNADOC:
                    String txt = getCharacters();
                    try {
                        ((MutableDevice) getInstance()).dlnaDocs.add(DLNADoc.valueOf(txt));
                        return;
                    } catch (InvalidValueException e) {
                        UDA10DeviceDescriptorBinderSAXImpl.log.info("Invalid X_DLNADOC value, ignoring value: " + txt);
                        return;
                    }
                case X_DLNACAP:
                    ((MutableDevice) getInstance()).dlnaCaps = DLNACaps.valueOf(getCharacters());
                    return;
                default:
                    return;
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    protected static class DeviceListHandler extends DeviceDescriptorHandler<List<MutableDevice>> {
        public static final ELEMENT EL = ELEMENT.deviceList;

        public DeviceListHandler(List<MutableDevice> instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void startElement(ELEMENT element, Attributes attributes) throws SAXException {
            if (element.equals(DeviceHandler.EL)) {
                MutableDevice device = new MutableDevice();
                ((List) getInstance()).add(device);
                DeviceHandler deviceHandler = new DeviceHandler(device, this);
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    protected static class IconHandler extends DeviceDescriptorHandler<MutableIcon> {
        public static final ELEMENT EL = ELEMENT.icon;

        public IconHandler(MutableIcon instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void endElement(ELEMENT element) throws SAXException {
            switch (C03851.f24x2107e7d[element.ordinal()]) {
                case 18:
                    ((MutableIcon) getInstance()).width = Integer.valueOf(getCharacters()).intValue();
                    return;
                case NIOServer.RESP_APLIST /*19*/:
                    ((MutableIcon) getInstance()).height = Integer.valueOf(getCharacters()).intValue();
                    return;
                case 20:
                    ((MutableIcon) getInstance()).depth = Integer.valueOf(getCharacters()).intValue();
                    return;
                case 21:
                    ((MutableIcon) getInstance()).uri = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                case 22:
                    ((MutableIcon) getInstance()).mimeType = getCharacters();
                    return;
                default:
                    return;
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    protected static class IconListHandler extends DeviceDescriptorHandler<List<MutableIcon>> {
        public static final ELEMENT EL = ELEMENT.iconList;

        public IconListHandler(List<MutableIcon> instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void startElement(ELEMENT element, Attributes attributes) throws SAXException {
            if (element.equals(IconHandler.EL)) {
                MutableIcon icon = new MutableIcon();
                ((List) getInstance()).add(icon);
                IconHandler iconHandler = new IconHandler(icon, this);
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    protected static class RootHandler extends DeviceDescriptorHandler<MutableDevice> {
        public RootHandler(MutableDevice instance, SAXParser parser) {
            super((Object) instance, parser);
        }

        public void startElement(ELEMENT element, Attributes attributes) throws SAXException {
            if (element.equals(SpecVersionHandler.EL)) {
                MutableUDAVersion udaVersion = new MutableUDAVersion();
                ((MutableDevice) getInstance()).udaVersion = udaVersion;
                SpecVersionHandler specVersionHandler = new SpecVersionHandler(udaVersion, this);
            }
            if (element.equals(DeviceHandler.EL)) {
                DeviceHandler deviceHandler = new DeviceHandler((MutableDevice) getInstance(), this);
            }
        }

        public void endElement(ELEMENT element) throws SAXException {
            switch (element) {
                case URLBase:
                    try {
                        ((MutableDevice) getInstance()).baseURL = new URL(getCharacters());
                        return;
                    } catch (Exception ex) {
                        throw new SAXException("Invalid URLBase: " + ex.toString());
                    }
                default:
                    return;
            }
        }
    }

    protected static class ServiceHandler extends DeviceDescriptorHandler<MutableService> {
        public static final ELEMENT EL = ELEMENT.service;

        public ServiceHandler(MutableService instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void endElement(ELEMENT element) throws SAXException {
            switch (C03851.f24x2107e7d[element.ordinal()]) {
                case ExtendedInfo.DOWNLOADSCOUNTTEXT_FIELD_NUMBER /*23*/:
                    ((MutableService) getInstance()).serviceType = ServiceType.valueOf(getCharacters());
                    return;
                case App.PACKAGENAME_FIELD_NUMBER /*24*/:
                    ((MutableService) getInstance()).serviceId = ServiceId.valueOf(getCharacters());
                    return;
                case App.VERSIONCODE_FIELD_NUMBER /*25*/:
                    ((MutableService) getInstance()).descriptorURI = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                case ExtendedInfo.CONTACTPHONE_FIELD_NUMBER /*26*/:
                    ((MutableService) getInstance()).controlURI = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                case ExtendedInfo.CONTACTWEBSITE_FIELD_NUMBER /*27*/:
                    ((MutableService) getInstance()).eventSubscriptionURI = UDA10DeviceDescriptorBinderImpl.parseURI(getCharacters());
                    return;
                default:
                    return;
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    protected static class ServiceListHandler extends DeviceDescriptorHandler<List<MutableService>> {
        public static final ELEMENT EL = ELEMENT.serviceList;

        public ServiceListHandler(List<MutableService> instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void startElement(ELEMENT element, Attributes attributes) throws SAXException {
            if (element.equals(ServiceHandler.EL)) {
                MutableService service = new MutableService();
                ((List) getInstance()).add(service);
                ServiceHandler serviceHandler = new ServiceHandler(service, this);
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    protected static class SpecVersionHandler extends DeviceDescriptorHandler<MutableUDAVersion> {
        public static final ELEMENT EL = ELEMENT.specVersion;

        public SpecVersionHandler(MutableUDAVersion instance, DeviceDescriptorHandler parent) {
            super((Object) instance, parent);
        }

        public void endElement(ELEMENT element) throws SAXException {
            switch (element) {
                case major:
                    ((MutableUDAVersion) getInstance()).major = Integer.valueOf(getCharacters()).intValue();
                    return;
                case minor:
                    ((MutableUDAVersion) getInstance()).minor = Integer.valueOf(getCharacters()).intValue();
                    return;
                default:
                    return;
            }
        }

        public boolean isLastElement(ELEMENT element) {
            return element.equals(EL);
        }
    }

    public <D extends Device> D describe(D undescribedDevice, String descriptorXml) throws DescriptorBindingException, ValidationException {
        if (descriptorXml == null || descriptorXml.length() == 0) {
            throw new DescriptorBindingException("Null or empty descriptor");
        }
        try {
            log.fine("Populating device from XML descriptor: " + undescribedDevice);
            SAXParser parser = new SAXParser();
            MutableDevice descriptor = new MutableDevice();
            RootHandler rootHandler = new RootHandler(descriptor, parser);
            parser.parse(new InputSource(new StringReader(descriptorXml.trim())));
            return descriptor.build(undescribedDevice);
        } catch (ValidationException ex) {
            throw ex;
        } catch (Exception ex2) {
            throw new DescriptorBindingException("Could not parse device descriptor: " + ex2.toString(), ex2);
        }
    }
}
