package org.teleal.cling.model;

import com.wireme.mediaserver.ContentTree;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.util.Collections;
import java.util.Iterator;
import java.util.Set;
import org.teleal.cling.model.message.header.EXTHeader;

public class ModelUtil {
    public static final boolean ANDROID_EMULATOR;
    public static final boolean ANDROID_RUNTIME;

    static {
        boolean foundAndroid = false;
        try {
            foundAndroid = Thread.currentThread().getContextClassLoader().loadClass("android.os.Build").getField("ID").get(null) != null;
        } catch (Exception e) {
        }
        ANDROID_RUNTIME = foundAndroid;
        boolean foundEmulator = false;
        try {
            String product = (String) Thread.currentThread().getContextClassLoader().loadClass("android.os.Build").getField("PRODUCT").get(null);
            if ("google_sdk".equals(product) || "sdk".equals(product)) {
                foundEmulator = true;
            }
        } catch (Exception e2) {
        }
        ANDROID_EMULATOR = foundEmulator;
    }

    public static boolean isStringConvertibleType(Set<Class> stringConvertibleTypes, Class clazz) {
        if (clazz.isEnum()) {
            return true;
        }
        for (Class toStringOutputType : stringConvertibleTypes) {
            if (toStringOutputType.isAssignableFrom(clazz)) {
                return true;
            }
        }
        return false;
    }

    public static boolean isValidUDAName(String name) {
        if (ANDROID_RUNTIME) {
            if (name == null || name.length() == 0) {
                return false;
            }
            return true;
        } else if (name == null || name.length() == 0 || name.toLowerCase().startsWith("xml") || !name.matches(Constants.REGEX_UDA_NAME)) {
            return false;
        } else {
            return true;
        }
    }

    public static InetAddress getInetAddressByName(String name) {
        try {
            return InetAddress.getByName(name);
        } catch (Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    public static String toCommaSeparatedList(Object[] o) {
        return toCommaSeparatedList(o, true, false);
    }

    public static String toCommaSeparatedList(Object[] o, boolean escapeCommas, boolean escapeDoubleQuotes) {
        if (o == null) {
            return EXTHeader.DEFAULT_VALUE;
        }
        StringBuilder sb = new StringBuilder();
        for (Object obj : o) {
            String objString = obj.toString().replaceAll("\\\\", "\\\\\\\\");
            if (escapeCommas) {
                objString = objString.replaceAll(",", "\\\\,");
            }
            if (escapeDoubleQuotes) {
                objString = objString.replaceAll("\"", "\\\"");
            }
            sb.append(objString).append(",");
        }
        if (sb.length() > 1) {
            sb.deleteCharAt(sb.length() - 1);
        }
        return sb.toString();
    }

    public static String[] fromCommaSeparatedList(String s) {
        return fromCommaSeparatedList(s, true);
    }

    public static String[] fromCommaSeparatedList(String s, boolean unescapeCommas) {
        if (s == null || s.length() == 0) {
            return null;
        }
        String QUOTED_COMMA_PLACEHOLDER = "XXX1122334455XXX";
        if (unescapeCommas) {
            s = s.replaceAll("\\\\,", "XXX1122334455XXX");
        }
        String[] split = s.split(",");
        for (int i = 0; i < split.length; i++) {
            split[i] = split[i].replaceAll("XXX1122334455XXX", ",");
            split[i] = split[i].replaceAll("\\\\\\\\", "\\\\");
        }
        return split;
    }

    public static String toTimeString(long seconds) {
        long hours = seconds / 3600;
        long remainder = seconds % 3600;
        long minutes = remainder / 60;
        long secs = remainder % 60;
        return (hours < 10 ? ContentTree.ROOT_ID : EXTHeader.DEFAULT_VALUE) + hours + ":" + (minutes < 10 ? ContentTree.ROOT_ID : EXTHeader.DEFAULT_VALUE) + minutes + ":" + (secs < 10 ? ContentTree.ROOT_ID : EXTHeader.DEFAULT_VALUE) + secs;
    }

    public static long fromTimeString(String s) {
        String[] split = s.split(":");
        return ((Long.parseLong(split[0]) * 3600) + (Long.parseLong(split[1]) * 60)) + Long.parseLong(split[2]);
    }

    public static String commaToNewline(String s) {
        StringBuilder sb = new StringBuilder();
        for (String splitString : s.split(",")) {
            sb.append(splitString).append(",").append("\n");
        }
        if (sb.length() > 2) {
            sb.deleteCharAt(sb.length() - 2);
        }
        return sb.toString();
    }

    public static String getLocalHostName(boolean includeDomain) {
        try {
            String hostname = InetAddress.getLocalHost().getHostName();
            if (includeDomain || hostname.indexOf(".") == -1) {
                return hostname;
            }
            return hostname.substring(0, hostname.indexOf("."));
        } catch (Exception e) {
            return "UNKNOWN HOST";
        }
    }

    public static byte[] getFirstNetworkInterfaceHardwareAddress() {
        try {
            Iterator i$ = Collections.list(NetworkInterface.getNetworkInterfaces()).iterator();
            while (i$.hasNext()) {
                NetworkInterface iface = (NetworkInterface) i$.next();
                if (!iface.isLoopback() && iface.isUp() && iface.getHardwareAddress() != null) {
                    return iface.getHardwareAddress();
                }
            }
            throw new RuntimeException("Could not discover first network interface hardware address");
        } catch (Exception e) {
            throw new RuntimeException("Could not discover first network interface hardware address");
        }
    }
}
