package org.teleal.cling.model;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import org.teleal.cling.model.message.header.EXTHeader;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class XMLUtil {
    public static String documentToString(Document document) throws Exception {
        return documentToString(document, true);
    }

    public static String documentToString(Document document, boolean standalone) throws Exception {
        return ("<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"" + (standalone ? "yes" : "no") + "\"?>") + nodeToString(document.getDocumentElement(), new HashSet(), document.getDocumentElement().getNamespaceURI());
    }

    public static String documentToFragmentString(Document document) throws Exception {
        return nodeToString(document.getDocumentElement(), new HashSet(), document.getDocumentElement().getNamespaceURI());
    }

    protected static String nodeToString(Node node, Set<String> parentPrefixes, String namespaceURI) throws Exception {
        StringBuilder b = new StringBuilder();
        if (node == null) {
            return EXTHeader.DEFAULT_VALUE;
        }
        if (node instanceof Element) {
            int i;
            Element element = (Element) node;
            b.append("<");
            b.append(element.getNodeName());
            Map<String, String> thisLevelPrefixes = new HashMap();
            if (element.getPrefix() != null) {
                if (!parentPrefixes.contains(element.getPrefix())) {
                    thisLevelPrefixes.put(element.getPrefix(), element.getNamespaceURI());
                }
            }
            if (element.hasAttributes()) {
                NamedNodeMap map = element.getAttributes();
                for (i = 0; i < map.getLength(); i++) {
                    Node attr = map.item(i);
                    if (!attr.getNodeName().startsWith("xmlns")) {
                        if (attr.getPrefix() != null) {
                            if (!parentPrefixes.contains(attr.getPrefix())) {
                                thisLevelPrefixes.put(attr.getPrefix(), element.getNamespaceURI());
                            }
                        }
                        b.append(" ");
                        b.append(attr.getNodeName());
                        b.append("=\"");
                        b.append(attr.getNodeValue());
                        b.append("\"");
                    }
                }
            }
            if (!(namespaceURI == null || thisLevelPrefixes.containsValue(namespaceURI))) {
                if (!namespaceURI.equals(element.getParentNode().getNamespaceURI())) {
                    b.append(" xmlns=\"").append(namespaceURI).append("\"");
                }
            }
            for (Entry<String, String> entry : thisLevelPrefixes.entrySet()) {
                b.append(" xmlns:").append((String) entry.getKey()).append("=\"").append((String) entry.getValue()).append("\"");
                parentPrefixes.add(entry.getKey());
            }
            NodeList children = element.getChildNodes();
            boolean hasOnlyAttributes = true;
            for (i = 0; i < children.getLength(); i++) {
                if (children.item(i).getNodeType() != (short) 2) {
                    hasOnlyAttributes = false;
                    break;
                }
            }
            if (hasOnlyAttributes) {
                b.append("/>");
            } else {
                b.append(">");
                for (i = 0; i < children.getLength(); i++) {
                    b.append(nodeToString(children.item(i), parentPrefixes, children.item(i).getNamespaceURI()));
                }
                b.append("</");
                b.append(element.getNodeName());
                b.append(">");
            }
            for (String thisLevelPrefix : thisLevelPrefixes.keySet()) {
                parentPrefixes.remove(thisLevelPrefix);
            }
        } else if (node.getNodeValue() != null) {
            b.append(encodeText(node.getNodeValue()));
        }
        return b.toString();
    }

    protected static String encodeText(String s) {
        return s.replaceAll("&", "&amp;").replaceAll("<", "&lt;").replaceAll(">", "&gt;").replaceAll("'", "&apos;").replaceAll("\"", "&quot;");
    }

    public static Element appendNewElement(Document document, Element parent, Enum el) {
        return appendNewElement(document, parent, el.toString());
    }

    public static Element appendNewElement(Document document, Element parent, String element) {
        Element child = document.createElement(element);
        parent.appendChild(child);
        return child;
    }

    public static Element appendNewElementIfNotNull(Document document, Element parent, Enum el, Object content) {
        return appendNewElementIfNotNull(document, parent, el, content, null);
    }

    public static Element appendNewElementIfNotNull(Document document, Element parent, Enum el, Object content, String namespace) {
        return appendNewElementIfNotNull(document, parent, el.toString(), content, namespace);
    }

    public static Element appendNewElementIfNotNull(Document document, Element parent, String element, Object content) {
        return appendNewElementIfNotNull(document, parent, element, content, null);
    }

    public static Element appendNewElementIfNotNull(Document document, Element parent, String element, Object content, String namespace) {
        return content == null ? parent : appendNewElement(document, parent, element, content, namespace);
    }

    public static Element appendNewElement(Document document, Element parent, String element, Object content) {
        return appendNewElement(document, parent, element, content, null);
    }

    public static Element appendNewElement(Document document, Element parent, String element, Object content, String namespace) {
        Element childElement;
        if (namespace != null) {
            childElement = document.createElementNS(namespace, element);
        } else {
            childElement = document.createElement(element);
        }
        if (content != null) {
            childElement.appendChild(document.createTextNode(content.toString()));
        }
        parent.appendChild(childElement);
        return childElement;
    }

    public static String getTextContent(Node node) {
        StringBuffer buffer = new StringBuffer();
        NodeList childList = node.getChildNodes();
        for (int i = 0; i < childList.getLength(); i++) {
            Node child = childList.item(i);
            if (child.getNodeType() == (short) 3) {
                buffer.append(child.getNodeValue());
            }
        }
        return buffer.toString();
    }
}
