package org.teleal.cling.model.action;

import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.util.Map;
import java.util.logging.Logger;
import org.teleal.cling.model.meta.ActionArgument;
import org.teleal.cling.model.meta.LocalService;
import org.teleal.cling.model.state.StateVariableAccessor;
import org.teleal.cling.model.types.ErrorCode;
import org.teleal.common.util.Reflections;

public class MethodActionExecutor extends AbstractActionExecutor {
    private static Logger log = Logger.getLogger(MethodActionExecutor.class.getName());
    protected Method method;

    public MethodActionExecutor(Method method) {
        this.method = method;
    }

    public MethodActionExecutor(Map<ActionArgument<LocalService>, StateVariableAccessor> outputArgumentAccessors, Method method) {
        super(outputArgumentAccessors);
        this.method = method;
    }

    public Method getMethod() {
        return this.method;
    }

    protected void execute(ActionInvocation<LocalService> actionInvocation, Object serviceImpl) throws Exception {
        Object[] inputArgumentValues = createInputArgumentValues(actionInvocation, this.method);
        if (actionInvocation.getAction().hasOutputArguments()) {
            Object result;
            boolean isVoid = this.method.getReturnType().equals(Void.TYPE);
            log.fine("Calling local service method with output arguments: " + this.method);
            boolean isArrayResultProcessed = true;
            if (isVoid) {
                log.fine("Action method is void, calling declared accessors(s) on service instance to retrieve ouput argument(s)");
                Reflections.invoke(this.method, serviceImpl, inputArgumentValues);
                result = readOutputArgumentValues(actionInvocation.getAction(), serviceImpl);
            } else if (isUseOutputArgumentAccessors(actionInvocation)) {
                log.fine("Action method is not void, calling declared accessor(s) on returned instance to retrieve ouput argument(s)");
                result = readOutputArgumentValues(actionInvocation.getAction(), Reflections.invoke(this.method, serviceImpl, inputArgumentValues));
            } else {
                log.fine("Action method is not void, using returned value as (single) output argument");
                result = Reflections.invoke(this.method, serviceImpl, inputArgumentValues);
                isArrayResultProcessed = false;
            }
            ActionArgument<LocalService>[] outputArgs = actionInvocation.getAction().getOutputArguments();
            if (isArrayResultProcessed && (result instanceof Object[])) {
                Object[] results = (Object[]) result;
                log.fine("Accessors returned Object[], setting output argument values: " + results.length);
                for (int i = 0; i < outputArgs.length; i++) {
                    setOutputArgumentValue(actionInvocation, outputArgs[i], results[i]);
                }
                return;
            } else if (outputArgs.length == 1) {
                setOutputArgumentValue(actionInvocation, outputArgs[0], result);
                return;
            } else {
                throw new ActionException(ErrorCode.ACTION_FAILED, "Method return does not match required number of output arguments: " + outputArgs.length);
            }
        }
        log.fine("Calling local service method with no output arguments: " + this.method);
        Reflections.invoke(this.method, serviceImpl, inputArgumentValues);
    }

    protected boolean isUseOutputArgumentAccessors(ActionInvocation<LocalService> actionInvocation) {
        for (ActionArgument argument : actionInvocation.getAction().getOutputArguments()) {
            if (getOutputArgumentAccessors().get(argument) != null) {
                return true;
            }
        }
        return false;
    }

    protected Object[] createInputArgumentValues(ActionInvocation<LocalService> actionInvocation, Method method) throws ActionException {
        Exception ex;
        LocalService service = (LocalService) actionInvocation.getAction().getService();
        Object[] values = new Object[actionInvocation.getAction().getInputArguments().length];
        ActionArgument[] arr$ = actionInvocation.getAction().getInputArguments();
        int len$ = arr$.length;
        int i$ = 0;
        int i = 0;
        while (i$ < len$) {
            ActionArgument argument = arr$[i$];
            Class methodParameterType = method.getParameterTypes()[i];
            ActionArgumentValue<LocalService> inputValue = actionInvocation.getInput(argument);
            if (methodParameterType.isPrimitive() && (inputValue == null || inputValue.toString().length() == 0)) {
                throw new ActionException(ErrorCode.ARGUMENT_VALUE_INVALID, "Primitive action method argument '" + argument.getName() + "' requires input value, can't be null or empty string");
            }
            int i2;
            if (inputValue == null) {
                i2 = i + 1;
                values[i] = null;
            } else {
                if (inputValue.toString().length() <= 0 || !service.isStringConvertibleType(methodParameterType) || methodParameterType.isEnum()) {
                    i2 = i + 1;
                    values[i] = inputValue.getValue();
                } else {
                    try {
                        Constructor<String> ctor = methodParameterType.getConstructor(new Class[]{String.class});
                        log.finer("Creating new input argument value instance with String.class constructor of type: " + methodParameterType);
                        i2 = i + 1;
                        try {
                            values[i] = ctor.newInstance(new Object[]{inputCallValueString});
                        } catch (Exception e) {
                            ex = e;
                        }
                    } catch (Exception e2) {
                        ex = e2;
                        i2 = i;
                    }
                }
            }
            i$++;
            i = i2;
        }
        return values;
        ex.printStackTrace(System.err);
        throw new ActionException(ErrorCode.ARGUMENT_VALUE_INVALID, "Can't convert input argment string to desired type of '" + argument.getName() + "': " + ex);
    }
}
