package org.teleal.cling.model.gena;

import java.beans.PropertyChangeSupport;
import java.net.URL;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.teleal.cling.model.Location;
import org.teleal.cling.model.Namespace;
import org.teleal.cling.model.NetworkAddress;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.meta.RemoteDevice;
import org.teleal.cling.model.meta.RemoteService;
import org.teleal.cling.model.state.StateVariableValue;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;

public abstract class RemoteGENASubscription extends GENASubscription<RemoteService> {
    protected PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);

    public abstract void ended(CancelReason cancelReason, UpnpResponse upnpResponse);

    public abstract void eventsMissed(int i);

    public abstract void failed(UpnpResponse upnpResponse);

    protected RemoteGENASubscription(RemoteService service) {
        super(service);
    }

    protected RemoteGENASubscription(RemoteService service, int requestedDurationSeconds) {
        super(service, requestedDurationSeconds);
    }

    public synchronized URL getEventSubscriptionURL() {
        return ((RemoteDevice) ((RemoteService) getService()).getDevice()).normalizeURI(((RemoteService) getService()).getEventSubscriptionURI());
    }

    public synchronized List<URL> getEventCallbackURLs(List<NetworkAddress> activeStreamServers, Namespace namespace) {
        List<URL> callbackURLs;
        callbackURLs = new ArrayList();
        for (NetworkAddress activeStreamServer : activeStreamServers) {
            callbackURLs.add(new Location(activeStreamServer, namespace.getEventCallbackPath(getService())).getURL());
        }
        return callbackURLs;
    }

    public synchronized void establish() {
        established();
    }

    public synchronized void fail(UpnpResponse responseStatus) {
        failed(responseStatus);
    }

    public synchronized void end(CancelReason reason, UpnpResponse response) {
        ended(reason, response);
    }

    public synchronized void receive(UnsignedIntegerFourBytes sequence, Collection<StateVariableValue> newValues) {
        if (this.currentSequence != null) {
            if (this.currentSequence.getValue().equals(Long.valueOf(this.currentSequence.getBits().getMaxValue())) && sequence.getValue().longValue() == 1) {
                System.err.println("TODO: HANDLE ROLLOVER");
            } else if (this.currentSequence.getValue().longValue() < sequence.getValue().longValue()) {
                int difference = (int) (sequence.getValue().longValue() - (this.currentSequence.getValue().longValue() + 1));
                if (difference != 0) {
                    eventsMissed(difference);
                }
            }
        }
        this.currentSequence = sequence;
        for (StateVariableValue newValue : newValues) {
            this.currentValues.put(newValue.getStateVariable().getName(), newValue);
        }
        eventReceived();
    }

    public String toString() {
        return "(SID: " + getSubscriptionId() + ") " + getService();
    }
}
