package org.teleal.cling.model.message;

import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import org.teleal.cling.model.ServerClientTokens;
import org.teleal.cling.model.message.header.EXTHeader;

public class UpnpRequest extends UpnpOperation {
    private Method method;
    private URI uri;

    public enum Method {
        GET("GET"),
        POST("POST"),
        NOTIFY("NOTIFY"),
        MSEARCH("M-SEARCH"),
        SUBSCRIBE("SUBSCRIBE"),
        UNSUBSCRIBE("UNSUBSCRIBE"),
        UNKNOWN(ServerClientTokens.UNKNOWN_PLACEHOLDER);
        
        private static Map<String, Method> byName;
        private String httpName;

        static class C03891 extends HashMap<String, Method> {
            C03891() {
                for (Method m : Method.values()) {
                    put(m.getHttpName(), m);
                }
            }
        }

        static {
            byName = new C03891();
        }

        private Method(String httpName) {
            this.httpName = httpName;
        }

        public String getHttpName() {
            return this.httpName;
        }

        public static Method getByHttpName(String httpName) {
            if (httpName == null) {
                return UNKNOWN;
            }
            Method m = (Method) byName.get(httpName.toUpperCase());
            return m == null ? UNKNOWN : m;
        }
    }

    public UpnpRequest(Method method) {
        this.method = method;
    }

    public UpnpRequest(Method method, URI uri) {
        this.method = method;
        this.uri = uri;
    }

    public UpnpRequest(Method method, URL url) {
        this.method = method;
        if (url != null) {
            try {
                this.uri = url.toURI();
            } catch (URISyntaxException e) {
                throw new IllegalArgumentException(e);
            }
        }
    }

    public Method getMethod() {
        return this.method;
    }

    public String getHttpMethodName() {
        return this.method.getHttpName();
    }

    public URI getURI() {
        return this.uri;
    }

    public void setUri(URI uri) {
        this.uri = uri;
    }

    public String toString() {
        return getHttpMethodName() + (getURI() != null ? " " + getURI() : EXTHeader.DEFAULT_VALUE);
    }
}
