package org.teleal.cling.model.message.discovery;

import java.net.URL;
import org.teleal.cling.model.message.IncomingDatagramMessage;
import org.teleal.cling.model.message.UpnpRequest;
import org.teleal.cling.model.message.header.DeviceUSNHeader;
import org.teleal.cling.model.message.header.InterfaceMacHeader;
import org.teleal.cling.model.message.header.LocationHeader;
import org.teleal.cling.model.message.header.MaxAgeHeader;
import org.teleal.cling.model.message.header.NTSHeader;
import org.teleal.cling.model.message.header.ServiceUSNHeader;
import org.teleal.cling.model.message.header.UDNHeader;
import org.teleal.cling.model.message.header.USNRootDeviceHeader;
import org.teleal.cling.model.message.header.UpnpHeader;
import org.teleal.cling.model.message.header.UpnpHeader.Type;
import org.teleal.cling.model.types.NamedDeviceType;
import org.teleal.cling.model.types.NamedServiceType;
import org.teleal.cling.model.types.NotificationSubtype;
import org.teleal.cling.model.types.UDN;

public class IncomingNotificationRequest extends IncomingDatagramMessage<UpnpRequest> {
    public IncomingNotificationRequest(IncomingDatagramMessage<UpnpRequest> source) {
        super(source);
    }

    public boolean isAliveMessage() {
        NTSHeader nts = (NTSHeader) getHeaders().getFirstHeader(Type.NTS, NTSHeader.class);
        return nts != null && ((NotificationSubtype) nts.getValue()).equals(NotificationSubtype.ALIVE);
    }

    public boolean isByeByeMessage() {
        NTSHeader nts = (NTSHeader) getHeaders().getFirstHeader(Type.NTS, NTSHeader.class);
        return nts != null && ((NotificationSubtype) nts.getValue()).equals(NotificationSubtype.BYEBYE);
    }

    public URL getLocationURL() {
        LocationHeader header = (LocationHeader) getHeaders().getFirstHeader(Type.LOCATION, LocationHeader.class);
        if (header != null) {
            return (URL) header.getValue();
        }
        return null;
    }

    public UDN getUDN() {
        UpnpHeader<UDN> udnHeader = getHeaders().getFirstHeader(Type.USN, USNRootDeviceHeader.class);
        if (udnHeader != null) {
            return (UDN) udnHeader.getValue();
        }
        udnHeader = getHeaders().getFirstHeader(Type.USN, UDNHeader.class);
        if (udnHeader != null) {
            return (UDN) udnHeader.getValue();
        }
        UpnpHeader<NamedDeviceType> deviceTypeHeader = getHeaders().getFirstHeader(Type.USN, DeviceUSNHeader.class);
        if (deviceTypeHeader != null) {
            return ((NamedDeviceType) deviceTypeHeader.getValue()).getUdn();
        }
        UpnpHeader<NamedServiceType> serviceTypeHeader = getHeaders().getFirstHeader(Type.USN, ServiceUSNHeader.class);
        if (serviceTypeHeader != null) {
            return ((NamedServiceType) serviceTypeHeader.getValue()).getUdn();
        }
        return null;
    }

    public Integer getMaxAge() {
        MaxAgeHeader header = (MaxAgeHeader) getHeaders().getFirstHeader(Type.MAX_AGE, MaxAgeHeader.class);
        if (header != null) {
            return (Integer) header.getValue();
        }
        return null;
    }

    public byte[] getInterfaceMacHeader() {
        InterfaceMacHeader header = (InterfaceMacHeader) getHeaders().getFirstHeader(Type.EXT_IFACE_MAC, InterfaceMacHeader.class);
        if (header != null) {
            return (byte[]) header.getValue();
        }
        return null;
    }
}
