package org.teleal.cling.model.message.gena;

import java.util.ArrayList;
import java.util.List;
import org.teleal.cling.model.message.StreamRequestMessage;
import org.teleal.cling.model.message.header.EventSequenceHeader;
import org.teleal.cling.model.message.header.NTEventHeader;
import org.teleal.cling.model.message.header.NTSHeader;
import org.teleal.cling.model.message.header.SubscriptionIdHeader;
import org.teleal.cling.model.message.header.UpnpHeader;
import org.teleal.cling.model.message.header.UpnpHeader.Type;
import org.teleal.cling.model.meta.RemoteService;
import org.teleal.cling.model.state.StateVariableValue;
import org.teleal.cling.model.types.NotificationSubtype;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;

public class IncomingEventRequestMessage extends StreamRequestMessage {
    private final RemoteService service;
    private final List<StateVariableValue> stateVariableValues = new ArrayList();

    public IncomingEventRequestMessage(StreamRequestMessage source, RemoteService service) {
        super(source);
        this.service = service;
    }

    public RemoteService getService() {
        return this.service;
    }

    public List<StateVariableValue> getStateVariableValues() {
        return this.stateVariableValues;
    }

    public String getSubscrptionId() {
        SubscriptionIdHeader header = (SubscriptionIdHeader) getHeaders().getFirstHeader(Type.SID, SubscriptionIdHeader.class);
        return header != null ? (String) header.getValue() : null;
    }

    public UnsignedIntegerFourBytes getSequence() {
        EventSequenceHeader header = (EventSequenceHeader) getHeaders().getFirstHeader(Type.SEQ, EventSequenceHeader.class);
        return header != null ? (UnsignedIntegerFourBytes) header.getValue() : null;
    }

    public boolean hasNotificationHeaders() {
        UpnpHeader ntHeader = getHeaders().getFirstHeader(Type.NT);
        UpnpHeader ntsHeader = getHeaders().getFirstHeader(Type.NTS);
        return (ntHeader == null || ntHeader.getValue() == null || ntsHeader == null || ntsHeader.getValue() == null) ? false : true;
    }

    public boolean hasValidNotificationHeaders() {
        NTEventHeader ntHeader = (NTEventHeader) getHeaders().getFirstHeader(Type.NT, NTEventHeader.class);
        NTSHeader ntsHeader = (NTSHeader) getHeaders().getFirstHeader(Type.NTS, NTSHeader.class);
        return (ntHeader == null || ntHeader.getValue() == null || ntsHeader == null || !((NotificationSubtype) ntsHeader.getValue()).equals(NotificationSubtype.PROPCHANGE)) ? false : true;
    }

    public String toString() {
        return super.toString() + " SEQUENCE: " + getSequence().getValue();
    }
}
