package org.teleal.cling.model.types;

import java.lang.reflect.ParameterizedType;
import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.cling.model.types.Datatype.Builtin;

public abstract class AbstractDatatype<V> implements Datatype<V> {
    private Builtin builtin;

    protected Class<V> getValueType() {
        return (Class) ((ParameterizedType) getClass().getGenericSuperclass()).getActualTypeArguments()[0];
    }

    public boolean isHandlingJavaType(Class type) {
        return getValueType().isAssignableFrom(type);
    }

    public V valueOf(String s) throws InvalidValueException {
        return null;
    }

    public Builtin getBuiltin() {
        return this.builtin;
    }

    public void setBuiltin(Builtin builtin) {
        this.builtin = builtin;
    }

    public String getString(V value) throws InvalidValueException {
        if (value == null) {
            return EXTHeader.DEFAULT_VALUE;
        }
        if (isValid(value)) {
            return value.toString();
        }
        throw new InvalidValueException("Value is not valid: " + value);
    }

    public boolean isValid(V value) {
        return value == null || getValueType().isAssignableFrom(value.getClass());
    }

    public String toString() {
        return "(" + getClass().getSimpleName() + ")";
    }

    public String getDisplayString() {
        if (this instanceof CustomDatatype) {
            return ((CustomDatatype) this).getName();
        }
        if (getBuiltin() != null) {
            return getBuiltin().getDescriptorName();
        }
        return getValueType().getSimpleName();
    }
}
