package org.teleal.cling.model.types;

import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.cling.support.model.ProtocolInfo.DLNAFlags;

public class IntegerDatatype extends AbstractDatatype<Integer> {
    private int byteSize;

    public IntegerDatatype(int byteSize) {
        this.byteSize = byteSize;
    }

    public boolean isHandlingJavaType(Class type) {
        return type == Integer.TYPE || Integer.class.isAssignableFrom(type);
    }

    public Integer valueOf(String s) throws InvalidValueException {
        if (s.equals(EXTHeader.DEFAULT_VALUE)) {
            return null;
        }
        try {
            Integer value = Integer.valueOf(Integer.parseInt(s));
            if (isValid(value)) {
                return value;
            }
            throw new InvalidValueException("Not a " + getByteSize() + " byte(s) integer: " + s);
        } catch (NumberFormatException ex) {
            throw new InvalidValueException("Can't convert string to number: " + s, ex);
        }
    }

    public boolean isValid(Integer value) {
        return value == null || (value.intValue() >= getMinValue() && value.intValue() <= getMaxValue());
    }

    public int getMinValue() {
        switch (getByteSize()) {
            case 1:
                return -128;
            case 2:
                return -32768;
            case 4:
                return DLNAFlags.SENDER_PACED;
            default:
                throw new IllegalArgumentException("Invalid integer byte size: " + getByteSize());
        }
    }

    public int getMaxValue() {
        switch (getByteSize()) {
            case 1:
                return 127;
            case 2:
                return 32767;
            case 4:
                return Integer.MAX_VALUE;
            default:
                throw new IllegalArgumentException("Invalid integer byte size: " + getByteSize());
        }
    }

    public int getByteSize() {
        return this.byteSize;
    }
}
