package org.teleal.cling.model.types;

public class NamedDeviceType {
    private DeviceType deviceType;
    private UDN udn;

    public NamedDeviceType(UDN udn, DeviceType deviceType) {
        this.udn = udn;
        this.deviceType = deviceType;
    }

    public UDN getUdn() {
        return this.udn;
    }

    public DeviceType getDeviceType() {
        return this.deviceType;
    }

    public static NamedDeviceType valueOf(String s) throws InvalidValueException {
        String[] strings = s.split("::");
        if (strings.length != 2) {
            throw new InvalidValueException("Can't parse UDN::DeviceType from: " + s);
        }
        try {
            return new NamedDeviceType(UDN.valueOf(strings[0]), DeviceType.valueOf(strings[1]));
        } catch (Exception e) {
            throw new InvalidValueException("Can't parse UDN: " + strings[0]);
        }
    }

    public String toString() {
        return getUdn().toString() + "::" + getDeviceType().toString();
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || !(o instanceof NamedDeviceType)) {
            return false;
        }
        NamedDeviceType that = (NamedDeviceType) o;
        if (!this.deviceType.equals(that.deviceType)) {
            return false;
        }
        if (this.udn.equals(that.udn)) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return (this.udn.hashCode() * 31) + this.deviceType.hashCode();
    }
}
