package org.teleal.cling.model.types;

public class NamedServiceType {
    private ServiceType serviceType;
    private UDN udn;

    public NamedServiceType(UDN udn, ServiceType serviceType) {
        this.udn = udn;
        this.serviceType = serviceType;
    }

    public UDN getUdn() {
        return this.udn;
    }

    public ServiceType getServiceType() {
        return this.serviceType;
    }

    public static NamedServiceType valueOf(String s) throws InvalidValueException {
        String[] strings = s.split("::");
        if (strings.length != 2) {
            throw new InvalidValueException("Can't parse UDN::ServiceType from: " + s);
        }
        try {
            return new NamedServiceType(UDN.valueOf(strings[0]), ServiceType.valueOf(strings[1]));
        } catch (Exception e) {
            throw new InvalidValueException("Can't parse UDN: " + strings[0]);
        }
    }

    public String toString() {
        return getUdn().toString() + "::" + getServiceType().toString();
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || !(o instanceof NamedServiceType)) {
            return false;
        }
        NamedServiceType that = (NamedServiceType) o;
        if (!this.serviceType.equals(that.serviceType)) {
            return false;
        }
        if (this.udn.equals(that.udn)) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return (this.udn.hashCode() * 31) + this.serviceType.hashCode();
    }
}
