package org.teleal.cling.model.types;

import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.teleal.cling.model.Constants;

public class ServiceId {
    public static final Pattern PATTERN = Pattern.compile("urn:([a-zA-Z0-9\\-\\.]+):serviceId:([a-zA-Z_0-9\\-:\\.]{1,64})");
    private String id;
    private String namespace;

    public ServiceId(String namespace, String id) {
        if (namespace == null || namespace.matches(Constants.REGEX_NAMESPACE)) {
            this.namespace = namespace;
            if (id == null || id.matches(Constants.REGEX_ID)) {
                this.id = id;
                return;
            }
            throw new IllegalArgumentException("Service ID suffix too long (64) or contains illegal characters");
        }
        throw new IllegalArgumentException("Service ID namespace contains illegal characters");
    }

    public String getNamespace() {
        return this.namespace;
    }

    public String getId() {
        return this.id;
    }

    public static ServiceId valueOf(String s) throws InvalidValueException {
        ServiceId serviceId = null;
        try {
            serviceId = UDAServiceId.valueOf(s);
        } catch (Exception e) {
        }
        if (serviceId != null) {
            return serviceId;
        }
        Matcher matcher = PATTERN.matcher(s);
        if (matcher.matches()) {
            return new ServiceId(matcher.group(1), matcher.group(2));
        }
        throw new InvalidValueException("Can't parse Service ID string (namespace/id): " + s);
    }

    public String toString() {
        return "urn:" + getNamespace() + ":serviceId:" + getId();
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || !(o instanceof ServiceId)) {
            return false;
        }
        ServiceId serviceId = (ServiceId) o;
        if (!this.id.equals(serviceId.id)) {
            return false;
        }
        if (this.namespace.equals(serviceId.namespace)) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return (this.namespace.hashCode() * 31) + this.id.hashCode();
    }
}
