package org.teleal.cling.model.types;

import com.wireme.mediaserver.ContentTree;
import java.util.logging.Logger;

public abstract class UnsignedVariableInteger {
    private static final Logger log = Logger.getLogger(UnsignedVariableInteger.class.getName());
    protected long value;

    public enum Bits {
        EIGHT(255),
        SIXTEEN(65535),
        TWENTYFOUR(16777215),
        THIRTYTWO(4294967295L);
        
        private long maxValue;

        private Bits(long maxValue) {
            this.maxValue = maxValue;
        }

        public long getMaxValue() {
            return this.maxValue;
        }
    }

    public abstract Bits getBits();

    protected UnsignedVariableInteger() {
    }

    public UnsignedVariableInteger(long value) throws NumberFormatException {
        setValue(value);
    }

    public UnsignedVariableInteger(String s) throws NumberFormatException {
        if (s.startsWith("-")) {
            log.warning("Invalid negative integer value '" + s + "', assuming value 0!");
            s = ContentTree.ROOT_ID;
        }
        setValue(Long.parseLong(s));
    }

    protected UnsignedVariableInteger setValue(long value) {
        isInRange(value);
        this.value = value;
        return this;
    }

    public Long getValue() {
        return Long.valueOf(this.value);
    }

    public void isInRange(long value) throws NumberFormatException {
        if (value < ((long) getMinValue()) || value > getBits().getMaxValue()) {
            throw new NumberFormatException("Value must be between " + getMinValue() + " and " + getBits().getMaxValue() + ": " + value);
        }
    }

    public int getMinValue() {
        return 0;
    }

    public UnsignedVariableInteger increment(boolean rolloverToOne) {
        long j = 1;
        if (this.value + 1 > getBits().getMaxValue()) {
            if (!rolloverToOne) {
                j = 0;
            }
            this.value = j;
        } else {
            this.value = 1 + this.value;
        }
        return this;
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        if (this.value != ((UnsignedVariableInteger) o).value) {
            return false;
        }
        return true;
    }

    public int hashCode() {
        return (int) (this.value ^ (this.value >>> 32));
    }

    public String toString() {
        return Long.toString(this.value);
    }
}
