package org.teleal.cling.model.types.csv;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.teleal.cling.model.ModelUtil;
import org.teleal.cling.model.types.Datatype.Builtin;
import org.teleal.cling.model.types.Datatype.Default;
import org.teleal.cling.model.types.InvalidValueException;
import org.teleal.common.util.Reflections;

public abstract class CSV<T> extends ArrayList<T> {
    protected final Builtin datatype = getBuiltinDatatype();

    public CSV(String s) throws InvalidValueException {
        addAll(parseString(s));
    }

    protected List parseString(String s) throws InvalidValueException {
        String[] strings = ModelUtil.fromCommaSeparatedList(s);
        List values = new ArrayList();
        for (String string : strings) {
            values.add(this.datatype.getDatatype().valueOf(string));
        }
        return values;
    }

    protected Builtin getBuiltinDatatype() throws InvalidValueException {
        Class csvType = (Class) Reflections.getTypeArguments(ArrayList.class, getClass()).get(0);
        Default defaultType = Default.getByJavaType(csvType);
        if (defaultType != null) {
            return defaultType.getBuiltinType();
        }
        throw new InvalidValueException("No built-in UPnP datatype for Java type of CSV: " + csvType);
    }

    public String toString() {
        List<String> stringValues = new ArrayList();
        Iterator i$ = iterator();
        while (i$.hasNext()) {
            stringValues.add(this.datatype.getDatatype().getString(i$.next()));
        }
        return ModelUtil.toCommaSeparatedList(stringValues.toArray(new Object[stringValues.size()]));
    }
}
