package org.teleal.cling.protocol.async;

import java.util.logging.Logger;
import org.teleal.cling.UpnpService;
import org.teleal.cling.model.message.OutgoingDatagramMessage;
import org.teleal.cling.model.message.discovery.OutgoingSearchRequest;
import org.teleal.cling.model.message.header.MXHeader;
import org.teleal.cling.model.message.header.STAllHeader;
import org.teleal.cling.model.message.header.UpnpHeader;
import org.teleal.cling.model.message.header.UpnpHeader.Type;
import org.teleal.cling.protocol.SendingAsync;

public class SendingSearch extends SendingAsync {
    private static final Logger log = Logger.getLogger(SendingSearch.class.getName());
    private final int mxSeconds;
    private final UpnpHeader searchTarget;

    public SendingSearch(UpnpService upnpService) {
        this(upnpService, new STAllHeader());
    }

    public SendingSearch(UpnpService upnpService, UpnpHeader searchTarget) {
        this(upnpService, searchTarget, MXHeader.DEFAULT_VALUE.intValue());
    }

    public SendingSearch(UpnpService upnpService, UpnpHeader searchTarget, int mxSeconds) {
        super(upnpService);
        if (Type.ST.isValidHeaderType(searchTarget.getClass())) {
            this.searchTarget = searchTarget;
            this.mxSeconds = mxSeconds;
            return;
        }
        throw new IllegalArgumentException("Given search target instance is not a valid header class for type ST: " + searchTarget.getClass());
    }

    public UpnpHeader getSearchTarget() {
        return this.searchTarget;
    }

    public int getMxSeconds() {
        return this.mxSeconds;
    }

    protected void execute() {
        log.fine("Executing search for target: " + this.searchTarget.getString() + " with MX seconds: " + getMxSeconds());
        OutgoingDatagramMessage msg = new OutgoingSearchRequest(this.searchTarget, getMxSeconds());
        for (int i = 0; i < getBulkRepeat(); i++) {
            try {
                getUpnpService().getRouter().send(msg);
                log.finer("Sleeping " + getBulkIntervalMilliseconds() + " milliseconds");
                Thread.sleep((long) getBulkIntervalMilliseconds());
            } catch (InterruptedException ex) {
                log.warning("Search sending thread was interrupted: " + ex);
            }
        }
    }

    public int getBulkRepeat() {
        return 2;
    }

    public int getBulkIntervalMilliseconds() {
        return 100;
    }
}
