package org.teleal.cling.protocol.sync;

import java.util.logging.Logger;
import org.teleal.cling.UpnpService;
import org.teleal.cling.model.gena.CancelReason;
import org.teleal.cling.model.gena.RemoteGENASubscription;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.message.gena.IncomingSubscribeResponseMessage;
import org.teleal.cling.model.message.gena.OutgoingRenewalRequestMessage;
import org.teleal.cling.protocol.SendingSync;

public class SendingRenewal extends SendingSync<OutgoingRenewalRequestMessage, IncomingSubscribeResponseMessage> {
    private static final Logger log = Logger.getLogger(SendingRenewal.class.getName());
    protected final RemoteGENASubscription subscription;

    class C03941 implements Runnable {
        C03941() {
        }

        public void run() {
            SendingRenewal.this.subscription.end(CancelReason.RENEWAL_FAILED, null);
        }
    }

    public SendingRenewal(UpnpService upnpService, RemoteGENASubscription subscription) {
        super(upnpService, new OutgoingRenewalRequestMessage(subscription));
        this.subscription = subscription;
    }

    protected IncomingSubscribeResponseMessage executeSync() {
        log.fine("Sending subscription renewal request: " + getInputMessage());
        StreamResponseMessage response = getUpnpService().getRouter().send(getInputMessage());
        if (response == null) {
            log.fine("Subscription renewal failed, no response received");
            getUpnpService().getRegistry().removeRemoteSubscription(this.subscription);
            getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new C03941());
            return null;
        }
        final IncomingSubscribeResponseMessage responseMessage = new IncomingSubscribeResponseMessage(response);
        if (((UpnpResponse) response.getOperation()).isFailed()) {
            log.fine("Subscription renewal failed, response was: " + response);
            getUpnpService().getRegistry().removeRemoteSubscription(this.subscription);
            getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new Runnable() {
                public void run() {
                    SendingRenewal.this.subscription.end(CancelReason.RENEWAL_FAILED, (UpnpResponse) responseMessage.getOperation());
                }
            });
            return responseMessage;
        }
        log.fine("Subscription renewed, updating in registry, response was: " + response);
        this.subscription.setActualSubscriptionDurationSeconds(responseMessage.getSubscriptionDurationSeconds());
        getUpnpService().getRegistry().updateRemoteSubscription(this.subscription);
        return responseMessage;
    }
}
