package org.teleal.cling.protocol.sync;

import java.util.logging.Logger;
import org.teleal.cling.UpnpService;
import org.teleal.cling.model.gena.RemoteGENASubscription;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.message.gena.IncomingSubscribeResponseMessage;
import org.teleal.cling.model.message.gena.OutgoingSubscribeRequestMessage;
import org.teleal.cling.model.meta.RemoteDevice;
import org.teleal.cling.model.meta.RemoteDeviceIdentity;
import org.teleal.cling.model.meta.RemoteService;
import org.teleal.cling.protocol.SendingSync;

public class SendingSubscribe extends SendingSync<OutgoingSubscribeRequestMessage, IncomingSubscribeResponseMessage> {
    private static final Logger log = Logger.getLogger(SendingSubscribe.class.getName());
    protected final RemoteGENASubscription subscription;

    class C03961 implements Runnable {
        C03961() {
        }

        public void run() {
            SendingSubscribe.this.subscription.fail(null);
        }
    }

    class C03972 implements Runnable {
        C03972() {
        }

        public void run() {
            SendingSubscribe.this.subscription.fail(null);
        }
    }

    class C04005 implements Runnable {
        C04005() {
        }

        public void run() {
            SendingSubscribe.this.subscription.establish();
        }
    }

    public SendingSubscribe(UpnpService upnpService, RemoteGENASubscription subscription) {
        super(upnpService, new OutgoingSubscribeRequestMessage(subscription, subscription.getEventCallbackURLs(upnpService.getRouter().getActiveStreamServers(((RemoteDeviceIdentity) ((RemoteDevice) ((RemoteService) subscription.getService()).getDevice()).getIdentity()).getDiscoveredOnLocalAddress()), upnpService.getConfiguration().getNamespace())));
        this.subscription = subscription;
    }

    protected IncomingSubscribeResponseMessage executeSync() {
        IncomingSubscribeResponseMessage incomingSubscribeResponseMessage = null;
        if (((OutgoingSubscribeRequestMessage) getInputMessage()).hasCallbackURLs()) {
            log.fine("Sending subscription request: " + getInputMessage());
            try {
                getUpnpService().getRegistry().lockRemoteSubscriptions();
                StreamResponseMessage response = getUpnpService().getRouter().send(getInputMessage());
                if (response == null) {
                    log.fine("Subscription failed, no response received");
                    getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new C03972());
                } else {
                    incomingSubscribeResponseMessage = new IncomingSubscribeResponseMessage(response);
                    if (((UpnpResponse) response.getOperation()).isFailed()) {
                        log.fine("Subscription failed, response was: " + incomingSubscribeResponseMessage);
                        getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new Runnable() {
                            public void run() {
                                SendingSubscribe.this.subscription.fail((UpnpResponse) incomingSubscribeResponseMessage.getOperation());
                            }
                        });
                    } else if (incomingSubscribeResponseMessage.isVaildHeaders()) {
                        log.fine("Subscription established, adding to registry, response was: " + response);
                        this.subscription.setSubscriptionId(incomingSubscribeResponseMessage.getSubscriptionId());
                        this.subscription.setActualSubscriptionDurationSeconds(incomingSubscribeResponseMessage.getSubscriptionDurationSeconds());
                        getUpnpService().getRegistry().addRemoteSubscription(this.subscription);
                        getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new C04005());
                    } else {
                        log.severe("Subscription failed, invalid or missing (SID, Timeout) response headers");
                        getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new Runnable() {
                            public void run() {
                                SendingSubscribe.this.subscription.fail((UpnpResponse) incomingSubscribeResponseMessage.getOperation());
                            }
                        });
                    }
                    getUpnpService().getRegistry().unlockRemoteSubscriptions();
                }
            } finally {
                getUpnpService().getRegistry().unlockRemoteSubscriptions();
            }
        } else {
            log.fine("Subscription failed, no active local callback URLs available (network disabled?)");
            getUpnpService().getConfiguration().getRegistryListenerExecutor().execute(new C03961());
        }
        return incomingSubscribeResponseMessage;
    }
}
