package org.teleal.cling.support.avtransport.lastchange;

import java.net.URI;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Map.Entry;
import java.util.Set;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;
import org.teleal.cling.support.lastchange.EventedValue;
import org.teleal.cling.support.lastchange.EventedValueEnum;
import org.teleal.cling.support.lastchange.EventedValueEnumArray;
import org.teleal.cling.support.lastchange.EventedValueString;
import org.teleal.cling.support.lastchange.EventedValueURI;
import org.teleal.cling.support.lastchange.EventedValueUnsignedIntegerFourBytes;
import org.teleal.cling.support.model.PlayMode;
import org.teleal.cling.support.model.RecordQualityMode;
import org.teleal.cling.support.model.StorageMedium;
import org.teleal.cling.support.model.TransportAction;

public class AVTransportVariable {
    public static Set<Class<? extends EventedValue>> ALL = new C04111();

    class C04111 extends HashSet<Class<? extends EventedValue>> {
        C04111() {
            add(TransportState.class);
            add(TransportStatus.class);
            add(RecordStorageMedium.class);
            add(PossibleRecordStorageMedia.class);
            add(PossiblePlaybackStorageMedia.class);
            add(CurrentPlayMode.class);
            add(TransportPlaySpeed.class);
            add(RecordMediumWriteStatus.class);
            add(CurrentRecordQualityMode.class);
            add(PossibleRecordQualityModes.class);
            add(NumberOfTracks.class);
            add(CurrentTrack.class);
            add(CurrentTrackDuration.class);
            add(CurrentMediaDuration.class);
            add(CurrentTrackMetaData.class);
            add(CurrentTrackURI.class);
            add(AVTransportURI.class);
            add(NextAVTransportURI.class);
            add(AVTransportURIMetaData.class);
            add(NextAVTransportURIMetaData.class);
            add(CurrentTransportActions.class);
        }
    }

    public static class AVTransportURI extends EventedValueURI {
        public AVTransportURI(URI value) {
            super(value);
        }

        public AVTransportURI(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class AVTransportURIMetaData extends EventedValueString {
        public AVTransportURIMetaData(String value) {
            super(value);
        }

        public AVTransportURIMetaData(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class CurrentMediaDuration extends EventedValueString {
        public CurrentMediaDuration(String value) {
            super(value);
        }

        public CurrentMediaDuration(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class CurrentPlayMode extends EventedValueEnum<PlayMode> {
        public CurrentPlayMode(PlayMode playMode) {
            super((Enum) playMode);
        }

        public CurrentPlayMode(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected PlayMode enumValueOf(String s) {
            return PlayMode.valueOf(s);
        }
    }

    public static class CurrentRecordQualityMode extends EventedValueEnum<RecordQualityMode> {
        public CurrentRecordQualityMode(RecordQualityMode recordQualityMode) {
            super((Enum) recordQualityMode);
        }

        public CurrentRecordQualityMode(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected RecordQualityMode enumValueOf(String s) {
            return RecordQualityMode.valueOf(s);
        }
    }

    public static class CurrentTrack extends EventedValueUnsignedIntegerFourBytes {
        public CurrentTrack(UnsignedIntegerFourBytes value) {
            super(value);
        }

        public CurrentTrack(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class CurrentTrackDuration extends EventedValueString {
        public CurrentTrackDuration(String value) {
            super(value);
        }

        public CurrentTrackDuration(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class CurrentTrackMetaData extends EventedValueString {
        public CurrentTrackMetaData(String value) {
            super(value);
        }

        public CurrentTrackMetaData(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class CurrentTrackURI extends EventedValueURI {
        public CurrentTrackURI(URI value) {
            super(value);
        }

        public CurrentTrackURI(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class CurrentTransportActions extends EventedValueEnumArray<TransportAction> {
        public CurrentTransportActions(TransportAction[] e) {
            super((Enum[]) e);
        }

        public CurrentTransportActions(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected TransportAction[] enumValueOf(String[] names) {
            int i = 0;
            if (names == null) {
                return new TransportAction[0];
            }
            List<TransportAction> list = new ArrayList();
            int length = names.length;
            while (i < length) {
                list.add(TransportAction.valueOf(names[i]));
                i++;
            }
            return (TransportAction[]) list.toArray(new TransportAction[list.size()]);
        }
    }

    public static class NextAVTransportURI extends EventedValueURI {
        public NextAVTransportURI(URI value) {
            super(value);
        }

        public NextAVTransportURI(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class NextAVTransportURIMetaData extends EventedValueString {
        public NextAVTransportURIMetaData(String value) {
            super(value);
        }

        public NextAVTransportURIMetaData(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class NumberOfTracks extends EventedValueUnsignedIntegerFourBytes {
        public NumberOfTracks(UnsignedIntegerFourBytes value) {
            super(value);
        }

        public NumberOfTracks(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class PossibleRecordQualityModes extends EventedValueEnumArray<RecordQualityMode> {
        public PossibleRecordQualityModes(RecordQualityMode[] e) {
            super((Enum[]) e);
        }

        public PossibleRecordQualityModes(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected RecordQualityMode[] enumValueOf(String[] names) {
            List<RecordQualityMode> list = new ArrayList();
            for (String s : names) {
                list.add(RecordQualityMode.valueOf(s));
            }
            return (RecordQualityMode[]) list.toArray(new RecordQualityMode[list.size()]);
        }
    }

    public static class PossibleRecordStorageMedia extends EventedValueEnumArray<StorageMedium> {
        public PossibleRecordStorageMedia(StorageMedium[] e) {
            super((Enum[]) e);
        }

        public PossibleRecordStorageMedia(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected StorageMedium[] enumValueOf(String[] names) {
            List<StorageMedium> list = new ArrayList();
            for (String s : names) {
                list.add(StorageMedium.valueOf(s));
            }
            return (StorageMedium[]) list.toArray(new StorageMedium[list.size()]);
        }
    }

    public static class RecordMediumWriteStatus extends EventedValueEnum<org.teleal.cling.support.model.RecordMediumWriteStatus> {
        public RecordMediumWriteStatus(org.teleal.cling.support.model.RecordMediumWriteStatus recordMediumWriteStatus) {
            super((Enum) recordMediumWriteStatus);
        }

        public RecordMediumWriteStatus(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected org.teleal.cling.support.model.RecordMediumWriteStatus enumValueOf(String s) {
            return org.teleal.cling.support.model.RecordMediumWriteStatus.valueOf(s);
        }
    }

    public static class RecordStorageMedium extends EventedValueEnum<StorageMedium> {
        public RecordStorageMedium(StorageMedium storageMedium) {
            super((Enum) storageMedium);
        }

        public RecordStorageMedium(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected StorageMedium enumValueOf(String s) {
            return StorageMedium.valueOf(s);
        }
    }

    public static class TransportPlaySpeed extends EventedValueString {
        public TransportPlaySpeed(String value) {
            super(value);
        }

        public TransportPlaySpeed(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }

    public static class TransportState extends EventedValueEnum<org.teleal.cling.support.model.TransportState> {
        public TransportState(org.teleal.cling.support.model.TransportState avTransportState) {
            super((Enum) avTransportState);
        }

        public TransportState(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected org.teleal.cling.support.model.TransportState enumValueOf(String s) {
            return org.teleal.cling.support.model.TransportState.valueOf(s);
        }
    }

    public static class TransportStatus extends EventedValueEnum<org.teleal.cling.support.model.TransportStatus> {
        public TransportStatus(org.teleal.cling.support.model.TransportStatus transportStatus) {
            super((Enum) transportStatus);
        }

        public TransportStatus(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }

        protected org.teleal.cling.support.model.TransportStatus enumValueOf(String s) {
            return org.teleal.cling.support.model.TransportStatus.valueOf(s);
        }
    }

    public static class PossiblePlaybackStorageMedia extends PossibleRecordStorageMedia {
        public PossiblePlaybackStorageMedia(StorageMedium[] e) {
            super(e);
        }

        public PossiblePlaybackStorageMedia(Entry<String, String>[] attributes) {
            super((Entry[]) attributes);
        }
    }
}
