package org.teleal.cling.support.contentdirectory.ui;

import android.app.Activity;
import android.widget.ArrayAdapter;
import com.wireme.activity.ContentItem;
import java.util.logging.Logger;
import org.teleal.cling.model.action.ActionException;
import org.teleal.cling.model.action.ActionInvocation;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.model.meta.Service;
import org.teleal.cling.model.types.ErrorCode;
import org.teleal.cling.support.contentdirectory.callback.Browse;
import org.teleal.cling.support.contentdirectory.callback.Browse.Status;
import org.teleal.cling.support.model.BrowseFlag;
import org.teleal.cling.support.model.DIDLContent;
import org.teleal.cling.support.model.SortCriterion;
import org.teleal.cling.support.model.container.Container;
import org.teleal.cling.support.model.item.Item;

public class ContentBrowseActionCallback extends Browse {
    private static Logger log = Logger.getLogger(ContentBrowseActionCallback.class.getName());
    private Activity activity;
    private Container container;
    private ArrayAdapter<ContentItem> listAdapter;
    private Service service;

    public ContentBrowseActionCallback(Activity activity, Service service, Container container, ArrayAdapter<ContentItem> listadapter) {
        Service service2 = service;
        super(service2, container.getId(), BrowseFlag.DIRECT_CHILDREN, "*", 0, null, new SortCriterion(true, "dc:title"));
        this.activity = activity;
        this.service = service;
        this.container = container;
        this.listAdapter = listadapter;
    }

    public void received(final ActionInvocation actionInvocation, final DIDLContent didl) {
        log.fine("Received browse action DIDL descriptor, creating tree nodes");
        this.activity.runOnUiThread(new Runnable() {
            public void run() {
                try {
                    ContentBrowseActionCallback.this.listAdapter.clear();
                    for (Container childContainer : didl.getContainers()) {
                        ContentBrowseActionCallback.log.fine("add child container " + childContainer.getTitle());
                        ContentBrowseActionCallback.this.listAdapter.add(new ContentItem(childContainer, ContentBrowseActionCallback.this.service));
                    }
                    for (Item childItem : didl.getItems()) {
                        ContentBrowseActionCallback.log.fine("add child item" + childItem.getTitle());
                        ContentBrowseActionCallback.this.listAdapter.add(new ContentItem(childItem, ContentBrowseActionCallback.this.service));
                    }
                } catch (Throwable ex) {
                    ContentBrowseActionCallback.log.fine("Creating DIDL tree nodes failed: " + ex);
                    actionInvocation.setFailure(new ActionException(ErrorCode.ACTION_FAILED, "Can't create list childs: " + ex, ex));
                    ContentBrowseActionCallback.this.failure(actionInvocation, null);
                }
            }
        });
    }

    public void updateStatus(Status status) {
    }

    public void failure(ActionInvocation invocation, UpnpResponse operation, String defaultMsg) {
    }
}
