package org.teleal.cling.support.model;

import java.util.Map;
import org.teleal.cling.model.action.ActionArgumentValue;
import org.teleal.cling.model.meta.Service;
import org.teleal.cling.model.types.UnsignedIntegerFourBytes;
import org.teleal.cling.model.types.UnsignedIntegerTwoBytes;

public class PortMapping {
    private String description;
    private boolean enabled;
    private UnsignedIntegerTwoBytes externalPort;
    private String internalClient;
    private UnsignedIntegerTwoBytes internalPort;
    private UnsignedIntegerFourBytes leaseDurationSeconds;
    private Protocol protocol;
    private String remoteHost;

    public enum Protocol {
        UDP,
        TCP
    }

    public PortMapping(Map<String, ActionArgumentValue<Service>> map) {
        this(((Boolean) ((ActionArgumentValue) map.get("NewEnabled")).getValue()).booleanValue(), (UnsignedIntegerFourBytes) ((ActionArgumentValue) map.get("NewLeaseDuration")).getValue(), (String) ((ActionArgumentValue) map.get("NewRemoteHost")).getValue(), (UnsignedIntegerTwoBytes) ((ActionArgumentValue) map.get("NewExternalPort")).getValue(), (UnsignedIntegerTwoBytes) ((ActionArgumentValue) map.get("NewInternalPort")).getValue(), (String) ((ActionArgumentValue) map.get("NewInternalClient")).getValue(), Protocol.valueOf(((ActionArgumentValue) map.get("NewProtocol")).toString()), (String) ((ActionArgumentValue) map.get("NewPortMappingDescription")).getValue());
    }

    public PortMapping(int port, String internalClient, Protocol protocol) {
        this(true, new UnsignedIntegerFourBytes(0), null, new UnsignedIntegerTwoBytes((long) port), new UnsignedIntegerTwoBytes((long) port), internalClient, protocol, null);
    }

    public PortMapping(int port, String internalClient, Protocol protocol, String description) {
        this(true, new UnsignedIntegerFourBytes(0), null, new UnsignedIntegerTwoBytes((long) port), new UnsignedIntegerTwoBytes((long) port), internalClient, protocol, description);
    }

    public PortMapping(String remoteHost, UnsignedIntegerTwoBytes externalPort, Protocol protocol) {
        this(true, new UnsignedIntegerFourBytes(0), remoteHost, externalPort, null, null, protocol, null);
    }

    public PortMapping(boolean enabled, UnsignedIntegerFourBytes leaseDurationSeconds, String remoteHost, UnsignedIntegerTwoBytes externalPort, UnsignedIntegerTwoBytes internalPort, String internalClient, Protocol protocol, String description) {
        this.enabled = enabled;
        this.leaseDurationSeconds = leaseDurationSeconds;
        this.remoteHost = remoteHost;
        this.externalPort = externalPort;
        this.internalPort = internalPort;
        this.internalClient = internalClient;
        this.protocol = protocol;
        this.description = description;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }

    public UnsignedIntegerFourBytes getLeaseDurationSeconds() {
        return this.leaseDurationSeconds;
    }

    public void setLeaseDurationSeconds(UnsignedIntegerFourBytes leaseDurationSeconds) {
        this.leaseDurationSeconds = leaseDurationSeconds;
    }

    public boolean hasRemoteHost() {
        return this.remoteHost != null && this.remoteHost.length() > 0;
    }

    public String getRemoteHost() {
        return this.remoteHost == null ? "-" : this.remoteHost;
    }

    public void setRemoteHost(String remoteHost) {
        if (remoteHost == null || remoteHost.equals("-") || remoteHost.length() == 0) {
            remoteHost = null;
        }
        this.remoteHost = remoteHost;
    }

    public UnsignedIntegerTwoBytes getExternalPort() {
        return this.externalPort;
    }

    public void setExternalPort(UnsignedIntegerTwoBytes externalPort) {
        this.externalPort = externalPort;
    }

    public UnsignedIntegerTwoBytes getInternalPort() {
        return this.internalPort;
    }

    public void setInternalPort(UnsignedIntegerTwoBytes internalPort) {
        this.internalPort = internalPort;
    }

    public String getInternalClient() {
        return this.internalClient;
    }

    public void setInternalClient(String internalClient) {
        this.internalClient = internalClient;
    }

    public Protocol getProtocol() {
        return this.protocol;
    }

    public void setProtocol(Protocol protocol) {
        this.protocol = protocol;
    }

    public boolean hasDescription() {
        return this.description != null;
    }

    public String getDescription() {
        return this.description == null ? "-" : this.description;
    }

    public void setDescription(String description) {
        if (description == null || description.equals("-") || description.length() == 0) {
            description = null;
        }
        this.description = description;
    }

    public String toString() {
        return "(" + getClass().getSimpleName() + ") Protocol: " + getProtocol() + ", " + getExternalPort() + " => " + getInternalClient();
    }
}
