package org.teleal.cling.support.model.container;

import java.net.URI;
import java.util.List;
import org.teleal.cling.support.model.DIDLObject.Class;
import org.teleal.cling.support.model.DIDLObject.Property.DC.CONTRIBUTOR;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DATE;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.PUBLISHER;
import org.teleal.cling.support.model.DIDLObject.Property.DC.RELATION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.RIGHTS;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.LONG_DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.STORAGE_MEDIUM;
import org.teleal.cling.support.model.Person;
import org.teleal.cling.support.model.StorageMedium;

public class Album extends Container {
    public static final Class CLASS = new Class("object.container.album");

    public Album() {
        setClazz(CLASS);
    }

    public Album(Container other) {
        super(other);
    }

    public Album(String id, Container parent, String title, String creator, Integer childCount) {
        this(id, parent.getId(), title, creator, childCount);
    }

    public Album(String id, String parentID, String title, String creator, Integer childCount) {
        super(id, parentID, title, creator, CLASS, childCount);
    }

    public String getDescription() {
        return (String) getFirstPropertyValue(DESCRIPTION.class);
    }

    public Album setDescription(String description) {
        replaceFirstProperty(new DESCRIPTION(description));
        return this;
    }

    public String getLongDescription() {
        return (String) getFirstPropertyValue(LONG_DESCRIPTION.class);
    }

    public Album setLongDescription(String description) {
        replaceFirstProperty(new LONG_DESCRIPTION(description));
        return this;
    }

    public StorageMedium getStorageMedium() {
        return (StorageMedium) getFirstPropertyValue(STORAGE_MEDIUM.class);
    }

    public Album setStorageMedium(StorageMedium storageMedium) {
        replaceFirstProperty(new STORAGE_MEDIUM(storageMedium));
        return this;
    }

    public String getDate() {
        return (String) getFirstPropertyValue(DATE.class);
    }

    public Album setDate(String date) {
        replaceFirstProperty(new DATE(date));
        return this;
    }

    public URI getFirstRelation() {
        return (URI) getFirstPropertyValue(RELATION.class);
    }

    public URI[] getRelations() {
        List<URI> list = getPropertyValues(RELATION.class);
        return (URI[]) list.toArray(new URI[list.size()]);
    }

    public Album setRelations(URI[] relations) {
        removeProperties(RELATION.class);
        for (URI relation : relations) {
            addProperty(new RELATION(relation));
        }
        return this;
    }

    public String getFirstRights() {
        return (String) getFirstPropertyValue(RIGHTS.class);
    }

    public String[] getRights() {
        List<String> list = getPropertyValues(RIGHTS.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public Album setRights(String[] rights) {
        removeProperties(RIGHTS.class);
        for (String right : rights) {
            addProperty(new RIGHTS(right));
        }
        return this;
    }

    public Person getFirstContributor() {
        return (Person) getFirstPropertyValue(CONTRIBUTOR.class);
    }

    public Person[] getContributors() {
        List<Person> list = getPropertyValues(CONTRIBUTOR.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public Album setContributors(Person[] contributors) {
        removeProperties(CONTRIBUTOR.class);
        for (Person p : contributors) {
            addProperty(new CONTRIBUTOR(p));
        }
        return this;
    }

    public Person getFirstPublisher() {
        return (Person) getFirstPropertyValue(PUBLISHER.class);
    }

    public Person[] getPublishers() {
        List<Person> list = getPropertyValues(PUBLISHER.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public Album setPublishers(Person[] publishers) {
        removeProperties(PUBLISHER.class);
        for (Person publisher : publishers) {
            addProperty(new PUBLISHER(publisher));
        }
        return this;
    }
}
