package org.teleal.cling.support.model.container;

import java.util.List;
import org.teleal.cling.support.model.DIDLObject.Class;
import org.teleal.cling.support.model.DIDLObject.Property.DC.CONTRIBUTOR;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DATE;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.LANGUAGE;
import org.teleal.cling.support.model.DIDLObject.Property.DC.RIGHTS;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.ARTIST;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.GENRE;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.LONG_DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.PRODUCER;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.STORAGE_MEDIUM;
import org.teleal.cling.support.model.Person;
import org.teleal.cling.support.model.PersonWithRole;
import org.teleal.cling.support.model.StorageMedium;

public class PlaylistContainer extends Container {
    public static final Class CLASS = new Class("object.container.playlist");

    public PlaylistContainer() {
        setClazz(CLASS);
    }

    public PlaylistContainer(Container other) {
        super(other);
    }

    public PlaylistContainer(String id, Container parent, String title, String creator, Integer childCount) {
        this(id, parent.getId(), title, creator, childCount);
    }

    public PlaylistContainer(String id, String parentID, String title, String creator, Integer childCount) {
        super(id, parentID, title, creator, CLASS, childCount);
    }

    public PersonWithRole getFirstArtist() {
        return (PersonWithRole) getFirstPropertyValue(ARTIST.class);
    }

    public PersonWithRole[] getArtists() {
        List<PersonWithRole> list = getPropertyValues(ARTIST.class);
        return (PersonWithRole[]) list.toArray(new PersonWithRole[list.size()]);
    }

    public PlaylistContainer setArtists(PersonWithRole[] artists) {
        removeProperties(ARTIST.class);
        for (PersonWithRole artist : artists) {
            addProperty(new ARTIST(artist));
        }
        return this;
    }

    public String getFirstGenre() {
        return (String) getFirstPropertyValue(GENRE.class);
    }

    public String[] getGenres() {
        List<String> list = getPropertyValues(GENRE.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public PlaylistContainer setGenres(String[] genres) {
        removeProperties(GENRE.class);
        for (String genre : genres) {
            addProperty(new GENRE(genre));
        }
        return this;
    }

    public String getDescription() {
        return (String) getFirstPropertyValue(DESCRIPTION.class);
    }

    public PlaylistContainer setDescription(String description) {
        replaceFirstProperty(new DESCRIPTION(description));
        return this;
    }

    public String getLongDescription() {
        return (String) getFirstPropertyValue(LONG_DESCRIPTION.class);
    }

    public PlaylistContainer setLongDescription(String description) {
        replaceFirstProperty(new LONG_DESCRIPTION(description));
        return this;
    }

    public Person getFirstProducer() {
        return (Person) getFirstPropertyValue(PRODUCER.class);
    }

    public Person[] getProducers() {
        List<Person> list = getPropertyValues(PRODUCER.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public PlaylistContainer setProducers(Person[] persons) {
        removeProperties(PRODUCER.class);
        for (Person p : persons) {
            addProperty(new PRODUCER(p));
        }
        return this;
    }

    public StorageMedium getStorageMedium() {
        return (StorageMedium) getFirstPropertyValue(STORAGE_MEDIUM.class);
    }

    public PlaylistContainer setStorageMedium(StorageMedium storageMedium) {
        replaceFirstProperty(new STORAGE_MEDIUM(storageMedium));
        return this;
    }

    public String getDate() {
        return (String) getFirstPropertyValue(DATE.class);
    }

    public PlaylistContainer setDate(String date) {
        replaceFirstProperty(new DATE(date));
        return this;
    }

    public String getFirstRights() {
        return (String) getFirstPropertyValue(RIGHTS.class);
    }

    public String[] getRights() {
        List<String> list = getPropertyValues(RIGHTS.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public PlaylistContainer setRights(String[] rights) {
        removeProperties(RIGHTS.class);
        for (String right : rights) {
            addProperty(new RIGHTS(right));
        }
        return this;
    }

    public Person getFirstContributor() {
        return (Person) getFirstPropertyValue(CONTRIBUTOR.class);
    }

    public Person[] getContributors() {
        List<Person> list = getPropertyValues(CONTRIBUTOR.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public PlaylistContainer setContributors(Person[] contributors) {
        removeProperties(CONTRIBUTOR.class);
        for (Person p : contributors) {
            addProperty(new CONTRIBUTOR(p));
        }
        return this;
    }

    public String getLanguage() {
        return (String) getFirstPropertyValue(LANGUAGE.class);
    }

    public PlaylistContainer setLanguage(String language) {
        replaceFirstProperty(new LANGUAGE(language));
        return this;
    }
}
