package org.teleal.cling.support.model.item;

import java.net.URI;
import java.util.Arrays;
import java.util.List;
import org.teleal.cling.support.model.DIDLObject.Class;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.LANGUAGE;
import org.teleal.cling.support.model.DIDLObject.Property.DC.PUBLISHER;
import org.teleal.cling.support.model.DIDLObject.Property.DC.RELATION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.RIGHTS;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.GENRE;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.LONG_DESCRIPTION;
import org.teleal.cling.support.model.Person;
import org.teleal.cling.support.model.Res;
import org.teleal.cling.support.model.container.Container;

public class AudioItem extends Item {
    public static final Class CLASS = new Class("object.item.audioItem");

    public AudioItem() {
        setClazz(CLASS);
    }

    public AudioItem(Item other) {
        super(other);
    }

    public AudioItem(String id, Container parent, String title, String creator, Res... resource) {
        this(id, parent.getId(), title, creator, resource);
    }

    public AudioItem(String id, String parentID, String title, String creator, Res... resource) {
        super(id, parentID, title, creator, CLASS);
        if (resource != null) {
            getResources().addAll(Arrays.asList(resource));
        }
    }

    public String getFirstGenre() {
        return (String) getFirstPropertyValue(GENRE.class);
    }

    public String[] getGenres() {
        List<String> list = getPropertyValues(GENRE.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public AudioItem setGenres(String[] genres) {
        removeProperties(GENRE.class);
        for (String genre : genres) {
            addProperty(new GENRE(genre));
        }
        return this;
    }

    public String getDescription() {
        return (String) getFirstPropertyValue(DESCRIPTION.class);
    }

    public AudioItem setDescription(String description) {
        replaceFirstProperty(new DESCRIPTION(description));
        return this;
    }

    public String getLongDescription() {
        return (String) getFirstPropertyValue(LONG_DESCRIPTION.class);
    }

    public AudioItem setLongDescription(String description) {
        replaceFirstProperty(new LONG_DESCRIPTION(description));
        return this;
    }

    public Person getFirstPublisher() {
        return (Person) getFirstPropertyValue(PUBLISHER.class);
    }

    public Person[] getPublishers() {
        List<Person> list = getPropertyValues(PUBLISHER.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public AudioItem setPublishers(Person[] publishers) {
        removeProperties(PUBLISHER.class);
        for (Person publisher : publishers) {
            addProperty(new PUBLISHER(publisher));
        }
        return this;
    }

    public URI getFirstRelation() {
        return (URI) getFirstPropertyValue(RELATION.class);
    }

    public URI[] getRelations() {
        List<URI> list = getPropertyValues(RELATION.class);
        return (URI[]) list.toArray(new URI[list.size()]);
    }

    public AudioItem setRelations(URI[] relations) {
        removeProperties(RELATION.class);
        for (URI relation : relations) {
            addProperty(new RELATION(relation));
        }
        return this;
    }

    public String getLanguage() {
        return (String) getFirstPropertyValue(LANGUAGE.class);
    }

    public AudioItem setLanguage(String language) {
        replaceFirstProperty(new LANGUAGE(language));
        return this;
    }

    public String getFirstRights() {
        return (String) getFirstPropertyValue(RIGHTS.class);
    }

    public String[] getRights() {
        List<String> list = getPropertyValues(RIGHTS.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public AudioItem setRights(String[] rights) {
        removeProperties(RIGHTS.class);
        for (String right : rights) {
            addProperty(new RIGHTS(right));
        }
        return this;
    }
}
