package org.teleal.cling.support.model.item;

import java.util.List;
import org.teleal.cling.support.model.DIDLObject.Class;
import org.teleal.cling.support.model.DIDLObject.Property.DC.CONTRIBUTOR;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DATE;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.ALBUM;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.ARTIST;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.ORIGINAL_TRACK_NUMBER;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.PLAYLIST;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.STORAGE_MEDIUM;
import org.teleal.cling.support.model.Person;
import org.teleal.cling.support.model.PersonWithRole;
import org.teleal.cling.support.model.Res;
import org.teleal.cling.support.model.StorageMedium;
import org.teleal.cling.support.model.container.Container;

public class MusicTrack extends AudioItem {
    public static final Class CLASS = new Class("object.item.audioItem.musicTrack");

    public MusicTrack() {
        setClazz(CLASS);
    }

    public MusicTrack(Item other) {
        super(other);
    }

    public MusicTrack(String id, Container parent, String title, String creator, String album, String artist, Res... resource) {
        this(id, parent.getId(), title, creator, album, artist, resource);
    }

    public MusicTrack(String id, Container parent, String title, String creator, String album, PersonWithRole artist, Res... resource) {
        this(id, parent.getId(), title, creator, album, artist, resource);
    }

    public MusicTrack(String id, String parentID, String title, String creator, String album, String artist, Res... resource) {
        this(id, parentID, title, creator, album, new PersonWithRole(artist), resource);
    }

    public MusicTrack(String id, String parentID, String title, String creator, String album, PersonWithRole artist, Res... resource) {
        super(id, parentID, title, creator, resource);
        setClazz(CLASS);
        if (album != null) {
            setAlbum(album);
        }
        if (artist != null) {
            addProperty(new ARTIST(artist));
        }
    }

    public PersonWithRole getFirstArtist() {
        return (PersonWithRole) getFirstPropertyValue(ARTIST.class);
    }

    public PersonWithRole[] getArtists() {
        List<PersonWithRole> list = getPropertyValues(ARTIST.class);
        return (PersonWithRole[]) list.toArray(new PersonWithRole[list.size()]);
    }

    public MusicTrack setArtists(PersonWithRole[] artists) {
        removeProperties(ARTIST.class);
        for (PersonWithRole artist : artists) {
            addProperty(new ARTIST(artist));
        }
        return this;
    }

    public String getAlbum() {
        return (String) getFirstPropertyValue(ALBUM.class);
    }

    public MusicTrack setAlbum(String album) {
        replaceFirstProperty(new ALBUM(album));
        return this;
    }

    public Integer getOriginalTrackNumber() {
        return (Integer) getFirstPropertyValue(ORIGINAL_TRACK_NUMBER.class);
    }

    public MusicTrack setOriginalTrackNumber(Integer number) {
        replaceFirstProperty(new ORIGINAL_TRACK_NUMBER(number));
        return this;
    }

    public String getFirstPlaylist() {
        return (String) getFirstPropertyValue(PLAYLIST.class);
    }

    public String[] getPlaylists() {
        List<String> list = getPropertyValues(PLAYLIST.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public MusicTrack setPlaylists(String[] playlists) {
        removeProperties(PLAYLIST.class);
        for (String s : playlists) {
            addProperty(new PLAYLIST(s));
        }
        return this;
    }

    public StorageMedium getStorageMedium() {
        return (StorageMedium) getFirstPropertyValue(STORAGE_MEDIUM.class);
    }

    public MusicTrack setStorageMedium(StorageMedium storageMedium) {
        replaceFirstProperty(new STORAGE_MEDIUM(storageMedium));
        return this;
    }

    public Person getFirstContributor() {
        return (Person) getFirstPropertyValue(CONTRIBUTOR.class);
    }

    public Person[] getContributors() {
        List<Person> list = getPropertyValues(CONTRIBUTOR.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public MusicTrack setContributors(Person[] contributors) {
        removeProperties(CONTRIBUTOR.class);
        for (Person p : contributors) {
            addProperty(new CONTRIBUTOR(p));
        }
        return this;
    }

    public String getDate() {
        return (String) getFirstPropertyValue(DATE.class);
    }

    public MusicTrack setDate(String date) {
        replaceFirstProperty(new DATE(date));
        return this;
    }
}
