package org.teleal.cling.support.model.item;

import java.util.Arrays;
import java.util.List;
import org.teleal.cling.support.model.DIDLObject.Class;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DATE;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.LANGUAGE;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.ARTIST;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.GENRE;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.LONG_DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.STORAGE_MEDIUM;
import org.teleal.cling.support.model.PersonWithRole;
import org.teleal.cling.support.model.Res;
import org.teleal.cling.support.model.StorageMedium;
import org.teleal.cling.support.model.container.Container;

public class PlaylistItem extends Item {
    public static final Class CLASS = new Class("object.item.playlistItem");

    public PlaylistItem() {
        setClazz(CLASS);
    }

    public PlaylistItem(Item other) {
        super(other);
    }

    public PlaylistItem(String id, Container parent, String title, String creator, Res... resource) {
        this(id, parent.getId(), title, creator, resource);
    }

    public PlaylistItem(String id, String parentID, String title, String creator, Res... resource) {
        super(id, parentID, title, creator, CLASS);
        if (resource != null) {
            getResources().addAll(Arrays.asList(resource));
        }
    }

    public PersonWithRole getFirstArtist() {
        return (PersonWithRole) getFirstPropertyValue(ARTIST.class);
    }

    public PersonWithRole[] getArtists() {
        List<PersonWithRole> list = getPropertyValues(ARTIST.class);
        return (PersonWithRole[]) list.toArray(new PersonWithRole[list.size()]);
    }

    public PlaylistItem setArtists(PersonWithRole[] artists) {
        removeProperties(ARTIST.class);
        for (PersonWithRole artist : artists) {
            addProperty(new ARTIST(artist));
        }
        return this;
    }

    public String getFirstGenre() {
        return (String) getFirstPropertyValue(GENRE.class);
    }

    public String[] getGenres() {
        List<String> list = getPropertyValues(GENRE.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public PlaylistItem setGenres(String[] genres) {
        removeProperties(GENRE.class);
        for (String genre : genres) {
            addProperty(new GENRE(genre));
        }
        return this;
    }

    public String getDescription() {
        return (String) getFirstPropertyValue(DESCRIPTION.class);
    }

    public PlaylistItem setDescription(String description) {
        replaceFirstProperty(new DESCRIPTION(description));
        return this;
    }

    public String getLongDescription() {
        return (String) getFirstPropertyValue(LONG_DESCRIPTION.class);
    }

    public PlaylistItem setLongDescription(String description) {
        replaceFirstProperty(new LONG_DESCRIPTION(description));
        return this;
    }

    public String getLanguage() {
        return (String) getFirstPropertyValue(LANGUAGE.class);
    }

    public PlaylistItem setLanguage(String language) {
        replaceFirstProperty(new LANGUAGE(language));
        return this;
    }

    public StorageMedium getStorageMedium() {
        return (StorageMedium) getFirstPropertyValue(STORAGE_MEDIUM.class);
    }

    public PlaylistItem setStorageMedium(StorageMedium storageMedium) {
        replaceFirstProperty(new STORAGE_MEDIUM(storageMedium));
        return this;
    }

    public String getDate() {
        return (String) getFirstPropertyValue(DATE.class);
    }

    public PlaylistItem setDate(String date) {
        replaceFirstProperty(new DATE(date));
        return this;
    }
}
