package org.teleal.cling.support.model.item;

import java.net.URI;
import java.util.Arrays;
import java.util.List;
import org.teleal.cling.support.model.DIDLObject.Class;
import org.teleal.cling.support.model.DIDLObject.Property.DC.DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.DC.LANGUAGE;
import org.teleal.cling.support.model.DIDLObject.Property.DC.PUBLISHER;
import org.teleal.cling.support.model.DIDLObject.Property.DC.RELATION;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.ACTOR;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.DIRECTOR;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.GENRE;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.LONG_DESCRIPTION;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.PRODUCER;
import org.teleal.cling.support.model.DIDLObject.Property.UPNP.RATING;
import org.teleal.cling.support.model.Person;
import org.teleal.cling.support.model.PersonWithRole;
import org.teleal.cling.support.model.Res;
import org.teleal.cling.support.model.container.Container;

public class VideoItem extends Item {
    public static final Class CLASS = new Class("object.item.videoItem");

    public VideoItem() {
        setClazz(CLASS);
    }

    public VideoItem(Item other) {
        super(other);
    }

    public VideoItem(String id, Container parent, String title, String creator, Res... resource) {
        this(id, parent.getId(), title, creator, resource);
    }

    public VideoItem(String id, String parentID, String title, String creator, Res... resource) {
        super(id, parentID, title, creator, CLASS);
        if (resource != null) {
            getResources().addAll(Arrays.asList(resource));
        }
    }

    public String getFirstGenre() {
        return (String) getFirstPropertyValue(GENRE.class);
    }

    public String[] getGenres() {
        List<String> list = getPropertyValues(GENRE.class);
        return (String[]) list.toArray(new String[list.size()]);
    }

    public VideoItem setGenres(String[] genres) {
        removeProperties(GENRE.class);
        for (String genre : genres) {
            addProperty(new GENRE(genre));
        }
        return this;
    }

    public String getDescription() {
        return (String) getFirstPropertyValue(DESCRIPTION.class);
    }

    public VideoItem setDescription(String description) {
        replaceFirstProperty(new DESCRIPTION(description));
        return this;
    }

    public String getLongDescription() {
        return (String) getFirstPropertyValue(LONG_DESCRIPTION.class);
    }

    public VideoItem setLongDescription(String description) {
        replaceFirstProperty(new LONG_DESCRIPTION(description));
        return this;
    }

    public Person getFirstProducer() {
        return (Person) getFirstPropertyValue(PRODUCER.class);
    }

    public Person[] getProducers() {
        List<Person> list = getPropertyValues(PRODUCER.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public VideoItem setProducers(Person[] persons) {
        removeProperties(PRODUCER.class);
        for (Person p : persons) {
            addProperty(new PRODUCER(p));
        }
        return this;
    }

    public String getRating() {
        return (String) getFirstPropertyValue(RATING.class);
    }

    public VideoItem setRating(String rating) {
        replaceFirstProperty(new RATING(rating));
        return this;
    }

    public PersonWithRole getFirstActor() {
        return (PersonWithRole) getFirstPropertyValue(ACTOR.class);
    }

    public PersonWithRole[] getActors() {
        List<PersonWithRole> list = getPropertyValues(ACTOR.class);
        return (PersonWithRole[]) list.toArray(new PersonWithRole[list.size()]);
    }

    public VideoItem setActors(PersonWithRole[] persons) {
        removeProperties(ACTOR.class);
        for (PersonWithRole p : persons) {
            addProperty(new ACTOR(p));
        }
        return this;
    }

    public Person getFirstDirector() {
        return (Person) getFirstPropertyValue(DIRECTOR.class);
    }

    public Person[] getDirectors() {
        List<Person> list = getPropertyValues(DIRECTOR.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public VideoItem setDirectors(Person[] persons) {
        removeProperties(DIRECTOR.class);
        for (Person p : persons) {
            addProperty(new DIRECTOR(p));
        }
        return this;
    }

    public Person getFirstPublisher() {
        return (Person) getFirstPropertyValue(PUBLISHER.class);
    }

    public Person[] getPublishers() {
        List<Person> list = getPropertyValues(PUBLISHER.class);
        return (Person[]) list.toArray(new Person[list.size()]);
    }

    public VideoItem setPublishers(Person[] publishers) {
        removeProperties(PUBLISHER.class);
        for (Person publisher : publishers) {
            addProperty(new PUBLISHER(publisher));
        }
        return this;
    }

    public String getLanguage() {
        return (String) getFirstPropertyValue(LANGUAGE.class);
    }

    public VideoItem setLanguage(String language) {
        replaceFirstProperty(new LANGUAGE(language));
        return this;
    }

    public URI getFirstRelation() {
        return (URI) getFirstPropertyValue(RELATION.class);
    }

    public URI[] getRelations() {
        List<URI> list = getPropertyValues(RELATION.class);
        return (URI[]) list.toArray(new URI[list.size()]);
    }

    public VideoItem setRelations(URI[] relations) {
        removeProperties(RELATION.class);
        for (URI relation : relations) {
            addProperty(new RELATION(relation));
        }
        return this;
    }
}
