package org.teleal.cling.support.shared;

import java.util.ArrayList;
import java.util.logging.Level;
import org.teleal.cling.binding.xml.DeviceDescriptorBinder;
import org.teleal.cling.binding.xml.ServiceDescriptorBinder;
import org.teleal.cling.model.DefaultServiceManager;
import org.teleal.cling.model.message.UpnpHeaders;
import org.teleal.cling.model.meta.LocalService;
import org.teleal.cling.protocol.ProtocolFactory;
import org.teleal.cling.protocol.RetrieveRemoteDescriptors;
import org.teleal.cling.protocol.sync.ReceivingAction;
import org.teleal.cling.protocol.sync.ReceivingEvent;
import org.teleal.cling.protocol.sync.ReceivingRetrieval;
import org.teleal.cling.protocol.sync.ReceivingSubscribe;
import org.teleal.cling.protocol.sync.ReceivingUnsubscribe;
import org.teleal.cling.protocol.sync.SendingAction;
import org.teleal.cling.protocol.sync.SendingEvent;
import org.teleal.cling.protocol.sync.SendingRenewal;
import org.teleal.cling.protocol.sync.SendingSubscribe;
import org.teleal.cling.protocol.sync.SendingUnsubscribe;
import org.teleal.cling.registry.Registry;
import org.teleal.cling.transport.Router;
import org.teleal.cling.transport.spi.DatagramIO;
import org.teleal.cling.transport.spi.DatagramProcessor;
import org.teleal.cling.transport.spi.GENAEventProcessor;
import org.teleal.cling.transport.spi.MulticastReceiver;
import org.teleal.cling.transport.spi.SOAPActionProcessor;
import org.teleal.cling.transport.spi.StreamClient;
import org.teleal.cling.transport.spi.StreamServer;
import org.teleal.cling.transport.spi.UpnpStream;
import org.teleal.common.swingfwk.logging.LogCategory;
import org.teleal.common.swingfwk.logging.LogCategory.Group;
import org.teleal.common.swingfwk.logging.LogCategory.LoggerLevel;

public class LogCategories extends ArrayList<LogCategory> {
    public LogCategories() {
        super(10);
        r2 = new Group[6];
        r2[0] = new Group("UDP communication", new LoggerLevel[]{new LoggerLevel(DatagramIO.class.getName(), Level.FINE), new LoggerLevel(MulticastReceiver.class.getName(), Level.FINE)});
        r2[1] = new Group("UDP datagram processing and content", new LoggerLevel[]{new LoggerLevel(DatagramProcessor.class.getName(), Level.FINER)});
        r2[2] = new Group("TCP communication", new LoggerLevel[]{new LoggerLevel(UpnpStream.class.getName(), Level.FINER), new LoggerLevel(StreamServer.class.getName(), Level.FINE), new LoggerLevel(StreamClient.class.getName(), Level.FINE)});
        r2[3] = new Group("SOAP action message processing and content", new LoggerLevel[]{new LoggerLevel(SOAPActionProcessor.class.getName(), Level.FINER)});
        r2[4] = new Group("GENA event message processing and content", new LoggerLevel[]{new LoggerLevel(GENAEventProcessor.class.getName(), Level.FINER)});
        r2[5] = new Group("HTTP header processing", new LoggerLevel[]{new LoggerLevel(UpnpHeaders.class.getName(), Level.FINER)});
        add(new LogCategory("Network", r2));
        r2 = new Group[4];
        r2[0] = new Group("Discovery (Notification & Search)", new LoggerLevel[]{new LoggerLevel(ProtocolFactory.class.getName(), Level.FINER), new LoggerLevel("org.teleal.cling.protocol.async", Level.FINER)});
        r2[1] = new Group("Description", new LoggerLevel[]{new LoggerLevel(ProtocolFactory.class.getName(), Level.FINER), new LoggerLevel(RetrieveRemoteDescriptors.class.getName(), Level.FINE), new LoggerLevel(ReceivingRetrieval.class.getName(), Level.FINE), new LoggerLevel(DeviceDescriptorBinder.class.getName(), Level.FINE), new LoggerLevel(ServiceDescriptorBinder.class.getName(), Level.FINE)});
        r2[2] = new Group("Control", new LoggerLevel[]{new LoggerLevel(ProtocolFactory.class.getName(), Level.FINER), new LoggerLevel(ReceivingAction.class.getName(), Level.FINER), new LoggerLevel(SendingAction.class.getName(), Level.FINER)});
        r2[3] = new Group("GENA ", new LoggerLevel[]{new LoggerLevel("org.teleal.cling.model.gena", Level.FINER), new LoggerLevel(ProtocolFactory.class.getName(), Level.FINER), new LoggerLevel(ReceivingEvent.class.getName(), Level.FINER), new LoggerLevel(ReceivingSubscribe.class.getName(), Level.FINER), new LoggerLevel(ReceivingUnsubscribe.class.getName(), Level.FINER), new LoggerLevel(SendingEvent.class.getName(), Level.FINER), new LoggerLevel(SendingSubscribe.class.getName(), Level.FINER), new LoggerLevel(SendingUnsubscribe.class.getName(), Level.FINER), new LoggerLevel(SendingRenewal.class.getName(), Level.FINER)});
        add(new LogCategory("UPnP Protocol", r2));
        r2 = new Group[4];
        r2[0] = new Group("Router", new LoggerLevel[]{new LoggerLevel(Router.class.getName(), Level.FINER)});
        r2[1] = new Group("Registry", new LoggerLevel[]{new LoggerLevel(Registry.class.getName(), Level.FINER)});
        r2[2] = new Group("Local service binding & invocation", new LoggerLevel[]{new LoggerLevel("org.teleal.cling.binding.annotations", Level.FINER), new LoggerLevel(LocalService.class.getName(), Level.FINER), new LoggerLevel("org.teleal.cling.model.action", Level.FINER), new LoggerLevel("org.teleal.cling.model.state", Level.FINER), new LoggerLevel(DefaultServiceManager.class.getName(), Level.FINER)});
        r2[3] = new Group("Control Point interaction", new LoggerLevel[]{new LoggerLevel("org.teleal.cling.controlpoint", Level.FINER)});
        add(new LogCategory("Core", r2));
    }
}
