package org.teleal.cling.transport.impl.apache;

import java.io.IOException;
import java.io.InterruptedIOException;
import java.net.InetAddress;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.SocketException;
import java.util.logging.Logger;
import org.apache.http.HttpRequestFactory;
import org.apache.http.impl.DefaultHttpServerConnection;
import org.apache.http.params.BasicHttpParams;
import org.apache.http.params.HttpParams;
import org.teleal.cling.transport.Router;
import org.teleal.cling.transport.spi.InitializationException;
import org.teleal.cling.transport.spi.StreamServer;

public class StreamServerImpl implements StreamServer<StreamServerConfigurationImpl> {
    private static final Logger log = Logger.getLogger(StreamServer.class.getName());
    protected final StreamServerConfigurationImpl configuration;
    protected HttpParams globalParams = new BasicHttpParams();
    protected Router router;
    protected ServerSocket serverSocket;
    private volatile boolean stopped = false;

    class C04251 extends DefaultHttpServerConnection {
        C04251() {
        }

        protected HttpRequestFactory createHttpRequestFactory() {
            return new UpnpHttpRequestFactory();
        }
    }

    public StreamServerImpl(StreamServerConfigurationImpl configuration) {
        this.configuration = configuration;
    }

    public StreamServerConfigurationImpl getConfiguration() {
        return this.configuration;
    }

    public synchronized void init(InetAddress bindAddress, Router router) throws InitializationException {
        try {
            this.router = router;
            log.info("jangpw: Created socket (for receiving TCP streams) on: start ");
            this.serverSocket = new ServerSocket(this.configuration.getListenPort(), this.configuration.getTcpConnectionBacklog(), bindAddress);
            log.info("Created socket (for receiving TCP streams) on: " + this.serverSocket.getLocalSocketAddress());
            this.globalParams.setIntParameter("http.socket.timeout", this.configuration.getDataWaitTimeoutSeconds() * 1000).setIntParameter("http.socket.buffer-size", this.configuration.getBufferSizeKilobytes() * 1024).setBooleanParameter("http.connection.stalecheck", this.configuration.isStaleConnectionCheck()).setBooleanParameter("http.tcp.nodelay", this.configuration.isTcpNoDelay());
            log.info("jangpw: After Created socket (for receiving TCP streams) on: " + this.serverSocket.getLocalSocketAddress());
        } catch (Exception ex) {
            log.info("jangpw: Could not initialize...");
            throw new InitializationException("Could not initialize " + getClass().getSimpleName() + ": " + ex.toString(), ex);
        }
    }

    public synchronized int getPort() {
        return this.serverSocket.getLocalPort();
    }

    public synchronized void stop() {
        this.stopped = true;
        try {
            this.serverSocket.close();
        } catch (IOException ex) {
            log.fine("Exception closing streaming server socket: " + ex);
        }
    }

    public void run() {
        log.fine("Entering blocking receiving loop, listening for HTTP stream requests on: " + this.serverSocket.getLocalSocketAddress());
        log.info("jangpw: Entering blocking receiving loop, listening for HTTP stream requests on: " + this.serverSocket.getLocalSocketAddress());
        while (!this.stopped) {
            try {
                Socket clientSocket = this.serverSocket.accept();
                DefaultHttpServerConnection httpServerConnection = new C04251();
                log.fine("Incoming connection from: " + clientSocket.getInetAddress());
                httpServerConnection.bind(clientSocket, this.globalParams);
                this.router.received(new HttpServerConnectionUpnpStream(this.router.getProtocolFactory(), httpServerConnection, this.globalParams));
            } catch (InterruptedIOException ex) {
                log.fine("I/O has been interrupted, stopping receiving loop, bytes transfered: " + ex.bytesTransferred);
            } catch (SocketException ex2) {
                if (!this.stopped) {
                    log.fine("Exception using server socket: " + ex2.getMessage());
                }
            } catch (IOException ex3) {
                log.fine("Exception initializing receiving loop: " + ex3.getMessage());
            }
        }
        try {
            log.fine("Receiving loop stopped");
            if (!this.serverSocket.isClosed()) {
                log.fine("Closing streaming server socket");
                this.serverSocket.close();
            }
        } catch (Exception ex4) {
            log.info("Exception closing streaming server socket: " + ex4.getMessage());
        }
    }
}
