package org.teleal.common.http;

import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import org.teleal.common.io.IO;

public class HttpFetch {

    public interface RepresentationFactory<E> {
        Representation<E> createRepresentation(URLConnection uRLConnection, InputStream inputStream) throws IOException;
    }

    static class C04711 implements RepresentationFactory<byte[]> {
        C04711() {
        }

        public Representation<byte[]> createRepresentation(URLConnection urlConnection, InputStream is) throws IOException {
            return new Representation(urlConnection, IO.readBytes(is));
        }
    }

    static class C04722 implements RepresentationFactory<String> {
        C04722() {
        }

        public Representation<String> createRepresentation(URLConnection urlConnection, InputStream is) throws IOException {
            return new Representation(urlConnection, IO.readLines(is));
        }
    }

    static class C04733 implements RepresentationFactory {
        C04733() {
        }

        public Representation createRepresentation(URLConnection urlConnection, InputStream is) throws IOException {
            return new Representation(urlConnection, null);
        }
    }

    public static Representation<byte[]> fetchBinary(URL url) throws IOException {
        return fetchBinary(url, 500, 500);
    }

    public static Representation<byte[]> fetchBinary(URL url, int connectTimeoutMillis, int readTimeoutMillis) throws IOException {
        return fetch(url, connectTimeoutMillis, readTimeoutMillis, new C04711());
    }

    public static Representation<String> fetchString(URL url, int connectTimeoutMillis, int readTimeoutMillis) throws IOException {
        return fetch(url, connectTimeoutMillis, readTimeoutMillis, new C04722());
    }

    public static <E> Representation<E> fetch(URL url, int connectTimeoutMillis, int readTimeoutMillis, RepresentationFactory<E> factory) throws IOException {
        return fetch(url, "GET", connectTimeoutMillis, readTimeoutMillis, factory);
    }

    public static <E> Representation<E> fetch(URL url, String method, int connectTimeoutMillis, int readTimeoutMillis, RepresentationFactory<E> factory) throws IOException {
        HttpURLConnection urlConnection = null;
        InputStream is = null;
        try {
            urlConnection = (HttpURLConnection) url.openConnection();
            urlConnection.setRequestMethod(method);
            urlConnection.setConnectTimeout(connectTimeoutMillis);
            urlConnection.setReadTimeout(readTimeoutMillis);
            is = urlConnection.getInputStream();
            Representation<E> createRepresentation = factory.createRepresentation(urlConnection, is);
            if (is != null) {
                is.close();
            }
            return createRepresentation;
        } catch (IOException ex) {
            if (urlConnection != null) {
                throw new IOException("Fetching resource failed, returned status code: " + urlConnection.getResponseCode());
            }
            throw ex;
        } catch (Throwable th) {
            if (is != null) {
                is.close();
            }
        }
    }

    public static void validate(URL url) throws IOException {
        fetch(url, "HEAD", 500, 500, new C04733());
    }
}
