package org.teleal.common.http;

import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Enumeration;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.TreeMap;
import org.teleal.cling.model.message.header.EXTHeader;

public class Query {
    private Map<String, List<String>> parameters;
    private String qs;

    public static String parseParameters(Map<String, String[]> parameters) {
        StringBuilder sb = new StringBuilder();
        for (Entry<String, String[]> entry : parameters.entrySet()) {
            for (String v : (String[]) entry.getValue()) {
                if (!(v == null || v.length() == 0)) {
                    if (sb.length() > 0) {
                        sb.append("&");
                    }
                    sb.append((String) entry.getKey());
                    sb.append("=");
                    sb.append(v);
                }
            }
        }
        return sb.toString();
    }

    public Query() {
        this.qs = EXTHeader.DEFAULT_VALUE;
        this.parameters = new TreeMap();
    }

    public Query(Map<String, String[]> parameters) {
        this(parseParameters(parameters));
    }

    public Query(URL url) {
        this(url.getQuery());
    }

    public Query(String qs) {
        this.qs = EXTHeader.DEFAULT_VALUE;
        this.parameters = new TreeMap();
        if (qs != null) {
            this.qs = qs;
            for (String pair : qs.split("&")) {
                String name;
                String value;
                int pos = pair.indexOf(61);
                if (pos == -1) {
                    name = pair;
                    value = null;
                } else {
                    try {
                        name = URLDecoder.decode(pair.substring(0, pos), "UTF-8");
                        value = URLDecoder.decode(pair.substring(pos + 1, pair.length()), "UTF-8");
                    } catch (UnsupportedEncodingException e) {
                        throw new IllegalStateException("Query string is not UTF-8");
                    }
                }
                List<String> list = (List) this.parameters.get(name);
                if (list == null) {
                    list = new ArrayList();
                    this.parameters.put(name, list);
                }
                list.add(value);
            }
        }
    }

    public String get(String name) {
        List<String> values = (List) this.parameters.get(name);
        if (values == null) {
            return EXTHeader.DEFAULT_VALUE;
        }
        if (values.size() == 0) {
            return EXTHeader.DEFAULT_VALUE;
        }
        return (String) values.get(0);
    }

    public String[] getValues(String name) {
        List<String> values = (List) this.parameters.get(name);
        if (values == null) {
            return null;
        }
        return (String[]) values.toArray(new String[values.size()]);
    }

    public Enumeration<String> getNames() {
        return Collections.enumeration(this.parameters.keySet());
    }

    public Map<String, String[]> getMap() {
        Map<String, String[]> map = new TreeMap();
        for (Entry<String, List<String>> entry : this.parameters.entrySet()) {
            String[] values;
            List<String> list = (List) entry.getValue();
            if (list == null) {
                values = null;
            } else {
                values = (String[]) list.toArray(new String[list.size()]);
            }
            map.put(entry.getKey(), values);
        }
        return map;
    }

    public boolean isEmpty() {
        return this.parameters.size() == 0;
    }

    public String toString() {
        return this.qs;
    }
}
