package org.teleal.common.logging;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Map.Entry;
import java.util.Properties;
import java.util.logging.Handler;
import java.util.logging.LogManager;
import java.util.logging.Logger;
import org.teleal.cling.model.message.header.EXTHeader;

public class LoggingUtil {
    public static final String DEFAULT_CONFIG = "default-logging.properties";

    public static void loadDefaultConfiguration() throws Exception {
        loadDefaultConfiguration(null);
    }

    public static void loadDefaultConfiguration(InputStream is) throws Exception {
        if (System.getProperty("java.util.logging.config.file") == null) {
            if (is == null) {
                is = Thread.currentThread().getContextClassLoader().getResourceAsStream(DEFAULT_CONFIG);
            }
            if (is != null) {
                List<String> handlerNames = new ArrayList();
                LogManager.getLogManager().readConfiguration(spliceHandlers(is, handlerNames));
                resetRootHandler(instantiateHandlers(handlerNames));
            }
        }
    }

    public static Handler[] instantiateHandlers(List<String> handlerNames) throws Exception {
        List<Handler> list = new ArrayList();
        for (String handlerName : handlerNames) {
            list.add((Handler) Thread.currentThread().getContextClassLoader().loadClass(handlerName).newInstance());
        }
        return (Handler[]) list.toArray(new Handler[list.size()]);
    }

    public static InputStream spliceHandlers(InputStream is, List<String> handlers) throws IOException {
        Properties props = new Properties();
        props.load(is);
        StringBuilder sb = new StringBuilder();
        List<String> handlersProperties = new ArrayList();
        for (Entry<Object, Object> entry : props.entrySet()) {
            if (entry.getKey().equals("handlers")) {
                handlersProperties.add(entry.getValue().toString());
            } else {
                sb.append(entry.getKey()).append("=").append(entry.getValue()).append("\n");
            }
        }
        for (String handlersProperty : handlersProperties) {
            for (String handlerClass : handlersProperty.trim().split(" ")) {
                handlers.add(handlerClass.trim());
            }
        }
        return new ByteArrayInputStream(sb.toString().getBytes("ISO-8859-1"));
    }

    public static void resetRootHandler(Handler... h) {
        Logger rootLogger = LogManager.getLogManager().getLogger(EXTHeader.DEFAULT_VALUE);
        for (Handler handler : rootLogger.getHandlers()) {
            rootLogger.removeHandler(handler);
        }
        for (Handler handler2 : h) {
            LogManager.getLogManager().getLogger(EXTHeader.DEFAULT_VALUE).addHandler(handler2);
        }
    }
}
