package org.teleal.common.mock.http;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import org.teleal.cling.model.ServiceReference;

public class MockServletContext implements ServletContext {
    private Map<String, Object> attributes = new HashMap();
    private Map<String, String> initParameters = new HashMap();
    private File webInfClassesRoot;
    private File webInfRoot;
    private File webappRoot;

    public MockServletContext() {
        try {
            URL webxml = getClass().getResource("/WEB-INF/web.xml");
            if (webxml != null) {
                this.webInfRoot = new File(webxml.toURI()).getParentFile();
                if (this.webInfRoot != null) {
                    this.webInfClassesRoot = new File(this.webInfRoot.getParentFile().getPath() + "/classes");
                    this.webappRoot = this.webInfRoot.getParentFile();
                }
                processContextParameters(webxml);
                return;
            }
            this.webappRoot = new File(getClass().getResource("/.").toURI());
        } catch (URISyntaxException e) {
            throw new RuntimeException(e);
        }
    }

    private void processContextParameters(URL webXML) {
    }

    public Map<String, String> getInitParameters() {
        return this.initParameters;
    }

    public Map<String, Object> getAttributes() {
        return this.attributes;
    }

    public ServletContext getContext(String name) {
        return this;
    }

    public int getMajorVersion() {
        return 2;
    }

    public int getMinorVersion() {
        return 4;
    }

    public String getMimeType(String arg0) {
        return null;
    }

    public Set getResourcePaths(String name) {
        try {
            Enumeration<URL> enumeration = getClass().getClassLoader().getResources("WEB-INF");
            Set<String> result = new HashSet();
            while (enumeration.hasMoreElements()) {
                File rootFile = new File(((URL) enumeration.nextElement()).getPath()).getParentFile();
                File[] files = new File(rootFile.getPath() + name).listFiles();
                if (files != null) {
                    addPaths(result, files, rootFile.getPath());
                }
            }
            return result;
        } catch (IOException e) {
            throw new RuntimeException("Error finding webroot.", e);
        }
    }

    private static void addPaths(Set<String> result, File[] files, String rootPath) {
        for (File file : files) {
            String filePath = file.getPath().substring(rootPath.length()).replace('\\', '/');
            if (file.isDirectory()) {
                result.add(filePath + ServiceReference.DELIMITER);
            } else {
                result.add(filePath);
            }
        }
    }

    public URL getResource(String name) throws MalformedURLException {
        File file = getFile(name, this.webappRoot);
        if (file == null) {
            file = getFile(name, this.webInfRoot);
        }
        if (file == null) {
            file = getFile(name, this.webInfClassesRoot);
        }
        if (file != null) {
            return file.toURI().toURL();
        }
        return null;
    }

    private static File getFile(String name, File root) {
        if (root == null) {
            return null;
        }
        if (name.startsWith(ServiceReference.DELIMITER)) {
            name = name.substring(1);
        }
        File f = new File(root, name);
        if (f.exists()) {
            return f;
        }
        return null;
    }

    public InputStream getResourceAsStream(String name) {
        return getClass().getResourceAsStream(name);
    }

    public RequestDispatcher getRequestDispatcher(String url) {
        throw new UnsupportedOperationException();
    }

    public RequestDispatcher getNamedDispatcher(String name) {
        throw new UnsupportedOperationException();
    }

    public Servlet getServlet(String name) throws ServletException {
        throw new UnsupportedOperationException();
    }

    public Enumeration getServlets() {
        return null;
    }

    public Enumeration getServletNames() {
        return null;
    }

    public void log(String msg) {
    }

    public void log(Exception ex, String msg) {
    }

    public void log(String msg, Throwable ex) {
    }

    public String getRealPath(String relativePath) {
        if (this.webappRoot != null) {
            return this.webappRoot.getAbsolutePath() + relativePath;
        }
        return relativePath;
    }

    public String getServerInfo() {
        return null;
    }

    public String getInitParameter(String param) {
        return (String) this.initParameters.get(param);
    }

    public Enumeration getInitParameterNames() {
        return new IteratorEnumeration(this.initParameters.keySet().iterator());
    }

    public Object getAttribute(String att) {
        return this.attributes.get(att);
    }

    public Enumeration getAttributeNames() {
        return new IteratorEnumeration(this.attributes.keySet().iterator());
    }

    public void setAttribute(String att, Object value) {
        if (value == null) {
            this.attributes.remove(value);
        } else {
            this.attributes.put(att, value);
        }
    }

    public void removeAttribute(String att) {
        this.attributes.remove(att);
    }

    public String getServletContextName() {
        return "Mock";
    }

    public String getContextPath() {
        return null;
    }
}
