package org.teleal.common.swingfwk.logging;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JToolBar;
import javax.swing.SwingUtilities;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import org.teleal.common.swingfwk.AbstractController;
import org.teleal.common.swingfwk.Application;
import org.teleal.common.swingfwk.Controller;

public abstract class LogController extends AbstractController<JPanel> {
    private final JButton clearButton;
    private final JButton configureButton;
    private final JButton copyButton;
    private final JButton expandButton;
    private final JComboBox expirationComboBox;
    private final LogCategorySelector logCategorySelector;
    private final JTable logTable;
    private final LogTableModel logTableModel;
    private final JButton pauseButton;
    private final JLabel pauseLabel;
    private final JToolBar toolBar;

    class C04312 implements ListSelectionListener {
        C04312() {
        }

        public void valueChanged(ListSelectionEvent e) {
            if (!e.getValueIsAdjusting() && e.getSource() == LogController.this.logTable.getSelectionModel()) {
                int[] rows = LogController.this.logTable.getSelectedRows();
                if (rows == null || rows.length == 0) {
                    LogController.this.copyButton.setEnabled(false);
                    LogController.this.expandButton.setEnabled(false);
                } else if (rows.length == 1) {
                    LogController.this.copyButton.setEnabled(true);
                    if (((LogMessage) LogController.this.logTableModel.getValueAt(rows[0], 0)).getMessage().length() > LogController.this.getExpandMessageCharacterLimit()) {
                        LogController.this.expandButton.setEnabled(true);
                    } else {
                        LogController.this.expandButton.setEnabled(false);
                    }
                } else {
                    LogController.this.copyButton.setEnabled(true);
                    LogController.this.expandButton.setEnabled(false);
                }
            }
        }
    }

    class C04334 implements ActionListener {
        C04334() {
        }

        public void actionPerformed(ActionEvent e) {
            Application.center(LogController.this.logCategorySelector, LogController.this.getParentWindow());
            LogController.this.logCategorySelector.setVisible(!LogController.this.logCategorySelector.isVisible());
        }
    }

    class C04345 implements ActionListener {
        C04345() {
        }

        public void actionPerformed(ActionEvent e) {
            LogController.this.logTableModel.clearMessages();
        }
    }

    class C04356 implements ActionListener {
        C04356() {
        }

        public void actionPerformed(ActionEvent e) {
            StringBuilder sb = new StringBuilder();
            for (LogMessage message : LogController.this.getSelectedMessages()) {
                sb.append(message.toString()).append("\n");
            }
            Application.copyToClipboard(sb.toString());
        }
    }

    class C04367 implements ActionListener {
        C04367() {
        }

        public void actionPerformed(ActionEvent e) {
            List<LogMessage> messages = LogController.this.getSelectedMessages();
            if (messages.size() == 1) {
                LogController.this.expand((LogMessage) messages.get(0));
            }
        }
    }

    class C04378 implements ActionListener {
        C04378() {
        }

        public void actionPerformed(ActionEvent e) {
            LogController.this.logTableModel.setPaused(!LogController.this.logTableModel.isPaused());
            if (LogController.this.logTableModel.isPaused()) {
                LogController.this.pauseLabel.setText(" (Paused)");
            } else {
                LogController.this.pauseLabel.setText(" (Active)");
            }
        }
    }

    class C04389 implements ActionListener {
        C04389() {
        }

        public void actionPerformed(ActionEvent e) {
            LogController.this.logTableModel.setMaxAgeSeconds(((Expiration) ((JComboBox) e.getSource()).getSelectedItem()).getSeconds());
        }
    }

    public enum Expiration {
        TEN_SECONDS(10, "10 Seconds"),
        SIXTY_SECONDS(60, "60 Seconds"),
        FIVE_MINUTES(300, "5 Minutes"),
        NEVER(Integer.MAX_VALUE, "Never");
        
        private String label;
        private int seconds;

        private Expiration(int seconds, String label) {
            this.seconds = seconds;
            this.label = label;
        }

        public int getSeconds() {
            return this.seconds;
        }

        public String getLabel() {
            return this.label;
        }

        public String toString() {
            return getLabel();
        }
    }

    class C04751 extends LogTableCellRenderer {
        C04751() {
        }

        protected ImageIcon getWarnErrorIcon() {
            return LogController.this.getWarnErrorIcon();
        }

        protected ImageIcon getDebugIcon() {
            return LogController.this.getDebugIcon();
        }

        protected ImageIcon getTraceIcon() {
            return LogController.this.getTraceIcon();
        }

        protected ImageIcon getInfoIcon() {
            return LogController.this.getInfoIcon();
        }
    }

    protected abstract void expand(LogMessage logMessage);

    protected abstract Frame getParentWindow();

    public LogController(Controller parentController, List<LogCategory> logCategories) {
        this(parentController, Expiration.SIXTY_SECONDS, logCategories);
    }

    public LogController(Controller parentController, Expiration expiration, List<LogCategory> logCategories) {
        super(new JPanel(new BorderLayout()), parentController);
        this.toolBar = new JToolBar();
        this.configureButton = createConfigureButton();
        this.clearButton = createClearButton();
        this.copyButton = createCopyButton();
        this.expandButton = createExpandButton();
        this.pauseButton = createPauseButton();
        this.pauseLabel = new JLabel(" (Active)");
        this.expirationComboBox = new JComboBox(Expiration.values());
        this.logCategorySelector = new LogCategorySelector(logCategories);
        this.logTableModel = new LogTableModel(expiration.getSeconds());
        this.logTable = new JTable(this.logTableModel);
        this.logTable.setDefaultRenderer(LogMessage.class, new C04751());
        this.logTable.setCellSelectionEnabled(false);
        this.logTable.setRowSelectionAllowed(true);
        this.logTable.getSelectionModel().addListSelectionListener(new C04312());
        adjustTableUI();
        initializeToolBar(expiration);
        ((JPanel) getView()).setPreferredSize(new Dimension(250, 100));
        ((JPanel) getView()).setMinimumSize(new Dimension(250, 50));
        ((JPanel) getView()).add(new JScrollPane(this.logTable), "Center");
        ((JPanel) getView()).add(this.toolBar, "South");
    }

    public void pushMessage(final LogMessage message) {
        SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                LogController.this.logTableModel.pushMessage(message);
                if (!LogController.this.logTableModel.isPaused()) {
                    LogController.this.logTable.scrollRectToVisible(LogController.this.logTable.getCellRect(LogController.this.logTableModel.getRowCount() - 1, 0, true));
                }
            }
        });
    }

    protected void adjustTableUI() {
        this.logTable.setFocusable(false);
        this.logTable.setRowHeight(18);
        this.logTable.getTableHeader().setReorderingAllowed(false);
        this.logTable.setBorder(BorderFactory.createEmptyBorder());
        this.logTable.getColumnModel().getColumn(0).setMinWidth(30);
        this.logTable.getColumnModel().getColumn(0).setMaxWidth(30);
        this.logTable.getColumnModel().getColumn(0).setResizable(false);
        this.logTable.getColumnModel().getColumn(1).setMinWidth(90);
        this.logTable.getColumnModel().getColumn(1).setMaxWidth(90);
        this.logTable.getColumnModel().getColumn(1).setResizable(false);
        this.logTable.getColumnModel().getColumn(2).setMinWidth(100);
        this.logTable.getColumnModel().getColumn(2).setMaxWidth(250);
        this.logTable.getColumnModel().getColumn(3).setPreferredWidth(150);
        this.logTable.getColumnModel().getColumn(3).setMaxWidth(400);
        this.logTable.getColumnModel().getColumn(4).setPreferredWidth(600);
    }

    protected void initializeToolBar(Expiration expiration) {
        this.configureButton.setFocusable(false);
        this.configureButton.addActionListener(new C04334());
        this.clearButton.setFocusable(false);
        this.clearButton.addActionListener(new C04345());
        this.copyButton.setFocusable(false);
        this.copyButton.setEnabled(false);
        this.copyButton.addActionListener(new C04356());
        this.expandButton.setFocusable(false);
        this.expandButton.setEnabled(false);
        this.expandButton.addActionListener(new C04367());
        this.pauseButton.setFocusable(false);
        this.pauseButton.addActionListener(new C04378());
        this.expirationComboBox.setSelectedItem(expiration);
        this.expirationComboBox.setMaximumSize(new Dimension(100, 32));
        this.expirationComboBox.addActionListener(new C04389());
        this.toolBar.setFloatable(false);
        this.toolBar.add(this.copyButton);
        this.toolBar.add(this.expandButton);
        this.toolBar.add(Box.createHorizontalGlue());
        this.toolBar.add(this.configureButton);
        this.toolBar.add(this.clearButton);
        this.toolBar.add(this.pauseButton);
        this.toolBar.add(this.pauseLabel);
        this.toolBar.add(Box.createHorizontalGlue());
        this.toolBar.add(new JLabel("Clear after:"));
        this.toolBar.add(this.expirationComboBox);
    }

    protected List<LogMessage> getSelectedMessages() {
        List<LogMessage> messages = new ArrayList();
        for (int row : this.logTable.getSelectedRows()) {
            messages.add((LogMessage) this.logTableModel.getValueAt(row, 0));
        }
        return messages;
    }

    protected int getExpandMessageCharacterLimit() {
        return 100;
    }

    public LogTableModel getLogTableModel() {
        return this.logTableModel;
    }

    protected JButton createConfigureButton() {
        return new JButton("Options...", Application.createImageIcon(LogController.class, "img/configure.png"));
    }

    protected JButton createClearButton() {
        return new JButton("Clear Log", Application.createImageIcon(LogController.class, "img/removetext.png"));
    }

    protected JButton createCopyButton() {
        return new JButton("Copy", Application.createImageIcon(LogController.class, "img/copyclipboard.png"));
    }

    protected JButton createExpandButton() {
        return new JButton("Expand", Application.createImageIcon(LogController.class, "img/viewtext.png"));
    }

    protected JButton createPauseButton() {
        return new JButton("Pause/Continue Log", Application.createImageIcon(LogController.class, "img/pause.png"));
    }

    protected ImageIcon getWarnErrorIcon() {
        return Application.createImageIcon(LogController.class, "img/warn.png");
    }

    protected ImageIcon getDebugIcon() {
        return Application.createImageIcon(LogController.class, "img/debug.png");
    }

    protected ImageIcon getTraceIcon() {
        return Application.createImageIcon(LogController.class, "img/trace.png");
    }

    protected ImageIcon getInfoIcon() {
        return Application.createImageIcon(LogController.class, "img/info.png");
    }
}
