package org.teleal.common.util;

import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import javax.imageio.ImageIO;
import javax.swing.ImageIcon;
import org.teleal.cling.model.message.header.EXTHeader;

public class Gfx {
    public static byte[] resizeProportionally(ImageIcon icon, String contentType, int newWidth, int newHeight) throws IOException {
        double widthRatio = newWidth != icon.getIconWidth() ? ((double) newWidth) / ((double) icon.getIconWidth()) : 1.0d;
        double heightRatio = newHeight != icon.getIconHeight() ? ((double) newHeight) / ((double) icon.getIconHeight()) : 1.0d;
        if (widthRatio < heightRatio) {
            newHeight = (int) (((double) icon.getIconHeight()) * widthRatio);
        } else {
            newWidth = (int) (((double) icon.getIconWidth()) * heightRatio);
        }
        BufferedImage bImg = new BufferedImage(icon.getIconWidth(), icon.getIconHeight(), "image/png".equals(contentType) ? 2 : 1);
        Graphics2D g2d = bImg.createGraphics();
        g2d.drawImage(icon.getImage(), 0, 0, icon.getIconWidth(), icon.getIconHeight(), null);
        g2d.dispose();
        BufferedImage scaledImg = getScaledInstance(bImg, newWidth, newHeight, RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR, false);
        String formatName = EXTHeader.DEFAULT_VALUE;
        if ("image/png".equals(contentType)) {
            formatName = "png";
        } else if ("image/jpeg".equals(contentType) || "image/jpg".equals(contentType)) {
            formatName = "jpeg";
        }
        ByteArrayOutputStream baos = new ByteArrayOutputStream(1024);
        ImageIO.write(scaledImg, formatName, baos);
        return baos.toByteArray();
    }

    public static BufferedImage getScaledInstance(BufferedImage img, int targetWidth, int targetHeight, Object hint, boolean higherQuality) {
        int w;
        int h;
        int type = 1;
        if (img.getTransparency() != 1) {
            type = 2;
        }
        BufferedImage ret = img;
        if (higherQuality) {
            w = img.getWidth();
            h = img.getHeight();
        } else {
            w = targetWidth;
            h = targetHeight;
        }
        while (true) {
            if (higherQuality && w > targetWidth) {
                w /= 2;
                if (w < targetWidth) {
                    w = targetWidth;
                }
            }
            if (higherQuality && h > targetHeight) {
                h /= 2;
                if (h < targetHeight) {
                    h = targetHeight;
                }
            }
            BufferedImage tmp = new BufferedImage(w, h, type);
            Graphics2D g2 = tmp.createGraphics();
            g2.setRenderingHint(RenderingHints.KEY_INTERPOLATION, hint);
            g2.drawImage(ret, 0, 0, w, h, null);
            g2.dispose();
            ret = tmp;
            if (w == targetWidth && h == targetHeight) {
                return ret;
            }
        }
    }
}
