package org.teleal.common.util;

import java.io.UnsupportedEncodingException;
import org.teleal.cling.model.message.header.EXTHeader;

public final class HexBin {
    private static final int BASELENGTH = 255;
    private static final int LOOKUPLENGTH = 16;
    private static byte[] hexNumberTable = new byte[BASELENGTH];
    private static byte[] lookUpHexAlphabet = new byte[16];

    static {
        int i;
        for (i = 0; i < BASELENGTH; i++) {
            hexNumberTable[i] = (byte) -1;
        }
        for (i = 57; i >= 48; i--) {
            hexNumberTable[i] = (byte) (i - 48);
        }
        for (i = 70; i >= 65; i--) {
            hexNumberTable[i] = (byte) ((i - 65) + 10);
        }
        for (i = 102; i >= 97; i--) {
            hexNumberTable[i] = (byte) ((i - 97) + 10);
        }
        for (i = 0; i < 10; i++) {
            lookUpHexAlphabet[i] = (byte) (i + 48);
        }
        for (i = 10; i <= 15; i++) {
            lookUpHexAlphabet[i] = (byte) ((i + 65) - 10);
        }
    }

    static boolean isHex(byte octect) {
        return hexNumberTable[octect] != (byte) -1;
    }

    public static String bytesToString(byte[] binaryData) {
        if (binaryData == null) {
            return null;
        }
        return new String(encode(binaryData));
    }

    public static String bytesToString(byte[] binaryData, String separator) {
        if (binaryData == null) {
            return null;
        }
        String s = new String(encode(binaryData));
        StringBuilder sb = new StringBuilder();
        int i = 1;
        for (char c : s.toCharArray()) {
            sb.append(c);
            if (i == 2) {
                sb.append(separator);
                i = 1;
            } else {
                i++;
            }
        }
        sb.deleteCharAt(sb.length() - 1);
        return sb.toString();
    }

    public static byte[] stringToBytes(String hexEncoded) {
        return decode(hexEncoded.getBytes());
    }

    public static byte[] stringToBytes(String hexEncoded, String separator) {
        return decode(hexEncoded.replaceAll(separator, EXTHeader.DEFAULT_VALUE).getBytes());
    }

    public static byte[] encode(byte[] binaryData) {
        if (binaryData == null) {
            return null;
        }
        int lengthData = binaryData.length;
        byte[] encodedData = new byte[(lengthData * 2)];
        for (int i = 0; i < lengthData; i++) {
            encodedData[i * 2] = lookUpHexAlphabet[(binaryData[i] >> 4) & 15];
            encodedData[(i * 2) + 1] = lookUpHexAlphabet[binaryData[i] & 15];
        }
        return encodedData;
    }

    public static byte[] decode(byte[] binaryData) {
        if (binaryData == null) {
            return null;
        }
        int lengthData = binaryData.length;
        if (lengthData % 2 != 0) {
            return null;
        }
        int lengthDecode = lengthData / 2;
        byte[] decodedData = new byte[lengthDecode];
        int i = 0;
        while (i < lengthDecode) {
            if (!isHex(binaryData[i * 2]) || !isHex(binaryData[(i * 2) + 1])) {
                return null;
            }
            decodedData[i] = (byte) ((hexNumberTable[binaryData[i * 2]] << 4) | hexNumberTable[binaryData[(i * 2) + 1]]);
            i++;
        }
        return decodedData;
    }

    public static String decode(String binaryData) {
        if (binaryData == null) {
            return null;
        }
        byte[] decoded = null;
        try {
            decoded = decode(binaryData.getBytes("utf-8"));
        } catch (UnsupportedEncodingException e) {
        }
        if (decoded != null) {
            return new String(decoded);
        }
        return null;
    }

    public static String encode(String binaryData) {
        if (binaryData == null) {
            return null;
        }
        byte[] encoded = null;
        try {
            encoded = encode(binaryData.getBytes("utf-8"));
        } catch (UnsupportedEncodingException e) {
        }
        if (encoded != null) {
            return new String(encoded);
        }
        return null;
    }
}
