package org.teleal.common.util;

import java.io.UnsupportedEncodingException;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.BitSet;
import org.teleal.cling.model.ServiceReference;
import org.teleal.cling.model.message.header.EXTHeader;

public class URIUtil {
    static final /* synthetic */ boolean $assertionsDisabled;
    public static final BitSet ALPHA = new BitSet();
    public static final BitSet ALPHANUM = new BitSet();
    public static final BitSet DIGIT = new BitSet();
    public static final BitSet FRAGMENT = new BitSet();
    public static final BitSet GEN_DELIMS = new BitSet();
    public static final BitSet LOW_ALPHA = new BitSet();
    public static final BitSet PATH_PARAM_NAME = new BitSet();
    public static final BitSet PATH_PARAM_VALUE = new BitSet();
    public static final BitSet PATH_SEGMENT = new BitSet();
    public static final BitSet PCHAR = new BitSet();
    public static final BitSet QUERY = new BitSet();
    public static final BitSet RESERVED = new BitSet();
    public static final BitSet SUB_DELIMS = new BitSet();
    public static final BitSet UNRESERVED = new BitSet();
    public static final BitSet UP_ALPHA = new BitSet();

    static {
        boolean z;
        if (URIUtil.class.desiredAssertionStatus()) {
            z = false;
        } else {
            z = true;
        }
        $assertionsDisabled = z;
        GEN_DELIMS.set(58);
        GEN_DELIMS.set(47);
        GEN_DELIMS.set(63);
        GEN_DELIMS.set(35);
        GEN_DELIMS.set(91);
        GEN_DELIMS.set(93);
        GEN_DELIMS.set(64);
        SUB_DELIMS.set(33);
        SUB_DELIMS.set(36);
        SUB_DELIMS.set(38);
        SUB_DELIMS.set(39);
        SUB_DELIMS.set(40);
        SUB_DELIMS.set(41);
        SUB_DELIMS.set(42);
        SUB_DELIMS.set(43);
        SUB_DELIMS.set(44);
        SUB_DELIMS.set(59);
        SUB_DELIMS.set(61);
        RESERVED.or(GEN_DELIMS);
        RESERVED.or(SUB_DELIMS);
        LOW_ALPHA.set(97);
        LOW_ALPHA.set(98);
        LOW_ALPHA.set(99);
        LOW_ALPHA.set(100);
        LOW_ALPHA.set(101);
        LOW_ALPHA.set(102);
        LOW_ALPHA.set(103);
        LOW_ALPHA.set(104);
        LOW_ALPHA.set(105);
        LOW_ALPHA.set(106);
        LOW_ALPHA.set(107);
        LOW_ALPHA.set(108);
        LOW_ALPHA.set(109);
        LOW_ALPHA.set(110);
        LOW_ALPHA.set(111);
        LOW_ALPHA.set(112);
        LOW_ALPHA.set(113);
        LOW_ALPHA.set(114);
        LOW_ALPHA.set(115);
        LOW_ALPHA.set(116);
        LOW_ALPHA.set(117);
        LOW_ALPHA.set(118);
        LOW_ALPHA.set(119);
        LOW_ALPHA.set(120);
        LOW_ALPHA.set(121);
        LOW_ALPHA.set(122);
        UP_ALPHA.set(65);
        UP_ALPHA.set(66);
        UP_ALPHA.set(67);
        UP_ALPHA.set(68);
        UP_ALPHA.set(69);
        UP_ALPHA.set(70);
        UP_ALPHA.set(71);
        UP_ALPHA.set(72);
        UP_ALPHA.set(73);
        UP_ALPHA.set(74);
        UP_ALPHA.set(75);
        UP_ALPHA.set(76);
        UP_ALPHA.set(77);
        UP_ALPHA.set(78);
        UP_ALPHA.set(79);
        UP_ALPHA.set(80);
        UP_ALPHA.set(81);
        UP_ALPHA.set(82);
        UP_ALPHA.set(83);
        UP_ALPHA.set(84);
        UP_ALPHA.set(85);
        UP_ALPHA.set(86);
        UP_ALPHA.set(87);
        UP_ALPHA.set(88);
        UP_ALPHA.set(89);
        UP_ALPHA.set(90);
        ALPHA.or(LOW_ALPHA);
        ALPHA.or(UP_ALPHA);
        DIGIT.set(48);
        DIGIT.set(49);
        DIGIT.set(50);
        DIGIT.set(51);
        DIGIT.set(52);
        DIGIT.set(53);
        DIGIT.set(54);
        DIGIT.set(55);
        DIGIT.set(56);
        DIGIT.set(57);
        ALPHANUM.or(ALPHA);
        ALPHANUM.or(DIGIT);
        UNRESERVED.or(ALPHA);
        UNRESERVED.or(DIGIT);
        UNRESERVED.set(45);
        UNRESERVED.set(46);
        UNRESERVED.set(95);
        UNRESERVED.set(126);
        PCHAR.or(UNRESERVED);
        PCHAR.or(SUB_DELIMS);
        PCHAR.set(58);
        PCHAR.set(64);
        PATH_SEGMENT.or(PCHAR);
        PATH_SEGMENT.clear(59);
        PATH_PARAM_NAME.or(PCHAR);
        PATH_PARAM_NAME.clear(59);
        PATH_PARAM_NAME.clear(61);
        PATH_PARAM_VALUE.or(PCHAR);
        PATH_PARAM_VALUE.clear(59);
        QUERY.or(PCHAR);
        QUERY.set(47);
        QUERY.set(63);
        QUERY.clear(61);
        QUERY.clear(38);
        QUERY.clear(43);
        FRAGMENT.or(PCHAR);
        FRAGMENT.set(47);
        FRAGMENT.set(63);
    }

    public static URI createAbsoluteURI(URI base, String uri) throws IllegalArgumentException {
        return createAbsoluteURI(base, URI.create(uri));
    }

    public static URI createAbsoluteURI(URI base, URI relativeOrNot) throws IllegalArgumentException {
        if (base == null && !relativeOrNot.isAbsolute()) {
            throw new IllegalArgumentException("Base URI is null and given URI is not absolute");
        } else if (base == null && relativeOrNot.isAbsolute()) {
            return relativeOrNot;
        } else {
            if ($assertionsDisabled || base != null) {
                if (base.getPath().length() == 0) {
                    try {
                        base = new URI(base.getScheme(), base.getAuthority(), ServiceReference.DELIMITER, base.getQuery(), base.getFragment());
                    } catch (Exception ex) {
                        throw new IllegalArgumentException(ex);
                    }
                }
                return base.resolve(relativeOrNot);
            }
            throw new AssertionError();
        }
    }

    public static URL createAbsoluteURL(URL base, String uri) throws IllegalArgumentException {
        return createAbsoluteURL(base, URI.create(uri));
    }

    public static URL createAbsoluteURL(URL base, URI relativeOrNot) throws IllegalArgumentException {
        if (base != null || relativeOrNot.isAbsolute()) {
            URL toURL;
            if (base == null && relativeOrNot.isAbsolute()) {
                try {
                    toURL = relativeOrNot.toURL();
                } catch (Exception e) {
                    throw new IllegalArgumentException("Base URL was null and given URI can't be converted to URL");
                }
            }
            try {
                if ($assertionsDisabled || base != null) {
                    toURL = createAbsoluteURI(base.toURI(), relativeOrNot).toURL();
                } else {
                    throw new AssertionError();
                }
            } catch (Exception ex) {
                throw new IllegalArgumentException("Base URL is not an URI, or can't create absolute URI (null?), or absolute URI can not be converted to URL", ex);
            }
            return toURL;
        }
        throw new IllegalArgumentException("Base URL is null and given URI is not absolute");
    }

    public static URL createAbsoluteURL(URI base, URI relativeOrNot) throws IllegalArgumentException {
        try {
            return createAbsoluteURI(base, relativeOrNot).toURL();
        } catch (Exception ex) {
            throw new IllegalArgumentException("Absolute URI can not be converted to URL", ex);
        }
    }

    public static URL createAbsoluteURL(InetAddress address, int localStreamPort, URI relativeOrNot) throws IllegalArgumentException {
        try {
            if (address instanceof Inet6Address) {
                return createAbsoluteURL(new URL("http://[" + address.getHostAddress() + "]:" + localStreamPort), relativeOrNot);
            }
            if (address instanceof Inet4Address) {
                return createAbsoluteURL(new URL("http://" + address.getHostAddress() + ":" + localStreamPort), relativeOrNot);
            }
            throw new IllegalArgumentException("InetAddress is neither IPv4 nor IPv6: " + address);
        } catch (Exception ex) {
            throw new IllegalArgumentException("Address, port, and URI can not be converted to URL", ex);
        }
    }

    public static URI createRelativePathURI(URI uri) {
        assertRelativeURI("Given", uri);
        String uriString = uri.normalize().toString();
        while (true) {
            int idx = uriString.indexOf("../");
            if (idx == -1) {
                break;
            }
            uriString = uriString.substring(0, idx) + uriString.substring(idx + 3);
        }
        while (uriString.startsWith(ServiceReference.DELIMITER)) {
            uriString = uriString.substring(1);
        }
        return URI.create(uriString);
    }

    public static URI createRelativeURI(URI base, URI full) {
        return base.relativize(full);
    }

    public static URI createRelativeURI(URL base, URL full) throws IllegalArgumentException {
        try {
            return createRelativeURI(base.toURI(), full.toURI());
        } catch (Exception ex) {
            throw new IllegalArgumentException("Can't convert base or full URL to URI", ex);
        }
    }

    public static URI createRelativeURI(URI base, URL full) throws IllegalArgumentException {
        try {
            return createRelativeURI(base, full.toURI());
        } catch (Exception ex) {
            throw new IllegalArgumentException("Can't convert full URL to URI", ex);
        }
    }

    public static URI createRelativeURI(URL base, URI full) throws IllegalArgumentException {
        try {
            return createRelativeURI(base.toURI(), full);
        } catch (Exception ex) {
            throw new IllegalArgumentException("Can't convert base URL to URI", ex);
        }
    }

    public static boolean isAbsoluteURI(String s) {
        return URI.create(s).isAbsolute();
    }

    public static void assertRelativeURI(String what, URI uri) {
        if (uri.isAbsolute()) {
            throw new IllegalArgumentException(what + " URI must be relative, without scheme and authority");
        }
    }

    public static URL toURL(URI uri) {
        if (uri == null) {
            return null;
        }
        try {
            return uri.toURL();
        } catch (MalformedURLException ex) {
            throw new RuntimeException(ex);
        }
    }

    public static URI toURI(URL url) {
        if (url == null) {
            return null;
        }
        try {
            return url.toURI();
        } catch (URISyntaxException ex) {
            throw new RuntimeException(ex);
        }
    }

    public static String percentEncode(String s) {
        if (s == null) {
            return EXTHeader.DEFAULT_VALUE;
        }
        try {
            return URLEncoder.encode(s, "UTF-8");
        } catch (Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    public static String percentDecode(String s) {
        if (s == null) {
            return EXTHeader.DEFAULT_VALUE;
        }
        try {
            return URLDecoder.decode(s, "UTF-8");
        } catch (Exception ex) {
            throw new RuntimeException(ex);
        }
    }

    public static String encodePathParamName(String pathParamName) {
        try {
            return encodePart(pathParamName, "UTF-8", PATH_PARAM_NAME);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException(e);
        }
    }

    public static String encodePathParamValue(String pathParamValue) {
        try {
            return encodePart(pathParamValue, "UTF-8", PATH_PARAM_VALUE);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException(e);
        }
    }

    public static String encodeQueryNameOrValue(String queryNameOrValue) {
        try {
            return encodePart(queryNameOrValue, "UTF-8", QUERY);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException(e);
        }
    }

    public static String encodeQueryNameOrValueNoParen(String queryNameOrValueNoParen) {
        try {
            return encodePart(queryNameOrValueNoParen, "UTF-8", QUERY).replace("(", EXTHeader.DEFAULT_VALUE).replace(")", EXTHeader.DEFAULT_VALUE);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException(e);
        }
    }

    public static String encodePathSegment(String pathSegment) {
        try {
            return encodePart(pathSegment, "UTF-8", PATH_SEGMENT);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException(e);
        }
    }

    public static String encodePart(String part, String charset, BitSet allowed) throws UnsupportedEncodingException {
        if (part == null) {
            return null;
        }
        StringBuffer encoded = new StringBuffer(part.length() * 3);
        for (char c : part.toCharArray()) {
            if (allowed.get(c)) {
                encoded.append(c);
            } else {
                int len$ = String.valueOf(c).getBytes(charset).length;
                for (int i$ = 0; i$ < len$; i$++) {
                    encoded.append(String.format("%%%1$02X", new Object[]{Integer.valueOf(arr$[i$] & 255)}));
                }
            }
        }
        return encoded.toString();
    }
}
