package org.teleal.common.xhtml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

public class Option {
    private String key;
    private String[] values;

    public Option(String key, String[] values) {
        this.key = key;
        this.values = values;
    }

    public static Option[] fromString(String string) {
        if (string == null || string.length() == 0) {
            return new Option[0];
        }
        List<Option> options = new ArrayList();
        try {
            for (String field : string.split(";")) {
                String[] keyValues = field.trim().split(":");
                String key = keyValues[0].trim();
                String[] values = keyValues[1].split(",");
                for (int i = 0; i < values.length; i++) {
                    values[i] = values[i].trim();
                }
                options.add(new Option(key, values));
            }
            return (Option[]) options.toArray(new Option[options.size()]);
        } catch (Exception ex) {
            throw new IllegalArgumentException("Can't parse options string: " + string, ex);
        }
    }

    public String getKey() {
        return this.key;
    }

    public String[] getValues() {
        return this.values;
    }

    public boolean isTrue() {
        return getValues().length == 1 && getValues()[0].toLowerCase().equals("true");
    }

    public boolean isFalse() {
        return getValues().length == 1 && getValues()[0].toLowerCase().equals("false");
    }

    public String getFirstValue() {
        return getValues()[0];
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getKey()).append(": ");
        Iterator<String> it = Arrays.asList(getValues()).iterator();
        while (it.hasNext()) {
            sb.append((String) it.next());
            if (it.hasNext()) {
                sb.append(", ");
            }
        }
        return sb.toString();
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Option that = (Option) o;
        if (!this.key.equals(that.key)) {
            return false;
        }
        if (Arrays.equals(this.values, that.values)) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return (this.key.hashCode() * 31) + Arrays.hashCode(this.values);
    }
}
