package org.teleal.common.xhtml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.xpath.XPath;
import org.teleal.common.xhtml.XHTML.ATTR;
import org.teleal.common.xhtml.XHTML.ELEMENT;
import org.teleal.common.xml.DOMElement;
import org.teleal.common.xml.DOMElement.ArrayBuilder;
import org.teleal.common.xml.DOMElement.Builder;
import org.w3c.dom.Element;

public class XHTMLElement extends DOMElement<XHTMLElement, XHTMLElement> {
    public static final String XPATH_PREFIX = "h";

    public XHTMLElement(XPath xpath, Element element) {
        super(xpath, element);
    }

    protected Builder<XHTMLElement> createParentBuilder(DOMElement el) {
        return new Builder<XHTMLElement>(el) {
            public XHTMLElement build(Element element) {
                return new XHTMLElement(XHTMLElement.this.getXpath(), element);
            }
        };
    }

    protected ArrayBuilder<XHTMLElement> createChildBuilder(DOMElement el) {
        return new ArrayBuilder<XHTMLElement>(el) {
            public XHTMLElement[] newChildrenArray(int length) {
                return new XHTMLElement[length];
            }

            public XHTMLElement build(Element element) {
                return new XHTMLElement(XHTMLElement.this.getXpath(), element);
            }
        };
    }

    protected String prefix(String localName) {
        return "h:" + localName;
    }

    public ELEMENT getConstant() {
        return ELEMENT.valueOf(getElementName());
    }

    public XHTMLElement[] getChildren(ELEMENT el) {
        return (XHTMLElement[]) super.getChildren(el.name());
    }

    public XHTMLElement getFirstChild(ELEMENT el) {
        return (XHTMLElement) super.getFirstChild(el.name());
    }

    public XHTMLElement[] findChildren(ELEMENT el) {
        return (XHTMLElement[]) super.findChildren(el.name());
    }

    public XHTMLElement createChild(ELEMENT el) {
        return (XHTMLElement) super.createChild(el.name(), XHTML.NAMESPACE_URI);
    }

    public String getAttribute(ATTR attribute) {
        return getAttribute(attribute.name());
    }

    public XHTMLElement setAttribute(ATTR attribute, String value) {
        super.setAttribute(attribute.name(), value);
        return this;
    }

    public String getId() {
        return getAttribute(ATTR.id);
    }

    public XHTMLElement setId(String id) {
        setAttribute(ATTR.id, id);
        return this;
    }

    public String getTitle() {
        return getAttribute(ATTR.title);
    }

    public XHTMLElement setTitle(String title) {
        setAttribute(ATTR.title, title);
        return this;
    }

    public XHTMLElement setClasses(String classes) {
        setAttribute(ATTR.CLASS, classes);
        return this;
    }

    public XHTMLElement setClasses(String[] classes) {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < classes.length; i++) {
            sb.append(classes[i]);
            if (i != classes.length - 1) {
                sb.append(" ");
            }
        }
        setAttribute(ATTR.CLASS, sb.toString());
        return this;
    }

    public String[] getClasses() {
        String v = getAttribute(ATTR.CLASS);
        if (v == null) {
            return new String[0];
        }
        return v.split(" ");
    }

    public Option[] getOptions() {
        return Option.fromString(getAttribute(ATTR.style));
    }

    public Option getOption(String key) {
        for (Option option : getOptions()) {
            if (option.getKey().equals(key)) {
                return option;
            }
        }
        return null;
    }

    public Anchor[] findAllAnchors(String requiredScheme) {
        return findAllAnchors(requiredScheme, null);
    }

    public Anchor[] findAllAnchors(String requiredScheme, String requiredClass) {
        XHTMLElement[] elements = findChildrenWithClass(ELEMENT.a, requiredClass);
        List<Anchor> anchors = new ArrayList(elements.length);
        for (XHTMLElement element : elements) {
            String href = element.getAttribute(ATTR.href);
            if (requiredScheme == null || (href != null && href.startsWith(requiredScheme))) {
                anchors.add(new Anchor(getXpath(), element.getW3CElement()));
            }
        }
        return (Anchor[]) anchors.toArray(new Anchor[anchors.size()]);
    }

    public XHTMLElement[] findChildrenWithClass(ELEMENT el, String clazz) {
        List<XHTMLElement> list = new ArrayList();
        for (XHTMLElement child : findChildren(el)) {
            if (clazz == null) {
                list.add(child);
            } else {
                for (String c : child.getClasses()) {
                    if (c.matches(clazz)) {
                        list.add(child);
                        break;
                    }
                }
            }
        }
        return (XHTMLElement[]) list.toArray(this.CHILD_BUILDER.newChildrenArray(list.size()));
    }

    public XHTMLElement setContent(String content) {
        super.setContent(content);
        return this;
    }

    public XHTMLElement setAttribute(String attribute, String value) {
        super.setAttribute(attribute, value);
        return this;
    }
}
