package org.teleal.common.xhtml;

import java.util.HashSet;
import java.util.Set;
import javax.xml.xpath.XPath;
import org.teleal.cling.model.message.header.EXTHeader;
import org.teleal.common.xhtml.XHTML.ATTR;
import org.teleal.common.xml.DOMParser;
import org.teleal.common.xml.DOMParser.NodeVisitor;
import org.teleal.common.xml.NamespaceContextMap;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

public class XHTMLParser extends DOMParser<XHTML> {

    class C04802 extends NamespaceContextMap {
        C04802() {
        }

        protected String getDefaultNamespaceURI() {
            return XHTML.NAMESPACE_URI;
        }
    }

    public XHTMLParser() {
        super(XHTML.createSchemaSources());
    }

    protected XHTML createDOM(Document document) {
        return document != null ? new XHTML(document) : null;
    }

    public void checkDuplicateIdentifiers(XHTML document) throws IllegalStateException {
        final Set<String> identifiers = new HashSet();
        DOMParser.accept(document.getW3CDocument().getDocumentElement(), new NodeVisitor((short) 1) {
            public void visit(Node node) {
                String id = ((Element) node).getAttribute(ATTR.id.name());
                if (!EXTHeader.DEFAULT_VALUE.equals(id)) {
                    if (identifiers.contains(id)) {
                        throw new IllegalStateException("Duplicate identifier, override/change value: " + id);
                    }
                    identifiers.add(id);
                }
            }
        });
    }

    public NamespaceContextMap createDefaultNamespaceContext(String... optionalPrefixes) {
        NamespaceContextMap ctx = new C04802();
        for (String optionalPrefix : optionalPrefixes) {
            ctx.put(optionalPrefix, XHTML.NAMESPACE_URI);
        }
        return ctx;
    }

    public XPath createXPath() {
        return super.createXPath(createDefaultNamespaceContext(XHTMLElement.XPATH_PREFIX));
    }
}
