package org.teleal.cling.transport.impl;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.ProtocolException;
import java.net.Proxy;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLStreamHandler;
import java.net.URLStreamHandlerFactory;
import java.util.List;
import java.util.Map.Entry;
import java.util.logging.Logger;
import org.teleal.cling.model.message.StreamRequestMessage;
import org.teleal.cling.model.message.StreamResponseMessage;
import org.teleal.cling.model.message.UpnpHeaders;
import org.teleal.cling.model.message.UpnpMessage.BodyType;
import org.teleal.cling.model.message.UpnpResponse;
import org.teleal.cling.transport.spi.InitializationException;
import org.teleal.cling.transport.spi.StreamClient;
import org.teleal.common.http.Headers;
import org.teleal.common.io.IO;
import org.teleal.common.mock.http.MockHttpServletRequest;
import sun.net.www.protocol.http.Handler;
import sun.net.www.protocol.http.HttpURLConnection;

public class StreamClientImpl implements StreamClient {
    static final String HACK_STREAM_HANDLER_SYSTEM_PROPERTY = "hackStreamHandlerProperty";
    private static final Logger log = Logger.getLogger(StreamClient.class.getName());
    protected final StreamClientConfigurationImpl configuration;

    class C04191 implements URLStreamHandlerFactory {

        class C04181 extends Handler {
            C04181() {
            }

            protected URLConnection openConnection(URL u) throws IOException {
                return openConnection(u, null);
            }

            protected URLConnection openConnection(URL u, Proxy p) throws IOException {
                return new UpnpURLConnection(u, this);
            }
        }

        C04191() {
        }

        public URLStreamHandler createURLStreamHandler(String protocol) {
            StreamClientImpl.log.fine("Creating new URLStreamHandler for protocol: " + protocol);
            return MockHttpServletRequest.DEFAULT_PROTOCOL.equals(protocol) ? new C04181() : null;
        }
    }

    static class UpnpURLConnection extends HttpURLConnection {
        private static final String[] methods = new String[]{"GET", "POST", "HEAD", "OPTIONS", "PUT", "DELETE", "SUBSCRIBE", "UNSUBSCRIBE", "NOTIFY"};

        protected UpnpURLConnection(URL u, Handler handler) throws IOException {
            super(u, handler);
        }

        public UpnpURLConnection(URL u, String host, int port) throws IOException {
            super(u, host, port);
        }

        public synchronized OutputStream getOutputStream() throws IOException {
            OutputStream os;
            String savedMethod = this.method;
            if (this.method.equals("PUT") || this.method.equals("POST") || this.method.equals("NOTIFY")) {
                this.method = "PUT";
            } else {
                this.method = "GET";
            }
            os = super.getOutputStream();
            this.method = savedMethod;
            return os;
        }

        public void setRequestMethod(String method) throws ProtocolException {
            if (this.connected) {
                throw new ProtocolException("Cannot reset method once connected");
            }
            for (String m : methods) {
                if (m.equals(method)) {
                    this.method = method;
                    return;
                }
            }
            throw new ProtocolException("Invalid UPnP HTTP method: " + method);
        }
    }

    public org.teleal.cling.model.message.StreamResponseMessage sendRequest(org.teleal.cling.model.message.StreamRequestMessage r12) {
        /* JADX: method processing error */
/*
Error: jadx.core.utils.exceptions.JadxRuntimeException: Can't find block by offset: 0x0086 in list [B:5:0x0083]
	at jadx.core.utils.BlockUtils.getBlockByOffset(BlockUtils.java:42)
	at jadx.core.dex.instructions.IfNode.initBlocks(IfNode.java:60)
	at jadx.core.dex.visitors.blocksmaker.BlockFinish.initBlocksInIfNodes(BlockFinish.java:48)
	at jadx.core.dex.visitors.blocksmaker.BlockFinish.visit(BlockFinish.java:33)
	at jadx.core.dex.visitors.DepthTraversal.visit(DepthTraversal.java:31)
	at jadx.core.dex.visitors.DepthTraversal.visit(DepthTraversal.java:17)
	at jadx.core.ProcessClass.process(ProcessClass.java:37)
	at jadx.api.JadxDecompiler.processClass(JadxDecompiler.java:306)
	at jadx.api.JavaClass.decompile(JavaClass.java:62)
	at jadx.api.JadxDecompiler$1.run(JadxDecompiler.java:199)
*/
        /*
        r11 = this;
        r8 = 0;
        r4 = r12.getOperation();
        r4 = (org.teleal.cling.model.message.UpnpRequest) r4;
        r7 = log;
        r9 = new java.lang.StringBuilder;
        r9.<init>();
        r10 = "Preparing HTTP request message with method '";
        r9 = r9.append(r10);
        r10 = r4.getHttpMethodName();
        r9 = r9.append(r10);
        r10 = "': ";
        r9 = r9.append(r10);
        r9 = r9.append(r12);
        r9 = r9.toString();
        r7.fine(r9);
        r7 = r4.getURI();
        r5 = org.teleal.common.util.URIUtil.toURL(r7);
        r6 = 0;
        r7 = r5.openConnection();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r0 = r7;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r0 = (java.net.HttpURLConnection) r0;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r6 = r0;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r4.getHttpMethodName();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r6.setRequestMethod(r7);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r11.configuration;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r7.getDataReadTimeoutSeconds();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r7 * 1000;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r6.setReadTimeout(r7);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r11.configuration;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r7.getConnectionTimeoutSeconds();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r7 * 1000;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r6.setConnectTimeout(r7);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r11.applyRequestProperties(r6, r12);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r11.applyRequestBody(r6, r12);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = log;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = new java.lang.StringBuilder;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9.<init>();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r10 = "Sending HTTP request: ";	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r10);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r12);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.toString();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7.fine(r9);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r3 = r6.getInputStream();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7 = r11.createResponse(r6, r3);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        if (r6 == 0) goto L_0x0086;
    L_0x0083:
        r6.disconnect();
    L_0x0086:
        return r7;
    L_0x0087:
        r2 = move-exception;
        r7 = log;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = new java.lang.StringBuilder;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9.<init>();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r10 = "Unrecoverable HTTP protocol exception: ";	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r10);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r2);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.toString();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7.fine(r9);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        if (r6 == 0) goto L_0x00a5;
    L_0x00a2:
        r6.disconnect();
    L_0x00a5:
        r7 = r8;
        goto L_0x0086;
    L_0x00a7:
        r2 = move-exception;
        if (r6 != 0) goto L_0x00cd;
    L_0x00aa:
        r7 = log;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = new java.lang.StringBuilder;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9.<init>();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r10 = "Could not open URL connection: ";	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r10);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r10 = r2.getMessage();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r10);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.toString();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7.info(r9);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        if (r6 == 0) goto L_0x00cb;
    L_0x00c8:
        r6.disconnect();
    L_0x00cb:
        r7 = r8;
        goto L_0x0086;
    L_0x00cd:
        r7 = log;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = "Exception occured, trying to read the error stream";	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7.fine(r9);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r3 = r6.getErrorStream();	 Catch:{ Exception -> 0x00e2 }
        r7 = r11.createResponse(r6, r3);	 Catch:{ Exception -> 0x00e2 }
        if (r6 == 0) goto L_0x0086;
    L_0x00de:
        r6.disconnect();
        goto L_0x0086;
    L_0x00e2:
        r1 = move-exception;
        r7 = log;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = new java.lang.StringBuilder;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9.<init>();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r10 = "Could not read error stream: ";	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r10);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r1);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.toString();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7.fine(r9);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        if (r6 == 0) goto L_0x0100;
    L_0x00fd:
        r6.disconnect();
    L_0x0100:
        r7 = r8;
        goto L_0x0086;
    L_0x0102:
        r2 = move-exception;
        r7 = log;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = new java.lang.StringBuilder;	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9.<init>();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r10 = "Unrecoverable exception occured, no error response possible: ";	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r10);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.append(r2);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r9 = r9.toString();	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        r7.info(r9);	 Catch:{ ProtocolException -> 0x0087, IOException -> 0x00a7, Exception -> 0x0102, all -> 0x0123 }
        if (r6 == 0) goto L_0x0120;
    L_0x011d:
        r6.disconnect();
    L_0x0120:
        r7 = r8;
        goto L_0x0086;
    L_0x0123:
        r7 = move-exception;
        if (r6 == 0) goto L_0x0129;
    L_0x0126:
        r6.disconnect();
    L_0x0129:
        throw r7;
        */
        throw new UnsupportedOperationException("Method not decompiled: org.teleal.cling.transport.impl.StreamClientImpl.sendRequest(org.teleal.cling.model.message.StreamRequestMessage):org.teleal.cling.model.message.StreamResponseMessage");
    }

    public StreamClientImpl(StreamClientConfigurationImpl configuration) throws InitializationException {
        this.configuration = configuration;
        log.fine("Using persistent HTTP stream client connections: " + configuration.isUsePersistentConnections());
        System.setProperty("http.keepAlive", Boolean.toString(configuration.isUsePersistentConnections()));
        if (System.getProperty(HACK_STREAM_HANDLER_SYSTEM_PROPERTY) == null) {
            log.fine("Setting custom static URLStreamHandlerFactory to work around Sun JDK bugs");
            try {
                URL.setURLStreamHandlerFactory(new C04191());
                System.setProperty(HACK_STREAM_HANDLER_SYSTEM_PROPERTY, "alreadyWorkedAroundTheEvilJDK");
            } catch (Throwable th) {
                InitializationException initializationException = new InitializationException("URLStreamHandlerFactory already set for this JVM. Can't use bundled default client based on JDK's HTTPURLConnection. Consider alternatives, e.g. org.teleal.cling.transport.impl.apache.StreamClientImpl.");
            }
        }
    }

    public StreamClientConfigurationImpl getConfiguration() {
        return this.configuration;
    }

    public void stop() {
    }

    protected void applyRequestProperties(java.net.HttpURLConnection urlConnection, StreamRequestMessage requestMessage) {
        urlConnection.setInstanceFollowRedirects(false);
        urlConnection.setRequestProperty("User-Agent", getConfiguration().getUserAgentValue(requestMessage.getUdaMajorVersion(), requestMessage.getUdaMinorVersion()));
        applyHeaders(urlConnection, requestMessage.getHeaders());
    }

    protected void applyHeaders(java.net.HttpURLConnection urlConnection, Headers headers) {
        log.fine("Writing headers on HttpURLConnection: " + headers.size());
        for (Entry<String, List<String>> entry : headers.entrySet()) {
            for (String v : (List) entry.getValue()) {
                String headerName = (String) entry.getKey();
                log.fine("Setting header '" + headerName + "': " + v);
                urlConnection.setRequestProperty(headerName, v);
            }
        }
    }

    protected void applyRequestBody(java.net.HttpURLConnection urlConnection, StreamRequestMessage requestMessage) throws IOException {
        if (requestMessage.hasBody()) {
            urlConnection.setDoOutput(true);
            if (requestMessage.getBodyType().equals(BodyType.STRING)) {
                IO.writeUTF8(urlConnection.getOutputStream(), requestMessage.getBodyString());
            } else if (requestMessage.getBodyType().equals(BodyType.BYTES)) {
                IO.writeBytes(urlConnection.getOutputStream(), requestMessage.getBodyBytes());
            }
            urlConnection.getOutputStream().flush();
            return;
        }
        urlConnection.setDoOutput(false);
    }

    protected StreamResponseMessage createResponse(java.net.HttpURLConnection urlConnection, InputStream inputStream) throws Exception {
        if (urlConnection.getResponseCode() == -1) {
            log.fine("Did not receive valid HTTP response");
            return null;
        }
        UpnpResponse responseOperation = new UpnpResponse(urlConnection.getResponseCode(), urlConnection.getResponseMessage());
        log.fine("Received response: " + responseOperation);
        StreamResponseMessage responseMessage = new StreamResponseMessage(responseOperation);
        responseMessage.setHeaders(new UpnpHeaders(urlConnection.getHeaderFields()));
        byte[] bodyBytes = null;
        InputStream is = inputStream;
        if (inputStream != null) {
            try {
                bodyBytes = IO.readBytes(is);
            } catch (Throwable th) {
                if (is != null) {
                    is.close();
                }
            }
        }
        if (is != null) {
            is.close();
        }
        if (bodyBytes != null && bodyBytes.length > 0 && responseMessage.isContentTypeMissingOrText()) {
            log.fine("Response contains textual entity body, converting then setting string on message");
            responseMessage.setBodyCharacters(bodyBytes);
        } else if (bodyBytes == null || bodyBytes.length <= 0) {
            log.fine("Response did not contain entity body");
        } else {
            log.fine("Response contains binary entity body, setting bytes on message");
            responseMessage.setBody(BodyType.BYTES, bodyBytes);
        }
        log.fine("Response message complete: " + responseMessage);
        return responseMessage;
    }
}
